/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(sb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(){throw new Error("abort")}function q(m){h[2]=m}function r(){return h[2]}function qb(rb){var s=rb.a;var t=s.a;var u=t.buffer;t.grow=ob;var v=new Int8Array(u);var w=new Int16Array(u);var x=new Int32Array(u);var y=new Uint8Array(u);var z=new Uint16Array(u);var A=new Uint32Array(u);var B=new Float32Array(u);var C=new Float64Array(u);var D=Math.imul;var E=Math.fround;var F=Math.abs;var G=Math.clz32;var H=Math.min;var I=Math.max;var J=Math.floor;var K=Math.ceil;var L=Math.trunc;var M=Math.sqrt;var N=s.b;var O=s.c;var P=s.d;var Q=s.e;var R=s.f;var S=s.g;var T=s.h;var U=s.i;var V=s.j;var W=s.k;var X=s.l;var Y=s.m;var Z=s.n;var _=s.o;var $=s.p;var aa=s.q;var ba=s.r;var ca=s.s;var da=s.t;var ea=s.u;var fa=s.v;var ga=s.w;var ha=s.x;var ia=s.y;var ja=s.z;var ka=s.A;var la=s.B;var ma=s.C;var na=s.D;var oa=s.E;var pa=s.F;var qa=s.G;var ra=s.H;var sa=s.I;var ta=s.J;var ua=s.K;var va=s.L;var wa=s.M;var xa=s.N;var ya=s.O;var za=s.P;var Aa=s.Q;var Ba=s.R;var Ca=s.S;var Da=s.T;var Ea=s.U;var Fa=s.V;var Ga=s.W;var Ha=s.X;var Ia=s.Y;var Ja=s.Z;var Ka=s._;var La=s.$;var Ma=s.aa;var Na=s.ba;var Oa=s.ca;var Pa=s.da;var Qa=s.ea;var Ra=s.fa;var Sa=s.ga;var Ta=s.ha;var Ua=s.ia;var Va=s.ja;var Wa=s.ka;var Xa=s.la;var Ya=s.ma;var Za=s.na;var _a=s.oa;var $a=s.pa;var ab=s.qa;var bb=s.ra;var cb=s.sa;var db=s.ta;var eb=s.ua;var fb=568496;var gb=0;var hb=0;
// EMSCRIPTEN_START_FUNCS
function vM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,P=0,R=0,T=0,U=0,V=0,W=0,X=E(0),Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=E(0),Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=E(0),Ya=0;fa=fb-32|0;fb=fa;ha=fa+28|0;x[ha>>2]=49140;x[ha>>2]=49040;e=qB(fa+20|0);f=qB(fa+12|0);ia=b;la=x[e>>2];Ca=y[e+4|0];ma=x[f>>2];Da=y[f+4|0];b=0;K=fb-96|0;fb=K;d=a;na=a+24604|0;a=na;a:{if(!x[a+16>>2]){break a}e=x[a+20>>2];if(e>>>0>4|!(1<<e&22)){break a}a=x[a+28>>2];if(a>>>0>4){break a}b=23>>>a&1}if(!b){a=K+80|0;TR(a,9153,13091,220,45);b=fb-48|0;fb=b;e=uc(b+24|0,18573);x[31785]=0;O(891,b+12|0,17639);f=x[31785];x[31785]=0;b:{c:{d:{e:{if((f|0)!=1){x[31785]=0;S(2,b+36|0,e|0,b+12|0);f=x[31785];x[31785]=0;if((f|0)==1){break e}x[31785]=0;S(892,a|0,1,b+36|0);a=x[31785];x[31785]=0;if((a|0)!=1){break b}a=N()|0;tb(b+36|0);break d}a=N()|0;break c}a=N()|0}tb(b+12|0)}tb(e);Q(a|0);p()}tb(b+36|0);tb(b+12|0);tb(e);fb=b+48|0}oa=c;pa=d+8204|0;qa=d+397452|0;ra=d+397448|0;ea=d+393352|0;I=d+397456|0;aa=d+12|0;Ea=d+1074376|0;Fa=d+1298424|0;Ga=d+1074365|0;while(1){f:{g:{a=x[d+480208>>2];if(!(!ia|a&512)){h:{if(x[d+1074380>>2]){break h}c=a|512;i:{if(a&256){break i}l=fb-48|0;fb=l;r=fb-32|0;fb=r;i=d+1074312|0;f=d+1074992|0;g=d+1298264|0;m=d+1074424|0;H=d+484360|0;k=d+1074448|0;j=d+1074376|0;a=x[d+1074392>>2];R=d+480188|0;G=d+480180|0;q=d+484376|0;C=d+484348|0;M=d+480210|0;P=d+484364|0;j:{k:while(1){l:{a=a+1|0;x[d+1074392>>2]=a;if(Fl(j)>>>0>a>>>0){break l}nT(r+30|0,x[G>>2],z[R>>1],j,(x[d+480208>>2]&524288)>>>19|0);m:{n:{o:{p:{s=x[d+480208>>2];if(s&32){o=x[C>>2];t=x[d+484344>>2];c=z[d+1074446>>1];break p}c=65535;u=Wb(x[d+484360>>2],y[q|0]);n=x[u>>2];T=x[u+4>>2];e=Xc(n,T);a=z[d+1074448>>1];if(e>>>0>a>>>0){c=z[_b(n,a)>>1]}w[d+1074446>>1]=c;q:{r:{b=c&65535;t=x[d+484344>>2];o=x[C>>2];J=pg(t,o);if(b>>>0>=J>>>0){break r}b=Vb(t,b);if(Ib(x[b>>2],x[b+4>>2])){break r}b=0;break q}b=1}while(1){s:{t:{u:{Y=d;if(b){L=d;v:{w:{x:{b=c&65535;if(b>>>0>=J>>>0){c=a&65535;if(!((b|0)!=65535&e>>>0>c>>>0)){h=z[u+28>>1];if(h){b=Xc(n,T);break w}if(!(a&65535)|c>>>0>e>>>0){break x}while(1){h=c;a=a-1|0;b=a&65535;if(!b){break x}c=h-1|0;if(z[_b(n,b)>>1]!=65535){continue}break}b=e;break w}a=a+1|0;w[k>>1]=a;c=a&65535;break v}w[d+1074450>>1]=a;break p}b=e;h=0}a=h;w[L+1074448>>1]=a;s=s&-524289;x[d+480208>>2]=s;while(1){c=a&65535;if(c>>>0>=b>>>0){break o}if(z[_b(n,c)>>1]==65534){a=a+1|0;w[k>>1]=a;continue}break}if(!$i(u,a&65535)){break o}}if(c>>>0<e>>>0){break u}c=65535}else{c=65534}w[Y+1074446>>1]=c;break t}c=z[_b(n,c)>>1];w[d+1074446>>1]=c;if(c>>>0>=J>>>0){break t}b=Vb(t,c);if(!Ib(x[b>>2],x[b+4>>2])){break s}}b=1;continue}b=0;continue}}b=c&65535;if(!Ge(t,o,b)){break n}a=x[m>>2];if(a>>>0>=A[Vb(t,b)+12>>2]){x[m>>2]=0;a=0}if(s&32?x[d+480272>>2]!=-1:0){break m}if(!Fu(g,z[k>>1],a,uq(r+20|0,f),y[r+30|0])){break m}a=x[d+480272>>2];if(a){if((a|0)>0){x[d+480272>>2]=a-1}Fo(g,1);Fu(g,z[k>>1],x[m>>2],uq(r+20|0,f),y[r+30|0]);break m}if(!(y[M|0]&64)){break o}a=0;if(!Eu(g,k,m)){x[d+1074424>>2]=0;x[d+1074428>>2]=0;x[d+1074448>>2]=0;c=Kj(x[d+484360>>2],x[P>>2])-1|0;b=y[q|0];if((c|0)<=(b|0)){ak(H,0);break o}ak(H,b+1&255);Fo(g,1)}while(1)if((a|0)==256){KR(d);x[d+1074416>>2]=x[d+480196>>2];x[d+1074420>>2]=x[d+480204>>2];x[d+1074456>>2]=x[d+480200>>2];a=z[d+1074448>>1];w[d+1074450>>1]=a;b=x[d+1074424>>2];x[d+1074428>>2]=b;c=Wb(x[d+484360>>2],y[q|0]);e=x[c>>2];if(Xc(e,x[c+4>>2])>>>0>a>>>0){Va=d,Wa=z[_b(e,a)>>1],w[Va+1074446>>1]=Wa}Fu(g,a,b,uq(r+20|0,f),y[r+30|0]);if(!Ge(x[d+484344>>2],x[C>>2],z[d+1074446>>1])){break n}break m}else{Jo((D(a,872)+d|0)+1074992|0,d,a&65535,134217728);a=a+1|0;continue}}Fo(g,1)}a=0;break j}mT(d,j,(x[d+480208>>2]&32)>>>5|0);a=Vb(x[d+484344>>2],z[d+1074446>>1]);c=gd(x[a>>2],x[x[a+48>>2]+12>>2],x[d+1074424>>2],0);e=f+D(z[R>>1],872)|0;a=f;while(1){if((a|0)==(e|0)){y:{z:{a=x[d+484344>>2];b=z[d+1074446>>1];if(tn(a,x[d+484348>>2],b)){a=Vb(a,b);b=x[a+16>>2];a=x[a+20>>2];if(jT(b,a)){break z}}x[d+1074408>>2]=x[d+480216>>2];a=x[d+480220>>2];break y}x[d+1074408>>2]=b}x[d+1074412>>2]=a;if(!y[r+30|0]){break l}a=x[d+1074416>>2];x[d+1074392>>2]=a;continue k}Kb(r+20|0,i,82);A:{if(!Hb(x[x[r+20>>2]>>2],x[r+24>>2])|y[a+805|0]!=1){break A}b=y[c+3|0];if((b|0)!=2&(b|0)!=3){break A}Va=a,Wa=vh(d,y[a+800|0],w[a+772>>1],x[a+704>>2]),x[Va+700>>2]=Wa}Kb(r+20|0,i,91);B:{if(!Hb(x[x[r+20>>2]>>2],x[r+24>>2])){break B}if(zd(y[c|0])){break B}b=y[a+788|0];if(!zd(b)|y[a+791|0]!=19){break B}h=y[a+793|0];if((h&240)!=208|A[d+1074416>>2]>(h&15)>>>0){break B}Va=a,Wa=vh(d,b,w[a+772>>1],0),x[Va+700>>2]=Wa}Kb(r+20|0,i,118);C:{if(!Hb(x[x[r+20>>2]>>2],x[r+24>>2])){break C}if(zd(y[c|0])|!(y[a+89|0]&2)){break C}b=x[a+708>>2];if(!b){break C}if(!zd(y[a+788|0])){break C}if(!Hl(y[a+790|0],y[a+791|0])){break C}x[a+700>>2]=b}Kb(r+20|0,i,92);D:{if(!Hb(x[x[r+20>>2]>>2],x[r+24>>2])){break D}Kb(r+12|0,i,5);if(Hb(x[x[r+12>>2]>>2],x[r+16>>2])|x[d+1074416>>2]!=1|y[a+791|0]!=17){break D}v[r+20|0]=1;Va=d,Wa=D(y[af(r+20|0,a+793|0)|0],1e4),x[Va+1074420>>2]=Wa}b=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+788|0]=b;v[a+789|0]=b>>>8;v[a+790|0]=b>>>16;v[a+791|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8;v[a+792|0]=b;v[a+793|0]=b>>>8;b=x[a+676>>2];x[a+20>>2]=x[a+672>>2];x[a+24>>2]=b;x[a+88>>2]=x[a+88>>2]&-393217;Kb(r+20|0,i,21);if(!Hb(x[x[r+20>>2]>>2],x[r+24>>2])){v[a+831|0]=0}x[a+860>>2]=0;v[a+805|0]=0;c=c+6|0;a=a+872|0;continue}}break}b=x[d+1074416>>2];if(!b){x[d+1074416>>2]=1;b=1}a=x[d+480208>>2];e=x[d+1074392>>2];E:{F:{if(e){c=a&-4097;x[d+480208>>2]=c;f=x[d+480180>>2];if(f&1048580|!(a&2097152)&(f|0)==1){break E}if(Fl(j)>>>0<=e>>>0){break E}if(!((e>>>0)%(x[d+1074400>>2]+b>>>0)|0)){break F}break E}c=a&-528385}x[d+480208>>2]=c|4096}j=0;i=fb-16|0;fb=i;w[d+1074444>>1]=65535;a=d+1074436|0;x[a>>2]=-1;x[a+4>>2]=-1;ba=d+1075809|0;q=d+1074312|0;T=d+906300|0;H=d+1074376|0;_=d+480188|0;G=d+480208|0;Z=d+480209|0;C=d+480180|0;ca=d+480210|0;$=d+480190|0;M=d+480192|0;while(1){if(z[_>>1]<=j>>>0){G:{if(!(y[d+480209|0]&16)){break G}if(!bT(d,H,Wb(x[d+484360>>2],y[d+484376|0]),1)){break G}a=d+480208|0;x[a>>2]=x[a>>2]|524288}fb=i+16|0}else{m=D(j,872)+d|0;k=m+1075785|0;b=y[k|0];n=m+1075784|0;s=y[n|0];U=m+1075781|0;c=y[U|0];u=x[d+1074392>>2];J=x[d+1074400>>2];L=x[d+1074416>>2];V=m+1075782|0;g=y[V|0];o=m+1075783|0;t=y[o|0];e=Hl(g,t);P=m+1075843|0;v[P|0]=x[G>>2]>>>12&1|y[P|0]&254;R=m+1075780|0;f=y[R|0];H:{I:{J:{if((f|0)==252){h=Hj(g,s);W=Hj(t,b);f=252;a=c-1|0;if((a&255)>>>0>249){break J}if(!x[rd(T,a)>>2]){break J}a=x[rd(T,a)>>2];ib[x[x[a>>2]+44>>2]](a,h,E(E(W>>>0)/E(999)));f=y[R|0]}if((f&255)==251){break I}}if(B[m+1075852>>2]==E(0)|t){break H}}W=x[G>>2]&4096;K:{if(!W){h=y[m+1075862|0];break K}h=y[U|0];v[m+1075862|0]=h}if((h-1&255)>>>0>249){break H}a=h-1|0;if(!x[rd(T,a)>>2]){break H}L:{if(!W){f=z[m+1075860>>1];break L}f=eB(y[V|0],y[n|0]);w[m+1075860>>1]=f;X=E(E(eB(y[o|0],y[k|0])>>>0)/E(999));B[m+1075856>>2]=X;h=x[rd(T,a)>>2];Va=m+1075852|0,Xa=E(E(X-E(ib[x[x[h>>2]+48>>2]](h,f)))/E(Fl(H)>>>0)),B[Va>>2]=Xa}h=x[d+1074392>>2];k=Fl(H);a=x[rd(T,a)>>2];n=f;f=(k|0)==(h+1|0);ib[x[x[a>>2]+(f?44:108)>>2]](a,n,B[(f?m+1075856|0:m+1075852|0)>>2]);f=y[R|0]}o=m+1074992|0;if(TS(f&255)){b=fb-16|0;fb=b;w[b+12>>1]=0;x[b+8>>2]=0;a=Jg(b+8|0);c=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[o+788|0]=c;v[o+789|0]=c>>>8;v[o+790|0]=c>>>16;v[o+791|0]=c>>>24;a=y[a+4|0]|y[a+5|0]<<8;v[o+792|0]=a;v[o+793|0]=a>>>8;fb=b+16|0;t=0;s=0;g=0;c=0;e=0;b=0}h=(u>>>0)%(J+L>>>0)|0;M:{if(!(y[Z|0]&16)){uS(d,o);break M}if(!c){break M}x[m+1075752>>2]=0}N:{O:{if((t|0)==33){Kb(i+8|0,q,30);f=b>>>4|0;RA(d,j&65535,f+(b&15)|0,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));break O}f=0;if((t-19&255)>>>0>1){break O}P:{if(!(!(x[C>>2]&16777250)|b)){b=y[m+1075825|0];break P}v[m+1075825|0]=b}a=b&240;if((a|0)==208){a=b&15;if(!a){a=x[C>>2];if(a&16777248){f=1;break O}if((a|0)!=2){break O}break N}if(a>>>0>=x[d+1074400>>2]+x[d+1074416>>2]>>>0){Kb(i+8|0,q,14);f=a;if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break O}if(!c){break N}v[m+1075795|0]=c;break N}f=a;break O}if(!(y[Z|0]&16)|(a|0)!=224){break O}a=x[C>>2];if(x[d+1074396>>2]?a&16777250:0){break O}k=a&2;a=b&15;if(a?0:k){break O}x[d+1074396>>2]=a+1}a=f;f=x[C>>2]==16&(t|0)==19&(b&240)==208;u=f?0:a;Q:{if(!u|y[R|0]!=255|y[V|0]!=2){break Q}Kb(i+8|0,q,74);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Q}v[V|0]=0}J=b&15;a=x[d+1074392>>2];Kb(i+8|0,q,72);R:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){L=0;if(u>>>0>=A[d+1074416>>2]){break R}}Kb(i+8|0,q,88);L=(h|0)==(u|0)|(a|0)==(u|0);if(!(!u|!Hb(x[x[i+8>>2]>>2],x[i+12>>2]))){break R}L=(a|0)==(u|0)}Kb(i+8|0,q,44);b=f?J|144:b;S:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){a=y[P|0];break S}a=y[P|0]&-2|(h|0)==(u|0)}v[P|0]=a&253;Kb(i+8|0,q,66);h=(!u|Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1)&e;T:{U:{V:{if(!(x[d+1074392>>2]|(!(y[ca|0]&32)|!c))){x[m+1075652>>2]=0;if(L){e=y[R|0];break V}if(!Pi(x[o+8>>2],x[o+12>>2])){break T}v[m+1075795|0]=c;if(z[$>>1]<c>>>0){break T}a=D(c,104)+d|0;x[m+1075680>>2]=z[a+484410>>1];w[m+1075764>>1]=v[a+484417|0];break T}if(!L){break T}e=y[R|0];if(!c){break U}}v[m+1075795|0]=c}W:{X:{a=e&255;if(!zd(a)){break X}Kb(i+8|0,q,67);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break X}f=w[m+1075762>>1];Y:{if(!c|h){break Y}k=br(d,a,c);if(!k){break Y}f=v[ri(d,k)+36|0]}e=(a+f|0)-132>>>0>=4294967176?e:0;break W}if(!(x[C>>2]&25165856)){break W}f=z[M>>1];if(!f){break W}if(a){a=zd(a)}else{a=1}if(!a){break W}a=c;Z:{if(!a){a=y[m+1075796|0];if(!a){break Z}}if(x[((a<<2)+d|0)+900380>>2]?a>>>0<=f>>>0:0){break W}e=0}c=0}if(!((t|0)!=25|b)){Kb(i+8|0,q,55);a=Hb(x[x[i+8>>2]>>2],x[i+12>>2]);c=a?0:c;e=a?0:e}Kb(i+8|0,q,65);W=Hb(x[x[i+8>>2]>>2],x[i+12>>2]);n=1;if(!(x[C>>2]&16777248)){Kb(i+8|0,q,107);n=Hb(x[x[i+8>>2]>>2],x[i+12>>2])}f=(c|0)!=0;a=e&255;da=!a;Kb(i+8|0,q,85);_:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break _}if(Pi(x[o+8>>2],x[o+12>>2])){break _}k=x[m+1075096>>2];if(k){if(ge(x[k>>2],x[k+20>>2])){break _}}n=1}da=f&da;k=f&W;$:{aa:{ba:{ca:{da:{ea:{if(!(x[C>>2]&1048580)){break ea}fa:{if((a|0)!=255){break fa}if(!(!((g|0)==1|c)&(t|0)!=13)){Kb(i+8|0,q,55);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break fa}}f=x[m+1075648>>2];if(v[f+60|0]&1?f:0){break fa}x[m+1075680>>2]=0;a=m+1075080|0;x[a>>2]=x[a>>2]|2097152;ga:{if(!(x[G>>2]&4096)){break ga}Kb(i+8|0,q,86);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ga}x[a>>2]=x[a>>2]|4096}c=0;e=0;a=0;f=0;Y=1;if(k){break aa}break $}Kb(i+8|0,q,59);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|x[G>>2]&4096){break ea}ha:{if(!a){e=y[m+1075789|0]-y[m+1075762|0]|0;break ha}if(a>>>0>250){n=0;k=1;e=0;break ha}ia:{if(c){break ia}Kb(i+8|0,q,98);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ia}c=0;break ha}n=1;k=1}f=e;h=0;break da}f=0;if(!da){break ca}}Kb(i+8|0,q,65);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ba}e=f;f=1}a=e;Y=1;if(k){break aa}break $}e=f;f=1;Y=k}k=Y;ja:{ka:{if(!z[M>>1]){if(z[$>>1]<c>>>0){break ja}a=(D(c,104)+d|0)+484380|0;break ka}a=x[m+1075096>>2];if(!a){break ja}}la:{if(w[a+34>>1]<0){break la}if(x[C>>2]==2){if(!ge(x[a>>2],x[a+20>>2])){break la}}x[m+1075680>>2]=z[a+30>>1];W=m+1075080|0;x[W>>2]=x[W>>2]|2097152}if(!k){break ja}Fq(o,z[a+28>>1],d)}a=e}Kb(i+8|0,q,71);if(!(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c)){v[m+1075831|0]=32}ma:{if(!z[M>>1]){break ma}Kb(i+8|0,q,100);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c){break ma}if(zd(a&255)){break ma}e=x[G>>2];na:{if(h){if(e&8){break na}break ma}if(!(e&4)){break ma}}Wm(o);x[m+1075688>>2]=65536;e=m+1075080|0;x[e>>2]=x[e>>2]|2097152}if(f){Kb(i+8|0,q,11);oa:{pa:{qa:{if(!(Hb(x[x[i+8>>2]>>2],x[i+12>>2])|x[C>>2]==268435456)){e=z[M>>1];break qa}Kb(i+8|0,q,87);f=0;if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){f=Pi(x[o+8>>2],x[o+12>>2])^1}e=z[M>>1];ra:{if(e){if(c>>>0>e>>>0){break pa}if(x[m+1075648>>2]!=x[((c<<2)+d|0)+900380>>2]|f){break ra}break pa}if((f^-1)&x[m+1075096>>2]==((D(c,104)+d|0)+484380|0)){break oa}}a=y[m+1075789|0]}if(!(e&65535)){break oa}}if(!(x[C>>2]&1048588)){break oa}Wm(o);v[m+1075810|0]=0;x[m+1075748>>2]=0;x[m+1075688>>2]=65536;e=m+1075080|0;x[e>>2]=x[e>>2]&-2101249|2097152;Kb(i+8|0,q,86);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break oa}x[e>>2]=x[e>>2]&-2049}c=n?c:0}e=a&255;sa:{if(e>>>0<251){break sa}Kb(i+8|0,q,50);ta:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c){break ta}f=br(d,y[m+1075791|0],c);if(!f){break ta}f=D(f,104)+d|0;if(w[f+484414>>1]<0){break ta}x[m+1075680>>2]=z[f+484410>>1]}Kb(i+8|0,q,100);if(Va=Hb(x[x[i+8>>2]>>2],x[i+12>>2]),Wa=0,Ya=x[G>>2]&4,Ya?Va:Wa){break sa}c=0}k=zd(e);if(k){v[m+1075794|0]=a;v[m+1075791|0]=a;if(!h){vS(d,j&65535,c,e,0)}SU(o)}ua:{va:{wa:{xa:{ya:{if(c){a=m+1075096|0;f=x[a>>2];Eo(d,o,c,h,1,1);n=x[a>>2];za:{if(!n|!(y[n+35|0]&2)){break za}W=x[d+1298300>>2];if(!xd(W)){break za}EB(W,j&65535,n+68|0)}Aa:{Ba:{if(x[C>>2]==1){if(!h){break Ba}Kb(i+8|0,q,85);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ba}break Aa}Kb(i+8|0,q,50);if((k|Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1)!=1){break Aa}}v[m+1075795|0]=0}Kb(i+8|0,q,42);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!k|(f|0)==x[a>>2]){break xa}break ya}if(x[C>>2]&16777248){n=0;if(k&(f|0)!=x[a>>2]){break wa}}Kb(i+8|0,q,107);Ca:{if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|(!(k^1|h)|(f|0)==x[a>>2])){break Ca}a=m+1075068|0;if(A[a>>2]>=A[o+4>>2]){break Ca}x[a>>2]=0;break xa}Kb(i+8|0,q,85);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break xa}if(!Pi(x[o+8>>2],x[o+12>>2])){break ya}break xa}if(!e){a=h;break ua}f=0;a=m+1075795|0;n=y[a|0];if(!(!n|k^1)){Eo(d,o,n,h,!(x[m+1075096>>2]?1:x[m+1075648>>2]),!(x[C>>2]&1048580));v[a|0]=0;f=1}a=h;break va}x[o>>2]=0;x[o+4>>2]=0}n=h}a=n;f=0;if(!e){break ua}}h=x[m+1075096>>2];Da:{if(!h|!(y[h+35|0]&2)){break Da}k=x[d+1298300>>2];if(!xd(k)){break Da}if(!f){if(wS(k,j&65535)){break Da}}EB(k,j&65535,h+68|0)}f=j&65535;zu(d,o,e,a,!(x[C>>2]&1048580),0,f);gT(x[C>>2],z[_>>1],H,f);if(!(!(x[C>>2]&1048580)|(!a|!c))){c=m+1075080|0;x[c>>2]=x[c>>2]|2097152;Wm(o);v[m+1075810|0]=0;x[m+1075748>>2]=0}if(!(x[m+1075080>>2]&512)){break ua}if(!xd(x[d+1298300>>2])){break ua}if(e>>>0<=253){if((e|0)!=253){break ua}Kb(i+8|0,q,99);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ua}}Kb(i+8|0,q,110);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){FB(x[d+1298300>>2],f,0,1,0)}yk(x[d+1298300>>2],f)}Ea:{Fa:{switch(g-1|0){case 0:s=s>>>0>=64?64:s;x[m+1075680>>2]=s<<2;c=m+1075080|0;x[c>>2]=x[c>>2]|2097152;break Ea;case 1:break Fa;default:break Ea}}Xm(d,o,s,6)}if(z[M>>1]){tS(d,j&65535)}h=a}Kb(i+8|0,q,77);if(Va=Hb(x[x[i+8>>2]>>2],x[i+12>>2]),Wa=0,Ya=x[((j<<5)+d|0)+480280>>2]&1024,Ya?Va:Wa){break N}a=x[d+1074392>>2];Kb(i+8|0,q,75);c=a>>>0>=u>>>0;Ga:{Ha:{Ia:{Ja:{if(!u|!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ja}a=x[d+1074392>>2];if(!a){break Ia}c=1;if((a|0)!=(u|0)){break Ja}c=!y[U|0]&(g|0)!=11}a=g;if(!c|a>>>0<3){break Ia}if((a|0)==11){a=i+8|0;jB(a,d,y[R+3|0],y[R+4|0],u);a=y[Ze(a)|0];QA(d,j&65535,z[i+8>>1]);if(a){break Ha}g=11;break Ia}Kb(i+8|0,q,62);Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{if(!(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|s)){s=0;g=0;Ra:{switch(a-8|0){case 0:break Qa;case 1:break Ra;default:break Ia}}if(y[Z|0]&16){break Ia}x[m+1075684>>2]=0;break Ia}Kb(i+8|0,q,41);Sa:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Sa}if(s){v[m+1075826|0]=s;break Sa}s=y[m+1075826|0]}Ta:{switch(a-3|0){case 0:case 1:Ua:{Va:{if(s){break Va}Kb(i+8|0,q,41);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Va}s=y[m+1075826|0];if(s){break Ua}s=0;break Ia}v[m+1075826|0]=s}Co(d,o,((a|0)==3?s<<4:s)&255);break Ia;case 2:if((u|0)!=x[d+1074392>>2]){Kb(i+8|0,q,41);g=5;if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ia}}Kb(i+8|0,q,41);Bo(d,o,s,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));g=5;break Ia;case 3:if((u|0)!=x[d+1074392>>2]){Kb(i+8|0,q,41);g=6;if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ia}}Kb(i+8|0,q,41);Ao(d,o,s,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));g=6;break Ia;case 11:break Ka;case 12:break La;case 10:break Ma;case 9:break Na;case 7:break Oa;case 6:break Pa;case 5:break Qa;case 4:break Ta;default:break Ia}}Kb(i+8|0,q,53);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){v[m+1075815|0]=s&15;g=7;break Ia}El(o,s<<4);g=7;break Ia}El(o,s);g=8;break Ia}Kb(i+8|0,q,62);PA(d,o,s,Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1);g=9;break Ia}Kb(i+8|0,q,62);PA(d,o,s<<4&240,Hb(x[x[i+8>>2]>>2],x[i+12>>2])^1);g=10;break Ia}g=12;Kb(i+8|0,q,12);sS(d,j&65535,s<<2&252,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));break Ia}Kb(i+8|0,q,12);rS(d,j&65535,s<<2&252,Hb(x[x[i+8>>2]>>2],x[i+12>>2]));g=13;break Ia}g=15;if(!L){break Ia}a=x[m+1075096>>2];if(!a|s>>>0>9){break Ia}Wa:{if(!s){c=x[m+1075656>>2];break Wa}c=x[wb(a+68|0,s-1|0)>>2];x[m+1075656>>2]=c}Do(d,o,c);break Ia}g=14;if(s>>>0>1){break Ia}v[P|0]=y[P|0]&247|!s<<3}c=b;Xa:{Ya:{Za:{switch(t-1|0){case 12:if(!(y[d+480209|0]&16)){break Ha}a=D(j,872)+d|0;x[a+1075680>>2]=b>>>0>=64?256:b<<2;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ha;case 45:if(!(y[d+480209|0]&16)){break Ha}a=D(j,872)+d|0;x[a+1075680>>2]=b;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ha;case 1:if(!b){c=0;if(v[d+480180|0]&1){break Ga}}sS(d,j&65535,b,0);break Ha;case 2:if(!b){c=0;if(v[d+480180|0]&1){break Ga}}rS(d,j&65535,b,0);break Ha;case 10:if(!b){c=0;if(x[d+480180>>2]==1){break Ga}}Co(d,o,b);break Ha;case 3:QA(d,j&65535,b);break Ha;case 5:if(!(!b&x[d+480180>>2]==1)){Co(d,o,b)}QA(d,j&65535,0);break Ha;case 4:El(o,b);break Ha;case 6:if(!(!b&x[d+480180>>2]==1)){Co(d,o,b)}El(o,0);break Ha;case 15:if(!(y[d+480209|0]&16)){break Ha}break Xa;case 16:Kb(i+8|0,q,5);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!(y[d+480209|0]&16)){break Ha}if(b){break Xa}break Ha}c=zo(d,z[d+1074446>>1],x[d+1074424>>2],j&65535,0);_a:{if(!(x[d+480180>>2]&16777250)){break _a}if(c){v[(D(j,872)+d|0)+1075827|0]=c;break _a}c=y[(D(j,872)+d|0)+1075827|0]}x[i+8>>2]=D(c,1e4);vc(i+8|0,D(x[x[d+8>>2]+24>>2],1e4));a=fb-16|0;fb=a;e=x[i+8>>2];x[a+12>>2]=e;b=x[d+8>>2];$a:{if(e>>>0>=(x[d+480180>>2]&16393?1e4:32e4)>>>0){e=x[d+480208>>2];Kb(a+4|0,d+1074312|0,92);if((Hb(x[x[a+4>>2]>>2],x[a+8>>2])|0)==((e&4096)>>>12|0)){break $a}x[a+4>>2]=D(x[b+24>>2],1e4);Va=d+1074420|0,Wa=x[Gb(a+12|0,a+4|0)>>2],x[Va>>2]=Wa;break $a}if(y[d+480209|0]&16){break $a}f=d+1074420|0;e=(e>>>0)/1e4|0;h=D(e&15,1e4);x[f>>2]=x[f>>2]+((e&240)==16?h:0-h|0);e=x[b+20>>2];b=x[b+24>>2];Kb(a+4|0,d+1074312|0,8);vp(f,D(e,1e4),Hb(x[x[a+4>>2]>>2],x[a+8>>2])?255e4:D(b,1e4))}fb=a+16|0;break Ga;case 9:if(!L|x[d+480180>>2]==4&h){break Ha}fT(d,o,j&65535,x[d+1074424>>2],z[d+1074446>>1]);break Ha;case 43:if(!L){break Ha}a=sua(x[(D(j,872)+d|0)+1075068>>2],0,b,0);c=hb;e=c>>>8|0;Do(d,o,Bc((c&255)<<24|a>>>8,e));break Ha;case 0:if(x[d+1074392>>2]){break Ha}a=D(j,872)+d|0;ab:{if(y[a+1075789|0]?x[a+1075692>>2]:0){break ab}a=x[a+1075648>>2];if(a){if(Nj(y[a+31|0])){break ab}}Kb(i+8|0,q,13);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break ab}if(x[d+480180>>2]&16777248){break Ha}}if(!b){c=0;if(y[d+480180|0]&5){break Ga}v[(D(j,872)+d|0)+1075797|0]=1;break Ga}a=D(j,872)+d|0;v[a+1075798|0]=b;v[a+1075797|0]=1;break Ha;case 14:if(x[d+480180>>2]&1048580){b=b&240?b:y[(D(j,872)+d|0)+1075799|0]&240|b;if(!(b&15)){b=y[(D(j,872)+d|0)+1075799|0]&15|b}b=b|256}c=b;Kb(i+8|0,q,23);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){b=d;e=j&65535;if(c){v[(D(j,872)+d|0)+1075799|0]=c;a=c}else{a=y[(D(j,872)+d|0)+1075799|0]}OA(b,e,a&255,(g|0)==15?s+1|0:0);break Ga}bb:{if(c){v[(D(j,872)+d|0)+1075799|0]=c;break bb}c=y[(D(j,872)+d|0)+1075799|0]}OA(d,j&65535,c,(g|0)==15?s+1|0:0);break Ga;case 17:if(!(y[d+480209|0]&16)){break Ha}Kb(i+8|0,q,22);cb:{db:{if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(!b){b=0;break db}if(y[d+480208|0]&4){break db}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;v[(D(j,872)+d|0)+1075832|0]=b;break db}Kb(i+8|0,q,71);if(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break cb}}a=(D(j,872)+d|0)+1075831|0;v[a|0]=y[a|0]|128}a=D(j,872)+d|0;v[a+1075797|0]=18;if(!b){c=0;break Ga}v[a+1075832|0]=b;break Ha;case 22:if(!(y[d+480209|0]&16)){break Ha}a=x[d+480180>>2];c=b<<!(a&59593760);if(c>>>0<=128){x[d+1074456>>2]=c<<1;break Ga}if(a&16777250){break Ga}x[d+1074456>>2]=256;break Ga;case 23:Kb(i+8|0,q,9);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){qS(d,b,(D(j,872)+d|0)+1075809|0);break Ha}qS(d,b,ba);break Ha;case 8:if(!(y[d+480209|0]&16)){break Ha}Xm(d,o,b,8);break Ha;case 28:PA(d,o,b,1);break Ha;case 7:ZS(o,b);break Ha;case 25:_S(d,o,b);break Ha;case 18:f=fb-16|0;fb=f;g=d+1074376|0;c=j&65535;h=D(c,872);e=(g+h|0)+616|0;a=b&15;eb:{fb:{switch(b>>>4|0){case 0:c=(b&1)<<14;e=z[d+480188>>1];a=0;while(1){if((a|0)==(e|0)){break eb}h=(D(a,872)+d|0)+1075080|0;x[h>>2]=(c|x[h>>2]&-16385)^16384;a=a+1|0;continue};case 1:if(!a){a=0;if(!(x[d+480180>>2]&1048580)){break eb}}aB(d,e,a);Kb(f+8|0,d+1074312|0,117);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break eb}to(d,c,b|240,1);break eb;case 2:if(!a){a=0;if(!(x[d+480180>>2]&1048580)){break eb}}$A(d,e,a);Kb(f+8|0,d+1074312|0,117);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break eb}to(d,c,0-(b|240)|0,1);break eb;case 3:c=(d+h|0)+1075080|0;x[c>>2]=x[c>>2]&-1048577|((a|0)!=0)<<20;break eb;case 4:v[(d+h|0)+1075814|0]=b&7;break eb;case 5:if(!(y[d+480209|0]&16)){break eb}h=x[d+480180>>2];if(h&69206025){e=D(c,872)+d|0;a=a<<28>>24;w[e+1075764>>1]=a;h=e+1075692|0;if(!x[h>>2]){break eb}if(!zd(y[e+1075780|0])){break eb}c=D(c,872)+d|0;Va=h,Wa=vh(d,y[c+1075789|0],a,x[c+1075696>>2]),x[Va>>2]=Wa;break eb}e=zd(y[(D(c,872)+d|0)+1075780|0]);if((h|0)==16){if(!e){break eb}e=D(c,872)+d|0;h=x[e+1075096>>2];if(!h){break eb}v[h+37|0]=a;w[e+1075764>>1]=a;e=e+1075692|0;if(!x[e>>2]){break eb}c=D(c,872)+d|0;Va=e,Wa=vh(d,y[c+1075789|0],a,x[c+1075696>>2]),x[Va>>2]=Wa;break eb}if(!e){break eb}a=D(c,872)+d|0;c=(b<<4^-128)<<24>>24;w[a+1075764>>1]=c;e=a+1075692|0;if(!x[e>>2]){break eb}Va=e,Wa=vh(d,y[a+1075789|0],c,x[a+1075696>>2]),x[Va>>2]=Wa;break eb;case 6:if(!(y[d+480209|0]&16)){break eb}hB(d,g,c,a);break eb;case 7:v[(d+h|0)+1075817|0]=b&7;break eb;case 8:if(!(y[d+480209|0]&16)){break eb}Xm(d,e,a,4);break eb;case 9:OA(d,c,a,0);break eb;case 10:if(a){Bo(d,e,a,0);break eb}if(!(x[d+480180>>2]&1048580)){break eb}Bo(d,e,0,0);break eb;case 11:if(a){Ao(d,e,a,0);break eb}if(!(x[d+480180>>2]&1048580)){break eb}Ao(d,e,0,0);break eb;case 12:RA(d,c,a,0);break eb;case 15:break fb;default:break eb}}if(x[d+480180>>2]==1){v[(D(c,872)+d|0)+1075838|0]=a;if(!(y[d+480209|0]&16)){break eb}uS(d,e);break eb}v[(D(c,872)+d|0)+1075836|0]=a}fb=f+16|0;break Ha;case 19:pS(d,j&65535,b);break Ha;case 24:Kb(i+8|0,q,55);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){if(x[d+1074392>>2]!=(b|0)){break Ha}a=x[(D(j,872)+d|0)+1075648>>2];if(v[a+60|0]&1?a:0){break Ya}if(!(!(y[U|0]|y[V|0])|b)){a=(D(j,872)+d|0)+1075080|0;x[a>>2]=x[a>>2]|4096;break Ya}a=D(j,872)+d|0;x[a+1075680>>2]=0;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ya}if(y[d+480209|0]&16){break Ya}break Ha;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Ha}if(!(1<<a&880)){if(a){if((a|0)!=1){break Ha}_A(d,o,J);Kb(i+8|0,q,117);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ha}to(d,j&65535,-224-J|0,1);break Ha}bB(d,o,J);Kb(i+8|0,q,117);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ha}to(d,j&65535,J|224,1);break Ha}Kb(i+8|0,q,58);if(Hb(x[x[i+8>>2]>>2],x[i+12>>2])){break Ha}pS(d,j&65535,b);break Ha;case 34:case 35:if(!(y[d+480209|0]&16)&(t|0)!=36){break Ha}c=j&65535;e=H+D(c,872)|0;f=e+616|0;a=cT(d,z[d+1074446>>1],x[d+1074424>>2],c);gb:{if((t|0)!=36){break gb}h=Fl(H)-x[H+16>>2]|0;if((h|0)<2){break gb}k=a;a=w[(H+D(c,872)|0)+1390>>1];a=dd(((k-a|0)/(h|0)|0)+a|0)}w[e+1390>>1]=a;e=qq(d,x[e+704>>2],x[f+656>>2]);if(e){ib[x[x[e>>2]+80>>2]](e,(a<<16>>16)+32768>>>2|0,c)}break Ha;case 20:if(!(y[d+480209|0]&16)|b>>>0>64){break Ha}a=D(j,872)+d|0;x[a+1075740>>2]=b;a=a+1075080|0;x[a>>2]=x[a>>2]|2097152;break Ha;case 21:h=x[d+480180>>2];f=x[d+480208>>2];a=b;hb:{if(a){v[o+816|0]=a;break hb}a=y[o+816|0]}c=a&15;e=a&255;ib:{jb:{if(!((c|0)!=15|e>>>0<16)){if(!(f&4096)){break ib}a=e>>>4|0;break jb}f=f&4096;g=e&240;if(!(!c|(g|0)!=240)){if(!f){break ib}a=0-c|0;break jb}if(f){break ib}if(c){a=0-c|0;if(!(h&25690144)|!g){break jb}break ib}if((a&255)>>>0<16){break ib}a=e>>>4|0}Va=o,Wa=Xb(a+x[o+748>>2]|0,0,64),x[Va+748>>2]=Wa}break Ha;case 26:YS(o,b);break Ha;case 29:if(!(y[d+480209|0]&16)){break Ha}a=D(j,872)+d|0;x[a+1075716>>2]=b;Kb(i+8|0,q,60);if(Va=0,Wa=Hb(x[x[i+8>>2]>>2],x[i+12>>2]),Ya=y[a+1075722|0]&4,Ya?Va:Wa){break Ha}a=D(j,872)+d|0;x[a+1075732>>2]=b;x[a+1075724>>2]=b;break Ha;case 11:aT(d,H,j&65535);break Ha;case 13:a=$S(d,H,j&65535,b);if((a|0)==-1){break Ha}x[d+1074436>>2]=a;if(!(y[d+480208|0]&32)){break Ha}w[d+1074444>>1]=z[d+1074448>>1];break Ha;case 37:case 38:case 39:case 40:QS(d,o,b,(t|0)==38|(t|0)==40,(t&254)==40);break Ha;case 41:eT(o,b);break Ha;case 42:if(x[d+1074392>>2]|J>>>0>1|b>>>0>47){break Ha}a=(b&240)==16;f=a?z[d+480188>>1]-1|0:j;c=a?0:j;a=((J|0)==1)<<26;while(1){e=c&65535;if(e>>>0>(f&65535)>>>0){break Ha}h=((e<<5)+d|0)+480280|0;x[h>>2]=a|x[h>>2]&-67108865;e=(D(e,872)+d|0)+1075080|0;x[e>>2]=a|x[e>>2]&-67108865;c=c+1|0;continue};case 44:break Za;default:break Ga}}dT(o,b);break Ha}yo(d,o);break Ha}kT(d,H,b)}c=b}Kb(i+8|0,q,78);if(!(!Hb(x[x[i+8>>2]>>2],x[i+12>>2])|!c)){VS(o,c&255)}a=y[U|0];if(!a){break N}v[m+1075796|0]=a}j=j+1|0;continue}break}a=1}fb=r+32|0;M=a&x[d+1074420>>2]!=0;kb:{if(!M){break kb}a=iT(d,d+1074376|0);x[d+1074380>>2]=a;x[d+1074404>>2]=a;b=Hd(z[d+480188>>1],1,31);lb:{if(Ad(y[d+1074366|0])){a=x[d+24628>>2];if((a|0)>=129){a=((D(a-128|0,b+4|0)|0)/16|0)+128|0}P=((D(a,x[d+480228>>2])<<1&-128)>>>0)/y[(b>>>1|0)+30800|0]|0;break lb}P=x[d+480228>>2]}w[d+480212>>1]=0;k=d+1074312|0;T=d+1074365|0;o=d+480180|0;H=d+480210|0;R=d+480209|0;L=d+1074366|0;U=d+1074364|0;V=d+1074360|0;t=0;while(1){if((t|0)==256){a=x[d+24608>>2];b=z[d+480212>>1];if(a>>>0>b>>>0){break kb}g=fb-16|0;fb=g;x[g+12>>2]=d;e=d+1074478|0;c=e+(a<<1)|0;if((c|0)!=(e|0)){a=e+(b<<1)|0;mb:{b=c-e|0;if((b|0)<3){break mb}f=b>>1;b=f-2>>>1|0;while(1){if((b|0)<0){break mb}vR(e,x[g+12>>2],f,e+(b<<1)|0);b=b-1|0;continue}}f=c-e>>1;b=c;while(1){if((a|0)!=(b|0)){if(Bl(x[g+12>>2],z[b>>1],z[e>>1])){uR(b,e);vR(e,x[g+12>>2],f,e)}b=b+2|0;continue}break}b=c-e>>1;while(1){if((b|0)>1){i=z[e>>1];a=e;n=x[g+12>>2];h=0;f=b;m=b-2>>>1|0;while(1){b=h<<1;h=b|1;k=b+2|0;b=k+a|0;if((f|0)>(k|0)){j=k;k=Bl(n,z[b>>1],z[b+2>>1]);h=k?j:h;b=k?b+2|0:b}w[a>>1]=z[b>>1];a=b;if((h|0)<=(m|0)){continue}break}b=c-2|0;nb:{if((b|0)==(a|0)){w[a>>1]=i;break nb}w[a>>1]=z[b>>1];w[b>>1]=i;i=x[g+12>>2];a=a+2|0;b=a-e>>1;ob:{if((b|0)<2){break ob}h=b-2|0;b=e+(h&-2)|0;a=a-2|0;if(!Bl(i,z[b>>1],z[a>>1])){break ob}h=h>>>1|0;k=z[a>>1];while(1){pb:{j=a;a=b;w[j>>1]=z[a>>1];if(!h){break pb}b=h-1|0;h=b>>>1|0;b=e+(b&-2)|0;if(Bl(i,z[b>>1],k)){continue}}break}w[a>>1]=k}}b=f-1|0;c=c-2|0;continue}break}}fb=g+16|0}else{h=D(t,872)+d|0;i=h+1075080|0;qb:{if(!(x[i>>2]&4096)|(x[h+1075016>>2]|(x[h+1075012>>2]|x[h+1075688>>2]))){break qb}Kb(l+16|0,k,64);if(Hb(x[x[l+16>>2]>>2],x[l+20>>2])){break qb}x[h+1075068>>2]=0;a=h+1075084|0;x[a>>2]=0;x[a+4>>2]=0}a=x[i>>2];b=z[d+480188>>1];rb:{if(x[h+1075068>>2]|b>>>0>t>>>0?a&1024:1){if(b>>>0>t>>>0){AR(d,t&65535)}w[h+1075834>>1]=0;break rb}c=0;J=h+1075712|0;x[J>>2]=0;q=h+1075672|0;x[q>>2]=0;m=h+1075e3|0;e=m;x[e>>2]=0;x[e+4>>2]=0;x[h+1075092>>2]=0;x[l+44>>2]=1065353216;w[l+42>>1]=0;C=h+1075648|0;r=x[C>>2];x[l+36>>2]=0;n=h+1075692|0;u=x[n>>2]?x[h+1075068>>2]!=0:0;f=h+1074992|0;sb:{tb:{ub:{if(b>>>0<=t>>>0){break ub}if(y[((t<<5)+d|0)+480288|0]){break tb}if(!r){break ub}c=y[r+34|0]!=0}if((c|u)!=1){break sb}}x[l+8>>2]=x[h+1075680>>2];x[l+32>>2]=x[h+1075744>>2];Kb(l+16|0,k,28);a=l+8|0;b=Hb(x[x[l+16>>2]>>2],x[l+20>>2])?l+32|0:a;c=d+1074312|0;vb:{if(Pb(c,28)){x[b>>2]=x[b>>2]+w[f+776>>1];Ee(b,0,64);break vb}e=Pb(c,1);c=w[f+776>>1];if(e){x[b>>2]=c+x[b>>2];Ee(b,0,256);break vb}x[f+688>>2]=c+x[f+688>>2];Ee(f+688|0,0,256);x[b>>2]=x[f+688>>2];w[f+776>>1]=0}wb:{xb:{b=d+1074312|0;if(!Pb(b,28)){if(!Pb(b,1)){break xb}}x[f+684>>2]=x[f+692>>2]+w[f+778>>1];Ee(f+684|0,0,256);break wb}x[f+692>>2]=x[f+692>>2]+w[f+778>>1];Ee(f+692|0,0,256);w[f+778>>1]=0;x[f+684>>2]=x[f+692>>2]}yb:{if(!(y[f+90|0]&4)|(x[d+480208>>2]&2101248)==2101248){break yb}zb:{if(x[a>>2]<=0){if(!Pb(d+1074312|0,21)){break zb}}c=5;if(!(y[d+480180|0]&5)){c=Pb(d+1074312|0,21)?5:6}b=xA(d,y[f+825|0],y[f+820|0]);Ab:{if((y[f+825|0]&3)!=1){break Ab}if(!Pb(d+1074312|0,89)){break Ab}b=y[f+820|0];e=b<<2&124;j=e^127;g=e;e=y[f+819|0];e=(!(y[f+90|0]&2)|y[d+480209|0]&16?e:y[f+823|0]+e|0)&32?j:g;b=b&32?0-e|0:e}if(x[d+480180>>2]!=131072){b=x[a>>2]+((D(y[f+827|0],b)|0)/(1<<c)|0)|0}else{c=x[a>>2];b=((D(y[f+827|0],D(c,64-b|0))|0)/-8192|0)+c|0}x[a>>2]=b}b=x[d+480208>>2];if(!(x[d+480180>>2]&16777248)|b&4?b&4096:0){break yb}b=Pb(d+1074312|0,21);c=y[f+826|0];e=y[f+820|0];v[f+820|0]=(b?c<<2:e)+(b?e:c)}e=t&65535;b=fb-16|0;fb=b;c=d+1074312|0;Kb(b+8|0,c,71);Bb:{if(Hb(x[x[b+8>>2]>>2],x[b+12>>2])){g=(D(e,872)+d|0)+1075831|0;c=v[g|0];if((c|0)>=0){break Bb}if(!(y[d+480209|0]&16|y[(D(e,872)+d|0)+1075797|0]!=18)){Cb:{Db:{if((c&-33)!=-64){c=c&223;if((c|0)!=128){break Db}c=y[(D(e,872)+d|0)+1075832|0]>>>4|-64;break Cb}c=y[(D(e,872)+d|0)+1075832|0]&15|-128;break Cb}c=c-1|0}v[g|0]=c;g=(D(e,872)+d|0)+1075080|0;x[g>>2]=x[g>>2]|2097152}if((c&224)!=128){break Bb}x[a>>2]=0;break Bb}if(y[(D(e,872)+d|0)+1075797|0]!=18){break Bb}Kb(b+8|0,c,22);Eb:{if(Hb(x[x[b+8>>2]>>2],x[b+12>>2])){j=D(e,872)+d|0;s=j+1075831|0;g=y[s|0];c=g<<24>>24;if(!((c|0)>=0|!x[j+1075068>>2])){Fb:{Gb:{if((g|0)!=192){if((g|0)!=128){break Gb}c=y[(D(e,872)+d|0)+1075832|0]>>>4|-64;break Fb}c=y[(D(e,872)+d|0)+1075832|0]&15|-128;break Fb}c=c-1|0}v[s|0]=c}if((c&192)!=128){break Eb}x[a>>2]=0;break Eb}g=y[(D(e,872)+d|0)+1075832|0];c=g>>>4|0;s=c+(g&15)|0;G=x[d+480180>>2];if(!(y[d+480208|0]&4?0:G&16777248)){s=s+2|0;c=c+1|0}g=(D(e,872)+d|0)+1075831|0;j=y[g|0];if(!(G&4)){j=(j&255)>>>0<s>>>0?j:0;if(c>>>0<=(j&255)>>>0){x[a>>2]=0}v[g|0]=j+1;break Eb}Hb:{if(y[d+480209|0]&16){g=j&255;j=g-1|0;j=g>>>0>=j>>>0?j:0;break Hb}v[g|0]=j+1}if(((j&255)>>>0)%(s>>>0)>>>0<c>>>0){break Eb}x[a>>2]=0}c=(D(e,872)+d|0)+1075080|0;x[c>>2]=x[c>>2]|2097152}c=D(e,872)+d|0;Ib:{if(y[c+1075797|0]!=18){break Ib}g=x[c+1075648>>2];if(!g){break Ib}c=y[g+34|0];if(!c|y[g+15|0]&2){break Ib}j=D(e,872)+d|0;if(x[j+1075080>>2]&134218752){break Ib}j=j+1075791|0;s=y[j|0];if(!zd(s)){break Ib}c=x[rd(d+906300|0,c-1|0)>>2];if(!c){break Ib}s=ib[x[x[c>>2]+104>>2]](c,s,e)|0;G=x[a>>2];if(!(!s|G)){ib[x[x[c>>2]+96>>2]](c,g,y[j|0]|256,0,e);break Ib}if(s|!G){break Ib}ib[x[x[c>>2]+96>>2]](c,g,y[j|0],z[(D(e,872)+d|0)+1075680>>1],e)}fb=b+16|0;Ee(a,0,256);x[l+8>>2]=x[l+8>>2]<<6;Jb:{if(r){Kb(l+16|0,k,31);if(Hb(x[x[l+16>>2]>>2],x[l+20>>2])){uu(d,f)}a=l+8|0;Kb:{if(!vA(d,f,0)){break Kb}c=x[f+656>>2];g=d+1074312|0;j=Pb(g,31);b=x[f+724>>2];if(b?0:j){break Kb}s=b-Pb(g,31)|0;b=Eq(c+48|0,s,256,64);G=y[c+65|0];Lb:{if((G|0)==255){break Lb}j=w[f+728>>1];if((j|0)==-1){break Lb}G=wb(x[c+48>>2],G);Z=y[G+2|0];c=Z<<2;b=(s|0)==z[G>>1]?c:b;if(Pb(g,94)){b=j+(b-c<<1)|0;break Lb}if(!Z){b=0;break Lb}b=(D(b,j)|0)/(c|0)|0}Va=a,Wa=(D(Xb(b,0,512),x[a>>2])|0)/256|0,x[Va>>2]=Wa}OS(f,a);Mb:{if(!vA(d,f,1)){break Mb}a=x[f+656>>2];b=d+1074312|0;g=Pb(b,31);c=x[f+732>>2];if(c?0:g){break Mb}b=Eq(a+68|0,c-Pb(b,31)|0,64,64)-32|0;a=x[f+684>>2];Va=f,Wa=Xb(((D(b,(a|0)>127?256-a|0:a)|0)/32|0)+a|0,0,256),x[Va+684>>2]=Wa}Kb(l+16|0,k,115);if(Hb(x[x[l+16>>2]>>2],x[l+20>>2])){break Jb}b=y[h+1075789|0];if(!b){break Jb}a=x[C>>2];if(!a|!y[a+26|0]){break Jb}RS(h+1075676|0,b,y[a+26|0],y[a+27|0]);break Jb}if(!(y[i+1|0]&16)){break Jb}x[h+1075688>>2]=0;x[l+8>>2]=0}Nb:{if(y[h+1075843|0]&8){c=0;x[l+8>>2]=0;break Nb}c=x[l+8>>2];if(!c){c=0;break Nb}if(y[i+3|0]&8){x[q>>2]=0;break Nb}if(Ad(y[T|0])){a=D(x[l+32>>2],x[h+1075740>>2]);b=a;g=a>>31;a=c<<8;Va=q,Wa=Fc(tua(sua(b,g,a,a>>31),hb,1048576,0),hb),x[Va>>2]=Wa;break Nb}a=D(x[l+32>>2],x[h+1075740>>2]);b=a;g=a>>31;a=D(x[d+1074456>>2],c);Va=q,Wa=Fc(tua(sua(b,g,a,a>>31),hb,1048576,0),hb),x[Va>>2]=Wa}x[J>>2]=c;Ob:{Pb:{a=x[n>>2];if(!(x[o>>2]==2|(a|0)>=x[d+480260>>2])){if(!Ej(d)){break Pb}a=x[n>>2]}if((a|0)<x[d+480264>>2]){break Ob}Kb(l+16|0,k,113);if(!Hb(x[x[l+16>>2]>>2],x[l+20>>2])){break Ob}if(Ej(d)){break Ob}x[n>>2]=x[d+480264>>2];break Ob}x[n>>2]=x[d+480260>>2]}Kb(l+16|0,k,73);a=x[n>>2];x[l+36>>2]=a;Qb:{if((x[i>>2]&1572864)!=1572864){break Qb}b=x[d+480208>>2];if(b&2097152){if(!Hl(y[h+1075782|0],y[h+1075783|0])|b&4096){break Qb}}b=h+1075704|0;Rb:{if((a|0)==x[b>>2]){c=x[h+1075708>>2];break Rb}x[b>>2]=a;c=a;a=h+1075764|0;b=h+1075696|0;c=vh(d,ru(d,c,w[a>>1],x[b>>2]),w[a>>1],x[b>>2]);x[h+1075708>>2]=c}x[l+36>>2]=c}g=fb-16|0;fb=g;G=D(e,872)+d|0;Z=G+1075648|0;a=x[Z>>2];Sb:{if(!a){break Sb}b=y[a+34|0];if(x[(D(e,872)+d|0)+1075080>>2]&134218752|(!b|y[a+15|0]&2)){break Sb}if(!x[rd(d+906300|0,b-1|0)>>2]){break Sb}a=D(e,872)+d|0;j=a+1075780|0;b=y[a+1075793|0];_=a+1075783|0;s=y[_|0];Tb:{Ub:{if((s|0)==1){a=b;Vb:{Wb:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 0:a=b+(y[(D(e,872)+d|0)+1075798|0]>>>4|0)|0;break Vb;case 1:break Wb;default:break Vb}}a=b+(y[(D(e,872)+d|0)+1075798|0]&15)|0}c=D(e,872)+d|0;if(y[c+1075792|0]==(a&255)){break Tb}if(!(v[c+1075843|0]&1)){break Ub}if(!zd(y[j|0])){break Ub}if(Hl(y[j+2|0],1)){break Ub}break Tb}if(y[j|0]){a=b;if(!Hl(y[j+2|0],s)){break Tb}}a=b;if(!y[(D(e,872)+d|0)+1075792|0]){break Tb}}Um(d,e,a&255|512,z[(D(e,872)+d|0)+1075680>>1])}$=(D(e,872)+d|0)+1075792|0;c=y[$|0];Xb:{Yb:{if(c){if((s|0)!=1|(a&255)!=(c|0)){break Yb}break Xb}if(!(v[(D(e,872)+d|0)+1075843|0]&1)|(s|0)!=1){break Xb}if(zd(y[j|0])){break Xb}c=b;if(!zd(b)){break Xb}}Um(d,e,c&255|256,0)}v[$|0]=y[_|0]==1?a:0}Zb:{if(y[G+1075797|0]!=1){break Zb}if(Oj(x[Z>>2])){a=0;_b:{$b:{ac:{switch(A[d+1074392>>2]%3|0){case 1:a=y[(D(e,872)+d|0)+1075798|0]>>>4|0;break $b;case 0:break $b;case 2:break ac;default:break _b}}a=y[(D(e,872)+d|0)+1075798|0]&15}w[l+42>>1]=a}a=(D(e,872)+d|0)+1075843|0;v[a|0]=y[a|0]|96;break Zb}if(!(!(y[d+480209|0]&16)|x[d+480180>>2]!=1048576)){a=D(e,872)+d|0;b=vh(d,y[a+1075789|0],w[a+1075764>>1],x[a+1075696>>2]);x[l+36>>2]=b;x[a+1075692>>2]=b}c=d+1074312|0;Kb(g+8|0,c,13);if(Hb(x[x[g+8>>2]>>2],x[g+12>>2])){a=y[(D(e,872)+d|0)+1075798|0];if(!a){break Zb}b=65536;bc:{switch(((A[d+1074392>>2]%(x[d+1074400>>2]+x[d+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:a=a<<4;case 0:b=x[((a&240)<<2)+35808>>2];break;default:break bc}}e=Ej(d);a=x[l+36>>2];c=a>>31;if(e){a=sua(a,c,b,b>>31);b=hb;a=a+32768|0;b=a>>>0<32768?b+1|0:b;a=tua(a,b,65536,0);b=hb}else{e=(b|0)/2|0;j=e>>31;s=e;e=a<<16;s=s+e|0;a=(c<<16|a>>>16)+j|0;a=tua(s,e>>>0>s>>>0?a+1|0:a,b,b>>31);b=hb}Va=l,Wa=Fc(a,b),x[Va+36>>2]=Wa;break Zb}Kb(g+8|0,c,51);if(Hb(x[x[g+8>>2]>>2],x[g+12>>2])){if(y[d+480209|0]&16){break Zb}cc:{dc:{a=x[d+1074416>>2];a=a-(A[d+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break dc}if((a|0)==16){break Zb}b=0;ec:{switch((a|0)%3|0){case 0:break Zb;case 2:break dc;case 1:break ec;default:break cc}}b=y[(D(e,872)+d|0)+1075798|0]>>>4|0;break cc}b=y[(D(e,872)+d|0)+1075798|0]&15}a=D(e,872)+d|0;c=a+1075764|0;a=a+1075696|0;b=ru(d,x[l+36>>2],w[c>>1],x[a>>2])+b|0;c=vh(d,b,w[c>>1],x[a>>2]);x[l+36>>2]=c;if(b>>>0<109){break Zb}x[g+8>>2]=c;Va=g,Wa=vh(d,109,0,x[a>>2]),x[Va+4>>2]=Wa;Va=l,Wa=x[_c(g+8|0,g+4|0)>>2],x[Va+36>>2]=Wa;break Zb}j=x[d+1074392>>2];s=d+480180|0;a=x[s>>2];fc:{if((a|0)!=1){b=y[(D(e,872)+d|0)+1075789|0];break fc}a=D(e,872)+d|0;b=ru(d,x[l+36>>2],w[a+1075764>>1],x[a+1075696>>2]);a=x[s>>2]}gc:{hc:{switch((((a&67633152?j+2|0:j)>>>0)%3|0)-1|0){case 0:b=(y[(D(e,872)+d|0)+1075798|0]>>>4|0)+b|0;break gc;case 1:break hc;default:break gc}}b=(y[(D(e,872)+d|0)+1075798|0]&15)+b|0}if(!(a&67633408|y[(D(e,872)+d|0)+1075789|0]!=(b&255))){Kb(g+8|0,c,82);if(!Hb(x[x[g+8>>2]>>2],x[g+12>>2])){break Zb}}if(y[d+480210|0]&32){a=b&255;if((a|0)==85){x[l+36>>2]=2147483647;break Zb}b=a>>>0>85?b-37|0:b}a=D(e,872)+d|0;j=vh(d,b&255,w[a+1075764>>1],x[a+1075696>>2]);x[l+36>>2]=j;if(x[d+480180>>2]&71860480){x[a+1075692>>2]=j;break Zb}Kb(g+8|0,c,82);if(!Hb(x[x[g+8>>2]>>2],x[g+12>>2])){break Zb}v[(D(e,872)+d|0)+1075792|0]=b}fb=g+16|0;if(!(!(y[H|0]&33)|x[l+36>>2]==2147483647)){ic:{if(x[o>>2]==2){c=452;a=3424;break ic}a=D(z[h+1075764>>1]>>>4&15,24);b=z[a+31542>>1]>>>1|0;c=b>>>0<=452?452:b;a=z[a+31520>>1]<<1}Ee(l+36|0,c,a);Ee(n,c,a)}WS(d,f);a=x[i>>2]}jc:{if(!(a&256)|y[R|0]&64){break jc}Kb(l+16|0,k,37);if(!Hb(x[x[l+16>>2]>>2],x[l+20>>2])){break jc}x[h+1075676>>2]=128}a=hT(d,f);kc:{if((a|0)<0|!(y[i+1|0]&2)){break kc}b=x[d+1298300>>2];if(!xd(b)){break kc}Bq(b,t&65535,a&255,1)}n=t&65535;AR(d,n);lc:{if(!u){break lc}a=PS(d,f,l+36|0);if((a|0)<0|!(y[i+1|0]&2)){break lc}b=x[d+1298300>>2];if(!xd(b)){break lc}Bq(b,n,a>>>2&255,1)}mc:{if(y[h+1075782|0]!=8){break mc}nc:{oc:{a=y[h+1075783|0];switch(a-5|0){case 1:break mc;case 0:case 2:break nc;default:break oc}}if((a|0)!=26){break mc}}a=x[o>>2];if((a|0)==4){if(y[R|0]&16){break mc}a=h+1075811|0;v[a|0]=y[a|0]+y[h+1075815|0];break mc}if(!(a&16777248)){break mc}El(f,y[h+1075784|0]);zR(d,n,l+36|0,l+44|0)}zR(d,n,l+36|0,l+44|0);pc:{if(!u){break pc}x[l+32>>2]=0;e=l+36|0;s=fb-16|0;fb=s;c=x[f+104>>2];qc:{if(!c|!y[c+40|0]){break qc}u=Oj(x[f+656>>2]);j=Ej(d);b=j?36832:35808;a=j?35808:36832;g=d+480180|0;if(!(u|!Pb(d+1074312|0,21)|x[g>>2]==1048576)){G=y[c+41|0];if(!G){break qc}g=y[f+818|0];x[s+12>>2]=x[f+756>>2]+y[c+39|0];xi(s+12|0,y[c+40|0]<<8);u=x[s+12>>2];v[f+818|0]=g+G;x[f+756>>2]=u;u=(u|0)/256|0;rc:{sc:{switch(y[c+38|0]-1|0){case 3:g=xR(xo(d))+-64|0;break rc;case 2:g=64-(g+1>>>1|0)|0;break rc;case 1:g=(g+1>>>1|0)+-64|0;break rc;case 0:g=(g^-1)>>>1&64;break rc;default:break sc}}g=v[g+32112|0]}xi(e,8388607);c=x[e>>2]<<8;x[e>>2]=c;G=D(g,u);u=(G|0)/64|0;g=u>>31;u=(g^u)-g|0;g=u&3;u=u>>>2|0;Y=e;e=c>>31;tc:{uc:{if((G|0)<=-64){a=x[(u<<2)+b>>2];b=Fc(tua(sua(a,a>>31,c,e),hb,65536,0),hb)-c|0;if(!g){break tc}a=j?35744:35680;break uc}a=x[a+(u<<2)>>2];b=Fc(tua(sua(a,a>>31,c,e),hb,65536,0),hb)-c|0;if(!g){break tc}a=j?35680:35744}a=x[a+(g<<2)>>2];b=(Fc(tua(sua(c,e,a,a>>31),hb,65536,0),hb)+b|0)-c|0}a=b;x[Y>>2]=(a+c|0)/256;x[l+32>>2]=a&255;break qc}j=x[g>>2]&16777248;g=y[c+39|0];vc:{if(!(j|g)){x[f+756>>2]=y[c+40|0]<<8;break vc}wc:{xc:{if(j){g=g<<1;j=x[f+756>>2];Y=f+756|0;break xc}if(y[f+89|0]&8){break wc}j=((y[c+40|0]<<8&65280)>>>0)/(g>>>0)|0;g=x[f+756>>2];Y=f+756|0}x[Y>>2]=g+j}xi(f+756|0,y[c+40|0]<<8)}g=y[f+818|0]+y[c+41|0]|0;v[f+818|0]=g;g=g<<24>>24;yc:{zc:{switch(y[c+38|0]-1|0){case 3:v[f+818|0]=g+1;j=v[(g&63)+32048|0];break yc;case 2:j=(64-(g>>>1|0)&127)+-64|0;break yc;case 1:j=((g>>>1|0)- -64&127)+-64|0;break yc;case 0:j=(g|0)>=0?-64:64;break yc;default:break zc}}j=0-v[(g&255)+32112|0]|0;if(x[d+480180>>2]!=1048576){break yc}j=(64-v[(g+-64&255)+32112|0]|0)/2<<16>>16}G=D(j,x[f+756>>2]);g=(G|0)/256|0;if(u){B[l+44>>2]=B[l+44>>2]+E(E(E(E(y[c+40|0])*E(.05000000074505806))*E(j|0))*E(.000244140625));v[f+851|0]=y[f+851|0]|64;break qc}if(x[d+480180>>2]!=4){Ac:{if((G|0)<=-256){g=0-g|0;c=g>>>8|0;a=(c<<2)+b|0;break Ac}b=a;c=g>>>8|0;a=a+(c<<2)|0}j=x[e>>2];a=x[a>>2];a=((D(x[((c<<2)+b|0)+4>>2]-a|0,g>>>2&63)|0)/64|0)+a|0;a=Fc(tua(sua(j,j>>31,a,a>>31),hb,256,0),hb);x[e>>2]=a;x[l+32>>2]=a&255;x[e>>2]=x[e>>2]/256;break qc}x[e>>2]=x[e>>2]+((G|0)/16384|0)}fb=s+16|0;g=x[l+36>>2];if((g|0)<=x[d+480260>>2]){Kb(l+16|0,k,81);if(Hb(x[x[l+16>>2]>>2],x[l+20>>2])){x[h+1075068>>2]=0}g=x[d+480260>>2];x[l+36>>2]=g}Bc:{if(!Oj(x[f+656>>2])){break Bc}a=h+1075843|0;b=y[a|0];if(!(x[d+1074392>>2]|!(b&32)?b&64:1)){break Bc}RU(f,B[l+44>>2],w[l+42>>1],d);b=a;a=y[a|0];v[b|0]=(a&64?-65:-33)&a}a=l+16|0;lB(a,d,f,g,x[l+32>>2]);c=Ab(a);b=sua(x[l+16>>2],x[l+20>>2],x[d+480240>>2],0);a=hb;g=tua(b,a,65536,0);j=a+1|0;e=a;a=b+65535|0;a=!(a>>>0<65535?j:e)&a>>>0<131071;b=a?1:g;x[l+16>>2]=b;a=a?0:hb;x[l+20>>2]=a;x[m>>2]=b;x[m+4>>2]=a;if((x[i>>2]&134219264)!=512){break pc}if(!xd(x[d+1298300>>2])){break pc}Kb(l+8|0,k,99);Cc:{Dc:{if(Va=Hb(x[x[l+8>>2]>>2],x[l+12>>2]),Wa=1,Ya=y[i+1|0]&16,Ya?Va:Wa){b=x[o>>2];break Dc}b=x[o>>2];if((b|0)!=2){break Cc}}e=(b|0)==2;a=x[i>>2];b=a&2048;Ec:{if(b?e:0){break Ec}c=sua(x[c>>2],0,261625,0);e=hb;c=c+66904|0;e=c>>>0<66904?e+1|0:e;c=Bc(uua(c,e,133808,0),hb);e=1;Fc:{if(b){break Fc}e=0;if(!(a&4096)){break Fc}e=!x[h+1075688>>2]}a=e;Kb(l+8|0,k,110);if(Va=Hb(x[x[l+8>>2]>>2],x[l+12>>2]),Wa=0,Ya=a,Ya?Va:Wa){break Ec}b=x[d+1298300>>2];Kb(l+8|0,k,95);FB(b,n,c,a,Hb(x[x[l+8>>2]>>2],x[l+12>>2]))}a=x[d+1298300>>2];b=sua(D(x[h+1075744>>2],D(x[h+1075740>>2],x[J>>2])),0,63,0);c=a;a=hb;g=a+1|0;e=a;a=b+33554432|0;b=a>>>0<33554432?g:e;Bq(c,n,Bc((b&67108863)<<6|a>>>26,b>>>26|0)&255,0);a=h+1075676|0;g=a;b=x[a>>2];c=0;a=x[d+1298300>>2];e=Nl(a,n);Gc:{if((e|0)==255){break Gc}j=x[a>>2];if(Ak(j)){break Gc}c=xb(Dd(a+318|0,e),10);s=x[a+4>>2];e=Lu(e)|192;a=y[c|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;wh(j,s,n,e,a&255);c=(a>>>5&1)+(a<<27>>31)|0}x[g>>2]=(c<<7)+128}Hc:{a=x[C>>2];if(!a|(y[a+60|0]&7)!=1){break Hc}b=x[a+48>>2];a=x[a+52>>2];if(mc(b,a)){break Hc}b=x[yR(f,0)>>2];a=qi(a);if(b>>>0<z[a>>1]|y[a+2|0]){break Hc}Jj(x[d+1298300>>2],n,1);Kb(l+8|0,k,109);a=x[i>>2];Va=i,Wa=(Hb(x[x[l+8>>2]>>2],x[l+12>>2])?a:a&-4609)|4096,x[Va>>2]=Wa;x[h+1075688>>2]=0;break pc}Kb(l+8|0,k,99);if(!Hb(x[x[l+8>>2]>>2],x[l+12>>2])|!(y[i+1|0]&16)|x[h+1075688>>2]){break pc}Jj(x[d+1298300>>2],n,1);x[i>>2]=x[i>>2]&-513}Ic:{if(!r){break Ic}Kb(l+16|0,k,31);if(Hb(x[x[l+16>>2]>>2],x[l+20>>2])){break Ic}uu(d,f)}b=x[i>>2];a=b&-65537;n=x[q>>2];s=h+1075016|0;r=h+1075012|0;c=n|(x[s>>2]|x[r>>2])?(a|b<<7&65536)^65536:a;x[i>>2]=c;u=h+1075664|0;a=u;x[a>>2]=0;x[a+4>>2]=0;a=h+1075834|0;b=y[a|0];e=b-4|0;e=b>>>0>=e>>>0?e:0;v[a|0]=e;j=h+1075835|0;b=y[j|0];g=b-4|0;b=b>>>0>=g>>>0?g:0;v[j|0]=b;Jc:{Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{Rc:{g=x[h+1075096>>2];Sc:{if(!g){break Sc}q=x[g>>2];g=x[g+20>>2];if(!ge(q,g)|!x[h+1075068>>2]){break Sc}if(Pi(x[f+8>>2],x[f+12>>2])){break Rc}}x[h+1075008>>2]=0;break Qc}x[h+1075008>>2]=g;if(g){break Pc}}if(!Gj(x[f+656>>2])){break Oc}g=0;if(c&6144){break Oc}}J=x[h+1075676>>2];q=(D(n,256-J|0)|0)/16384|0;q=q>>>0>=127?127:q;G=q>>>1|0;if(e<<24>>24<0){v[a|0]=q;e=q}if(G>>>0>(e&255)>>>0){v[a|0]=G}a=(D(n,J)|0)/16384|0;a=a>>>0>=127?127:a;if(b<<24>>24<0){v[j|0]=a;b=a}a=a>>>1|0;if(a>>>0>(b&255)>>>0){break Nc}break Mc}if((e&255)>>>0>=129){v[a|0]=0}g=0;a=0;if((b&255)>>>0<129){break Lc}}v[j|0]=a}if(!g){break Lc}g=128;j=x[d+24624>>2];if(j>>>0>=2){g=Xb(x[h+1075676>>2],0,256)}x[l+16>>2]=g;a=D(n,P)>>>(Ad(y[L|0])?7:8)|0;Tc:{Uc:{Vc:{switch(y[U|0]){case 0:if(!(y[d+24616|0]&16)){break Uc}case 1:if((g|0)<=127){b=a>>>1|0;e=(D(a,g)|0)/256|0;break Tc}b=(D(a,256-g|0)|0)/256|0;e=a>>>1|0;break Tc;case 3:break Vc;default:break Uc}}xi(l+16|0,255);e=x[l+16>>2];if((e|0)<=0){b=65536}else{b=z[(0-e<<1)+38368>>1]}b=D(b,a)>>>16|0;e=D(a,z[(e<<1)+37856>>1])>>>16|0;break Tc}b=(D(a,256-g|0)|0)/256|0;e=(D(a,g)|0)/256|0}a=x[C>>2];Wc:{if(a){g=y[a+14|0];if(kp(g)){break Wc}}g=y[d+480268|0];if(kp(g)){break Wc}a=y[d+24648|0];g=y[H|0]&128?x[d+24668>>2]?-1:a:a}n=h+1075786|0;v[n|0]=g;a=x[m>>2];q=x[m+4>>2];if(!(c&131072|((a|0)!=0|(q|0)!=1)|(x[h+1075748>>2]|(g&255)==255))){v[n|0]=0}g=b;b=1<<x[V>>2];x[u>>2]=(g|0)/(b|0);b=(e|0)/(b|0)|0;x[h+1075668>>2]=(c&256)>>>8|0?(j|0)==2?0-b|0:b:b;if(c&128){x[m>>2]=0-a;x[m+4>>2]=0-(((a|0)!=0)+q|0)}j=0;n=fb-16|0;fb=n;x[f+28>>2]=0;x[f+32>>2]=0;xi(f+672|0,524287);xi(f+676|0,524287);Xc:{Yc:{e=x[f+88>>2];if(!(e&65536)){a=x[f+676>>2];b=x[f+672>>2];break Yc}b=x[f+20>>2];g=x[f+672>>2];Zc:{if((b|0)!=(g|0)){a=x[f+24>>2];c=x[f+676>>2];break Zc}a=x[f+24>>2];c=x[f+676>>2];if((a|0)==(c|0)){break Yc}}e=x[d+24620>>2];c=(b|0)>=(g|0)&(a|0)>=(c|0);_c:{if(!c){b=Nu(e,x[d+24636>>2]);break _c}b=Nu(e,x[d+24640>>2])}if(!(!Pb(d+1074312|0,4)|!(y[d+480180|0]&4))){a=x[d+24620>>2];a=sua(a,a>>31,5,0);b=hb;a=a+500|0;b=a>>>0<500?b+1|0:b;b=Fc(tua(a,b,1e3,0),hb)}a=b;e=x[f+656>>2];$c:{if(c|!e){break $c}c=z[e+12>>1];if(!c){break $c}j=1;a=(D(c,x[d+24620>>2])>>>0)/1e5|0}g=a>>>0<=1?1:a;c=x[f+672>>2];a=x[f+20>>2];q=c-a<<12;s=f;e=x[f+676>>2];m=x[f+24>>2];Y=e-m<<12;if(!(y[f+90|0]&32|(!(c|e)|(!(a|m)|j)))){x[n+12>>2]=x[d+1074380>>2];Ee(n+12|0,b,2048);g=x[n+12>>2]}m=(Y|0)/(g|0)|0;x[s+32>>2]=m;j=(q|0)/(g|0)|0;x[f+28>>2]=j;a=e+((D(g,m)|0)/-4096|0)|0;x[f+24>>2]=a;b=c+((D(g,j)|0)/-4096|0)|0;x[f+20>>2]=b;if(j|m){x[f+100>>2]=g;c=x[f+88>>2];break Xc}x[f+24>>2]=e;x[f+20>>2]=c;a=e;b=c;c=x[f+88>>2]&-65537;break Xc}x[f+24>>2]=a;x[f+20>>2]=b;c=e&-65537}x[f+88>>2]=c&-2097153;x[f+40>>2]=a<<12;x[f+36>>2]=b<<12;fb=n+16|0;c=x[i>>2];if(!(c&512)){break Kc}break Jc}x[r>>2]=0;x[s>>2]=0;x[h+1075068>>2]=0;if(x[h+1075088>>2]){break Kc}if(!x[h+1075084>>2]){break Jc}}a=z[d+480212>>1];w[d+480212>>1]=a+1;w[((a<<1)+d|0)+1074478>>1]=t}x[h+1075660>>2]=c;a=h+1075843|0;v[a|0]=y[a|0]&253}t=t+1|0;continue}break}}fb=l+48|0;if(M){a=x[d+480208>>2];break h}if(Ad(y[Fa|0])){c=x[d+480208>>2]|512;break i}l=0;ad:{a=x[d+24620>>2]/10|0;b=Fc(a,a>>31);if(!b){break ad}c=b>>>0>=1048576?1048576:b;x[d+1074380>>2]=c;f=z[d+480212>>1];e=d+1074376|0;while(1){if((f|0)==(l|0)){break ad}a=e+D(z[(e+(l<<1)|0)+102>>1],872)|0;h=a+1288|0;x[h>>2]=0;x[h+4>>2]=0;x[a+716>>2]=c;h=x[a+640>>2]<<12;x[a+656>>2]=h;g=x[a+636>>2]<<12;x[a+652>>2]=g;x[a+704>>2]=x[a+704>>2]|65536;x[a+644>>2]=(0-g|0)/(c|0);x[a+648>>2]=(0-h|0)/(c|0);l=l+1|0;continue}}a=x[d+480208>>2];c=a|256;if(b){break i}c=a|512}a=c;x[d+480208>>2]=a}if(!(a&512)){break g}Va=d+1074392|0,Wa=Fl(Ea),x[Va>>2]=Wa}fb=K+96|0;break f}x[K+80>>2]=512;a=x[d+1074380>>2];x[K+88>>2]=ia;x[K+84>>2]=a;i=aE(K+80|0);if(x[d+24632>>2]){a=0;b=fb-48|0;fb=b;c=i<<2;while(1){if((a|0)==4){bd:{a=0;while(1){if((a|0)==4){break bd}x[(b+32|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}}}else{x[b+32>>2]=0;e=((a<<11)+d|0)+16396|0;Oz(e,c+e|0,b+32|0);a=a+1|0;continue}break}a=x[d+24632>>2];x[b+28>>2]=i;x[b+24>>2]=a;x[b+20>>2]=b+32;a=x[x[ha>>2]+8>>2];x[b+16>>2]=i;c=x[b+24>>2];x[b+8>>2]=x[b+20>>2];x[b+12>>2]=c;ib[a|0](ha,b+8|0);fb=b+48|0}if(Ad(Da)){a=0;while(1){if((a|0)==4){a=x[d+24632>>2];x[K+76>>2]=i;x[K+72>>2]=a;x[K+68>>2]=K+80;a=x[x[ma>>2]+8>>2];x[K+40>>2]=i;b=x[K+72>>2];x[K+32>>2]=x[K+68>>2];x[K+36>>2]=b;ib[a|0](ma,K+32|0)}else{x[(K+80|0)+(a<<2)>>2]=((a<<11)+d|0)+16396;a=a+1|0;continue}break}}V=0;da=0;r=fb-48|0;fb=r;if(i){Y=d+12|0;o=d+24592|0;q=d+24588|0;Dn(Y,i,o,q);if(A[d+24624>>2]>=3){Dn(d+8204|0,i,d+24600|0,d+24596|0)}w[r+42>>1]=0;sa=d+1074312|0;Ha=d+24648|0;Z=d+906300|0;Ia=d+24596|0;Ja=d+24600|0;Ka=d+8204|0;s=d+397452|0;t=d+397448|0;ta=d+393352|0;ua=d+397456|0;ja=d+1074376|0;La=d+480190|0;while(1){if(z[d+480212>>1]<=V>>>0){Va=d,Wa=z[se(d+480214|0,r+42|0)>>1],w[Va+480214>>1]=Wa}else{h=ja+(V<<1)|0;j=z[h+102>>1];a=D(j,872);J=a+ja|0;cd:{dd:{if(x[J+632>>2]){break dd}b=a+d|0;if(x[b+1075088>>2]){break dd}if(!x[b+1075084>>2]){break cd}}f=a+d|0;a=y[f+1075786|0]+1&255;if(a>>>0<=5){g=x[(a<<2)+26384>>2]}else{g=0}u=f+1075080|0;e=x[u>>2];ed:{if(!(!(e&16777216)&y[d+24612|0]>>>5)){a=o;c=q;b=e;k=Y;if(!(b&8388608)){break ed}}a=t;c=s;if(!y[ua+12|0]){Dn(ta,i,a,c)}v[ua+12|0]=1;j=z[h+102>>1];b=x[u>>2];k=ta}h=k;b=b>>>8&A[d+24624>>2]>2;G=b?Ia:c;M=b?Ja:a;b=b?Ka:h;_=lm(d,ja,j,2,1)-1|0;va=(_&255)>>>0>249;fd:{if(va){break fd}if(!x[rd(Z,_)>>2]){break fd}c=x[rd(Z,_)>>2];a=x[c+24>>2];if(!a){break fd}G=c+36|0;M=c+40|0;if(!(v[c+28|0]&1)){Dn(a,i,M,G);x[c+28>>2]=x[c+28>>2]|1}b=a}C=J+616|0;if(y[f+1075843|0]&8){FF(C,b,i);a=f+1075084|0;x[M>>2]=x[M>>2]+x[a>>2];x[G>>2]=x[G>>2]+x[f+1075088>>2];x[a>>2]=0;x[a+4>>2]=0;break cd}$=0;a=r+20|0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;c=d+1074312|0;Va=a,Wa=Pb(c,33),v[Va+16|0]=Wa;Va=a,Wa=Pb(c,116)^1,v[Va+17|0]=Wa;if(x[C+16>>2]){EF(a,C);h=x[C+12>>2];c=h>>31;k=c^x[C+8>>2];c=(c^h)-((c>>>0>k>>>0)+c|0)|0;x[a+12>>2]=c>>>0>8191?2:16384/(c+1>>>0)|0}Ma=e>>>12&8|(e>>>5&2|(g|e&1));Na=da&65535;Oa=f+1075795|0;Pa=f+1075778|0;Qa=f+1075688|0;Ra=f+1075024|0;Sa=f+1075020|0;Ta=f+1075668|0;Ua=f+1075664|0;P=f+1075088|0;T=f+1075084|0;wa=f+1075016|0;xa=f+1075012|0;ba=f+1075096|0;L=f+1075076|0;R=f+1075068|0;H=f+1075e3|0;ca=f+1075072|0;U=f+1075092|0;m=a;a=i;while(1){gd:{c=x[U>>2];W=c?a>>>0>c>>>0?c:a:a;x[r+12>>2]=W;hd:{id:{if(!W){break id}c=x[H+4>>2];k=c;e=x[H>>2];if(!(c|e)){break id}n=x[R>>2];if(!n){break id}f=x[m>>2];if(!f){break id}c=x[u>>2];g=x[ca>>2];x[J+632>>2]=f;h=x[C>>2];jd:{kd:{l=g&c<<30>>31;f=x[C+4>>2];if((l|0)>(f|0)){if((k|0)<0){h=fh(0,l<<1,h,f);x[C>>2]=h;f=hb;x[C+4>>2]=f;if(!(f>>>0<l+n>>>1>>>0&(f|0)>=(l|0))){h=0;x[C>>2]=h;f=l;x[C+4>>2]=f}ld:{if(c&4){c=c&-129;x[u>>2]=c;k=0-(((e|0)!=0)+k|0)|0;e=0-e|0;x[H>>2]=e;x[H+4>>2]=k;break ld}x[C>>2]=h;f=n-1|0;x[C+4>>2]=f}if(!(c&2)){break id}if(f>>>0<n>>>0){break jd}break id}if((f|0)>0|(f|0)>=0){break jd}f=0;break kd}if(f>>>0<n>>>0){break jd}if(!(c&2)){break id}if(c&4){if(!!e&(k|0)>=0|(k|0)>0){k=0-(((e|0)!=0)+k|0)|0;e=0-e|0;x[H>>2]=e;x[H+4>>2]=k}c=c|128;x[u>>2]=c;if(y[r+37|0]){j=y[r+36|0];ga=x[L>>2]-(j+g|0)|0;f=fh(h,f,0,n);h=hb;if(h>>>0<ga>>>0){h=fh(0,n-j|0,f,h);f=hb;break kd}f=g;h=0;break kd}j=(n<<1)-((1-((h|0)!=0)|0)+f|0)|0;f=j;h=0-h|0;x[C>>2]=h;x[C+4>>2]=f;if(g>>>0<f>>>0&f>>>0<n>>>0){break jd}x[r+44>>2]=y[r+36|0]+1;f=n-x[Gb(R,r+44|0)>>2]|0;break kd}if((k|0)<0){c=0-(((e|0)!=0)+k|0)|0;k=c;e=0-e|0;x[H>>2]=e;x[H+4>>2]=c}Qb(C,0,l-n|0);c=x[u>>2]|8192;x[u>>2]=c;h=x[C>>2];f=x[C+4>>2];break jd}x[C>>2]=h;x[C+4>>2]=f}md:{if((f|0)<(l|0)){if((f|k)<0){break id}x[r+44>>2]=W;g=e;n=k;break md}g=x[R>>2];if(g>>>0<f>>>0|(!!e&(k|0)>=0|(k|0)>0)&(f|0)==(g|0)){break id}x[r+44>>2]=W;n=k>>31;j=n^e;g=j-n|0;n=(k^n)-((j>>>0<n>>>0)+n|0)|0}vc(r+12|0,x[r+32>>2]);ya=x[r+12>>2];bg(h,f,sf(e,k,ya-1|0),hb);j=x[ca>>2];za=j>>>0>f>>>0|j+16>>>0<=f>>>0;if(za){c=c&-8193;x[u>>2]=c}ga=hb;nd:{od:{ka=x[r+24>>2];pd:{if(ka){j=x[r+28>>2];if(j>>>0<=f>>>0){qd:{if((k|0)<0){e=0;k=j;break qd}e=h;k=f;h=0;f=x[L>>2]}Va=r,Wa=wp(fh(fh(h,f,e,k),hb,1,0),hb,g,n)+1|0,x[Va+44>>2]=Wa;x[J+632>>2]=ka;break nd}if(!(za|!(c&8192))){Va=r,Wa=wp(fh(fh(0,l+16|0,h,f),hb,1,0),hb,g,n)+1|0,x[Va+44>>2]=Wa;Va=J,Wa=ka+D(x[L>>2]-l|0,$k(z[x[ba>>2]+34>>1]))|0,x[Va+632>>2]=Wa;break nd}if(!e&(k|0)<=0|(k|0)<0){break pd}if(W>>>0<2|j>>>0>ga>>>0){break od}Va=r,Wa=wp(fh(fh(0,j,h,f),hb,1,0),hb,g,n)+1|0,x[Va+44>>2]=Wa;break nd}if((k|0)>0|(k|0)>=0){break od}}if((l|0)<=(ga|0)){break nd}Va=r,Wa=wp(fh(fh(h,f,0,l),hb,1,0),hb,g,n)+1|0,x[Va+44>>2]=Wa;break nd}c=x[R>>2];if((c|0)>(ga|0)){break nd}Va=r,Wa=wp(fh(fh(0,c,h,f),hb,1,0),hb,g,n)+1|0,x[Va+44>>2]=Wa}vp(r+44|0,1,ya);e=x[r+44>>2];if((e|0)>0){break hd}}x[J+632>>2]=0;x[R>>2]=0;x[C>>2]=0;x[C+4>>2]=0;x[U>>2]=0;FF(C,b,a);x[M>>2]=x[M>>2]+x[T>>2];x[G>>2]=x[G>>2]+x[P>>2];x[P>>2]=0;x[T>>2]=0;x[u>>2]=x[u>>2]&-129;break gd}rd:{sd:{if(Na>>>0<A[d+24608>>2]){c=4;if(x[U>>2]){break sd}c=0;if(x[wa>>2]|x[xa>>2]){break sd}}Qb(C,sf(x[H>>2],x[H+4>>2],e),hb);$=0;x[P>>2]=0;x[T>>2]=0;b=(e<<3)+b|0;break rd}f=(e<<3)+b|0;h=f-8|0;x[T>>2]=0-x[h>>2];g=f-4|0;x[P>>2]=0-x[g>>2];ib[x[((c|Ma)<<2)+26e3>>2]](C,Ha,b,e);x[T>>2]=x[T>>2]+x[h>>2];x[P>>2]=x[P>>2]+x[g>>2];$=1;b=f}c=x[U>>2];td:{if(!c){break td}if(c>>>0<=e>>>0){x[U>>2]=0;x[xa>>2]=x[Ua>>2];x[wa>>2]=x[Ta>>2];x[Sa>>2]=0;x[Ra>>2]=0;if(x[Qa>>2]|!(y[u+1|0]&16)){break td}x[R>>2]=0;x[J+632>>2]=0;break td}x[U>>2]=c-e}g=y[u|0]&2;c=x[C+4>>2];f=g>>>1&c>>>0>=A[L>>2];h=x[R>>2];g=!(c>>>0<h>>>0|(g|!h)?1:z[Pa>>1]);a=a-e|0;Kb(r+12|0,sa,85);ud:{vd:{wd:{if(!Hb(x[x[r+12>>2]>>2],x[r+16>>2])){break wd}c=y[Oa|0];if(!c){break wd}if(c>>>0<=z[La>>1]){break vd}}c=0;break ud}k=x[ba>>2];e=D(c,104)+d|0;h=e+484380|0;c=(k|0)!=(h|0);if((h|0)==(k|0)|(f|g)!=1){break ud}x[ba>>2]=h;c=x[e+484400>>2];x[J+632>>2]=c;f=z[e+484414>>1];x[u>>2]=f|x[u>>2]&-768;h=x[e+484388>>2];x[R>>2]=h&f<<30>>31;e=x[e+484384>>2];x[ca>>2]=e;x[L>>2]=h;x[C+4>>2]=e;EF(m,C);if(!c){break gd}if((a|0)>0){continue}break gd}xd:{if(!f|c){break xd}Kb(r+12|0,sa,83);if(!Hb(x[x[r+12>>2]>>2],x[r+16>>2])|x[ca>>2]){break xd}x[C>>2]=x[C>>2];x[C+4>>2]=0;c=x[x[ba>>2]+8>>2];x[R>>2]=c;x[L>>2]=c}if((a|0)>0){continue}}break}x[J+632>>2]=x[m>>2];da=$+da|0;w[r+42>>1]=da;if(va|!$){break cd}if(!x[rd(Z,_)>>2]){break cd}a=x[rd(Z,_)>>2];ib[x[x[a>>2]+152>>2]](a)}V=V+1|0;continue}break}}fb=r+48|0;q=x[d+1298300>>2];if(xd(q)){a=aa;c=i;b=(D(x[d+480232>>2],x[d+480236>>2])>>>0)/48|0;k=fb-16|0;fb=k;yd:{if(!y[q+534|0]){break yd}b=sua(b,0,6169,0);e=hb;f=e>>>16|0;s=Bc((e&65535)<<16|b>>>16,f);while(1){if(!c){break yd}e=x[q>>2];g=x[e>>2];b=x[e+4>>2];while(1){if((b|0)>=(g|0)){x[e+8>>2]=x[e+12>>2];g=0;l=0;n=0;h=fb-16|0;fb=h;while(1){if((n|0)==18){b=(g|0)>=32767?32767:g;w[e+12>>1]=(b|0)<=-32768?-32768:b;b=(l|0)>=32767?32767:l;w[e+14>>1]=(b|0)<=-32768?-32768:b;w[e+3832>>1]=z[e+3832>>1]+1;b=(z[e+3834>>1]+1>>>0)%13440|0;w[e+3834>>1]=b;b=b>>>0<6720?b:13440-b|0;w[e+3836>>1]=b>>>8;if(!y[e+3843|0]){w[e+3836>>1]=b>>>10}b=z[e+3838>>1]+1|0;w[e+3838>>1]=b;if((b&65535)>>>0>=1024){w[e+3838>>1]=0;w[e+3840>>1]=z[e+3840>>1]+1&7}fb=h+16|0}else{b=e+D(n,44)|0;zd:{if(!y[b+56|0]){w[h+12>>1]=0;w[h+14>>1]=0;break zd}m=x[b+32>>2];f=z[m+3840>>1];if(f&3){m=(z[b+36>>1]>>>7&7)>>>!y[m+3844|0]>>>(f&1)<<z[b+38>>1];f=f&4?0-m|0:m}else{f=0}m=x[b+52>>2];Ad:{if(m){r=z[m+32>>1];t=z[b+48>>1];f=f<<16>>16;m=zg(x[b+16>>2],x[b+40>>2],f,0,w[b+46>>1]);j=x[b+40>>2];o=x[b+20>>2];if(!r){if(!t){m=zg(o,j,f,m,0);m=zg(x[b+24>>2],x[b+40>>2],f,m,0);f=zg(x[b+28>>2],x[b+40>>2],f,m,0);break Ad}j=zg(o,j,f,0,0);j=zg(x[b+24>>2],x[b+40>>2],f,j,0);f=zg(x[b+28>>2],x[b+40>>2],f,j,0)+m|0;break Ad}if(!t){m=zg(o,j,f,m,0);j=zg(x[b+24>>2],x[b+40>>2],f,0,0);f=zg(x[b+28>>2],x[b+40>>2],f,j,0)+m|0;break Ad}j=zg(o,j,f,0,0);f=(zg(x[b+24>>2],x[b+40>>2],f,j,0)+m|0)+zg(x[b+28>>2],x[b+40>>2],f,0,0)|0;break Ad}t=z[b+48>>1];f=f<<16>>16;m=zg(x[b+16>>2],x[b+40>>2],f,0,w[b+46>>1]);j=x[b+40>>2];o=x[b+20>>2];if(!t){f=zg(o,j,f,m,0);break Ad}f=zg(o,j,f,0,0)+m|0}w[h+14>>1]=y[b+57|0]?f:0;w[h+12>>1]=y[b+58|0]?f:0}n=n+1|0;l=w[h+12>>1]+l|0;g=w[h+14>>1]+g|0;continue}break}g=x[e>>2];b=x[e+4>>2]-g|0;x[e+4>>2]=b;continue}break}f=g-b|0;w[k+14>>1]=(D(w[e+12>>1],b)+D(f,w[e+8>>1])|0)/(g|0);w[k+12>>1]=(D(w[e+14>>1],b)+D(f,w[e+10>>1])|0)/(g|0);x[e+4>>2]=b+49716;x[a>>2]=x[a>>2]+D(s,w[k+14>>1]);x[a+4>>2]=x[a+4>>2]+D(s,w[k+12>>1]);a=a+8|0;c=c-1|0;continue}}fb=k+16|0}a=y[I+12|0];if(a|x[I+16>>2]){if(!a){Dn(ea,i,ra,qa)}a=x[I>>2];b=x[I+80>>2];c=D(a,b)>>>4|0;c=c>>>0>=32767?32767:c;w[I+98>>1]=c;w[I+96>>1]=c;c=x[I+49948>>2];e=D(c,a)>>>4|0;e=e>>>0>=65536?65536:e;f=e+127>>>3|0;w[I+49946>>1]=f;e=e+255>>>4|0;w[I+49944>>1]=e;w[I+49942>>1]=e;w[I+49940>>1]=f;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0<=8?8:a)|0;a=16-(D((b|0)>=32768?32768:b,a>>>0<=16?a:0)>>15)|0;e=0;while(1){if((e|0)!=(i|0)){b=e<<3;c=b+aa|0;x[c>>2]=x[c>>2]+D(a,x[b+ea>>2]>>4);b=b|4;c=b+aa|0;x[c>>2]=x[c>>2]+D(a,x[b+ea>>2]>>4);e=e+1|0;continue}break}m=I+68|0;l=0;c=w[I+84>>1];b=x[I+40>>2];g=x[I+36>>2];while(1){if((i|0)==(l|0)){x[I+40>>2]=b;x[I+36>>2]=g;f=i}else{a=(l<<3)+ea|0;e=x[a>>2]>>12;g=(D(c,e-g|0)>>15)+e|0;x[a>>2]=g;e=a;a=x[a+4>>2]>>12;b=(D(c,a-b|0)>>15)+a|0;x[e+4>>2]=b;l=l+1|0;continue}break}if(f){c=ea;a=f;n=x[m>>2]-1|0;h=z[m+22>>1];k=z[m+20>>1];b=w[m+26>>1];e=w[m+24>>1];q=w[m+18>>1];s=w[m+16>>1];j=x[m+4>>2];g=m+32928|0;while(1){if(a){l=ld(x[c>>2]);o=ld(x[c+4>>2]);k=ld((k<<16>>16)-l|0);h=ld((h<<16>>16)-o|0);k=dd(ld((D(k,s)|0)/65536<<1)+l|0);h=dd(ld((D(h,q)|0)/65536<<1)+o|0);o=g+(j<<2)|0;t=w[o>>1];l=dd(((D(t,e)|0)/-65536|0)+k|0);j=j+1&127;r=g+(j<<2)|0;o=w[o+2>>1];C=dd(((D(o,b)|0)/-65536|0)+h|0);w[r+2>>1]=C;w[r>>1]=l;n=n+1&8191;r=m+(n<<2)|0;Va=r,Wa=dd(t+((D(e,l)|0)/65536|0)|0),w[Va+160>>1]=Wa;Va=r,Wa=dd(o+((D(b,C)|0)/65536|0)|0),w[Va+162>>1]=Wa;c=c+8|0;a=a-1|0;continue}break}w[m+22>>1]=h;w[m+20>>1]=k;x[m+4>>2]=j}k=I+49892|0;C=I+33508|0;c=f;a=ea;while(1){if(c){e=x[I+76>>2];g=e&4095;h=C+(g<<2)|0;b=a;g=4096-g|0;t=e-x[I+49892>>2]&4095;e=4096-t|0;e=e>>>0>g>>>0?g:e;e=c>>>0<e>>>0?c:e;e=e>>>0>=64?64:e;j=e;g=0;q=fb-32|0;fb=q;l=x[m>>2];while(1){if((g|0)==7){Bd:{s=w[m+28>>1]/8<<16>>16;Cd:while(1){if(!j){break Bd}j=j-1|0;g=0;l=0;o=0;while(1)if((g|0)==4){g=4;n=0;r=dd((o|0)/32768|0);u=dd((l|0)/32768|0);l=0;while(1)if((g|0)==7){g=dd(r+((l|0)/32768|0)|0);w[h>>1]=g;x[b>>2]=D(g,s);g=dd(u+((n|0)/32768|0)|0);w[h+2>>1]=g;x[b+4>>2]=D(g,s);b=b+8|0;h=h+4|0;continue Cd}else{H=q+(g<<2)|0;o=x[H>>2]+1&8191;x[H>>2]=o;H=m+(o<<2)|0;R=w[H+160>>1];o=m+(g<<4)|0;H=w[H+162>>1];n=(n+D(R,w[o+44>>1])|0)+D(H,w[o+46>>1])|0;l=(D(R,w[o+40>>1])+l|0)+D(H,w[o+42>>1])|0;g=g+1|0;continue}}else{r=q+(g<<2)|0;n=x[r>>2]+1&8191;x[r>>2]=n;r=m+(n<<2)|0;u=w[r+160>>1];n=m+(g<<4)|0;r=w[r+162>>1];l=(l+D(u,w[n+44>>1])|0)+D(r,w[n+46>>1])|0;o=(D(u,w[n+40>>1])+o|0)+D(r,w[n+42>>1])|0;g=g+1|0;continue}}}}else{x[q+(g<<2)>>2]=l+(x[(m+(g<<4)|0)+32>>2]^-1);g=g+1|0;continue}break}fb=q+32|0;l=C+(t<<2)|0;h=a;b=e;u=k+2|0;j=x[k+4>>2];g=k+24640|0;n=k+16448|0;while(1){o=j&2047;if(b){T=k+8256|0;H=w[T+((j+1206&2047)<<2)>>1];t=k- -64|0;r=w[t+((j+1750&2047)<<2)>>1];R=w[(u+((j+754&2047)<<2)|0)+8256>>1];J=w[(u+((j+1602&2047)<<2)|0)- -64>>1];q=w[l>>1];s=w[l+2>>1];G=g+((j+502&2047)<<2)|0;M=w[G>>1];P=ld(w[k+32>>1]-M|0);G=w[G+2>>1];L=ld(w[k+34>>1]-G|0);U=w[k+26>>1];V=g+((j+22&2047)<<2)|0;Z=w[V>>1];_=ld(w[k+36>>1]-Z|0);$=w[k+28>>1];V=w[V+2>>1];ba=ld(w[k+38>>1]-V|0);ca=w[k+30>>1];M=dd(ld((D(P,w[k+24>>1])|0)/65536<<1)+M|0);w[k+32>>1]=M;Va=k,Wa=dd(ld((D(L,U)|0)/65536<<1)+G|0),w[Va+34>>1]=Wa;Va=k,Wa=dd(ld((D(_,$)|0)/65536<<1)+Z|0),w[Va+36>>1]=Wa;G=dd(ld((D(ba,ca)|0)/65536<<1)+V|0);w[k+38>>1]=G;M=ld((D(M,w[k+16>>1])|0)/32768|0);P=ld((D(G,w[k+22>>1])|0)/32768|0);G=ld(M+((q|0)/4<<16>>16)|0);M=ld(P+((s|0)/4<<16>>16)|0);q=w[k+8>>1];P=ld(G+((D(q,r)|0)/-65536|0)|0);s=o<<2;L=t+s|0;t=w[k+10>>1];U=ld(M+((D(t,J)|0)/-65536|0)|0);w[L+2>>1]=U;w[L>>1]=P;r=ld(r+((D(q,P)|0)/65536|0)|0);P=n+s|0;L=ld(J+((D(t,U)|0)/65536|0)|0);w[P+2>>1]=L;w[P>>1]=r;J=ld(r+G|0);G=ld(M+L|0);r=n+((j+682&2047)<<2)|0;M=w[r+2>>1];P=w[r>>1];r=ld((D(M,w[k+42>>1])+D(P,w[k+40>>1])|0)/32768|0);j=n+((j+426&2047)<<2)|0;L=w[j+2>>1];U=w[j>>1];j=ld((D(L,w[k+46>>1])+D(U,w[k+44>>1])|0)/32768|0);P=ld(ld(J+P|0)-r|0);M=ld(ld(G+M|0)-j|0);J=ld(ld(J+U|0)-r|0);G=ld(ld(G+L|0)-j|0);r=ld(r+((D(q,H)|0)/-65536|0)|0);T=s+T|0;L=ld(j+((D(t,R)|0)/-65536|0)|0);w[T+2>>1]=L;w[T>>1]=r;q=(D(r,q)|0)/65536|0;j=ld(q+H|0);s=g+s|0;t=(D(t,L)|0)/65536|0;r=ld(t+R|0);w[s+2>>1]=r;w[s>>1]=j;Va=h,Wa=(x[h>>2]+D(ld(j+P|0),w[k+48>>1])|0)+D(ld(r+M|0),w[k+50>>1])|0,x[Va>>2]=Wa;Va=h,Wa=(x[h+4>>2]+D(ld(ld(q)+J|0),w[k+52>>1])|0)+D(ld(ld(t)+G|0),w[k+54>>1])|0,x[Va+4>>2]=Wa;h=h+8|0;j=o+1|0;l=l+4|0;b=b-1|0;continue}break}x[k+4>>2]=o;x[I+76>>2]=e+x[I+76>>2]&4095;x[I+68>>2]=e+x[I+68>>2]&8191;c=c-e|0;a=(e<<3)+a|0;continue}break}x[I+68>>2]=x[I+68>>2]&8191;l=ea;h=aa;b=f;g=0;k=0;n=x[I+56>>2];c=x[I- -64>>2];e=x[I+52>>2];a=x[I+60>>2];while(1){if(b){g=x[l>>2];k=x[l+4>>2];c=c-k|0;c=(((c|0)/1024|0)-c|0)+n|0;x[h+4>>2]=c+x[h+4>>2];a=a-g|0;a=(((a|0)/1024|0)-a|0)+e|0;x[h>>2]=a+x[h>>2];n=c+((c|0)/-512|0)|0;e=a+((a|0)/-512|0)|0;h=h+8|0;l=l+8|0;b=b-1|0;a=g;c=k;continue}break}x[I+64>>2]=k;x[I+60>>2]=g;x[I+56>>2]=n;x[I+52>>2]=e;a=x[I+20>>2];Dd:{if(y[I+12|0]){break Dd}a=x[I+16>>2];if(a>>>0>f>>>0){a=a-f|0;break Dd}AP(I,ra,qa);a=0}v[I+12|0]=0;x[I+16>>2]=a}if(x[d+946300>>2]){Ed:{g=0;h=0;e=i<<2;q=d+906300|0;j=z[d+480214>>1]!=0;Aa=B[d+1074336>>2];X=B[d+1074332>>2];while(1)if((g|0)==250){k=d+12|0;l=d+12300|0;m=d+14348|0;Lw(k,l,m,i,X);a=d+1074476|0;C=y[a|0];v[a|0]=0;a=m;b=l;while(1){Fd:{Gd:{Hd:{if((h|0)!=250){o=rd(q,h);f=x[o>>2];if(!f|!x[f+24>>2]){break Fd}if(!wi(f+44|0)){break Fd}n=f;Id:{if(up(y[o+24|0])){break Id}c=ib[x[x[f>>2]+148>>2]](f)|0;n=x[o>>2];if(c){break Id}g=0;if(y[n+28|0]&2){break Id}while(1){if((g|0)==(h|0)){break Fd}c=rd(q,g);g=g+1|0;if((km(x[c+28>>2])|0)!=(h|0)){continue}break}}c=x[f+44>>2];s=Hc(c,0);r=Hc(c,1);t=(b|0)==(s|0);b=t?l:b;e=b;a=t?m:a;c=x[o+28>>2];g=a;Jd:{if(!c){break Jd}c=km(c);g=a;if(c>>>0<=h>>>0){break Jd}g=a;if(c>>>0>249){break Jd}g=a;if(!x[rd(q,c)>>2]){break Jd}c=x[rd(q,c)>>2];if(!(y[n+28|0]&4)){ib[x[x[c>>2]+152>>2]](c)}g=a;if(!wi(c+44|0)){break Jd}c=x[c+44>>2];e=Hc(c,0);g=Hc(c,1)}c=g;if(!up(y[o+24|0])){break Gd}g=0;Kd:{if(t){break Kd}while(1){if((g|0)==(i|0)){break Kd}t=g<<2;u=t+s|0;H=b+t|0;B[u>>2]=B[H>>2]+B[u>>2];u=r+t|0;t=a+t|0;B[u>>2]=B[t>>2]+B[u>>2];x[H>>2]=0;x[t>>2]=0;g=g+1|0;continue}}a=c;b=e;if(!(j&1)){break Gd}a=x[o>>2];if(a){ib[x[x[a>>2]+152>>2]](a)}g=km(x[o+28>>2]);a=h;while(1){b=g;g=b&255;if(g>>>0>249|g>>>0<=(a&255)>>>0){break Hd}t=rd(q,g);g=km(x[t+28>>2]);a=b;b=x[t>>2];if(!b){continue}ib[x[x[b>>2]+152>>2]](b);continue}}c=0;while(1){if((c|0)!=(i|0)){X=E(B[b>>2]*Aa);Ld:{if(E(F(X))<E(2147483648)){e=~~X;break Ld}e=-2147483648}x[k>>2]=e;X=E(B[a>>2]*Aa);Md:{if(E(F(X))<E(2147483648)){e=~~X;break Md}e=-2147483648}x[k+4>>2]=e;c=c+1|0;k=k+8|0;a=a+4|0;b=b+4|0;continue}break}break Ed}a=c;b=e}g=0;Nd:{Od:{t=y[o+24|0];if(!BF(t)){if(!AF(t)|!(y[n+28|0]&4)){break Od}}while(1){if((g|0)==(i|0)){break Nd}f=g<<2;o=f+e|0;B[o>>2]=B[f+s>>2]+B[o>>2];o=c+f|0;B[o>>2]=B[f+r>>2]+B[o>>2];g=g+1|0;continue}}if(C){ib[x[x[f>>2]+132>>2]](f)}ib[x[x[f>>2]+60>>2]](f,e,c,i);x[n+32>>2]=i+x[n+32>>2];if(!AF(y[o+24|0])){break Nd}if((ib[x[x[f>>2]+160>>2]](f)|0)<=0|A[n+32>>2]<x[d+24620>>2]<<2>>>0){break Nd}Pd:{while(1){if((g|0)==(i|0)){break Pd}f=g<<2;X=B[f+e>>2];Qd:{if(X>=E(1.1920928955078125e-7)|X<=E(-1.1920928955078125e-7)){break Qd}X=B[c+f>>2];if(X>=E(1.1920928955078125e-7)){break Qd}g=g+1|0;if(!(X<=E(-1.1920928955078125e-7))){continue}}break}x[n+32>>2]=0;break Nd}x[n+28>>2]=x[n+28>>2]|4}x[n+28>>2]=x[n+28>>2]&-3}h=h+1|0;continue}}else{f=rd(q,g);a=x[f>>2];Rd:{if(!a|!x[a+24>>2]){break Rd}if(!wi(a+44|0)){break Rd}if(!(ib[x[x[a>>2]+116>>2]](a)|0)){ib[x[x[a>>2]+112>>2]](a,1);ib[x[x[a>>2]+124>>2]](a)}c=x[a+44>>2];b=Hc(c,0);c=Hc(c,1);Sd:{if(v[a+28|0]&1){Lw(x[a+24>>2],b,c,i,X);break Sd}k=a+40|0;if(x[k>>2]|x[a+36>>2]){Dn(x[a+24>>2],i,k,a+36|0);Lw(x[a+24>>2],b,c,i,X);break Sd}Tb(b,0,e);Tb(c,0,e)}b=a;a=x[a+28>>2];x[b+28>>2]=a&-2;if(up(y[f+24|0])){break Rd}j=!(a&4)|j}g=g+1|0;continue}}}if(x[d+24624>>2]==1){c=0;while(1){if((c|0)!=(i|0)){a=(c<<3)+aa|0;x[(c<<2)+aa>>2]=(x[a+4>>2]+x[a>>2]|0)/2;c=c+1|0;continue}break}}if(Ad(y[Ga|0])){b=0;f=fb-16|0;fb=f;Td:{if(!x[d+1074376>>2]){l=d+1074460|0;a=l;x[a>>2]=0;x[a+4>>2]=0;a=x[d+1074456>>2];x[d+1074468>>2]=a;break Td}a=x[d+1074456>>2];c=x[d+1074468>>2];Ud:{if((a|0)==(c|0)){h=x[d+1074460>>2];break Ud}x[d+1074468>>2]=a;e=x[d+24620>>2];k=d+1074460|0;Vd:{if((a|0)>(c|0)){h=Nu(e,x[d+24636>>2]);break Vd}h=Nu(e,x[d+24640>>2])}x[k>>2]=h;x[d+1074464>>2]=h;c=a}l=d+1074460|0;if((h|0)<=0){break Td}c=(c<<12)-x[d+1074472>>2]|0;b=(c|0)/(h|0)|0;if(y[d+1074368|0]!=2){break Td}x[f+12>>2]=50;e=x[d+1074464>>2];x[f+8>>2]=1e4/(e+1|0);g=x[We(f+12|0,f+8|0)>>2];while(1){k=b>>31;if((g|0)>=((k^b)-k|0)){break Td}h=e+h|0;x[l>>2]=h;b=(c|0)/(h|0)|0;continue}}Wd:{Xd:{switch(x[d+24624>>2]-1|0){case 0:g=a<<12;h=d+12|0;k=a>>31;c=0;while(1){if((c|0)==(i|0)){break Wd}Yd:{if(x[l>>2]>0){e=x[d+1074472>>2]+b|0;x[d+1074472>>2]=e;n=x[h>>2];Va=h,Wa=Fc(tua(sua(n,n>>31,e,e>>31),hb,1048576,0),hb),x[Va>>2]=Wa;x[d+1074460>>2]=x[d+1074460>>2]-1;break Yd}e=x[h>>2];Va=h,Wa=Fc(tua(sua(e,e>>31,a,k),hb,256,0),hb),x[Va>>2]=Wa;x[d+1074472>>2]=g}c=c+1|0;h=h+4|0;continue};case 1:k=a<<12;h=d+12|0;e=a>>31;c=0;while(1){if((c|0)==(i|0)){break Wd}Zd:{if(x[l>>2]>0){g=x[d+1074472>>2]+b|0;x[d+1074472>>2]=g;n=x[h>>2];Va=h,Wa=Fc(tua(sua(n,n>>31,g,g>>31),hb,1048576,0),hb),x[Va>>2]=Wa;g=x[d+1074472>>2];j=g;m=g>>31;g=x[h+4>>2];Va=h,Wa=Fc(tua(sua(j,m,g,g>>31),hb,1048576,0),hb),x[Va+4>>2]=Wa;x[d+1074460>>2]=x[d+1074460>>2]-1;break Zd}g=x[h>>2];Va=h,Wa=Fc(tua(sua(g,g>>31,a,e),hb,256,0),hb),x[Va>>2]=Wa;g=x[h+4>>2];Va=h,Wa=Fc(tua(sua(g,g>>31,a,e),hb,256,0),hb),x[Va+4>>2]=Wa;x[d+1074472>>2]=k}c=c+1|0;h=h+8|0;continue};case 3:break Xd;default:break Wd}}n=a<<12;h=d+8204|0;c=d+12|0;e=a;g=a>>31;a=0;while(1){if((a|0)==(i|0)){break Wd}_d:{if(x[l>>2]>0){k=x[d+1074472>>2]+b|0;x[d+1074472>>2]=k;m=x[c>>2];Va=c,Wa=Fc(tua(sua(m,m>>31,k,k>>31),hb,1048576,0),hb),x[Va>>2]=Wa;k=x[d+1074472>>2];j=k;m=k>>31;k=x[c+4>>2];Va=c,Wa=Fc(tua(sua(j,m,k,k>>31),hb,1048576,0),hb),x[Va+4>>2]=Wa;k=x[d+1074472>>2];j=k;m=k>>31;k=x[h>>2];Va=h,Wa=Fc(tua(sua(j,m,k,k>>31),hb,1048576,0),hb),x[Va>>2]=Wa;k=x[d+1074472>>2];j=k;m=k>>31;k=x[h+4>>2];Va=h,Wa=Fc(tua(sua(j,m,k,k>>31),hb,1048576,0),hb),x[Va+4>>2]=Wa;x[d+1074460>>2]=x[d+1074460>>2]-1;break _d}k=x[c>>2];Va=c,Wa=Fc(tua(sua(k,k>>31,e,g),hb,256,0),hb),x[Va>>2]=Wa;k=x[c+4>>2];Va=c,Wa=Fc(tua(sua(k,k>>31,e,g),hb,256,0),hb),x[Va+4>>2]=Wa;k=x[h>>2];Va=h,Wa=Fc(tua(sua(k,k>>31,e,g),hb,256,0),hb),x[Va>>2]=Wa;k=x[h+4>>2];Va=h,Wa=Fc(tua(sua(k,k>>31,e,g),hb,256,0),hb),x[Va+4>>2]=Wa;x[d+1074472>>2]=n}a=a+1|0;h=h+8|0;c=c+8|0;continue}}fb=f+16|0}if(x[na>>2]!=128){b=d+12|0;c=d+8204|0;a=x[d+24604>>2];e=x[d+24624>>2];$d:{if((a|0)==128|e>>>0<2){break $d}tR(b,i,a);if(e>>>0<4){break $d}tR(c,i,a)}}if(x[d+24624>>2]==4){a=i;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+aa|0;c=a<<3;e=c|4;x[b+12>>2]=x[e+pa>>2];x[b+8>>2]=x[c+pa>>2];x[b+4>>2]=x[e+aa>>2];x[b>>2]=x[c+aa>>2];continue}break}}if(Ad(Ca)){a=x[d+24624>>2];x[K- -64>>2]=i;x[K+60>>2]=a;x[K+56>>2]=aa;a=x[x[la>>2]+8>>2];x[K+24>>2]=i;b=x[K+60>>2];x[K+16>>2]=x[K+56>>2];x[K+20>>2]=b;ib[a|0](la,K+16|0)}a=x[d+24624>>2];x[K+52>>2]=i;x[K+48>>2]=a;x[K+44>>2]=aa;a=x[x[oa>>2]+8>>2];x[K+8>>2]=i;b=x[K+48>>2];x[K>>2]=x[K+44>>2];x[K+4>>2]=b;ib[a|0](oa,K);x[d+1074380>>2]=x[d+1074380>>2]-i;x[d+1074376>>2]=i+x[d+1074376>>2];ia=ia-i|0;Ba=i+Ba|0;continue}break}fb=fa+32|0;return Ba}function qg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,m=0,o=0,q=0,s=0,t=0,u=E(0),G=0,H=0,I=0,J=E(0),K=0,L=0,M=0,O=0,V=0;k=fb-2240|0;fb=k;a:{b:{c:{d:{e:{f:{if(Ow(x[c>>2])){vc(b,268435456);L=x[c+8>>2];I=k+2220|0;f=I;x[f>>2]=0;x[f+4>>2]=0;Nb(f+8|0);x[k+2216>>2]=0;g:{h:{i:{j:{k:{l:{m:{f=y[a+3|0];n:{o:{if((f-4&255)>>>0<=4){x[31785]=0;d=R(205,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break m}x[k+2216>>2]=d;break o}if(f>>>0>17){break n}p:{g=1<<f;if(!(g&63503)){if(!(g&198144)){break n}break p}if(y[a|0]){break p}break o}f=0;e=gD(a,x[b>>2]);x[31785]=0;S(189,k+48|0,c|0,e|0);e=x[31785];x[31785]=0;if((e|0)==1){break l}d=k+48|0;e=x[d+4>>2];x[I>>2]=x[d>>2];x[I+4>>2]=e;pn(I+8|0,d+8|0);Jc(d);e=Se(I);d=x[I>>2];x[k+2216>>2]=d;if(!e){break g}}f=y[a+3|0]}q:{r:{switch(f&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=!y[a|0];case 9:case 10:case 16:case 17:g=x[b>>2];if(!(g>>>0<262145|h)){f=f&255;x[k+48>>2]=((f|0)==10)<<4;h=d-x[Gb(k+48|0,k+2216|0)>>2]|0;if(f>>>0>15){break k}s:{if(!(1<<f&63503)){if((f|0)==10){break s}break k}if(!(y[a|0]&7)){break k}}f=(h|0)<0?-1:h<<1;break j}f=f&255;if(f>>>0>8){break h}if(1<<f&432){break q}if((f|0)!=6){break h}break;case 4:case 5:case 7:case 8:break q;case 6:break r;default:break i}}f=0;if(d>>>0<10){break g}x[31785]=0;P(186,c|0,4)|0;d=x[31785];x[31785]=0;if((d|0)==1){break m}x[31785]=0;f=R(154,c|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){x[k+48>>2]=f;x[k+28>>2]=x[k+2216>>2];d=x[Gb(k+48|0,k+28|0)>>2];Eh(c,8);f=((d>>>0>50529027?-1:D(d,85))>>>0)/(y[a|0]>>>3>>>0)|0;break j}a=N()|0;break a}g=8/(Xq(y[a+1|0])>>>0)|0;f=D(g,d);sua(g,0,d,0);f=hb?-1:f;break j}a=N()|0;break a}a=N()|0;break a}g=0;d=Xq(y[a+1|0]);t:{u:{switch(f|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:g=y[a|0];break t;case 9:g=16;break t;case 10:g=4;break t;case 16:case 17:break u;default:break t}}g=8}f=D(d,g&255)>>>3|0;d=(f+h|0)-1|0;f=((d>>>0<h>>>0?-1:d)>>>0)/(f>>>0)|0}vc(b,f)}g=x[b>>2]}if(!g){f=0;break g}w[b+34>>1]=z[b+34>>1]&65470|y[a|0]>15|(y[a+1|0]!=1)<<6;if(!Bh(b)){f=0;x[b>>2]=0;break g}v:{if(me(a,ad(k+48|0,8,1,0,10))){x[31785]=0;d=P(206,c|0,k+48|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){f=0;if(!d){break v}a=x[b>>2];d=0;x[31785]=0;x[k+28>>2]=a+1>>>1;f=R(205,c|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break b}vc(k+28|0,f);a=e+16|0;b=x[b+20>>2];h=x[k+28>>2];f=h;while(1)if(f){g=k+48|0;e=d+y[g|y[a|0]&15]|0;v[b|0]=e;d=y[g|y[a|0]>>>4]+(e&255)|0;v[b+1|0]=d;f=f-1|0;a=a+1|0;b=b+2|0;continue}else{f=h+16|0;break v}}a=N()|0;break a}w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{g=y[a+3|0];switch(g-4|0){case 3:break E;case 4:break F;case 5:break G;case 2:break H;case 0:case 1:break I;default:break C}}x[31785]=0;b=ba(207,k+1128|0,c|0,b|0,(g|0)==5|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break f}ub(b);f=x[c+8>>2]-L|0;break v}if(y[a+1|0]!=1){break D}x[31785]=0;P(186,c|0,4)|0;a=x[31785];x[31785]=0;if((a|0)==1){break f}x[31785]=0;e=R(154,c|0)|0;a=x[31785];x[31785]=0;J:{K:{L:{if((a|0)!=1){x[31785]=0;x[k+28>>2]=e;d=R(200,c|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break L}x[31785]=0;S(208,k+48|0,c|0,e|0);a=x[31785];x[31785]=0;if((a|0)==1){break K}vc(k+28|0,x[k+48>>2]);e=x[k+28>>2];Fn(k+1120|0,k+48|0);bc(k+1112|0,x[b+20>>2],Rk(x[b>>2],z[b+34>>1]));x[31785]=0;aa(209,x[k+1120>>2],x[k+1124>>2],x[k+1112>>2],x[k+1116>>2],d<<24>>24);a=x[31785];x[31785]=0;if((a|0)==1){break J}f=e+9|0;Jc(k+48|0);break v}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;Jc(k+48|0);break a}if(y[a+1|0]!=1|y[a|0]!=16){break D}f=x[k+2216>>2];d=Zk(k+1110|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];h=fb-16|0;fb=h;x[h+12>>2]=f>>>1;x[h+8>>2]=a;d=x[Gb(h+12|0,h+8|0)>>2];f=d;while(1){if(f){a=y[e|0]+g|0;g=a+y[e+1|0]|0;w[b>>1]=g<<8|a&255;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=h+16|0;f=d<<1;break v}if(y[a+1|0]!=1|y[a|0]>16){break D}d=x[c+8>>2];e=x[c>>2];f=0;x[31785]=0;d=U(153,e|0,d|0,8)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}if(!d){break v}x[31785]=0;d=R(154,c|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}x[k+2216>>2]=d;if(d>>>0<4){break v}x[31785]=0;S(188,k+28|0,c|0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break c}e=k+28|0;t=Zr(k+48|0,e);ub(e);e=x[t>>2];x[31785]=0;d=R(210,e|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break e}f=d+4|0;m=y[a|0];s=(m|0)!=16;g=0;h=0;while(1){if(A[b>>2]<=h>>>0){break x}M:{if(s){break M}x[31785]=0;o=P(161,t|0,8)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break M}a=T(29088)|0;break y}x[31785]=0;i=P(161,t|0,1)|0;a=x[31785];x[31785]=0;if((a|0)==1){break z}x[31785]=0;e=P(161,t|0,1)|0;a=x[31785];x[31785]=0;if((a|0)==1){break z}N:{O:{P:{if(!e){e=8;while(1){x[31785]=0;d=P(161,t|0,1)|0;a=x[31785];x[31785]=0;if((a|0)==1){break N}if(d){break P}e=e+16|0;continue}}x[31785]=0;a=P(161,t|0,3)|0;e=x[31785];x[31785]=0;if((e|0)!=1){break O}break z}x[31785]=0;d=P(161,t|0,4)|0;a=x[31785];x[31785]=0;if((a|0)==1){break z}a=e+d|0}g=(g&255)+(((i?-1:0)^a)&255)|0;Q:{if((m|0)!=16){v[x[b+20>>2]+h|0]=g;break Q}w[x[b+20>>2]+(h<<1)>>1]=o&255|g<<8}h=h+1|0;continue}break}a=T(29088)|0;break y}if(y[a+1|0]!=1){break C}break B}if((g|0)!=7){break C}if(y[a+1|0]==1){break B}}f=y[a|0];break A}f=y[a|0];if(f>>>0>16){break A}f=0;if(A[k+2216>>2]<5){break v}d=z[b+34>>1];e=x[b+20>>2];a=x[b>>2];x[31785]=0;f=U(211,c|0,e|0,Rk(a,d)|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break v}break f}R:{if((g&254)!=16|(f&255)!=16){break R}d=y[a+1|0];if((d-1&255)>>>0>1){break R}M=k,O=D(x[b>>2],Xq(d)),x[M+48>>2]=O;vc(k+48|0,x[k+2216>>2]);a=x[b+20>>2];f=x[k+48>>2];if((g|0)==16){b=f;while(1){if(!b){break v}M=a,O=z[_b(29120,y[e|0])>>1],w[M>>1]=O;a=a+2|0;e=e+1|0;b=b-1|0;continue}}b=f;while(1){if(!b){break v}M=a,O=z[_b(29632,y[e|0])>>1],w[M>>1]=O;a=a+2|0;e=e+1|0;b=b-1|0;continue}}d=(f&255)!=8;if(!(d|y[a+1|0]!=1)){S:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2];x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0];b=b+1|0;e=e+1|0;f=f-1|0;continue}break};fb=d+16|0;f=a;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2];x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0]^128;b=b+1|0;e=e+1|0;f=f-1|0;continue}break};fb=d+16|0;f=a;break v;default:f=0;if((g|0)!=11){break v}break;case 2:break S}}f=x[k+2216>>2];d=Yu(k+27|0);a=x[b>>2];b=x[b+20>>2];g=y[d|0];d=fb-16|0;fb=d;x[d+12>>2]=f;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=y[e|0]+g|0;v[b|0]=g;b=b+1|0;e=e+1|0;f=f-1|0;continue}break}fb=d+16|0;f=a;break v}if(!(y[a+1|0]!=3|d)){T:{switch(g|0){case 0:i=fb-16|0;fb=i;f=x[k+2216>>2];x[i+12>>2]=f;d=x[b>>2];x[i+8>>2]=d;a=i+8|0;g=x[Gb(a,i+12|0)>>2];x[i+8>>2]=d;x[i+4>>2]=f-g;f=x[Gb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=e;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+e|0;a=f;while(1){if(a){v[h|0]=y[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};fb=i+16|0;f=f+g|0;break v;case 1:i=fb-16|0;fb=i;f=x[k+2216>>2];x[i+12>>2]=f;d=x[b>>2];x[i+8>>2]=d;a=i+8|0;g=x[Gb(a,i+12|0)>>2];x[i+8>>2]=d;x[i+4>>2]=f-g;f=x[Gb(a,i+4|0)>>2];h=x[b+20>>2];a=g;d=e;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=x[b+20>>2]+1|0;d=x[b>>2]+e|0;a=f;while(1){if(a){v[h|0]=y[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};fb=i+16|0;f=f+g|0;break v;default:f=0;if((g|0)!=11){break v}break;case 2:break T}}h=x[k+2216>>2];f=y[Yu(k+26|0)|0];m=fb-16|0;fb=m;x[m+12>>2]=h;g=x[b>>2];x[m+8>>2]=g;d=m+8|0;i=x[Gb(d,m+12|0)>>2];x[m+8>>2]=g;x[m+4>>2]=h-i;h=x[Gb(d,m+4|0)>>2];s=b;o=x[b+20>>2];d=f;b=i;g=e;while(1){if(b){d=y[g|0]+d|0;v[o|0]=d;o=o+2|0;g=g+1|0;b=b-1|0;continue}break}o=x[s+20>>2]+1|0;g=x[s>>2]+e|0;b=h;while(1){if(b){f=y[g|0]+f|0;v[o|0]=f;o=o+2|0;g=g+1|0;b=b-1|0;continue}break}fb=m+16|0;f=h+i|0;if(y[a+3|0]!=11){break v}a=x[s+20>>2];b=a+(x[s>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break v}v[a+1|0]=y[a+1|0]+y[a|0];a=a+2|0;continue}}d=f&255;h=a;if(!((d|0)!=8|y[a+1|0]!=2)){f=0;U:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0];v[b+1|0]=y[e+1|0];b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<1;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){v[b|0]=y[e|0]^128;v[b+1|0]=y[e+1|0]^128;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<1;break v;case 2:break U;default:break v}}f=x[k+2216>>2];a=Yu(k+25|0);d=x[b>>2];g=x[b+20>>2];a=y[a|0];h=fb-16|0;fb=h;x[h+12>>2]=f>>>1;x[h+8>>2]=d;b=a;f=x[Gb(h+12|0,h+8|0)>>2];d=f;while(1){if(d){a=y[e|0]+a|0;v[g|0]=a;b=y[e+1|0]+b|0;v[g+1|0]=b;g=g+2|0;e=e+2|0;d=d-1|0;continue}break}fb=h+16|0;f=f<<1;break v}if(!(y[h+2|0]|((d|0)!=16|y[h+1|0]!=1))){V:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<1;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<1;break v;default:f=0;if((g|0)!=11){break v}break;case 2:break V}}f=x[k+2216>>2];d=Zk(k+22|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];d=fb-16|0;fb=d;x[d+12>>2]=f>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=(y[e|0]+g|0)+(y[e+1|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=d+16|0;f=a<<1;break v}a=f&255;if(!((a|0)!=16|y[h+1|0]!=1|y[h+2|0]!=1)){f=0;W:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=x[k+2216>>2]>>>1;x[g+8>>2]=a;d=x[Gb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=a<<8|a>>>8;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=g+16|0;f=d<<1;break v;case 1:a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=x[k+2216>>2]>>>1;x[g+8>>2]=a;d=x[Gb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;e=e+2|0;f=f-1|0;continue}break};fb=g+16|0;f=d<<1;break v;case 2:break W;default:break v}}f=x[k+2216>>2];d=Zk(k+20|0);a=x[b>>2];b=x[b+20>>2];g=z[d>>1];d=fb-16|0;fb=d;x[d+12>>2]=f>>>1;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){g=(y[e+1|0]+g|0)+(y[e|0]<<8)|0;w[b>>1]=g;b=b+2|0;e=e+2|0;f=f-1|0;continue}break}fb=d+16|0;f=a<<1;break v}if(!(y[h+2|0]|((a|0)!=16|y[h+1|0]!=3))){X:{switch(g|0){case 0:s=fb-16|0;fb=s;d=x[k+2216>>2];x[s+12>>2]=d;i=x[b>>2]<<1;x[s+8>>2]=i;a=s+8|0;g=x[Gb(a,s+12|0)>>2];x[s+8>>2]=i;x[s+4>>2]=d-g;a=x[Gb(a,s+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){w[f>>1]=y[d|0]|y[d+1|0]<<8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){w[d>>1]=y[f|0]|y[f+1|0]<<8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=s+16|0;f=a+h<<1;break v;case 1:s=fb-16|0;fb=s;d=x[k+2216>>2];x[s+12>>2]=d;i=x[b>>2]<<1;x[s+8>>2]=i;a=s+8|0;g=x[Gb(a,s+12|0)>>2];x[s+8>>2]=i;x[s+4>>2]=d-g;a=x[Gb(a,s+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){w[f>>1]=(y[d|0]|y[d+1|0]<<8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+i|0;d=x[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){w[d>>1]=(y[f|0]|y[f+1|0]<<8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=s+16|0;f=a+h<<1;break v;default:f=0;if((g|0)!=11){break v}break;case 2:break X}}g=x[k+2216>>2];a=z[Zk(k+18|0)>>1];t=fb-16|0;fb=t;x[t+12>>2]=g;m=x[b>>2]<<1;x[t+8>>2]=m;d=t+8|0;f=x[Gb(d,t+12|0)>>2];x[t+8>>2]=m;x[t+4>>2]=g-f;s=x[Gb(d,t+4|0)>>2];g=b;d=x[g+20>>2];b=a;i=f>>>1|0;o=i;f=e;while(1){if(o){b=(y[f|0]+b|0)+(y[f+1|0]<<8)|0;w[d>>1]=b;d=d+4|0;f=f+2|0;o=o-1|0;continue}break}f=e+m|0;d=x[g+20>>2]+2|0;b=s>>>1|0;o=b;while(1){if(o){a=(y[f|0]+a|0)+(y[f+1|0]<<8)|0;w[d>>1]=a;d=d+4|0;f=f+2|0;o=o-1|0;continue}break}fb=t+16|0;f=b+i<<1;if(y[h+3|0]!=11){break v}a=x[g+20>>2];b=a+(x[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break v}w[a+2>>1]=z[a+2>>1]+z[a>>1];a=a+4|0;continue}}a=f&255;if(!((a|0)!=16|y[h+1|0]!=3|y[h+2|0]!=1)){f=0;Y:{switch(g|0){case 0:m=fb-16|0;fb=m;d=x[k+2216>>2];x[m+12>>2]=d;s=x[b>>2]<<1;x[m+8>>2]=s;a=m+8|0;g=x[Gb(a,m+12|0)>>2];x[m+8>>2]=s;x[m+4>>2]=d-g;i=x[Gb(a,m+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){a=y[d|0]|y[d+1|0]<<8;w[f>>1]=a<<8|a>>>8;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+s|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=y[f|0]|y[f+1|0]<<8;w[d>>1]=a<<8|a>>>8;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=m+16|0;f=b+h<<1;break v;case 1:m=fb-16|0;fb=m;d=x[k+2216>>2];x[m+12>>2]=d;s=x[b>>2]<<1;x[m+8>>2]=s;a=m+8|0;g=x[Gb(a,m+12|0)>>2];x[m+8>>2]=s;x[m+4>>2]=d-g;i=x[Gb(a,m+4|0)>>2];f=x[b+20>>2];h=g>>>1|0;g=h;d=e;while(1){if(g){a=y[d|0]|y[d+1|0]<<8;w[f>>1]=(a<<8|a>>>8)^32768;f=f+4|0;d=d+2|0;g=g-1|0;continue}break};f=e+s|0;d=x[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=y[f|0]|y[f+1|0]<<8;w[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;f=f+2|0;g=g-1|0;continue}break};fb=m+16|0;f=b+h<<1;break v;case 2:break Y;default:break v}}f=x[k+2216>>2];a=z[Zk(k+16|0)>>1];o=fb-16|0;fb=o;x[o+12>>2]=f;m=x[b>>2]<<1;x[o+8>>2]=m;d=o+8|0;g=x[Gb(d,o+12|0)>>2];x[o+8>>2]=m;x[o+4>>2]=f-g;s=x[Gb(d,o+4|0)>>2];f=b;h=x[b+20>>2];b=a;i=g>>>1|0;d=i;g=e;while(1){if(d){b=(y[g+1|0]+b|0)+(y[g|0]<<8)|0;w[h>>1]=b;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}g=e+m|0;h=x[f+20>>2]+2|0;b=s>>>1|0;d=b;while(1){if(d){a=(y[g+1|0]+a|0)+(y[g|0]<<8)|0;w[h>>1]=a;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}fb=o+16|0;f=b+i<<1;break v}if(!(y[h+2|0]|((a|0)!=16|y[h+1|0]!=2))){f=0;Z:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>2;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=y[e|0]|y[e+1|0]<<8;w[b+2>>1]=y[e+2|0]|y[e+3|0]<<8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<2;break v;case 1:a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=x[k+2216>>2]>>>2;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){w[b>>1]=(y[e|0]|y[e+1|0]<<8)^32768;w[b+2>>1]=(y[e+2|0]|y[e+3|0]<<8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=d+16|0;f=a<<2;break v;case 2:break Z;default:break v}}f=x[k+2216>>2];a=Zk(k+14|0);d=x[b>>2];g=x[b+20>>2];a=z[a>>1];h=fb-16|0;fb=h;x[h+12>>2]=f>>>2;x[h+8>>2]=d;b=a;f=x[Gb(h+12|0,h+8|0)>>2];d=f;while(1){if(d){a=(y[e|0]+a|0)+(y[e+1|0]<<8)|0;w[g>>1]=a;b=(y[e+2|0]+b|0)+(y[e+3|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}fb=h+16|0;f=f<<2;break v}a=f&255;if(!((a|0)!=16|y[h+1|0]!=2|y[h+2|0]!=1)){f=0;_:{switch(g|0){case 0:a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=x[k+2216>>2]>>>2;x[g+8>>2]=a;d=x[Gb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=a<<8|a>>>8;a=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=a<<8|a>>>8;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=g+16|0;f=d<<2;break v;case 1:a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=x[k+2216>>2]>>>2;x[g+8>>2]=a;d=x[Gb(g+12|0,g+8|0)>>2];f=d;while(1){if(f){a=y[e|0]|y[e+1|0]<<8;w[b>>1]=(a<<8|a>>>8)^32768;a=y[e+2|0]|y[e+3|0]<<8;w[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;e=e+4|0;f=f-1|0;continue}break};fb=g+16|0;f=d<<2;break v;case 2:break _;default:break v}}f=x[k+2216>>2];a=Zk(k+12|0);d=x[b>>2];g=x[b+20>>2];a=z[a>>1];h=fb-16|0;fb=h;x[h+12>>2]=f>>>2;x[h+8>>2]=d;b=a;f=x[Gb(h+12|0,h+8|0)>>2];d=f;while(1){if(d){a=(y[e+1|0]+a|0)+(y[e|0]<<8)|0;w[g>>1]=a;b=(y[e+3|0]+b|0)+(y[e+2|0]<<8)|0;w[g+2>>1]=b;g=g+4|0;e=e+4|0;d=d-1|0;continue}break}fb=h+16|0;f=f<<2;break v}if(!(g|y[h+1|0]!=1|(a|0)!=24)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=(b>>>0)/3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=O;a=a+2|0;e=e+3|0;f=f-1|0;continue}break}fb=g+16|0;f=D(b,3);break v}g=fb-16|0;fb=g;x[g+12>>2]=(b>>>0)/3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=O;a=a+2|0;e=e+3|0;f=f-1|0;continue}break}fb=g+16|0;f=D(b,3);break v}a=f&255;if(!(g|y[h+1|0]!=2|(a|0)!=24)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=(b>>>0)/6;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24,16),w[M>>1]=O;M=a,O=od(y[e+4|0]<<16|y[e+3|0]<<8|y[e+5|0]<<24,16),w[M+2>>1]=O;a=a+4|0;e=e+6|0;f=f-1|0;continue}break}fb=g+16|0;f=D(b,6);break v}g=fb-16|0;fb=g;x[g+12>>2]=(b>>>0)/6;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24,16),w[M>>1]=O;M=a,O=od(y[e+4|0]<<16|y[e+5|0]<<8|y[e+3|0]<<24,16),w[M+2>>1]=O;a=a+4|0;e=e+6|0;f=f-1|0;continue}break}fb=g+16|0;f=D(b,6);break v}if(!(g|y[h+1|0]!=1|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=O;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<2;break v}g=fb-16|0;fb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=a,O=od(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=O;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<2;break v}a=f&255;if(!(g|y[h+1|0]!=2|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=od(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),16),w[M>>1]=O;M=a,O=od(y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),16),w[M+2>>1]=O;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<3;break v}g=fb-16|0;fb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);M=a,O=od(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=a,O=od(d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24),16),w[M+2>>1]=O;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<3;break v}if(!(g|y[h+1|0]!=1|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=Rc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=O;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<3;break v}o=fb-16|0;fb=o;x[o+12>>2]=b>>>3;x[o+8>>2]=d;s=x[Gb(o+12|0,o+8|0)>>2];f=s;while(1){if(f){m=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=a,O=Rc(h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)),i|(b|g),48),w[M>>1]=O;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}fb=o+16|0;f=s<<3;break v}a=f&255;if(!(g|y[h+1|0]!=2|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>4;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){M=a,O=Rc(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24),y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24),48),w[M>>1]=O;M=a,O=Rc(y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24),y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24),48),w[M+2>>1]=O;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<4;break v}o=fb-16|0;fb=o;x[o+12>>2]=b>>>4;x[o+8>>2]=d;s=x[Gb(o+12|0,o+8|0)>>2];f=s;while(1){if(f){m=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);M=a,O=Rc(h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)),i|(b|g),48),w[M>>1]=O;m=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);M=a,O=Rc(h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)),i|(b|g),48),w[M+2>>1]=O;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}fb=o+16|0;f=s<<4;break v}if(!(y[h+1|0]!=1|(g|0)!=3|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){j=Wf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=oi(E(Ld(Fg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));$:{if(E(F(j))<E(2147483648)){d=~~j;break $}d=-2147483648}M=a,O=dd(d),w[M>>1]=O;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<2;break v}g=fb-16|0;fb=g;x[g+12>>2]=b>>>2;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=Wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=oi(E(Ld(Fg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));aa:{if(E(F(j))<E(2147483648)){d=~~j;break aa}d=-2147483648}M=a,O=dd(d),w[M>>1]=O;a=a+2|0;e=e+4|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<2;break v}a=f&255;if(!(y[h+1|0]!=2|(g|0)!=3|(a|0)!=32)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-16|0;fb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){j=Wf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=oi(E(Ld(Fg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ba:{if(E(F(j))<E(2147483648)){d=~~j;break ba}d=-2147483648}M=a,O=dd(d),w[M>>1]=O;j=Wf((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));j=oi(E(Ld(Fg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ca:{if(E(F(j))<E(2147483648)){d=~~j;break ca}d=-2147483648}M=a,O=dd(d),w[M+2>>1]=O;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<3;break v}g=fb-16|0;fb=g;x[g+12>>2]=b>>>3;x[g+8>>2]=d;b=x[Gb(g+12|0,g+8|0)>>2];f=b;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=Wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=oi(E(Ld(Fg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));da:{if(E(F(j))<E(2147483648)){d=~~j;break da}d=-2147483648}M=a,O=dd(d),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);j=Wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=oi(E(Ld(Fg(j)?j>=E(0)?E(1):E(-1):j,E(-1))*E(32768)));ea:{if(E(F(j))<E(2147483648)){d=~~j;break ea}d=-2147483648}M=a,O=dd(d),w[M+2>>1]=O;a=a+4|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=b<<3;break v}if(!(y[h+1|0]!=1|(g|0)!=3|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-32|0;fb=g;x[g+24>>2]=b>>>3;x[g+16>>2]=d;d=x[Gb(g+24|0,g+16|0)>>2];f=d;while(1){if(f){b=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,b|0);q=Eg(+n());M=g,V=wf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=De(C[Ug(g+24|0,g+16|0,g+8|0)>>3]*32768);fa:{if(F(q)<2147483648){b=~~q;break fa}b=-2147483648}M=a,O=dd(b),w[M>>1]=O;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}fb=g+32|0;f=d<<3;break v}m=fb-32|0;fb=m;x[m+24>>2]=b>>>3;x[m+16>>2]=d;i=x[Gb(m+24|0,m+16|0)>>2];f=i;while(1){if(f){s=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);h=s<<24|(s&65280)<<8;g=s&-16777216;d=g>>>24|0;b=s&16711680;o=b<<24|g<<8;g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,o|(((g&255)<<24|s>>>8)&-16777216|((g&16777215)<<8|s>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,h|(d|b>>>8));q=Eg(+n());M=m,V=wf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[m+16>>2]=0;x[m+20>>2]=-1074790400;x[m+8>>2]=0;x[m+12>>2]=1072693248;q=De(C[Ug(m+24|0,m+16|0,m+8|0)>>3]*32768);ga:{if(F(q)<2147483648){b=~~q;break ga}b=-2147483648}M=a,O=dd(b),w[M>>1]=O;a=a+2|0;e=e+8|0;f=f-1|0;continue}break}fb=m+32|0;f=i<<3;break v}a=f&255;if(!(y[h+1|0]!=2|(g|0)!=3|(a|0)!=64)){a=x[b+20>>2];d=x[b>>2];b=x[k+2216>>2];if(!y[h+2|0]){g=fb-32|0;fb=g;x[g+24>>2]=b>>>4;x[g+16>>2]=d;d=x[Gb(g+24|0,g+16|0)>>2];f=d;while(1){if(f){b=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,b|0);q=Eg(+n());M=g,V=wf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=De(C[Ug(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(F(q)<2147483648){b=~~q;break ha}b=-2147483648}M=a,O=dd(b),w[M>>1]=O;b=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24));l(1,b|0);q=Eg(+n());M=g,V=wf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[g+16>>2]=0;x[g+20>>2]=-1074790400;x[g+8>>2]=0;x[g+12>>2]=1072693248;q=De(C[Ug(g+24|0,g+16|0,g+8|0)>>3]*32768);ia:{if(F(q)<2147483648){b=~~q;break ia}b=-2147483648}M=a,O=dd(b),w[M+2>>1]=O;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}fb=g+32|0;f=d<<4;break v}o=fb-32|0;fb=o;x[o+24>>2]=b>>>4;x[o+16>>2]=d;s=x[Gb(o+24|0,o+16|0)>>2];f=s;while(1){if(f){m=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);i=m<<24|(m&65280)<<8;h=m&16711680;g=h>>>8|0;d=m&-16777216;b=d>>>24|0;h=d<<8|h<<24;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,h|(((d&255)<<24|m>>>8)&-16777216|((d&16777215)<<8|m>>>24)&16711680|(d>>>8&65280|d>>>24)));l(1,i|(b|g));q=Eg(+n());M=o,V=wf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[o+16>>2]=0;x[o+20>>2]=-1074790400;x[o+8>>2]=0;x[o+12>>2]=1072693248;q=De(C[Ug(o+24|0,o+16|0,o+8|0)>>3]*32768);ja:{if(F(q)<2147483648){b=~~q;break ja}b=-2147483648}M=a,O=dd(b),w[M>>1]=O;i=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);h=i<<24|(i&65280)<<8;g=i&-16777216;d=g>>>24|0;b=i&16711680;m=b<<24|g<<8;g=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);l(0,m|(((g&255)<<24|i>>>8)&-16777216|((g&16777215)<<8|i>>>24)&16711680|(g>>>8&65280|g>>>24)));l(1,h|(d|b>>>8));q=Eg(+n());M=o,V=wf(q)?q>=0?1:-1:q,C[M+24>>3]=V;x[o+16>>2]=0;x[o+20>>2]=-1074790400;x[o+8>>2]=0;x[o+12>>2]=1072693248;q=De(C[Ug(o+24|0,o+16|0,o+8|0)>>3]*32768);ka:{if(F(q)<2147483648){b=~~q;break ka}b=-2147483648}M=a,O=dd(b),w[M+2>>1]=O;a=a+4|0;e=e+16|0;f=f-1|0;continue}break}fb=o+32|0;f=s<<4;break v}la:{if((a|0)==24){if((g|0)!=15|(y[h+1|0]-1&255)>>>0>1){break la}x[k+48>>2]=-2147483648;a=x[k+2216>>2];ma:{if(!y[h+2|0]){o=k+48|0;f=0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],Xd(z[b+34>>1])),x[M+12>>2]=O;vc(t+12|0,(a>>>0)/3|0);a=e;g=x[t+12>>2];h=g;while(1){if(h){i=y[a+1|0]<<16|y[a|0]<<8|y[a+2|0]<<24;na:{oa:{pa:{if((i|0)>=0){d=i;break pa}d=-2147483648;if((i|0)==-2147483648){break oa}d=0-i|0}if(d>>>0<=f>>>0){break na}}f=d}h=h-1|0;a=a+3|0;continue}else{qa:{if(!f){break qa}m=f-1|0;s=f>>>1|0;h=x[b+20>>2];a=g;while(1){if(!a){break qa}d=y[e+1|0]<<16|y[e|0]<<8|y[e+2|0]<<24;i=d&-2147483648|d>>>1;d=s|d<<31;ra:{if((i|0)>0|(i|0)>=0){d=uua(d,i,f,0);i=hb;break ra}i=uua(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,f,0);d=0-i|0;i=0-(hb+((i|0)!=0)|0)|0}M=h,O=od(Fc(d,i),16),w[M>>1]=O;a=a-1|0;e=e+3|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=f}fb=t+16|0;f=D(g,3);break ma}o=k+48|0;f=0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],Xd(z[b+34>>1])),x[M+12>>2]=O;vc(t+12|0,(a>>>0)/3|0);a=e;g=x[t+12>>2];h=g;while(1){if(h){i=y[a+1|0]<<16|y[a+2|0]<<8|y[a|0]<<24;sa:{ta:{ua:{if((i|0)>=0){d=i;break ua}d=-2147483648;if((i|0)==-2147483648){break ta}d=0-i|0}if(d>>>0<=f>>>0){break sa}}f=d}h=h-1|0;a=a+3|0;continue}else{va:{if(!f){break va}m=f-1|0;s=f>>>1|0;h=x[b+20>>2];a=g;while(1){if(!a){break va}d=y[e+1|0]<<16|y[e+2|0]<<8|y[e|0]<<24;i=d&-2147483648|d>>>1;d=s|d<<31;wa:{if((i|0)>0|(i|0)>=0){d=uua(d,i,f,0);i=hb;break wa}i=uua(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,f,0);d=0-i|0;i=0-(hb+((i|0)!=0)|0)|0}M=h,O=od(Fc(d,i),16),w[M>>1]=O;a=a-1|0;e=e+3|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=f}fb=t+16|0;f=D(g,3)}if(!f){break v}a=x[k+48>>2];if((a|0)==-2147483648){break v}e=sua(z[b+32>>1],0,a,0);a=hb;e=e+1073741824|0;a=e>>>0<1073741824?a+1|0:a;M=b,O=Hd(Bc((a&2147483647)<<1|e>>>31,a>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}a=f&255;if((a|0)==32){if(!((g|0)!=15|(y[h+1|0]-1&255)>>>0>1)){x[k+48>>2]=-2147483648;d=x[k+2216>>2];xa:{if(!y[h+2|0]){o=k+48|0;a=0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],Xd(z[b+34>>1])),x[M+12>>2]=O;vc(t+12|0,d>>>2|0);f=e;h=e;g=x[t+12>>2];e=g;while(1){if(e){i=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);ya:{za:{Aa:{if((i|0)>=0){d=i;break Aa}d=-2147483648;if((i|0)==-2147483648){break za}d=0-i|0}if(d>>>0<=a>>>0){break ya}}a=d}e=e-1|0;h=h+4|0;continue}else{Ba:{if(!a){break Ba}m=a-1|0;s=a>>>1|0;h=x[b+20>>2];e=g;while(1){if(!e){break Ba}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);i=d&-2147483648|d>>>1;d=s|d<<31;Ca:{if((i|0)>0|(i|0)>=0){d=uua(d,i,a,0);i=hb;break Ca}i=uua(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(hb+((i|0)!=0)|0)|0}M=h,O=od(Fc(d,i),16),w[M>>1]=O;e=e-1|0;f=f+4|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=a}fb=t+16|0;f=g<<2;break xa}o=k+48|0;a=0;t=fb-16|0;fb=t;M=t,O=D(x[b>>2],Xd(z[b+34>>1])),x[M+12>>2]=O;vc(t+12|0,d>>>2|0);f=e;h=e;g=x[t+12>>2];e=g;while(1){if(e){d=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);i=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);Da:{Ea:{Fa:{if((i|0)>=0){d=i;break Fa}d=-2147483648;if((i|0)==-2147483648){break Ea}d=0-i|0}if(a>>>0>=d>>>0){break Da}}a=d}e=e-1|0;h=h+4|0;continue}else{Ga:{if(!a){break Ga}m=a-1|0;s=a>>>1|0;h=x[b+20>>2];e=g;while(1){if(!e){break Ga}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);d=d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24);i=d&-2147483648|d>>>1;d=s|d<<31;Ha:{if((i|0)>0|(i|0)>=0){d=uua(d,i,a,0);i=hb;break Ha}i=uua(m-d|0,0-((d>>>0>m>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(hb+((i|0)!=0)|0)|0}M=h,O=od(Fc(d,i),16),w[M>>1]=O;e=e-1|0;f=f+4|0;h=h+2|0;continue}}}break}if(o){x[o>>2]=a}fb=t+16|0;f=g<<2}if(!f){break v}a=x[k+48>>2];if((a|0)==-2147483648){break v}e=sua(z[b+32>>1],0,a,0);a=hb;e=e+1073741824|0;a=e>>>0<1073741824?a+1|0:a;M=b,O=Hd(Bc((a&2147483647)<<1|e>>>31,a>>>31|0),1,64),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}if((g|0)!=14|(y[h+1|0]-1&255)>>>0>1){break la}x[k+48>>2]=1065353216;a=x[k+2216>>2];Ia:{if(!y[h+2|0]){f=k+48|0;h=fb-16|0;fb=h;M=h,O=D(x[b>>2],Xd(z[b+34>>1])),x[M+12>>2]=O;vc(h+12|0,a>>>2|0);g=e;d=x[h+12>>2];a=d;while(1){if(a){j=Wf((l(2,y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24)),r()));j=E(F(Fg(j)?j>=E(0)?E(1):E(-1):j));u=j>u?j:u;a=a-1|0;g=g+4|0;continue}else{Ja:{a=u==E(0);if(a){break Ja}J=a?E(1):E(E(1)/u);g=x[b+20>>2];a=d;while(1){if(!a){break Ja}j=Wf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=oi(E(Ld(E(J*(Fg(j)?j>=E(0)?E(1):E(-1):j)),E(-1))*E(32768)));Ka:{if(E(F(j))<E(2147483648)){i=~~j;break Ka}i=-2147483648}M=g,O=dd(i),w[M>>1]=O;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(f){B[f>>2]=u}fb=h+16|0;f=d<<2}break}break Ia}f=k+48|0;i=fb-16|0;fb=i;M=i,O=D(x[b>>2],Xd(z[b+34>>1])),x[M+12>>2]=O;vc(i+12|0,a>>>2|0);g=e;d=x[i+12>>2];a=d;while(1){if(a){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);j=Wf((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));j=E(F(Fg(j)?j>=E(0)?E(1):E(-1):j));u=j>u?j:u;a=a-1|0;g=g+4|0;continue}else{La:{a=u==E(0);if(a){break La}J=a?E(1):E(E(1)/u);g=x[b+20>>2];a=d;while(1){if(!a){break La}h=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=Wf((l(2,h<<24|(h&65280)<<8|(h>>>8&65280|h>>>24)),r()));j=oi(E(Ld(E(J*(Fg(j)?j>=E(0)?E(1):E(-1):j)),E(-1))*E(32768)));Ma:{if(E(F(j))<E(2147483648)){h=~~j;break Ma}h=-2147483648}M=g,O=dd(h),w[M>>1]=O;a=a-1|0;e=e+4|0;g=g+2|0;continue}}if(f){B[f>>2]=u}fb=i+16|0;f=d<<2}break}}if(!f){break v}j=B[k+48>>2];if(j==E(1)){break v}j=oi(oB(E(j*E(z[b+32>>1])),E(1),E(64)));a=65535;Na:{if(j>=E(65535)){break Na}a=0;if(j<=E(0)){break Na}a=~~j>>>0;if(j<E(4294967296)&j>=E(0)){break Na}a=0}w[b+32>>1]=a;w[b+34>>1]=z[b+34>>1]|8192;break v}if((g|0)!=14|(y[h+1|0]-1&255)>>>0>1|(a|0)!=64){break la}x[k+48>>2]=0;x[k+52>>2]=1072693248;a=x[k+2216>>2];Oa:{if(!y[h+2|0]){h=k+48|0;i=fb-32|0;fb=i;M=i,O=D(x[b>>2],Xd(z[b+34>>1])),x[M+4>>2]=O;vc(i+4|0,a>>>3|0);d=e;f=x[i+4>>2];a=f;while(1){if(a){g=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));l(1,g|0);q=Eg(+n());q=F(wf(q)?q>=0?1:-1:q);H=q>H?q:H;a=a-1|0;d=d+8|0;continue}else{Pa:{a=H==0;if(a){break Pa}K=a?1:1/H;d=x[b+20>>2];a=f;while(1){if(!a){break Pa}g=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));l(1,g|0);q=Eg(+n());M=i,V=K*(wf(q)?q>=0?1:-1:q),C[M+24>>3]=V;x[i+16>>2]=0;x[i+20>>2]=-1074790400;x[i+8>>2]=0;x[i+12>>2]=1072693248;q=De(C[Ug(i+24|0,i+16|0,i+8|0)>>3]*32768);Qa:{if(F(q)<2147483648){g=~~q;break Qa}g=-2147483648}M=d,O=dd(g),w[M>>1]=O;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(h){C[h>>3]=H}fb=i+32|0;f=f<<3}break}break Oa}o=k+48|0;G=fb-32|0;fb=G;M=G,O=D(x[b>>2],Xd(z[b+34>>1])),x[M+4>>2]=O;vc(G+4|0,a>>>3|0);d=e;f=x[G+4>>2];a=f;while(1){if(a){m=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);s=m<<24|(m&65280)<<8;i=m&-16777216;h=i>>>24|0;g=m&16711680;t=g<<24|i<<8;i=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);l(0,t|(((i&255)<<24|m>>>8)&-16777216|((i&16777215)<<8|m>>>24)&16711680|(i>>>8&65280|i>>>24)));l(1,s|(h|g>>>8));q=Eg(+n());q=F(wf(q)?q>=0?1:-1:q);H=q>H?q:H;a=a-1|0;d=d+8|0;continue}else{Ra:{a=H==0;if(a){break Ra}K=a?1:1/H;d=x[b+20>>2];a=f;while(1){if(!a){break Ra}t=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);m=t<<24|(t&65280)<<8;s=t&16711680;i=s>>>8|0;h=t&-16777216;g=h>>>24|0;s=h<<8|s<<24;h=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);l(0,s|(((h&255)<<24|t>>>8)&-16777216|((h&16777215)<<8|t>>>24)&16711680|(h>>>8&65280|h>>>24)));l(1,m|(g|i));q=Eg(+n());M=G,V=K*(wf(q)?q>=0?1:-1:q),C[M+24>>3]=V;x[G+16>>2]=0;x[G+20>>2]=-1074790400;x[G+8>>2]=0;x[G+12>>2]=1072693248;q=De(C[Ug(G+24|0,G+16|0,G+8|0)>>3]*32768);Sa:{if(F(q)<2147483648){g=~~q;break Sa}g=-2147483648}M=d,O=dd(g),w[M>>1]=O;a=a-1|0;e=e+8|0;d=d+2|0;continue}}if(o){C[o>>3]=H}fb=G+32|0;f=f<<3}break}}if(!f){break v}q=C[k+48>>3];if(q==1){break v}M=b,O=sD(Jv(q*+z[b+32>>1],1,64)),w[M+32>>1]=O;w[b+34>>1]=z[b+34>>1]|8192;break v}Ta:{Ua:{Va:{Wa:{a=(f&255)!=32;Xa:{if(!(a|(y[h+1|0]!=1|(g|0)!=12))){u=E(30517578125e-15);f=x[k+2216>>2];if(!y[h+2|0]){break Xa}break Ta}if(!(y[h+1|0]!=2|(g|0)!=12|a)){u=E(30517578125e-15);f=x[k+2216>>2];if(!y[h+2|0]){break Va}break Ua}a=(f&255)!=32;if(a|(y[h+1|0]!=1|(g|0)!=13)){break Wa}u=E(1.1920928955078125e-7);f=x[k+2216>>2];if(y[h+2|0]){break Ta}}a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=f>>>2;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){j=Wf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=oi(E(Ld(E((Fg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Ya:{if(E(F(j))<E(2147483648)){g=~~j;break Ya}g=-2147483648}M=b,O=dd(g),w[M>>1]=O;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}fb=d+16|0;f=a<<2;break v}f=0;if(y[h+1|0]!=2|(g|0)!=13|a){break v}u=E(1.1920928955078125e-7);f=x[k+2216>>2];if(y[h+2|0]){break Ua}}a=x[b>>2];b=x[b+20>>2];d=fb-16|0;fb=d;x[d+12>>2]=f>>>3;x[d+8>>2]=a;a=x[Gb(d+12|0,d+8|0)>>2];f=a;while(1){if(f){j=Wf((l(2,y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24)),r()));j=oi(E(Ld(E((Fg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));Za:{if(E(F(j))<E(2147483648)){g=~~j;break Za}g=-2147483648}M=b,O=dd(g),w[M>>1]=O;j=Wf((l(2,y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24)),r()));j=oi(E(Ld(E((Fg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));_a:{if(E(F(j))<E(2147483648)){g=~~j;break _a}g=-2147483648}M=b,O=dd(g),w[M+2>>1]=O;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}fb=d+16|0;f=a<<3;break v}a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=f>>>3;x[g+8>>2]=a;a=x[Gb(g+12|0,g+8|0)>>2];f=a;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=Wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=oi(E(Ld(E((Fg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));$a:{if(E(F(j))<E(2147483648)){d=~~j;break $a}d=-2147483648}M=b,O=dd(d),w[M>>1]=O;d=y[e+4|0]|y[e+5|0]<<8|(y[e+6|0]<<16|y[e+7|0]<<24);j=Wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=oi(E(Ld(E((Fg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));ab:{if(E(F(j))<E(2147483648)){d=~~j;break ab}d=-2147483648}M=b,O=dd(d),w[M+2>>1]=O;b=b+4|0;e=e+8|0;f=f-1|0;continue}break}fb=g+16|0;f=a<<3;break v}a=x[b>>2];b=x[b+20>>2];g=fb-16|0;fb=g;x[g+12>>2]=f>>>2;x[g+8>>2]=a;a=x[Gb(g+12|0,g+8|0)>>2];f=a;while(1){if(f){d=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);j=Wf((l(2,d<<24|(d&65280)<<8|(d>>>8&65280|d>>>24)),r()));j=oi(E(Ld(E((Fg(j)?j>=E(0)?E(1):E(-1):j)*u),E(-1))*E(32768)));bb:{if(E(F(j))<E(2147483648)){d=~~j;break bb}d=-2147483648}M=b,O=dd(d),w[M>>1]=O;b=b+2|0;e=e+4|0;f=f-1|0;continue}break}fb=g+16|0;f=a<<2;break v}a=T(29088)|0}if((gb|0)!=($(29088)|0)){break d}Y(a|0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break w}}ub(t);break v}a=N()|0;break d}x[31785]=0;P(152,c|0,f+L|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break f}}Jc(I)}fb=k+2240|0;return f|0}a=N()|0;break a}a=N()|0}ub(t);break a}a=N()|0;break a}a=N()|0}Jc(I);Q(a|0);p()}function Tra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0;d=fb-608|0;fb=d;xc(b);f=fb-16|0;fb=f;h=d+416|0;ew(f+8|0,h);j=x[f+12>>2];g=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(j|0)){Yb(g,x[f+12>>2])}fb=f+16|0;b=(b|0)==(j|0);if(!b){pZ(h)}a:{b:{c:{if(!b){break c}if(!rZ(d+416|0)){break c}if(!Mb(x[g>>2],x[g+8>>2],Bc(qZ(d+416|0),hb))){break c}if(!c){e=1;break c}Bd(a,32);v[d+415|0]=0;j=Fb(d+400|0);d:{e:{f:{g:{h:{i:{if(!Ob(d+416|0,16487,4)){x[31785]=0;O(421,a|0,16777216);b=x[31785];x[31785]=0;if((b|0)==1){break b}b=x[g>>2];x[31785]=0;b=R(157,b|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break b}x[31785]=0;P(152,g|0,b-4|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break b}x[31785]=0;B=R(154,g|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break i}break b}j:{k:{l:{m:{n:{o:{if(((y[d+456|0]|y[d+457|0]<<8)-2185&65535)>>>0>1910){break o}b=x[g>>2];x[31785]=0;b=R(157,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break b}x[31785]=0;P(152,g|0,b-4|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break b}x[31785]=0;B=R(154,g|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break b}if(B>>>0<256){break o}b=x[g>>2];x[31785]=0;b=R(157,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break b}if(b>>>0<=B>>>0){break o}x[31785]=0;b=P(152,g|0,B|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break b}if(!b){break o}x[31785]=0;b=R(422,g|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break b}if(!b){break o}x[31785]=0;O(421,a|0,16777216);b=x[31785];x[31785]=0;if((b|0)==1){break b}b=y[d+456|0]|y[d+457|0]<<8;if(b>>>0>=4096){x[31785]=0;c=P(1,d+160|0,16702)|0;b=x[31785];x[31785]=0;if((b|0)==1){break h}a=x[a+1298472>>2];x[31785]=0;S(389,a|0,1,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(c);break d}b=N()|0;tb(c);break a}if(b>>>0<2194){break o}x[31785]=0;e=P(1,d+388|0,16226)|0;b=x[31785];x[31785]=0;if((b|0)==1){break n}b=x[a+1298472>>2];x[31785]=0;S(389,b|0,4,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break m}tb(e)}if(x[a+480180>>2]!=32){break i}b=y[d+456|0]|y[d+457|0]<<8;if((b&61440)!=20480){break j}b=b&4095;e=b<<16;if(Ob(d+476|0,13717,4)){break l}v[d+415|0]=1;break k}b=N()|0;break a}b=N()|0;tb(e);break a}if(b>>>0<297){break k}e=y[d+476|0]|y[d+477|0]<<8|e}x[a+1074308>>2]=e;break i}e=y[d+458|0]|y[d+459|0]<<8;if(!((e|0)!=2184&(b|0)!=2184)){v[d+415|0]=1;x[a+1074308>>2]=18284544;break i}if((b|0)!=768){if((b|0)!=532|(e|0)!=514|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))){break i}x[a+1074308>>2]=17367040;x[31785]=0;b=P(1,d+376|0,14859)|0;e=x[31785];x[31785]=0;if((e|0)!=1){yb(j,b);tb(b);v[d+415|0]=1;break i}b=N()|0;break a}if(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)|(e|0)!=768|((y[d+448|0]|y[d+449|0]<<8)!=256|y[d+468|0]!=128)){break i}if(y[d+469|0]){break i}x[a+1074308>>2]=18285088;v[d+415|0]=1}b=y[d+460|0]|y[d+461|0]<<8;e=b>>>2|0;x[a+480208>>2]=b<<3&32768|(e&8|(e&4|(x[a+480208>>2]&-32797|b<<1&16)));b=d+280|0;Kr(b,d+420|0);x[31785]=0;O(221,d+160|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break g}b=d+160|0;yb(a+1298308|0,b);tb(b);if(!(!(y[d+462|0]&4)|x[a+1074308>>2]-18285314>>>0>4276681982)){x[a+480216>>2]=y[d+446|0];x[a+480220>>2]=y[d+447|0]}b=y[d+464|0];x[a+480200>>2]=b>>>0>128?256:b<<1;b=y[d+466|0];if(b){x[a+480196>>2]=b}v[d+160|0]=31;v[d+280|0]=y[d+467|0];b=d+160|0;e=d+280|0;T=a,X=D(y[af(b,e)|0],1e4),x[T+480204>>2]=X;v[d+160|0]=y[d+465|0];v[d+280|0]=128;T=a,X=y[Ub(b,e)|0],x[T+480228>>2]=X;e=0;while(1){if((e|0)==64){p:{x[31785]=0;P(152,g|0,192)|0;b=x[31785];x[31785]=0;if((b|0)==1){break b}if(x[a+480180>>2]==16777216&((y[d+456|0]|y[d+457|0]<<8)-2187&65535)>>>0<=2){break p}b=y[a+484376|0];e=x[a+484360>>2];x[31785]=0;aa(351,Wb(e,b)|0,g|0,y[d+448|0]|y[d+449|0]<<8,255,254);b=x[31785];x[31785]=0;if((b|0)==1){break b}break e}}else{h=(d+416|0)+e|0;i=h- -64|0;q:{if(y[i|0]==255){break q}f=(e<<5)+a|0;b=f+480280|0;Ye(b);T=f+480286|0,X=Hd(y[h+128|0],0,64),w[T>>1]=X;h=v[i|0];if((h|0)<0){x[b>>2]=x[b>>2]|1024}h=h&127;if(h>>>0<=64){w[f+480284>>1]=h<<2;break q}if((h|0)!=100){break q}x[b>>2]=x[b>>2]|256}e=e+1|0;continue}break}e=0;x[31785]=0;b=R(192,g|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break f}if(b){break d}x[31785]=0;b=R(154,g|0)|0;f=x[31785];x[31785]=0;r:{if((f|0)==1){break r}if(b>>>0>4e3){break d}f=y[a+484376|0];h=x[a+484360>>2];x[31785]=0;b=U(423,Wb(h,f)|0,g|0,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break r}if(!b){break d}break e}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}u=Nb(d+364|0);o=Nb(d+352|0);e=0;n=Nb(d+340|0);x[31785]=0;b=U(424,g|0,u|0,y[d+450|0]|y[d+451|0]<<8)|0;f=x[31785];x[31785]=0;s:{t:{u:{if((f|0)==1){break u}if(!b){break s}x[31785]=0;b=U(424,g|0,o|0,y[d+452|0]|y[d+453|0]<<8)|0;f=x[31785];x[31785]=0;if((f|0)==1){break u}if(!b){break s}x[31785]=0;b=U(424,g|0,n|0,y[d+454|0]|y[d+455|0]<<8)|0;f=x[31785];x[31785]=0;if((f|0)==1){break u}if(!b){break s}x[d+336>>2]=-1;T=d,X=vb(x[u>>2]),x[T+160>>2]=X;f=vb(x[u+4>>2]);b=x[d+336>>2];while(1){e=x[d+160>>2];if(Ib(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+336>>2]=e;b=e}Pe(d+160|0);continue}else{T=d,X=vb(x[o>>2]),x[T+160>>2]=X;f=vb(x[o+4>>2]);b=x[d+336>>2];while(1){e=x[d+160>>2];if(Ib(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+336>>2]=e;b=e}Pe(d+160|0);continue}else{T=d,X=vb(x[n>>2]),x[T+160>>2]=X;f=vb(x[n+4>>2]);b=x[d+336>>2];v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{while(1){e=x[d+160>>2];if(Ib(e,f)){e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);if(!(!e|b>>>0<=e>>>0)){x[d+336>>2]=e;b=e}Pe(d+160|0);continue}else{if(v[d+462|0]&1){x[d+160>>2]=y[d+472|0]|y[d+473|0]<<8|(y[d+474|0]<<16|y[d+475|0]<<24);b=x[Gb(d+336|0,d+160|0)>>2];x[d+336>>2]=b}e=0;if((y[d+458|0]|y[d+459|0]<<8)!=532){break D}f=y[d+456|0]|y[d+457|0]<<8;if(y[d+447|0]|(f?(f|0)!=532:0)|(y[d+446|0]|y[d+469|0])){break D}if(y[d+460|0]&192|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))){break D}if(y[d+450|0]|y[d+451|0]<<8){break E}f=y[d+452|0]|y[d+453|0]<<8;if(!f){break E}if((x[g+8>>2]+(oc(x[o>>2],x[o+4>>2])<<2)|0)+2>>>0>b>>>0){break E}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){x[31785]=0;b=R(154,g|0)|0;f=x[31785];x[31785]=0;F:{if((f|0)!=1){if(!b){break F}Eh(g,((e&65535)<<2)+4|0);break E}b=N()|0;break t}e=e+1|0;f=y[d+452|0]|y[d+453|0]<<8;continue}break}x[31785]=0;b=P(1,d+324|0,15133)|0;e=x[31785];x[31785]=0;if((e|0)==1){break C}yb(j,b);tb(b)}e=1;if(y[d+456|0]|y[d+457|0]<<8){break D}x[31785]=0;b=P(1,d+312|0,15642)|0;f=x[31785];x[31785]=0;if((f|0)==1){break B}yb(j,b);tb(b)}b=y[d+462|0]|y[d+463|0]<<8;G:{if(b&2){x[31785]=0;f=R(192,g|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break w}b=x[g+8>>2];h=x[g>>2];x[31785]=0;i=b;b=f<<3;h=U(153,h|0,i|0,b|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break w}if(!(!h|A[d+336>>2]<b+x[g+8>>2]>>>0)){x[31785]=0;b=a+1298412|0;O(425,b|0,f|0);h=x[31785];x[31785]=0;if((h|0)==1){break w}T=d,X=vb(x[b>>2]),x[T+280>>2]=X;h=vb(x[a+1298416>>2]);H:{I:{while(1){b=x[d+280>>2];if(!Ib(b,h)){if(!(!f&e)){break G}if(!(y[d+462|0]&4)){break H}x[31785]=0;b=P(1,d+300|0,15675)|0;e=x[31785];x[31785]=0;if((e|0)==1){break I}yb(j,b);tb(b);break G}x[31785]=0;O(426,g|0,d+160|0);i=x[31785];x[31785]=0;if((i|0)!=1){x[b>>2]=0;x[b+4>>2]=0;x[b+24>>2]=0;x[b+28>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b+16>>2]=0;i=y[d+160|0]|y[d+161|0]<<8;if(i|(y[d+162|0]|y[d+163|0]<<8)){x[b>>2]=((i&65024)>>>9|0)+1980;T=b,X=Xb((y[d+160|0]|y[d+161|0]<<8)>>>5&15,1,12),x[T+4>>2]=X;T=b,X=Xb((y[d+160|0]|y[d+161|0]<<8)&31,1,31),x[T+8>>2]=X;T=b,X=Xb((y[d+162|0]|y[d+163|0]<<8)>>>11|0,0,23),x[T+12>>2]=X;T=b,X=Xb((y[d+162|0]|y[d+163|0]<<8)>>>5&63,0,59),x[T+16>>2]=X;i=Xb((y[d+162|0]|y[d+163|0]<<8)<<1&62,0,59);x[b+24>>2]=i;x[b+28>>2]=i>>31}x[b+32>>2]=y[d+164|0]|y[d+165|0]<<8|(y[d+166|0]<<16|y[d+167|0]<<24);x[d+280>>2]=x[d+280>>2]+40;continue}break}b=N()|0;break t}b=N()|0;break t}x[31785]=0;b=P(1,d+300|0,15160)|0;e=x[31785];x[31785]=0;if((e|0)!=1){yb(j,b);tb(b);break G}b=N()|0;break t}Eh(g,2);break G}if(!(b>>>0<2&e)){break G}x[31785]=0;b=R(192,g|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break v}if(!b){x[31785]=0;b=P(1,d+300|0,15133)|0;e=x[31785];x[31785]=0;if((e|0)!=1){yb(j,b);tb(b);break G}b=N()|0;break t}Eh(g,2)}J:{if(!(y[d+460|0]&128|y[d+462|0]&8)){break J}x[31785]=0;b=a+901404|0;e=P(427,g|0,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break A}if(!e){break J}kD(b)}if((y[d+456|0]|y[d+457|0]<<8)>>>0<=531){Zq(a+901404|0)}x[31785]=0;C=R(171,d+280|0)|0;b=x[31785];x[31785]=0;K:{L:{M:{if((b|0)!=1){x[31785]=0;e=P(416,g|0,13954)|0;b=x[31785];x[31785]=0;if((b|0)==1){break M}if(e){x[31785]=0;b=R(154,g|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break L}x[31785]=0;S(188,d+260|0,g|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break L}b=d+260|0;f=ic(d+160|0,b);hd(C,f);ub(f);ub(b)}w[a+480188>>1]=1;x[31785]=0;b=P(416,g|0,13959)|0;f=x[31785];x[31785]=0;if((f|0)==1){break M}if(!b){break y}x[31785]=0;b=R(154,g|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){x[31785]=0;S(188,d+260|0,g|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break K}}b=N()|0;break x}b=N()|0;break t}b=N()|0;break x}b=N()|0;break x}b=d+260|0;f=ic(d+160|0,b);ub(b);b=x[f>>2];x[31785]=0;b=R(157,b|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break z}w[d+260>>1]=(b>>>0)/20;b=z[Mc(25252,d+260|0)>>1];w[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){ub(f);e=1;break y}x[31785]=0;S(428,f|0,((e<<5)+a|0)+480289|0,20);h=x[31785];x[31785]=0;if((h|0)!=1){e=e+1|0;continue}break}break z}b=N()|0;break t}b=N()|0;break t}b=N()|0;break t}b=N()|0;ub(f);break x}N:{O:{P:{Q:{R:{S:{T:{U:{V:{b=x[d+336>>2];f=x[g+8>>2];W:{if(b>>>0>=f>>>0){b=b-f|0;break W}x[31785]=0;b=R(205,g|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break V}}x[31785]=0;S(188,d+160|0,g|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break V}b=d+160|0;E=ic(d+260|0,b);ub(b);x[31785]=0;S(429,d+258|0,a|0,E|0);b=x[31785];x[31785]=0;if((b|0)==1){break U}F=Ic(d+258|0);G=y[d+258|0]!=0|e;if((y[d+456|0]|y[d+457|0]<<8)!=535|(y[d+458|0]|y[d+459|0]<<8)!=512|(y[F|0]|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)))){break Q}X:{if(G){break X}e=Wb(x[a+484360>>2],y[a+484376|0]);b=x[e+4>>2];if(!mc(x[e>>2],b)){if(z[t$(b)>>1]==65535){break X}}if(!jD(d+480|0,255,64)){break S}}x[a+1074308>>2]=18219008;x[31785]=0;b=P(1,d+244|0,14989)|0;e=x[31785];x[31785]=0;if((e|0)==1){break T}break R}b=N()|0;break x}b=N()|0;break N}b=N()|0;break N}x[a+1074308>>2]=18284544;x[31785]=0;b=P(1,d+244|0,17076)|0;e=x[31785];x[31785]=0;if((e|0)==1){break P}}yb(j,b);tb(b);v[d+415|0]=1}Y:{if(!(v[d+462|0]&1)|!(y[d+470|0]|y[d+471|0]<<8)){break Y}x[31785]=0;b=P(152,g|0,y[d+472|0]|y[d+473|0]<<8|(y[d+474|0]<<16|y[d+475|0]<<24))|0;e=x[31785];x[31785]=0;if((e|0)==1){break O}if(!b){break Y}x[31785]=0;V(339,a+1298332|0,g|0,y[d+470|0]|y[d+471|0]<<8,4);b=x[31785];x[31785]=0;if((b|0)==1){break O}}f=a+480192|0;w[f>>1]=0;b=0;if(y[d+460|0]&4){w[d+160>>1]=y[d+450|0]|y[d+451|0]<<8;w[d+100>>1]=255;b=z[Mc(d+160|0,d+100|0)>>1];w[f>>1]=b}e=0;Z:{while(1){if((b&65535)>>>0<=e>>>0){x[d+240>>2]=0;e=y[d+452|0]|y[d+453|0]<<8;if(e){b=wb(x[o>>2],e-1|0);x[d+240>>2]=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))+80}w[d+160>>1]=e;w[d+100>>1]=3999;m=a+480190|0;b=z[Mc(d+160|0,d+100|0)>>1];w[m>>1]=b;l=c&2;q=d+180|0;r=a+1298472|0;e=0;while(1){_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{if((b&65535)>>>0>e>>>0){b=wb(x[o>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(!b){break $}x[31785]=0;b=P(152,g|0,b|0)|0;f=x[31785];x[31785]=0;ha:{ia:{ja:{ka:{la:{if((f|0)==1){break la}if(!b){break $}x[31785]=0;b=P(430,g|0,d+160|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break la}if(!b){break $}x[31785]=0;b=e+1|0;f=D(b,104)+a|0;i=f+484380|0;h=P(431,d+160|0,i|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break ka}k=d+148|0;Kr(k,q);x[31785]=0;O(221,d+100|0,k|0);k=x[31785];x[31785]=0;if((k|0)==1){break ja}k=d+100|0;zc(((b<<5)+a|0)+946304|0,k);tb(k);x[31785]=0;h=P(152,g|0,h|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break ka}if(!h){break $}f=z[f+484414>>1];if(!(f&512)){break ia}x[31785]=0;b=P(432,g|0,d+100|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break ga}if(!b){break ha}x[d+16>>2]=y[d+108|0]|y[d+109|0]<<8|(y[d+110|0]<<16|y[d+111|0]<<24);b=y[d+104|0]|y[d+105|0]<<8|(y[d+106|0]<<16|y[d+107|0]<<24);x[d+8>>2]=y[d+100|0]|y[d+101|0]<<8|(y[d+102|0]<<16|y[d+103|0]<<24);x[d+12>>2]=b;Vk(i,1,d+8|0);break ha}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}if(!(f&16384)){s=y[d+456|0]|y[d+457|0]<<8;h=y[d+178|0];k=h&2;b=y[d+206|0];f=ad(d+100|0,k?16:8,1,0,(b^-1)&1);if(!(!(h&4)|s>>>0<532)){mp(f,3)}ma:{na:{if(h&8){h=b&4?5:4;break na}if(!k){h=10;if((b|0)==255){break na}}if(b&2){v[f+2|0]=1}if(b&4){ug(f,2)}if(!(b&8)){break ma}h=9;if(!k){break ma}}ug(f,h)}if(l){b=0;x[31785]=0;U(218,d+100|0,i|0,g|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){break ca}break _}b=1;f=y[d+103|0];if(f>>>0>17){break ba}h=1<<f;if(!(h&63503)){if(!(h&198144)){break ba}break da}if(y[d+100|0]){break da}break ca}x[31785]=0;O(433,g|0,d+88|0);f=x[31785];x[31785]=0;if((f|0)==1){break ea}h=x[d+88>>2];if(!(!l|!h)){f=Fb(d+100|0);x[31785]=0;S(273,g|0,f|0,h|0);h=x[31785];x[31785]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((h|0)!=1){x[31785]=0;O(387,d+136|0,16624);h=x[31785];x[31785]=0;if((h|0)==1){break ua}x[d+76>>2]=b;x[31785]=0;S(261,d+124|0,0,f|0);b=x[31785];x[31785]=0;if((b|0)==1){break ta}x[31785]=0;V(434,d+148|0,d+136|0,d+76|0,d+124|0);b=x[31785];x[31785]=0;if((b|0)==1){break sa}b=x[r>>2];x[31785]=0;S(389,b|0,2,d+148|0);b=x[31785];x[31785]=0;if((b|0)==1){break ra}tb(d+148|0);tb(d+124|0);Eb(d+136|0);tb(f);break ha}b=N()|0;break oa}b=N()|0;break oa}b=N()|0;break pa}b=N()|0;break qa}b=N()|0;tb(d+148|0)}tb(d+124|0)}Eb(d+136|0)}tb(f);break N}x[31785]=0;P(186,g|0,h|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break ea}}b=0;break aa}w[d+160>>1]=1;w[d+100>>1]=b;T=a+480190|0,X=z[se(d+160|0,d+100|0)>>1],w[T>>1]=X;if(!((y[d+456|0]|y[d+457|0]<<8)==516&t)|(y[d+458|0]|y[d+459|0]<<8)!=512|(y[d+462|0]|y[d+463|0]<<8|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)))){break fa}if(((y[d+460|0]|y[d+461|0]<<8)&65527)!=21|y[d+464|0]!=128|(y[d+465|0]!=48|y[d+468|0]!=128)){break fa}if(y[d+469|0]|(y[d+470|0]|y[d+471|0]<<8)){break fa}b=d+544|0;f=d+480|0;e=1;while(1)if((b|0)==(f|0)){f=d+608|0;while(1)if((b|0)==(f|0)){b=20;while(1){if((b|0)==26){va:{if(!(e&1)){break fa}x[31785]=0;b=P(1,d+148|0,9889)|0;e=x[31785];x[31785]=0;if((e|0)==1){break va}yb(j,b);tb(b);break fa}}else{e=!y[(b+d|0)+420|0]&e;b=b+1|0;continue}break}b=N()|0;break N}else{e=y[b|0]==64&e;b=b+1|0;continue}}else{e=(y[f|0]&127)==32&e;f=f+1|0;continue}}b=N()|0;break N}x[a+480260>>2]=0;x[a+480264>>2]=2147483647;b=oc(x[n>>2],x[n+4>>2]);w[d+160>>1]=b;q=z[Mc(d+160|0,x[a+8>>2]+10|0)>>1];w[d+122>>1]=q;wa:{xa:{ya:{za:{if((b|0)!=(q|0)){x[31785]=0;W(435,d+100|0);b=x[31785];x[31785]=0;if((b|0)==1){break wa}b=x[n+4>>2];e=x[n>>2];x[31785]=0;T=d,X=oc(e,b),x[T+136>>2]=X;V(436,d+160|0,d+100|0,d+136|0,d+122|0);b=x[31785];x[31785]=0;if((b|0)==1){break ya}b=x[a+1298472>>2];x[31785]=0;S(389,b|0,2,d+160|0);b=x[31785];x[31785]=0;if((b|0)==1){break za}tb(d+160|0);Eb(d+100|0)}if(!(c&1)){w[d+122>>1]=0;q=0}l=a+480188|0;h=0;Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{while(1){Ra:{if((h|0)==(q|0)){b=x[d+240>>2];if(!b){break Oa}x[31785]=0;P(152,g|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Qa}if(!s){break Oa}while(1){Sa:{b=x[g+8>>2];c=x[g>>2];x[31785]=0;b=U(153,c|0,b|0,4)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Sa}if(!b){break Oa}x[31785]=0;b=P(416,g|0,13928)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Sa}Ta:{if(!b){x[31785]=0;b=P(416,g|0,13933)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Sa}if(!b){break Ta}}x[31785]=0;b=R(154,g|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Pa}Eh(g,8);if(b&-2139062144){break Ta}if(b&1616928864){break Oa}}x[31785]=0;b=R(192,g|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Sa}x[31785]=0;P(186,g|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}b=N()|0;break N}Ua:{b=wb(x[n>>2],h);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);Va:{if(!b){break Va}x[31785]=0;b=P(152,g|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Na}if(!b){break Va}x[31785]=0;b=R(192,g|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Aa}x[31785]=0;m=R(192,g|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Ba}if((m-1025&65535)>>>0<64512){break Va}x[31785]=0;c=P(186,g|0,4)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Ba}if(!c){break Va}x[31785]=0;S(188,d+100|0,g|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break Ca}b=d+100|0;f=ic(d+160|0,b);ub(b);b=z[l>>1];k=0;x[31785]=0;i=P(437,d+136|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Ea}Wa:{while(1){if(k>>>0>=m>>>0){break Wa}b=x[f>>2];x[31785]=0;b=U(153,b|0,x[d+168>>2],1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Ua}if(!b){break Wa}x[31785]=0;b=R(200,f|0)|0;c=x[31785];x[31785]=0;Xa:{if((c|0)!=1){c=b<<24>>24;if(c){break Xa}k=k+1|0;continue}break Ra}Ya:{b=c&127;t=b?b-1|0:0;b=t&65535;if(Sc(x[i>>2],x[d+140>>2])>>>0>b>>>0){break Ya}x[31785]=0;v[d+100|0]=0;S(438,i|0,b+1|0,d+100|0);e=x[31785];x[31785]=0;if((e|0)!=1){break Ya}break Ra}Za:{if((c|0)<0){x[31785]=0;c=R(200,f|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Za}T=xb(x[i>>2],b),X=c,v[T|0]=X}e=xb(x[i>>2],b);c=y[e|0];if(!(!(c&15)|b>>>0<z[l>>1])){w[l>>1]=t+1;c=y[e|0]}if(c&1){x[31785]=0;P(186,f|0,1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Za}e=xb(x[i>>2],b)}if(y[e|0]&2){x[31785]=0;P(186,f|0,1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Za}e=xb(x[i>>2],b)}if(y[e|0]&4){x[31785]=0;P(186,f|0,1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Za}e=xb(x[i>>2],b)}if(!(y[e|0]&8)){continue}x[31785]=0;P(186,f|0,2)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}break Ra}x[d+100>>2]=x[g+8>>2];T=d,X=x[_c(d+240|0,d+100|0)>>2],x[T+240>>2]=X;dc(i);ub(f)}h=h+1|0;continue}}break}b=N()|0;dc(i);break Da}b=N()|0;break N}b=N()|0;break N}x[31785]=0;H=P(439,a|0,g|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){b=y[d+415|0]|H;v[d+415|0]=b;if(!(y[F|0]|!(b&255))){Ev(a+1074312|0);v[a+1074368|0]=0}x[31785]=0;I=ba(440,a|0,g|0,0,d+415|0)|0;b=x[31785];x[31785]=0;_a:{if((b|0)==1){break _a}x[31785]=0;r=a+484344|0;O(226,r|0,q|0);b=x[31785];x[31785]=0;if((b|0)==1){break _a}s=a+480188|0;M=a+480183|0;h=0;while(1){$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{if((h|0)!=(q|0)){b=wb(x[n>>2],h);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);if(b){x[31785]=0;b=P(152,g|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break nb}if(b){break mb}}x[31785]=0;b=U(199,r|0,h&65535,64)|0;c=x[31785];x[31785]=0;if((c|0)==1){break nb}if(b){break ob}w[d+64>>1]=h;x[31785]=0;W(441,d+100|0);b=x[31785];x[31785]=0;if((b|0)==1){break sb}x[31785]=0;S(442,d+160|0,d+100|0,d- -64|0);b=x[31785];x[31785]=0;if((b|0)==1){break rb}b=x[a+1298472>>2];x[31785]=0;S(389,b|0,2,d+160|0);b=x[31785];x[31785]=0;if((b|0)==1){break qb}tb(d+160|0);Eb(d+100|0)}if(!x[a+1074308>>2]){e=y[d+456|0]|y[d+457|0]<<8;if((e|0)!=2184){break kb}x[a+1074308>>2]=18284544}if(!yd(x[j+4>>2],y[j+11|0])){break lb}x[31785]=0;c=P(1,d+100|0,18434)|0;b=x[31785];x[31785]=0;if((b|0)==1){break bb}b=x[a+1074308>>2];x[31785]=0;O(137,d+76|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break db}x[31785]=0;S(2,d+160|0,c|0,d+76|0);b=x[31785];x[31785]=0;if((b|0)==1){break eb}e=d+160|0;b=yb(j,e);tb(e);tb(d+76|0);tb(c);e=x[a+1074308>>2];if(!Ob(d+476|0,13717,4)){break jb}if((e|0)!=18284544){break ib}e=18284544;if(!(G|I|H)){break hb}break gb}b=N()|0;break N}b=N()|0;break pb}b=N()|0;tb(d+160|0)}Eb(d+100|0);break N}b=x[r>>2];x[31785]=0;O(443,Vb(b,h)|0,C|0);b=x[31785];x[31785]=0;if((b|0)!=1){break $a}}b=N()|0;break N}x[31785]=0;b=R(192,g|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Fa}x[31785]=0;J=R(192,g|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Ga}x[31785]=0;c=P(186,g|0,4)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Ga}if(!c){break $a}x[31785]=0;c=U(199,r|0,h&65535,J|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Ga}if(!c){break $a}x[31785]=0;S(188,d+100|0,g|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break Ha}b=d+100|0;k=ic(d+160|0,b);ub(b);b=x[r>>2];x[31785]=0;O(443,Vb(b,h)|0,C|0);b=x[31785];x[31785]=0;if((b|0)==1){break Ja}b=z[s>>1];x[31785]=0;m=P(437,d+124|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Ka}b=z[s>>1];w[d+104>>1]=0;x[31785]=0;x[d+100>>2]=0;l=U(444,d+88|0,b|0,d+100|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Ma}T=d,X=vb(x[Vb(x[r>>2],h)>>2]),x[T+76>>2]=X;t=0;while(1){tb:{ub:{vb:{wb:{if(t>>>0>=J>>>0){break wb}b=x[k>>2];x[31785]=0;b=U(153,b|0,x[d+168>>2],1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ab}if(!b){break wb}x[31785]=0;b=R(200,k|0)|0;c=x[31785];x[31785]=0;xb:{if((c|0)!=1){b=b<<24>>24;if(b){break xb}d_(d+76|0,z[s>>1]);t=t+1|0;continue}break ab}yb:{c=b&127;i=c?c-1&65535:0;if(Sc(x[m>>2],x[d+128>>2])>>>0>i>>>0){break yb}x[31785]=0;v[d+100|0]=0;c=i+1|0;S(438,m|0,c|0,d+100|0);e=x[31785];x[31785]=0;if((e|0)==1){break ab}w[d+104>>1]=0;x[31785]=0;x[d+100>>2]=0;S(445,l|0,c|0,d+100|0);c=x[31785];x[31785]=0;if((c|0)!=1){break yb}break ab}if((b|0)<0){x[31785]=0;b=R(200,k|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ab}T=xb(x[m>>2],i),X=b,v[T|0]=X}w[d+104>>1]=0;x[d+100>>2]=0;b=d+100|0;if(i>>>0<z[s>>1]){b=Vc(x[d+76>>2],i)}f=xb(x[m>>2],i);e=y[f|0];if(e&16){T=b,X=y[Vc(x[l>>2],i)|0],v[T|0]=X;e=y[f|0]}if(e&32){T=b,X=y[Vc(x[l>>2],i)+1|0],v[T+1|0]=X;e=y[f|0]}if(e&64){c=Vc(x[l>>2],i);v[b+2|0]=y[c+2|0];v[b+4|0]=y[c+4|0];e=y[f|0]}if(e<<24>>24<0){c=Vc(x[l>>2],i);v[b+3|0]=y[c+3|0];v[b+5|0]=y[c+5|0];e=y[f|0]}if(e&1){x[31785]=0;c=R(200,k|0)|0;e=x[31785];x[31785]=0;zb:{Ab:{if((e|0)!=1){c=c<<24>>24;c=(((c^-1)&128)>>>7|0)+c|0;if(!(v[M|0]&1)){break Ab}e=c;break zb}break ab}e=253;if((c-121&255)>>>0<132){break zb}e=(c&255)!=253?c:0}v[b|0]=e;T=Vc(x[l>>2],i),X=e,v[T|0]=X;f=xb(x[m>>2],i)}if(y[f|0]&2){x[31785]=0;c=R(200,k|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break ab}v[b+1|0]=c;T=Vc(x[l>>2],i),X=c,v[T+1|0]=X;f=xb(x[m>>2],i)}if(!(y[f|0]&4)){break tb}x[31785]=0;f=R(200,k|0)|0;c=x[31785];x[31785]=0;Bb:{Cb:{if((c|0)!=1){if(f>>>0>64){break Cb}v[b+4|0]=f;e=1;break Bb}break ab}if(f<<24>>24<=-64){e=2;v[b+2|0]=2;f=f^-128;v[b+4|0]=f;break ub}if(f>>>0<=74){e=5;v[b+2|0]=5;f=f-65|0;v[b+4|0]=f;break ub}if(f>>>0<=84){e=6;v[b+2|0]=6;f=f-75|0;v[b+4|0]=f;break ub}if(f>>>0<=94){e=3;v[b+2|0]=3;f=f-85|0;v[b+4|0]=f;break ub}if(f>>>0<=104){e=4;v[b+2|0]=4;f=f-95|0;v[b+4|0]=f;break ub}if(f>>>0<=114){e=13;v[b+2|0]=13;f=f-105|0;v[b+4|0]=f;break ub}if(f>>>0<=124){e=12;v[b+2|0]=12;f=f-115|0;v[b+4|0]=f;break ub}c=f+63|0;if((c&255)>>>0<=9){v[b+4|0]=c;e=11;v[b+2|0]=11;f=c;break ub}c=f+53|0;K=c&255;if(K>>>0<=9){v[b+4|0]=c;e=8;v[b+2|0]=8;if(!K){f=0;break ub}if(x[a+1074308>>2]-1>>>0>18285139){break vb}e=7;v[b+2|0]=7;break vb}f=f+33|0;if((f&255)>>>0>=10){f=y[b+4|0];e=y[b+2|0];break ub}v[b+4|0]=f;e=15}v[b+2|0]=e;break ub}Nk(l);dc(m);ub(k);break $a}f=c}c=Vc(x[l>>2],i);v[c+4|0]=f;v[c+2|0]=e;f=xb(x[m>>2],i)}if(!(y[f|0]&8)){continue}x[31785]=0;O(201,d+52|0,k|0);c=x[31785];x[31785]=0;if((c|0)!=1){hD(b,y[d+52|0],y[Ic(d+52|0)|0],1);c=Vc(x[l>>2],i);v[c+3|0]=y[b+3|0];v[c+5|0]=y[b+5|0];continue}break}break ab}e=y[d+456|0]|y[d+457|0]<<8}Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{b=e&65535;switch(b>>>12|0){case 13:break Eb;case 7:break Fb;case 6:break Gb;case 4:break Hb;case 1:break Jb;case 0:break Kb;default:break fb}}if(y[F|0]){x[31785]=0;b=P(1,d+160|0,8360)|0;c=x[31785];x[31785]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{if((e&65535)==532){b=y[d+458|0]|y[d+459|0]<<8;if((b|0)!=532){if((b|0)!=512){e=532;break Xb}Zb:{if(y[d+462|0]|y[d+463|0]<<8|(y[d+460|0]|y[d+461|0]<<8)!=9|(y[d+447|0]|y[d+446|0])){break Zb}if(y[d+450|0]|y[d+451|0]<<8|((y[d+454|0]|y[d+455|0]<<8)+1|0)!=(y[d+448|0]|y[d+449|0]<<8)|(y[d+464|0]!=128|y[d+465|0]!=100)){break Zb}if(y[d+466|0]!=1|y[d+468|0]!=128|(y[d+469|0]|(y[d+470|0]|y[d+471|0]<<8))){break Zb}if(y[d+472|0]|y[d+473|0]<<8|(y[d+474|0]<<16|y[d+475|0]<<24)|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))){break Zb}x[31785]=0;b=P(1,d+160|0,9870)|0;c=x[31785];x[31785]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}e=532;if(y[d+447|0]|y[d+446|0]|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24))){break Wb}x[a+1074308>>2]=16777381;x[31785]=0;b=P(1,d+160|0,15070)|0;c=x[31785];x[31785]=0;if((c|0)!=1){yb(j,b);tb(b);v[d+415|0]=1;break fb}b=N()|0;break N}if(!Ob(d+476|0,14202,4)){x[31785]=0;b=P(1,d+160|0,8398)|0;c=x[31785];x[31785]=0;if((c|0)!=1){yb(j,b);tb(b);b=38;break Ib}b=N()|0;break N}e=532;if(y[d+469|0]|(y[d+462|0]|y[d+463|0]<<8)>>>0>1|(y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24)|((y[d+460|0]|y[d+461|0]<<8)&4294)!=4)){break Yb}if(!z[a+480190>>1]){break Yb}x[31785]=0;e=P(37,d+100|0,13582)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Ub}b=fb-32|0;fb=b;c=fb-16|0;fb=c;Fw(c+8|0,a+484527|0);XY(b+24|0,x[c+8>>2],x[c+12>>2]);fb=c+16|0;ue(b+16|0,e);c=x[b+20>>2];x[b+8>>2]=x[b+16>>2];x[b+12>>2]=c;c=Oc(x[b+24>>2],x[b+28>>2],b+8|0);fb=b+32|0;tb(e);if(c){break Vb}e=y[d+456|0]|y[d+457|0]<<8}if(e&65535){break Yb}if(yd(x[j+4>>2],y[j+11|0])){break Sb}}b=y[d+458|0]|y[d+459|0]<<8}if((b&65535)>>>0>767){break fb}}if(!yd(x[j+4>>2],y[j+11|0])){break fb}if((b&65535)>>>0<533){break Qb}x[31785]=0;b=P(1,d+76|0,15103)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Rb}yb(j,b);tb(b);break Pb}x[31785]=0;b=P(1,d+160|0,8424)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Tb}yb(j,b);tb(b);break fb}b=N()|0;break N}b=N()|0;break N}x[31785]=0;b=P(1,d+160|0,9760)|0;c=x[31785];x[31785]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}b=N()|0;break N}if((e&65535)>>>0>=533){x[31785]=0;O(446,d+76|0,4035);b=x[31785];x[31785]=0;_b:{if((b|0)!=1){x[31785]=0;x[d+64>>2]=(y[d+456|0]|y[d+457|0]<<8)-532;S(447,d+160|0,d+76|0,d- -64|0);b=x[31785];x[31785]=0;if((b|0)==1){break _b}b=d+160|0;yb(j,b);tb(b);Eb(d+76|0);break Pb}b=N()|0;break N}b=N()|0;Eb(d+76|0);break N}x[31785]=0;O(271,d+76|0,4334);b=x[31785];x[31785]=0;if((b|0)==1){break Ob}b=y[d+456|0]|y[d+457|0]<<8;x[d+52>>2]=b>>>8&15;x[31785]=0;x[d+40>>2]=b&255;O(448,d- -64|0,d+40|0);b=x[31785];x[31785]=0;if((b|0)==1){break Nb}x[31785]=0;V(434,d+160|0,d+76|0,d+52|0,d- -64|0);b=x[31785];x[31785]=0;if((b|0)==1){break Mb}b=d+160|0;yb(j,b);tb(b);tb(d- -64|0);Eb(d+76|0)}b=a+1298412|0;if(!mc(x[b>>2],x[a+1298416>>2])){break fb}c=y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24);if(!c){break fb}c=pF(y[d+456|0]|y[d+457|0]<<8,c);e=bp(d+160|0);x[e+32>>2]=c;x[31785]=0;O(449,b|0,e|0);b=x[31785];x[31785]=0;if((b|0)!=1){break fb}b=N()|0;break N}b=N()|0;break N}b=N()|0;break Lb}b=N()|0;tb(d- -64|0)}Eb(d+76|0);break N}c=y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24);x[31785]=0;S(450,d+160|0,b|0,y[d+476|0]|y[d+477|0]<<8|(y[d+478|0]<<16|y[d+479|0]<<24));e=x[31785];x[31785]=0;$b:{ac:{bc:{cc:{dc:{ec:{fc:{gc:{hc:{if((e|0)!=1){e=d+160|0;yb(j,e);tb(e);c=(b|0)==8191?c:b-4176|0;if((c|0)>1915){break hc}b=x[a+480208>>2];if(!(b&16)){break gc}x[31785]=0;P(270,a+1074312|0,7)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break fc}break Db}b=N()|0;break N}if(c>>>0>4200){break dc}b=x[a+480208>>2]}if(!(b&16)){x[31785]=0;P(270,a+1074312|0,7)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Db}}if((c|0)>2385){break ec}}x[31785]=0;P(270,a+1074312|0,38)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Db}}x[31785]=0;b=P(270,a+1074312|0,102)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Db}x[31785]=0;P(270,b|0,48)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Db}break cc}if(c>>>0>4383){break bc}}x[31785]=0;b=U(269,a+1074312|0,116,1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Db}x[31785]=0;P(270,b|0,115)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Db}break ac}if(c>>>0>4563){break $b}}x[31785]=0;b=P(270,a+1074312|0,43)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Db}x[31785]=0;b=P(270,b|0,42)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Db}x[31785]=0;P(270,b|0,87)|0;c=x[31785];x[31785]=0;b=120;if((c|0)==1){break Db}break Ib}b=120;if(c>>>0>4876){break fb}}x[31785]=0;P(270,a+1074312|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Db}break fb}x[31785]=0;W(451,d+100|0);b=x[31785];x[31785]=0;ic:{jc:{kc:{if((b|0)!=1){b=y[d+456|0]|y[d+457|0]<<8;x[d+64>>2]=b>>>8&15;x[31785]=0;x[d+52>>2]=b&255;O(448,d+76|0,d+52|0);b=x[31785];x[31785]=0;if((b|0)==1){break kc}x[31785]=0;V(434,d+160|0,d+100|0,d- -64|0,d+76|0);b=x[31785];x[31785]=0;if((b|0)==1){break jc}b=d+160|0;yb(j,b);tb(b);tb(d+76|0);Eb(d+100|0);break fb}b=N()|0;break N}b=N()|0;break ic}b=N()|0;tb(d+76|0)}Eb(d+100|0);break N}x[31785]=0;b=P(1,d+160|0,8360)|0;c=x[31785];x[31785]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}if(!((b|0)!=32767|(y[d+458|0]|y[d+459|0]<<8)!=533)){x[31785]=0;b=P(1,d+160|0,5062)|0;c=x[31785];x[31785]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}x[31785]=0;O(134,d+100|0,4170);b=x[31785];x[31785]=0;lc:{if((b|0)!=1){b=y[d+456|0]|y[d+457|0]<<8;x[d+76>>2]=b>>>8&15;x[d+64>>2]=b>>>4&15;x[31785]=0;x[d+52>>2]=b&15;aa(135,d+160|0,d+100|0,d+76|0,d- -64|0,d+52|0);b=x[31785];x[31785]=0;if((b|0)==1){break lc}b=d+160|0;yb(j,b);tb(b);Eb(d+100|0);break fb}b=N()|0;break N}b=N()|0;Eb(d+100|0);break N}x[31785]=0;b=P(1,d+160|0,6143)|0;c=x[31785];x[31785]=0;if((c|0)!=1){yb(j,b);tb(b);break fb}b=N()|0;break N}b=N()|0;break N}if(!((e|0)!=18284544|I|G|H)){break hb}break gb}if(((y[d+456|0]|y[d+457|0]<<8)&61440)!=20480){break gb}}x[31785]=0;c=P(1,d+160|0,17088)|0;e=x[31785];x[31785]=0;mc:{if((e|0)!=1){x[31785]=0;P(77,b|0,c|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break mc}tb(c);break fb}b=N()|0;break N}b=N()|0;tb(c);break N}if(!CG(e)){break fb}x[31785]=0;c=P(1,d+160|0,17324)|0;e=x[31785];x[31785]=0;nc:{if((e|0)!=1){x[31785]=0;P(77,b|0,c|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break nc}tb(c);break fb}b=N()|0;break N}b=N()|0;tb(c);break N}oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{wc:{if(L&1){x[31785]=0;c=P(1,d- -64|0,17338)|0;b=x[31785];x[31785]=0;if((b|0)==1){break wc}x[31785]=0;P(77,j|0,c|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break vc}tb(c)}e=x[a+480180>>2];if(!((e|0)!=16777216|(y[d+456|0]|y[d+457|0]<<8)>>>0<2186)){x[31785]=0;b=P(152,g|0,B|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break _a}if(b){x[31785]=0;S(452,a|0,g|0,y[d+456|0]|y[d+457|0]<<8);b=x[31785];x[31785]=0;if((b|0)==1){break _a}}e=x[a+480180>>2]}if((e|0)!=16777216){break uc}x[31785]=0;P(1,d+52|0,13901)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break tc}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(c);break N}x[31785]=0;O(271,d+40|0,4334);b=x[31785];x[31785]=0;if((b|0)==1){break sc}b=y[d+458|0]|y[d+459|0]<<8;x[d+36>>2]=b>>>8;x[31785]=0;x[d+20>>2]=b&255;O(448,d+24|0,d+20|0);b=x[31785];x[31785]=0;if((b|0)==1){break rc}x[31785]=0;V(434,d+52|0,d+40|0,d+36|0,d+24|0);b=x[31785];x[31785]=0;if((b|0)==1){break qc}}b=d+52|0;yb(a+1298344|0,b);tb(b);if((e|0)!=16777216){tb(d+24|0);Eb(d+40|0)}b=x[a+480180>>2];x[31785]=0;b=P(1,d+52|0,((b|0)==16777216?10134:6147)|0)|0;c=x[31785];x[31785]=0;e=1;if((c|0)==1){break oc}yb(a+1298356|0,b);tb(b);yb(a+1298368|0,j);T=a+1298404|0,X=x[Gc(d+36|0,x[a+1074308>>2]?22:4)>>2],x[T>>2]=X;x[a+1298408>>2]=0;ub(E);ub(C);break s}b=N()|0;break N}b=N()|0;break pc}b=N()|0;tb(d+24|0)}Eb(d+40|0);break N}b=N()|0;break N}b=N()|0;tb(d+76|0);break cb}b=N()|0}tb(c);break N}b=N()|0;break N}b=N()|0;Nk(l);break La}h=h+1|0;continue}}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}dc(m);break Ia}b=N()|0;break Ia}b=N()|0}ub(k);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(f);break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0;tb(d+160|0);break xa}b=N()|0}Eb(d+100|0);break N}b=N()|0;break N}b=N()|0;break N}b=0;f=gD(d+100|0,x[i>>2]);x[31785]=0;P(186,g|0,f|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break _}}f=y[d+103|0];if(!x[i>>2]|(f|0)!=1){break ba}t=1;break aa}L=(f|0)==10|L}x[d+100>>2]=x[g+8>>2];T=d,X=x[_c(d+240|0,d+100|0)>>2],x[T+240>>2]=X;s=(b|0)!=0}e=e+1|0;b=z[m>>1];continue}break}b=N()|0;break N}xc:{b=wb(x[u>>2],e);b=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);yc:{if(!b){break yc}x[31785]=0;b=P(152,g|0,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break xc}if(!b){break yc}b=x[g+8>>2];h=x[g>>2];x[31785]=0;b=U(153,h|0,b|0,554)|0;h=x[31785];x[31785]=0;if((h|0)==1){break xc}if(!b){break yc}x[31785]=0;b=U(254,a|0,e+1&65535,0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break Z}if(!b){break yc}x[31785]=0;V(453,a|0,g|0,b|0,y[d+458|0]|y[d+459|0]<<8);h=x[31785];x[31785]=0;if((h|0)==1){break Z}v[b+33|0]=y[d+469|0]}e=e+1|0;b=z[f>>1];continue}break}b=N()|0;break N}b=N()|0;break N}b=N()|0;break N}b=N()|0}ub(E)}ub(C);break t}b=N()|0;break t}b=N()|0;break t}}}}}b=N()|0}sc(n);sc(o);sc(u);break a}sc(n);sc(o);sc(u)}tb(j)}fb=d+608|0;return e|0}b=N()|0}tb(j);Q(b|0);p()}function uqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0;d=fb-1712|0;fb=d;xc(b);a:{if(!yi(b,d+1704|0)){break a}if(!eY(d+1704|0)){break a}if(!c){i=1;break a}j=y[d+1707|0];v[d+1703|0]=j;x[d+1696>>2]=-1;x[d+1692>>2]=1048576;if(j>>>0>=5){f=Mg(b);x[d+1696>>2]=f;if(!Mb(x[b>>2],x[b+8>>2],f)){break a}x[d+288>>2]=134217727;T=d,X=x[Gb(d+288|0,d+1696|0)>>2]<<5,x[T+1692>>2]=X}C=Nb(d+1680|0);x[d+288>>2]=y[d+1708|0]|y[d+1709|0]<<8|(y[d+1710|0]<<16|y[d+1711|0]<<24);f=x[Gb(d+1692|0,d+288|0)>>2];x[31785]=0;O(556,C|0,f|0);f=x[31785];x[31785]=0;b:{c:{d:{e:{f:{if((f|0)!=1){x[31785]=0;f=U(557,b|0,C|0,y[d+1708|0]|y[d+1709|0]<<8|(y[d+1710|0]<<16|y[d+1711|0]<<24))|0;e=x[31785];x[31785]=0;g:{if((e|0)==1){break g}if(!f){break b}if(j>>>0>=5){x[31785]=0;P(152,b|0,x[d+1696>>2]+12|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break g}}x[31785]=0;O(249,a|0,0);f=x[31785];x[31785]=0;if((f|0)==1){break g}ag(a);le(d+1648|0,x[C>>2],x[C+4>>2]);f=Jd(d+1640|0);x[31785]=0;e=x[f+4>>2];x[d+88>>2]=x[f>>2];x[d+92>>2]=e;n=dg(558,d+1660|0,x[d+1648>>2],x[d+1652>>2],d+88|0);f=x[31785];x[31785]=0;h:{i:{j:{if((f|0)!=1){x[31785]=0;S(361,n|0,a+1298308|0,-1);f=x[31785];x[31785]=0;if((f|0)==1){break j}x[31785]=0;S(361,n|0,a+1298332|0,-1);f=x[31785];x[31785]=0;if((f|0)==1){break j}x[31785]=0;f=P(559,n|0,d+1218|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}if(!f){break c}f=v[d+1218|0];if((f|0)<=0|(y[d+1227|0]|y[d+1228|0]<<8)>>>0>255|(y[d+1229|0]|y[d+1230|0]<<8)>>>0>3999){break c}E=a+480188|0;w[E>>1]=f&255;_e(Wb(x[a+484360>>2],y[a+484376|0]),y[d+1221|0]|y[d+1222|0]<<8);w[a+480192>>1]=y[d+1227|0]|y[d+1228|0]<<8;w[a+480190>>1]=y[d+1229|0]|y[d+1230|0]<<8;f=y[d+1231|0];x[a+480196>>2]=f?f:6;f=y[d+1232|0];x[a+480204>>2]=D(f?f:125,1e4);e=y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24);f=32;k:{if(e&256){break k}f=2;if(e&2){break k}f=1;if(e&128){break k}f=e&8?16:4}x[31785]=0;O(421,a|0,f|0);f=x[31785];x[31785]=0;if((f|0)==1){break f}g=x[a+480208>>2];e=g|16777216;x[a+480208>>2]=e;f=y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24);if(f&1){e=g|16777232;x[a+480208>>2]=e}g=x[a+480180>>2];k=(g|0)==32;h=k&!(f&1024);l=(g|0)==2;i=l&f>>>4;s=f&2097152;l=l&f>>>2;k=k&!(f&2048);if(h|(s|l|(k|i))){e=i?e|65536:e;e=l?e|2:e;e=k?e|4:e;x[a+480208>>2]=s>>>6|(h?e|8:e)}if(f&524288){x[31785]=0;U(269,a+1074312|0,5,1)|0;f=x[31785];x[31785]=0;if((f|0)==1){break f}g=x[a+480180>>2]}if((g|0)==2){break i}if((g|0)!=32){break h}v[d+288|0]=y[d+1237|0];v[d+220|0]=128;T=a,X=y[Ub(d+288|0,d+220|0)|0]<<1,x[T+480200>>2]=X;break h}h=N()|0;break d}h=N()|0;break e}v[d+288|0]=y[d+1237|0];v[d+220|0]=64;T=a,X=y[Ub(d+288|0,d+220|0)|0]<<2,x[T+480200>>2]=X}f=v[d+1239|0];l:{if((f|0)<0){f=f+52|0;break l}G=Ps(+(f|0)*3.1/20);m:{if(G<4294967296&G>=0){f=~~G>>>0;break m}f=0}f=f+51|0}x[a+480228>>2]=f;w[d+288>>1]=64;h=z[Mc(E,d+288|0)>>1];e=0;k=(g|0)!=32;l=(g|0)==4;i=0;while(1)if((h|0)==(i|0)){i=0;k=0;while(1){if((e|0)!=16){k=y[(d+e|0)+1368|0]!=0|k;e=e+1|0;continue}break}while(1){if((i|0)!=128){k=y[((i<<1)+d|0)+1385|0]!=0|k;i=i+1|0;continue}break}n:{if(!(k&1)){break n}f=a+901692|0;i=0;while(1){if((i|0)==16){f=a+902204|0;i=0;while(1){if((i|0)!=128){e=(d+1218|0)+(i<<1)|0;o:{if(y[e+167|0]){x[31785]=0;W(560,d+220|0);g=x[31785];x[31785]=0;p:{q:{r:{s:{t:{if((g|0)!=1){g=y[e+167|0];x[31785]=0;x[d+244>>2]=g-1;O(561,d+1164|0,d+244|0);g=x[31785];x[31785]=0;if((g|0)==1){break t}e=y[e+166|0];x[31785]=0;v[d+192|0]=e;O(562,d+1144|0,d+192|0);e=x[31785];x[31785]=0;if((e|0)==1){break s}x[31785]=0;V(563,d+288|0,d+220|0,d+1164|0,d+1144|0);e=x[31785];x[31785]=0;if((e|0)==1){break r}e=d+288|0;ue(d+1192|0,e);qf(Me(f,i),x[d+1192>>2],x[d+1196>>2]);tb(e);tb(d+1144|0);tb(d+1164|0);Eb(d+220|0);break o}h=N()|0;break e}h=N()|0;break p}h=N()|0;break q}h=N()|0;tb(d+1144|0)}tb(d+1164|0)}Eb(d+220|0);break e}e=pc(d+1184|0,22485);qf(Me(f,i),x[e>>2],x[d+1188>>2])}i=i+1|0;continue}break}g=x[a+480180>>2];break n}e=(d+i|0)+1368|0;u:{if(y[e|0]){x[31785]=0;W(564,d+220|0);g=x[31785];x[31785]=0;v:{w:{x:{if((g|0)!=1){e=y[e|0];x[31785]=0;x[d+1144>>2]=e-1;O(561,d+1164|0,d+1144|0);e=x[31785];x[31785]=0;if((e|0)==1){break x}x[31785]=0;S(293,d+288|0,d+220|0,d+1164|0);e=x[31785];x[31785]=0;if((e|0)==1){break w}e=d+288|0;ue(d+1208|0,e);qf(Me(f,i),x[d+1208>>2],x[d+1212>>2]);tb(e);tb(d+1164|0);Eb(d+220|0);break u}h=N()|0;break e}h=N()|0;break v}h=N()|0;tb(d+1164|0)}Eb(d+220|0);break e}e=pc(d+1200|0,22485);qf(Me(f,i),x[e>>2],x[d+1204>>2])}i=i+1|0;continue}}f=y[a+484376|0];e=x[a+484360>>2];x[31785]=0;e=Wb(e,f);f=g&5;aa(351,e|0,n|0,y[d+1219|0]|y[d+1220|0]<<8,(f?65535:255)|0,(f?65535:254)|0);f=x[31785];x[31785]=0;if((f|0)!=1){x[31785]=0;S(188,d+288|0,n|0,D(y[d+1218|0],y[d+1223|0]|y[d+1224|0]<<8)<<1);f=x[31785];x[31785]=0;if((f|0)!=1){f=d+288|0;H=ic(d+1164|0,f);ub(f);x[31785]=0;S(188,f|0,n|0,(y[d+1223|0]|y[d+1224|0]<<8)<<1);f=x[31785];x[31785]=0;y:{if((f|0)!=1){f=d+288|0;I=ic(d+1144|0,f);ub(f);x[31785]=0;s=P(217,d+1132|0,y[d+1225|0]|y[d+1226|0]<<8)|0;f=x[31785];x[31785]=0;z:{if((f|0)!=1){T=d,X=vb(x[s>>2]),x[T+244>>2]=X;f=vb(x[s+4>>2]);A:{B:{C:{while(1){e=x[d+244>>2];if(!Ib(e,f)){q=a+480180|0;f=x[q>>2];r=c&1;if(!r){break B}x[31785]=0;O(226,a+484344|0,y[d+1223|0]|y[d+1224|0]<<8);e=x[31785];x[31785]=0;if((e|0)!=1){break B}h=N()|0;break A}x[31785]=0;g=R(154,n|0)|0;h=x[31785];x[31785]=0;if((h|0)!=1){x[31785]=0;S(188,d+220|0,n|0,g|0);g=x[31785];x[31785]=0;if((g|0)==1){break C}h=e;e=d+220|0;g=ic(d+288|0,e);hd(h,g);ub(g);ub(e);Xf(d+244|0);continue}break}h=N()|0;break A}h=N()|0;break A}t=(f|0)==16?14:(f|0)==32?1:13;J=a+484344|0;l=1;while(1){D:{E:{F:{G:{H:{I:{if((y[d+1223|0]|y[d+1224|0]<<8)>>>0<=m>>>0){switch(x[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}x[31785]=0;f=R(192,I|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break H}x[d+220>>2]=f;if(!r){break D}x[31785]=0;f=U(199,J|0,m&65535,f|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break H}u=0;if(!f){break D}while(1){g=u&65535;if(g>>>0>=y[d+1218|0]){break D}x[31785]=0;f=R(192,H|0)|0;e=x[31785];x[31785]=0;J:{if((e|0)!=1){e=x[s>>2];if(Lf(e,x[s+4>>2])>>>0<=f>>>0){break J}o=$g(e,f);xc(o);e=0;f=Vb(x[J>>2],m);i=gd(x[f>>2],x[x[f+48>>2]+12>>2],0,g);K:while(1){if(A[d+220>>2]<=e>>>0){break J}x[31785]=0;f=R(200,o|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){if(!f){break J}B=f>>>4|0;K=f&15;k=0;g=Jg(d+288|0);while(1){L:{M:{N:{if(K>>>0>(k&255)>>>0){x[31785]=0;O(201,d+244|0,o|0);f=x[31785];x[31785]=0;if((f|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{f=y[xb(d+244|0,0)|0];switch(f-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(f-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}f=y[xb(d+244|0,1)|0];fa:{if(f>>>0<=119){f=f+t|0;break fa}ga:{switch(f-254|0){case 1:f=255;break fa;case 0:f=254;break fa;default:break ga}}f=253}v[g|0]=f;l=vD(f)&l;break L}T=d,X=y[xb(d+244|0,1)|0]+1|0,v[T+289|0]=X;break L}ha:{if(y[d+290|0]){break ha}f=x[q>>2];if((f|0)!=32){if((f|0)!=4){break ha}f=y[xb(d+244|0,1)|0];if(f&15){break ha}v[d+290|0]=11;v[d+292|0]=f>>>4;break L}f=y[xb(d+244|0,1)|0];h=0;while(1){if((h|0)==10){break ha}if((f|0)==y[h+42448|0]){v[d+292|0]=h;v[d+290|0]=11;break L}else{h=h+1|0;continue}}}T=d,X=y[xb(d+244|0,1)|0],v[T+293|0]=X;v[d+291|0]=4;break L}f=xb(d+244|0,1);ia:{if(y[d+290|0]){break ia}h=y[f|0];if(x[q>>2]!=32|h>>>0>9){break ia}v[d+292|0]=h;v[d+290|0]=8;break L}v[d+293|0]=y[f|0];v[d+291|0]=5;break L}ja:{if(y[d+290|0]){break ja}ka:{f=x[q>>2];if((f|0)!=4){if((f|0)!=32){break ja}h=xb(d+244|0,1);f=y[h|0];if((f|0)!=255){break ka}v[d+292|0]=64;v[d+290|0]=2;break L}h=xb(d+244|0,1);if(y[h|0]&15){break ja}break M}if(!(f&3)){break M}}T=d,X=y[xb(d+244|0,1)|0],v[T+293|0]=X;v[d+291|0]=9;break L}h=y[d+290|0];f=xb(d+244|0,1);la:{if(h|x[q>>2]==1){break la}h=y[f|0];if(h>>>0>64){break la}v[d+292|0]=h;v[d+290|0]=1;break L}v[d+293|0]=y[f|0];v[d+291|0]=13;break L}f=y[xb(d+244|0,1)|0];v[d+293|0]=f;v[d+291|0]=14;if(x[q>>2]==32){break L}v[d+293|0]=D((f&240)>>>4|0,10)+(f&15);break L}f=y[xb(d+244|0,1)|0];v[d+293|0]=f;v[d+291|0]=f>>>0<32?16:17;break L}h=y[xb(d+244|0,1)|0];if(h>>>0>=16){v[d+292|0]=h>>>4;v[d+290|0]=(f|0)==20?3:5;break L}v[d+292|0]=h&15;v[d+290|0]=(f|0)==20?4:6;break L}f=y[xb(d+244|0,1)|0];if(f>>>0>=16){v[d+290|0]=10;v[d+292|0]=f>>>4;break L}v[d+290|0]=9;v[d+292|0]=f&15;break L}f=y[xb(d+244|0,1)|0];v[d+291|0]=28;v[d+293|0]=f|16;break L}f=y[xb(d+244|0,1)|0];v[d+291|0]=28;v[d+293|0]=f|32;break L}T=d,X=y[xb(d+244|0,1)|0],v[T+292|0]=X;v[d+290|0]=(f|0)==31?7:8;break L}f=y[d+291|0];v[d+291|0]=(f|0)==4?6:(f|0)==5?7:11;T=d,X=y[xb(d+244|0,1)|0],v[T+293|0]=X;break L}f=xb(d+244|0,1);v[d+292|0]=y[f|0]%10;f=y[f|0];if(f>>>0<=9){v[d+290|0]=5;break L}if(f>>>0<=19){v[d+290|0]=6;break L}if(f>>>0<=29){v[d+290|0]=3;break L}if(f>>>0>39){break L}v[d+290|0]=4;break L}T=d,X=y[xb(d+244|0,1)|0],v[T+292|0]=X;v[d+290|0]=(f|0)==49?13:12;break L}f=y[xb(d+244|0,1)|0]+33|0;if((f&255)>>>0>9){break L}v[d+290|0]=15;v[d+292|0]=f;break L}if(f>>>0>57){break L}T=d,X=y[xb(d+244|0,1)|0],v[T+293|0]=X;v[d+291|0]=y[f+25424|0];break L}x[d+244>>2]=e+B;f=x[Gb(d+244|0,d+220|0)>>2];f=e>>>0>f>>>0?e:f;while(1){if((e|0)!=(f|0)){h=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[i|0]=h;v[i+1|0]=h>>>8;v[i+2|0]=h>>>16;v[i+3|0]=h>>>24;h=y[g+4|0]|y[g+5|0]<<8;v[i+4|0]=h;v[i+5|0]=h>>>8;e=e+1|0;i=D(y[d+1218|0],6)+i|0;continue}break}e=f;continue K}h=N()|0;break A}f=y[h|0];v[d+290|0]=2;v[d+292|0]=f>>>2}k=k+1|0;continue}}break}h=N()|0;break A}h=N()|0;break A}u=u+1|0;continue}}i=z[a+480192>>1];f=0;break E}h=N()|0;break A}if(!(z[E>>1]==4&l)){break F}x[a+480208>>2]=x[a+480208>>2]|8454144}i=0;f=!((y[d+1233|0]|y[d+1234|0]<<8|(y[d+1235|0]<<16|y[d+1236|0]<<24))&512)}x[31785]=0;u=P(565,d+1120|0,i|0)|0;e=x[31785];x[31785]=0;ma:{na:{oa:{pa:{qa:{if((e|0)!=1){q=a+480192|0;i=j>>>0<5;l=a+480180|0;k=1;ra:{while(1){h=k&65535;if(h>>>0>z[q>>1]){break ra}sa:{ta:{ua:{va:{if(!f){x[31785]=0;g=U(254,a|0,h|0,0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break va}if(g){break ua}}while(1){x[31785]=0;e=R(200,n|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break na}if(e){continue}break}if(!i){while(1){x[31785]=0;e=R(200,n|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){h=N()|0;break ma}if(e){continue}break}}x[31785]=0;P(186,n|0,826)|0;e=x[31785];x[31785]=0;if((e|0)!=1){break ta}}h=N()|0;break ma}e=Fb(d+220|0);x[31785]=0;S(361,n|0,e|0,-1);m=x[31785];x[31785]=0;if((m|0)==1){break sa}zc(g+492|0,e);if(!i){x[31785]=0;S(361,n|0,e|0,-1);m=x[31785];x[31785]=0;if((m|0)==1){break sa}zc(g+524|0,e)}x[31785]=0;m=P(566,n|0,d+288|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break oa}if(!m){break qa}m=x[l>>2];x[31785]=0;S(567,d+288|0,g|0,m|0);g=x[31785];x[31785]=0;if((g|0)==1){break oa}if(x[l>>2]==4){g=wb(x[u>>2],h-1|0);h=y[d+1090|0]|y[d+1091|0]<<8|(y[d+1092|0]<<16|y[d+1093|0]<<24);v[g|0]=h;v[g+1|0]=h>>>8;v[g+2|0]=h>>>16;v[g+3|0]=h>>>24}tb(e)}k=k+1|0;continue}break}break oa}if(!f){break pa}w[a+480192>>1]=0;break pa}h=N()|0;break A}tb(e)}f=z[a+480190>>1];x[31785]=0;q=P(568,d+276|0,f|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){B=y[d+1703|0];K=!(v[d+1233|0]&1)|B>>>0>4;o=c&2;M=a+480180|0;k=1;c=0;while(1){f=c;wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{l=k&65535;if(l>>>0<=z[a+480190>>1]){i=Fb(d+264|0);x[31785]=0;S(361,n|0,i|0,-1);c=x[31785];x[31785]=0;Ra:{Sa:{if((c|0)!=1){zc(((l<<5)+a|0)+946304|0,i);c=B>>>0<5;if(c){break Sa}x[31785]=0;S(361,n|0,i|0,-1);e=x[31785];x[31785]=0;if((e|0)!=1){break Ra}}h=N()|0;break za}rf(i)}x[31785]=0;e=P(569,n|0,d+288|0)|0;g=x[31785];x[31785]=0;Ta:{Ua:{if((g|0)==1){break Ua}if(!e){break Ta}g=x[M>>2];x[31785]=0;h=D(l,104)+a|0;e=h+484380|0;V(570,d+288|0,e|0,g|0,K|0);g=x[31785];x[31785]=0;if((g|0)==1){break Ua}ye(h+484423|0,i);r=0;Va:{if(((y[d+308|0]|y[d+309|0]<<8)&61440)!=28672|c){break Va}x[31785]=0;r=R(571,n|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break Va}h=N()|0;break za}if(!o){break xa}g=y[d+323|0]|y[d+324|0]<<8|(y[d+325|0]<<16|y[d+326|0]<<24);c=y[d+308|0]|y[d+309|0]<<8;m=c&61440;if(!(g|m)){c=ad(d+220|0,c&1?16:8,c&1024?3:1,0,0);x[31785]=0;U(218,c|0,e|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break xa}h=N()|0;break za}if((g|0)<0){c=g+l|0;if((c|0)<=0){break xa}dY(e,(D(c,104)+a|0)+484380|0);break xa}if((g|0)<=0){break xa}if(c&1){j=h+484414|0;w[j>>1]=z[j>>1]|1}if(c&1024){j=h+484414|0;w[j>>1]=z[j>>1]|64}x[31785]=0;S(188,d+220|0,b|0,g|0);g=x[31785];x[31785]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{if((g|0)!=1){j=d+220|0;g=ic(d+244|0,j);ub(j);j=Xd(z[e+34>>1]);L=(m|0)==16384;if(!L&(m|0)!=8192){break Za}t=x[g>>2];x[31785]=0;t=R(157,t|0)|0;F=x[31785];x[31785]=0;if((F|0)==1){break Wa}F=4/(j>>>0)|0;sua(F,0,t,0);vc(e,hb?-1:D(F,t));if((m|0)==8192){break $a}if(!L){break Za}if(!Bh(e)){break Ya}c=x[h+484400>>2];e=x[e>>2];if(!(v[d+308|0]&1)){break _a}x[31785]=0;V(572,g|0,c|0,e|0,j|0);e=x[31785];x[31785]=0;c=f;if((e|0)==1){break Ba}break Xa}h=N()|0;break za}if(!Bh(e)){break Ya}c=x[h+484400>>2];e=x[e>>2];if(v[d+308|0]&1){x[31785]=0;V(573,g|0,c|0,e|0,j|0);e=x[31785];x[31785]=0;c=f;if((e|0)!=1){break Xa}break Ba}x[31785]=0;V(574,g|0,c|0,e|0,j|0);e=x[31785];x[31785]=0;c=f;if((e|0)==1){break Ba}break Xa}x[31785]=0;V(575,g|0,c|0,e|0,j|0);e=x[31785];x[31785]=0;c=f;if((e|0)==1){break Ba}break Xa}if((c&45056)==12288){c=cY(d+220|0,g,y[d+327|0]|y[d+328|0]<<8,r);T=hd(tf(x[q>>2],l-1|0),c),X=x[c+20>>2],x[T+20>>2]=X;ub(c);break Ya}if((m|0)!=32768){c=1;if((m|0)!=4096){break Xa}m=Fe(d+220|0,g);x[31785]=0;c=P(576,d+214|0,g|0)|0;j=x[31785];x[31785]=0;if((j|0)!=1){ab:{bb:{if(!y[d+219|0]){break bb}r=y[d+327|0]|y[d+328|0]<<8;j=z[d+216>>1]<<1;if(r>>>0<(j&65535)>>>0){break bb}j=r-j|0;v[d+327|0]=j;v[d+328|0]=j>>>8;c=z[c>>1];x[31785]=0;P(152,g|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ab}x[31785]=0;c=R(205,g|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break ab}x[31785]=0;S(188,d+172|0,g|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break ab}c=d+172|0;j=ic(d+192|0,c);hd(m,j);ub(j);ub(c)}x[31785]=0;l=U(577,a|0,l|0,m|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ab}c=1;if(l){c=y[d+327|0]|y[d+328|0]<<8;cb:{if(!c){break cb}l=z[e+34>>1];j=Rk(x[e>>2],l);if(j>>>0<=c>>>0){break cb}l=$k(l);h=x[h+484400>>2];ai(h,c+h|0,j-c|0);x[e>>2]=x[e>>2]-((c>>>0)/(l>>>0)|0)}vc(e,y[d+296|0]|y[d+297|0]<<8|(y[d+298|0]<<16|y[d+299|0]<<24));c=f}ub(m);break Xa}}h=N()|0;ub(m);break Aa}x[31785]=0;c=P(432,g|0,d+220|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break Qa}if(!c){break Ya}x[d+80>>2]=y[d+228|0]|y[d+229|0]<<8|(y[d+230|0]<<16|y[d+231|0]<<24);c=y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24);x[d+72>>2]=y[d+220|0]|y[d+221|0]<<8|(y[d+222|0]<<16|y[d+223|0]<<24);x[d+76>>2]=c;Vk(e,1,d+72|0)}c=f}ub(g);break wa}h=N()|0;break Aa}h=N()|0;break za}tb(i)}db:{if(!o){break db}l=1;while(1){i=l&65535;if(i>>>0>z[a+480190>>1]){break db}b=tf(x[q>>2],i-1|0);c=x[b>>2];x[31785]=0;c=R(175,c|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Pa}eb:{fb:{if(!c){break fb}e=z[b+22>>1];c=e+l&65535;k=z[b+20>>1];m=(e|0)!=0&(c|0)!=0&c>>>0<=z[a+480190>>1]&(k|0)!=0;gb:{if(m){e=tf(x[q>>2],c-1|0);break gb}c=x[b>>2];x[31785]=0;k=R(157,c|0)|0;c=x[31785];x[31785]=0;e=b;if((c|0)==1){break Oa}}xc(e);hb:{if(m){c=x[e+8>>2];g=x[e>>2];h=z[b+20>>1];x[31785]=0;c=U(153,g|0,c|0,h|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Oa}if(!c){break fb}x[d+220>>2]=0;x[d+244>>2]=0;x[31785]=0;S(189,d+288|0,e|0,k|0);c=x[31785];x[31785]=0;ib:{if((c|0)!=1){g=LC(Se(d+288|0),Vi(x[d+288>>2]),d+220|0,d+244|0);x[31785]=0;P(186,e|0,x[d+220>>2])|0;c=x[31785];x[31785]=0;if((c|0)==1){break ib}Jc(d+288|0);break hb}h=N()|0;break ya}h=N()|0;Jc(d+288|0);break ya}g=0;x[d+220>>2]=0;x[d+244>>2]=0}x[31785]=0;O(578,d+288|0,b|0);c=x[31785];x[31785]=0;jb:{kb:{if((c|0)!=1){h=Se(d+288|0);k=x[d+288>>2];if(!m){g=LC(h,Vi(k),d+220|0,d+244|0);x[31785]=0;c=x[d+220>>2];P(186,b|0,c|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break eb}k=k-c|0;h=c+h|0}if(g){break kb}f=1;break jb}h=N()|0;break ya}c=D(i,104)+a|0;m=c+484380|0;Bh(m);t=c+484400|0;e=0;i=x[d+244>>2];while(1){lb:{if(!k|(i|0)!=1?i:0){break lb}c=x[m>>2];if(c>>>0<=e>>>0){break lb}if(!ge(c,x[m+20>>2])){break lb}x[d+192>>2]=0;x[d+172>>2]=0;j=bY(g,h,Vi(k),d+192|0,d+264|0,d+172|0);x[31785]=0;x[d+220>>2]=j;P(186,b|0,j|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Ca}xi(d+172|0,Vi(x[m>>2]-e|0));c=x[d+172>>2];mb:{if((c|0)<=0){break mb}i=x[d+192>>2];B=z[m+34>>1];if((Xd(B)|0)!=(i|0)){break mb}o=D(e,i);r=x[t>>2];if(B&1){x[d+168>>2]=c;x[d+156>>2]=c;x[d- -64>>2]=c;x[d+48>>2]=c;x[d+152>>2]=i;x[d+148>>2]=x[d+264>>2];x[d+164>>2]=i;x[d+160>>2]=r+(o<<1);x[31785]=0;i=x[d+152>>2];x[d+40>>2]=x[d+148>>2];x[d+44>>2]=i;i=x[d+164>>2];x[d+56>>2]=x[d+160>>2];x[d+60>>2]=i;O(579,d+56|0,d+40|0);i=x[31785];x[31785]=0;if((i|0)!=1){break mb}break Ca}x[d+144>>2]=c;x[d+132>>2]=c;x[d+32>>2]=c;x[d+16>>2]=c;x[d+128>>2]=i;x[d+124>>2]=x[d+264>>2];x[d+140>>2]=i;x[d+136>>2]=o+r;x[31785]=0;i=x[d+128>>2];x[d+8>>2]=x[d+124>>2];x[d+12>>2]=i;i=x[d+140>>2];x[d+24>>2]=x[d+136>>2];x[d+28>>2]=i;O(580,d+24|0,d+8|0);i=x[31785];x[31785]=0;if((i|0)==1){break Ca}}k=k-j|0;h=h+j|0;i=aY(g);x[d+244>>2]=i;e=c+e|0;continue}break}$X(g)}Jc(d+288|0)}l=l+1|0;continue}break}break Ca}nb:{if(x[a+480180>>2]!=4){break nb}i=0;c=a+480192|0;while(1){if(z[c>>1]<=i>>>0){break nb}b=wb(x[u>>2],i);e=y[b+3|0];g=y[b+2|0];h=y[b+1|0];b=y[b|0];x[31785]=0;i=i+1|0;ja(404,a|0,i&65535,b|0,h|0,g|0,e|0);b=x[31785];x[31785]=0;if((b|0)!=1){continue}break}h=N()|0;break ya}if(!(y[d+1235|0]&16)){break Ka}b=x[n+8>>2];c=x[n>>2];x[31785]=0;b=U(153,c|0,b|0,1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Ma}if(!b){break Ka}i=0;x[31785]=0;b=R(200,n|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Na}if(!(b&1)){break La}while(1){if(z[E>>1]<=i>>>0){break La}x[31785]=0;b=R(154,n|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){v[((i<<5)+a|0)+480288|0]=b;i=i+1|0;continue}break}h=N()|0;break ya}h=N()|0;break Aa}h=N()|0;break ya}h=N()|0;break ya}h=N()|0;break ya}h=N()|0;break ya}e=a+906300|0;while(1){b=x[n+8>>2];c=x[n>>2];x[31785]=0;b=U(153,c|0,b|0,1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Da}if(!b){break Ka}x[31785]=0;b=R(200,n|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Ia}if(!b){break Ka}x[31785]=0;c=R(154,n|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Ja}x[31785]=0;S(188,d+220|0,n|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break Ja}g=d+220|0;c=ic(d+288|0,g);ub(g);ob:{if(b>>>0<=250){b=rd(e,b-1|0);x[31785]=0;O(454,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break ob}}ub(c);continue}break}h=N()|0;ub(c);break ya}k=a+901404|0;c=Fb(d+192|0);l=a+480180|0;m=a+484348|0;e=0;h=0;while(1){b=x[n+8>>2];g=x[n>>2];x[31785]=0;b=U(153,g|0,b|0,8)|0;g=x[31785];x[31785]=0;pb:{qb:{rb:{sb:{tb:{if((g|0)!=1){if(b){x[31785]=0;g=R(154,n|0)|0;b=x[31785];x[31785]=0;ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{if((b|0)!=1){x[31785]=0;b=R(154,n|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break Bb}x[31785]=0;S(188,d+288|0,n|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break Ab}i=d+288|0;b=ic(d+220|0,i);ub(i);if((g|0)==1229211981){break xb}if((g|0)==1229476432){break yb}if((g|0)==1397900630){break zb}if((g|0)!=1414548815){break pb}x[31785]=0;g=P(416,b|0,13954)|0;i=x[31785];x[31785]=0;if((i|0)==1){break Ha}if(!g){break qb}x[31785]=0;g=R(154,b|0)|0;i=x[31785];x[31785]=0;if((i|0)!=1){x[31785]=0;S(188,d+288|0,b|0,g|0);g=x[31785];x[31785]=0;if((g|0)!=1){break wb}}h=N()|0;break Ga}h=N()|0;break Ea}h=N()|0;break Ea}h=N()|0;break Ea}Cb:{Db:{Eb:{g=x[l>>2];switch(g-2|0){case 1:break pb;case 0:break vb;case 2:break Db;default:break Eb}}if((g|0)==16){break Cb}if((g|0)!=32){break pb}x[31785]=0;e=R(192,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Ha}x[31785]=0;h=R(192,b|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){break pb}break Ha}g=Gc(d+120|0,4);x[d+288>>2]=32;i=x[b>>2];x[31785]=0;i=R(157,i|0)|0;j=x[31785];x[31785]=0;if((j|0)!=1){x[d+244>>2]=i;g=x[g>>2];i=x[Gb(d+288|0,d+244|0)>>2];x[31785]=0;V(581,b|0,c|0,g|0,i|0);g=x[31785];x[31785]=0;if((g|0)!=1){break pb}}h=N()|0;break Ga}x[31785]=0;g=R(200,b|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break ub}x[31785]=0;O(582,d+244|0,4231);i=x[31785];x[31785]=0;Fb:{if((i|0)!=1){x[d+264>>2]=g>>>4;x[31785]=0;x[d+104>>2]=g&15;V(310,d+288|0,d+244|0,d+264|0,d+104|0);g=x[31785];x[31785]=0;if((g|0)==1){break Fb}g=d+288|0;yb(c,g);tb(g);Eb(d+244|0);break pb}h=N()|0;break Ga}h=N()|0;Eb(d+244|0);break Ga}x[31785]=0;g=R(200,b|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break Ha}x[a+480216>>2]=g;x[31785]=0;g=R(200,b|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break Ha}x[a+480220>>2]=g;break pb}x[31785]=0;P(427,b|0,k|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Ha}kD(k);break pb}i=d+288|0;g=ic(d+244|0,i);ub(i);i=x[g>>2];x[31785]=0;i=R(157,i|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break rb}w[d+288>>1]=i>>>5;T=d,X=pg(x[a+484344>>2],x[m>>2]),w[T+264>>1]=X;j=z[Mc(d+288|0,d+264|0)>>1];i=0;while(1){if((i|0)==(j|0)){ub(g);break qb}x[31785]=0;O(583,g|0,d+288|0);o=x[31785];x[31785]=0;Gb:{if((o|0)==1){break Gb}o=x[J>>2];x[31785]=0;O(584,Vb(o,i)|0,d+288|0);o=x[31785];x[31785]=0;if((o|0)==1){break Gb}i=i+1|0;continue}break}break rb}x[31785]=0;e=R(192,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Ha}break pb}h=N()|0;break Ga}b=x[a+480180>>2];Hb:{Ib:{Jb:{if((b|0)!=32){break Jb}g=e&65535;if(g>>>0<256){break Jb}if(g>>>0<532){break Ib}}b=(b|0)!=2;Kb:{if(b){break Kb}g=e&65535;if(g>>>0<12544){break Kb}if(g>>>0<12820){break Ib}}if(b){break Hb}b=e&65535;if(b>>>0<4864|b>>>0>4895){break Hb}}Zq(k)}i=1;Lb:{if(!(v[d+1235|0]&1)){break Lb}e=x[a+1074308>>2];if(!e){e=a+480192|0;g=a+480180|0;while(1){b=i&65535;if(b>>>0<=z[e>>1]){b=x[((b<<2)+a|0)+900380>>2];if(b){k=x[g>>2];x[31785]=0;O(585,Xh(b,2)|0,k|0);k=x[31785];x[31785]=0;if((k|0)==1){break tb}v[b+19|0]=y[b+19|0]+3>>>2}i=i+1|0;continue}break}e=x[a+1074308>>2]}if(e>>>0<=18350079){x[31785]=0;b=P(270,a+1074312|0,27)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Fa}x[31785]=0;P(270,b|0,57)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Fa}e=x[a+1074308>>2]}if(e>>>0<=19070975){x[31785]=0;P(270,a+1074312|0,73)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Fa}e=x[a+1074308>>2]}if(e>>>0>19267583){break Lb}x[31785]=0;P(270,a+1074312|0,50)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Fa}}Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{if(yd(x[c+4>>2],y[c+11|0])){x[31785]=0;W(586,d+220|0);b=x[31785];x[31785]=0;_b:{if((b|0)!=1){x[31785]=0;S(554,d+288|0,d+220|0,d+1703|0);b=x[31785];x[31785]=0;if((b|0)==1){break _b}break Zb}h=N()|0;break Ea}h=N()|0;Eb(d+220|0);break Ea}x[31785]=0;W(587,d+220|0);b=x[31785];x[31785]=0;if((b|0)==1){break Yb}x[31785]=0;V(588,d+288|0,d+220|0,d+1703|0,c|0);b=x[31785];x[31785]=0;if((b|0)==1){break Xb}}b=d+288|0;yb(c,b);tb(b);b=d+220|0;Eb(b);x[31785]=0;O(553,b|0,3997);b=x[31785];x[31785]=0;if((b|0)==1){break Vb}x[31785]=0;S(554,d+288|0,d+220|0,d+1703|0);b=x[31785];x[31785]=0;if((b|0)==1){break Ub}b=d+288|0;yb(a+1298344|0,b);tb(b);Eb(d+220|0);x[31785]=0;b=P(1,b|0,15151)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Tb}yb(a+1298356|0,b);tb(b);b=x[a+480180>>2];switch(b-1|0){case 2:break sb;case 1:break Pb;case 3:break Qb;case 0:break Rb;default:break Wb}}h=N()|0;break Ea}h=N()|0;Eb(d+220|0);break Ea}if((b|0)==16){break Sb}if((b|0)==32){break Ob}if((b|0)!=16777216){break sb}x[31785]=0;b=P(1,d+220|0,10134)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Nb}yb(a+1298392|0,b);tb(b);x[31785]=0;b=P(1,d+244|0,13901)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Mb}yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;Eb(d+220|0);break Ea}h=N()|0;break Ea}x[31785]=0;b=P(1,d+220|0,10139)|0;e=x[31785];x[31785]=0;$b:{if((e|0)!=1){yb(a+1298392|0,b);tb(b);x[31785]=0;b=P(1,d+244|0,8385)|0;e=x[31785];x[31785]=0;if((e|0)==1){break $b}yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;break Ea}x[31785]=0;b=P(1,d+220|0,12407)|0;e=x[31785];x[31785]=0;ac:{if((e|0)!=1){yb(a+1298392|0,b);tb(b);x[31785]=0;b=P(1,d+244|0,14396)|0;e=x[31785];x[31785]=0;if((e|0)==1){break ac}yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;break Ea}x[31785]=0;b=P(1,d+220|0,10112)|0;e=x[31785];x[31785]=0;bc:{if((e|0)!=1){yb(a+1298392|0,b);tb(b);x[31785]=0;b=P(1,d+244|0,15442)|0;e=x[31785];x[31785]=0;if((e|0)==1){break bc}yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;break Ea}x[31785]=0;b=P(1,d+220|0,10484)|0;e=x[31785];x[31785]=0;cc:{if((e|0)!=1){yb(a+1298392|0,b);tb(b);x[31785]=0;b=P(1,d+244|0,15205)|0;e=x[31785];x[31785]=0;if((e|0)==1){break cc}yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;break Ea}x[31785]=0;b=P(1,d+220|0,6147)|0;e=x[31785];x[31785]=0;dc:{ec:{fc:{gc:{hc:{if((e|0)!=1){yb(a+1298392|0,b);tb(b);if(!(h&65535)){break dc}x[31785]=0;O(271,d+264|0,4334);b=x[31785];x[31785]=0;if((b|0)==1){break hc}x[d+116>>2]=(h&65280)>>>8;x[31785]=0;x[d+100>>2]=h&255;O(448,d+104|0,d+100|0);b=x[31785];x[31785]=0;if((b|0)==1){break gc}x[31785]=0;V(434,d+244|0,d+264|0,d+116|0,d+104|0);b=x[31785];x[31785]=0;if((b|0)==1){break fc}b=d+244|0;yb(a+1298380|0,b);tb(b);tb(d+104|0);Eb(d+264|0);break sb}h=N()|0;break Ea}h=N()|0;break Ea}h=N()|0;break ec}h=N()|0;tb(d+104|0)}Eb(d+264|0);break Ea}x[31785]=0;b=P(1,d+244|0,8577)|0;e=x[31785];x[31785]=0;if((e|0)!=1){yb(a+1298380|0,b);tb(b);break sb}h=N()|0;break Ea}h=N()|0;break Ea}h=N()|0;break Ea}h=N()|0;break Ea}h=N()|0;break Ea}yb(a+1298368|0,c);ic:{if(x[a+1074308>>2]){T=a,X=x[Gc(d+264|0,22)>>2],x[T+1298404>>2]=X;break ic}if(x[a+480180>>2]==1){T=a,X=x[Gc(d+264|0,28)>>2],x[T+1298404>>2]=X;break ic}T=a,X=x[Gc(d+264|0,4)>>2],x[T+1298404>>2]=X}i=1;jc:{kc:{if(f&1){x[31785]=0;b=P(1,d+264|0,16836)|0;f=x[31785];x[31785]=0;if((f|0)==1){break kc}a=x[a+1298472>>2];x[31785]=0;S(389,a|0,2,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break jc}tb(b)}tb(c);_X(q);sc(u);Qc(s);ub(I);ub(H);break c}h=N()|0;break Ea}h=N()|0;tb(b);break Ea}h=N()|0;ub(g);break Ga}x[31785]=0;g=P(416,b|0,13959)|0;i=x[31785];x[31785]=0;if((i|0)==1){break Ha}lc:{if(!g){break lc}x[31785]=0;g=R(154,b|0)|0;i=x[31785];x[31785]=0;mc:{if((i|0)!=1){x[31785]=0;S(188,d+244|0,b|0,g|0);g=x[31785];x[31785]=0;if((g|0)!=1){break mc}}h=N()|0;break Ga}i=d+244|0;g=ic(d+288|0,i);ub(i);i=x[g>>2];x[31785]=0;i=R(157,i|0)|0;j=x[31785];x[31785]=0;if((j|0)!=1){w[d+244>>1]=(i>>>0)/20;w[d+264>>1]=z[E>>1];j=z[Mc(d+244|0,d+264|0)>>1];i=0;while(1){if((i|0)==(j|0)){ub(g);break lc}x[31785]=0;S(428,g|0,((i<<5)+a|0)+480289|0,20);o=x[31785];x[31785]=0;if((o|0)!=1){i=i+1|0;continue}break}}h=N()|0;ub(g);break Ga}x[31785]=0;P(439,a|0,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Ha}x[31785]=0;ba(440,a|0,b|0,1,0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Ha}if((e-2186&65535)>>>0<=117){x[l>>2]=16777216;x[31785]=0;S(452,a|0,b|0,e&65535);g=x[31785];x[31785]=0;if((g|0)==1){break Ha}}if(!x[a+1074308>>2]){break pb}x[31785]=0;g=P(1,d+172|0,18434)|0;i=x[31785];x[31785]=0;nc:{oc:{pc:{if((i|0)!=1){i=x[a+1074308>>2];x[31785]=0;O(137,d+244|0,i|0);i=x[31785];x[31785]=0;if((i|0)==1){break pc}x[31785]=0;S(2,d+288|0,g|0,d+244|0);i=x[31785];x[31785]=0;if((i|0)==1){break oc}i=d+288|0;yb(c,i);tb(i);tb(d+244|0);tb(g);break pb}h=N()|0;break Ga}h=N()|0;break nc}h=N()|0;tb(d+244|0)}tb(g);break Ga}ub(b);continue}}h=N()|0;break ya}h=N()|0;break ya}h=N()|0}ub(b);break Ea}h=N()|0}tb(c);break ya}h=N()|0;break ya}h=N()|0;Jc(d+288|0);break ya}h=N()|0}ub(g)}tb(i)}_X(q);break ma}c=f}tb(i);k=k+1|0;continue}}h=N()|0;break ma}h=N()|0;tb(e);break ma}h=N()|0}sc(u);break A}m=m+1|0;continue}}Qc(s);break z}h=N()|0}ub(I);break y}h=N()|0}ub(H);break e}h=N()|0;break e}h=N()|0;break e}else{qc:{rc:{if(!k){v[d+288|0]=y[(d+i|0)+1240|0];v[d+220|0]=64;T=((i<<5)+a|0)+480286|0,X=y[Ub(d+288|0,d+220|0)|0],w[T>>1]=X;break rc}if(l){break qc}}sc:{f=y[(d+i|0)+1304|0];if((f|0)!=255){if((f|0)!=127){break sc}x[((i<<5)+a|0)+480280>>2]=256;break qc}w[((i<<5)+a|0)+480284>>1]=256;break qc}w[((i<<5)+a|0)+480284>>1]=f}i=i+1|0;continue}}h=N()|0;break d}h=N()|0;break d}h=N()|0}ub(n)}dc(C);Q(h|0);p()}ub(n)}dc(C)}fb=d+1712|0;return i|0}function Gqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;e=fb-944|0;fb=e;xc(b);a:{if(!pY(b,e+892|0)){break a}if(!tY(e+892|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(sY(e+892|0),hb))){break a}if(!c){f=1;break a}Bd(a,8);ag(a);h=y[e+895|0]-48|0;v[e+891|0]=h;bd(b,$b(y[e+900|0]|y[e+901|0]<<8|(y[e+902|0]<<16|y[e+903|0]<<24)));d=e+584|0;ce(d,b,504);aa=ic(e+868|0,d);ub(d);x[31785]=0;O(527,b|0,d|0);d=x[31785];x[31785]=0;b:{c:{d:{e:{f:{g:{if((d|0)!=1){if(y[e+867|0]>63){break b}if(Cb(z[e+584>>1])<<16>>16<0){break b}Tb(e+504|0,0,80);h:{d=$b(y[e+924|0]|y[e+925|0]<<8|(y[e+926|0]<<16|y[e+927|0]<<24));if(!d){break h}x[31785]=0;i=P(152,b|0,d|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){if(!i){break h}x[31785]=0;O(528,b|0,e+504|0);d=x[31785];x[31785]=0;if((d|0)!=1){break h}}g=N()|0;break e}x[31785]=0;S(529,e+500|0,b|0,h&255);d=x[31785];x[31785]=0;if((d|0)!=1){fa=Ze(e+500|0);d=z[e+500>>1];if((d-128&65535)>>>0<65409){break b}w[a+480188>>1]=d;Y=Nb(e+488|0);d=$b(y[e+916|0]|y[e+917|0]<<8|(y[e+918|0]<<16|y[e+919|0]<<24));i:{if(d){x[31785]=0;P(152,b|0,d|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break g}x[31785]=0;S(530,b|0,Y|0,y[e+867|0]);d=x[31785];x[31785]=0;if((d|0)==1){break g}k=y[e+867|0];break i}k=y[e+867|0];f=0;if(k){break c}}E=a+480188|0;k=k&255;w[a+480192>>1]=k;w[a+480190>>1]=k;ga=(h&255)>>>0<2|v[e+848|0]>=0;F=!ga;q=c&2;s=1;B=1;while(1){j:{k:{l:{m:{n:{o:{f=B&65535;if(f>>>0<=(k&65535)>>>0){x[31785]=0;t=s&65535;i=U(254,a|0,f|0,t|0)|0;d=x[31785];x[31785]=0;p:{if((d|0)!=1){if(i){break p}break d}g=N()|0;break f}k=x[((f<<2)+a|0)+900380>>2];w[e+92>>1]=0;x[e+88>>2]=0;x[31785]=0;G=R(171,e+468|0)|0;d=x[31785];x[31785]=0;q:{if((d|0)!=1){d=wb(x[Y>>2],f-1|0);d=$b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));r:{if(!d){break r}x[31785]=0;i=P(152,b|0,d|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break k}if(!i){break r}x[31785]=0;O(531,b|0,e+88|0);d=x[31785];x[31785]=0;if((d|0)==1){break k}i=x[e+88>>2];d=w[e+92>>1];x[31785]=0;f=$b(i);d=ve(d);S(188,e+128|0,b|0,f<<(d>>>5&1&(d|0)>0));d=x[31785];x[31785]=0;if((d|0)==1){break k}i=e+128|0;d=ic(e+188|0,i);hd(G,d);ub(d);ub(i)}o=ve(w[e+92>>1]);d=o&15;if((o|0)>=0){break q}yv(k,0);ia=1;break o}g=N()|0;break f}if(d>>>0>6){break o}C=y[d+25302|0];if(!d){break m}w[a+480190>>1]=(z[a+480190>>1]+C|0)-1;u=k+108|0;r=k+236|0;A=C-2|0;g=4;s:while(1){m=1;if((g|0)==10){break n}j=D(g,12);d=(A<<3)+g|0;h=y[d+25308|0]+s|0;i=y[d+25356|0];f=0;while(1)if((f|0)==12){g=g+1|0;continue s}else{d=f+j|0;ja=_b(r,d),ka=h,w[ja>>1]=ka;d=xb(u,d);v[d|0]=i+y[d|0];f=f+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{d=$b(x[e+508>>2]);if(!d){break G}if(!Cb(z[e+512>>1])){break G}x[31785]=0;i=P(152,b|0,d|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break F}if(!i){break G}ja=e,ka=Cb(z[e+512>>1]),w[ja+188>>1]=ka;w[e+128>>1]=y[e+867|0];F=z[Mc(e+188|0,e+128|0)>>1];q=e+136|0;u=e+132|0;B=Cb(z[e+514>>1]);r=B>>>0<5;A=B>>>0<19;j=B>>>0<21;h=B>>>0<15;f=B>>>0<6;k=0;while(1){if((k|0)==(F|0)){break G}x[31785]=0;S(532,b|0,e+188|0,B|0);d=x[31785];x[31785]=0;H:{I:{J:{if((d|0)!=1){k=k+1|0;s=x[((k<<2)+a|0)+900380>>2];t=y[e+188|0];if(t){i=Yl(e+128|0,0,64);Yl(u,t-1&65535,64);d=y[e+189|0];if(d){d=64/(d>>>0)|0}else{d=0}Yl(q,d+t|0,0);x[31785]=0;o=s+48|0;S(533,o|0,i|0,3);d=x[31785];x[31785]=0;if((d|0)==1){break J}if(y[e+188|0]==1){i=x[zb(e+464|0,vb(x[o>>2]))>>2];t=fb-16|0;fb=t;d=vb(x[o>>2]);d=x[o>>2]+(wv(i,d)<<2)|0;Yh(o,Ov(d+4|0,x[o+4>>2],d));zb(t+12|0,d);fb=t+16|0}d=y[e+189|0];x[s>>2]=d?d<<9:32767;v[s+60|0]=y[s+60|0]|1;J=1}K:{if(r){break K}d=y[e+192|0];if(d){ja=xb(s+108|0,24),ka=d+24|0,v[ja|0]=ka;J=1}if(A){break K}x[s+4>>2]=y[e+206|0]+1>>>1;if(j){break K}w[s+28>>1]=y[e+208|0]|y[e+209|0]<<8}i=D(z[_b(s+236|0,61)>>1],104)+a|0;v[i+484417|0]=y[e+191|0]<<4;if(h){break I}d=$b(y[e+198|0]|y[e+199|0]<<8|(y[e+200|0]<<16|y[e+201|0]<<24));x[i+484384>>2]=d;ja=i+484388|0,ka=$b(y[e+202|0]|y[e+203|0]<<8|(y[e+204|0]<<16|y[e+205|0]<<24))+d|0,x[ja>>2]=ka;break H}g=N()|0;break f}g=N()|0;break f}if(f){continue}}d=i+484414|0;m=d;g=z[d>>1]&65529;d=y[e+193|0];w[m>>1]=g|d<<1&2|d>>>1&4;if(!(d&4)){continue}w[i+484412>>1]=0;continue}}L:{d=$b(x[e+524>>2]);if(!d){break L}if(!Cb(z[e+528>>1])){break L}x[31785]=0;i=P(152,b|0,d|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break F}if(!i){break L}ja=e,ka=Cb(z[e+528>>1]),w[ja+188>>1]=ka;w[e+128>>1]=y[e+867|0];A=z[Mc(e+188|0,e+128|0)>>1];j=Cb(z[e+530>>1]);f=0;M:while(1){if((f|0)==(A|0)){break L}x[31785]=0;S(534,b|0,e+188|0,j|0);d=x[31785];x[31785]=0;if((d|0)==1){break t}d=e+88|0;k_(d,e+188|0);x[31785]=0;O(221,e+128|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break u}f=f+1|0;r=((f<<2)+a|0)+900380|0;i=e+128|0;zc(x[r>>2]+492|0,i);tb(i);d=x[r>>2];x[31785]=0;O(393,i|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break v}ja=e,ka=Yi(x[e+128>>2]),x[ja+88>>2]=ka;h=Jf(e+128|0);while(1){d=x[e+88>>2];if(Ib(d,h)){u=(z[Xo(d)>>1]<<5)+a|0;i=u+946328|0;q=x[r>>2];d=x[q+520>>2];x[i>>2]=x[q+516>>2];x[i+4>>2]=d;i=x[q+512>>2];d=u+946320|0;x[d>>2]=x[q+508>>2];x[d+4>>2]=i;i=x[q+504>>2];d=u+946312|0;x[d>>2]=x[q+500>>2];x[d+4>>2]=i;i=x[q+496>>2];d=u+946304|0;x[d>>2]=x[q+492>>2];x[d+4>>2]=i;Yg(e+88|0);continue}else{Hv(e+128|0);continue M}}}}Zq(a+901404|0);d=pc(e+456|0,4960);qf(Me(a+901692|0,0),x[d>>2],x[d+4>>2]);xc(b);G=c&1;L=a+484344|0;M=a+1298332|0;ha=a+1298308|0;ba=a+484360|0;i=0;while(1){d=i&255;if(d>>>0>=y[fa|0]){break w}x[31785]=0;V(535,b|0,e+892|0,e+504|0,e+584|0);c=x[31785];x[31785]=0;N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((c|0)==1){break W}X:{if(!d){f=0;break X}x[31785]=0;d=R(277,ba|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break W}f=i;if((d|0)==255){break d}}n=Sj(x[ba>>2],f&255);H=lg(e+444|0);gj(n);Y:{t=y[e+891|0];if(t>>>0<=1){d=Cb(z[e+586>>1]);if(d>>>0>256){break y}c=e+188|0;mY(c,e+584|0);x[31785]=0;S(536,n|0,c|0,d|0);c=x[31785];x[31785]=0;if((c|0)==1){break Y}ja=e,ka=vb(x[n>>2]),x[ja+188>>2]=ka;c=vb(x[n+4>>2]);while(1){d=x[e+188>>2];if(Ib(d,c)){w[d>>1]=z[d>>1]+T;Wd(e+188|0);continue}break}Ch(a,1);w[e+188>>1]=16;c=z[Mc(E,e+188|0)>>1];f=0;while(1)if((c|0)==(f|0)){f=32;break O}else{v[e+188|0]=y[(e+f|0)+850|0];v[e+128|0]=64;ja=((f<<5)+a|0)+480286|0,ka=y[Ub(e+188|0,e+128|0)|0],w[ja>>1]=ka;f=f+1|0;continue}}mY(e+188|0,e+584|0);c=Cb(z[e+200>>1]);if(!c|c>>>0>64|z[E>>1]>64){break y}F=$b(x[e+208>>2]);c=Cb(z[e+212>>1]);if(c){w[e+128>>1]=c;w[e+88>>1]=800;q=Bc(((z[Mc(e+128|0,e+88|0)>>1]<<5)+50>>>0)/100|0,0)}else{q=32}c=x[e+196>>2];x[31785]=0;d=P(152,b|0,$b(c)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break V}f=0;Z:{if(!d){break Z}while(1){if(z[E>>1]<=f>>>0){break Z}x[31785]=0;d=R(200,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){v[e+128|0]=d;v[e+88|0]=64;ja=((f<<5)+a|0)+480286|0,ka=y[Ub(e+128|0,e+88|0)|0],w[ja>>1]=ka;f=f+1|0;continue}break}g=N()|0;break z}_:{$:{c=$b(x[e+204>>2]);if(!c){break $}x[31785]=0;d=P(152,b|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break V}f=0;if(!d){break $}while(1){if(z[E>>1]<=f>>>0){break _}x[31785]=0;d=R(537,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){ja=((f<<5)+a|0)+480284|0,ka=(Xb(d,-16,16)<<3)+128|0,w[ja>>1]=ka;f=f+1|0;continue}break}g=N()|0;break z}Ch(a,1)}o=Nb(e+176|0);c=x[e+192>>2];x[31785]=0;d=P(152,b|0,$b(c)|0)|0;c=x[31785];x[31785]=0;aa:{if((c|0)==1){break aa}g=1;f=0;if(!d){break P}h=z[e+586>>1];d=x[b+8>>2];c=x[b>>2];x[31785]=0;d=U(153,c|0,d|0,Cb(h)<<1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break aa}if(!d){break P}c=z[e+586>>1];x[31785]=0;d=U(538,b|0,o|0,Cb(c)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break aa}if(!d){break P}ja=e,ka=vb(x[o>>2]),x[ja+172>>2]=ka;u=vb(x[e+180>>2]);r=x[e+188>>2];A=z[e+202>>1];while(1){c=x[e+172>>2];if(!Ib(c,u)){g=0;f=1;break P}c=Cb(y[c|0]|y[c+1|0]<<8);ba:{if(Cb(A)>>>0<c>>>0){break ba}x[31785]=0;P(152,b|0,$b(r)+(c<<2)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break U}x[31785]=0;d=R(284,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break U}x[31785]=0;d=P(152,b|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break U}if(!d){break ba}d=x[b+8>>2];c=x[b>>2];x[31785]=0;d=U(153,c|0,d|0,42)|0;c=x[31785];x[31785]=0;if((c|0)==1){break U}if(!d){break ba}x[31785]=0;O(539,b|0,e+128|0);c=x[31785];x[31785]=0;ca:{if((c|0)!=1){if(mc(x[n>>2],x[n+4>>2])){break ca}x[31785]=0;O(540,n|0,65534);c=x[31785];x[31785]=0;if((c|0)!=1){break ca}}g=N()|0;break Q}f=Cb(y[e+168|0]|y[e+169|0]<<8);x[e+124>>2]=f;d=x[b+8>>2];c=x[b>>2];x[31785]=0;d=U(153,c|0,d|0,f|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break T}if(!d){x[31785]=0;d=R(205,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break T}vc(e+124|0,d)}vc(e+124|0,65534);d=x[n+4>>2];c=x[n>>2];f=0;x[31785]=0;j=x[e+124>>2];h=Xc(c,d);O(541,n|0,j+h|0);c=x[31785];x[31785]=0;if((c|0)==1){break R}while(1){da:{if((f|0)==(j|0)){if(y[e+128|0]){zn(e+88|0,e+128|0);x[31785]=0;S(542,e+112|0,x[e+88>>2],x[e+92>>2]);c=x[31785];x[31785]=0;if((c|0)==1){break S}c=e+112|0;gp(n,c);tb(c)}c=$b(y[e+160|0]|y[e+161|0]<<8|(y[e+162|0]<<16|y[e+163|0]<<24));if(!c){break ba}x[31785]=0;d=P(152,b|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break da}break R}x[31785]=0;d=R(276,b|0)|0;c=x[31785];x[31785]=0;ea:{if((c|0)!=1){c=d<<16>>16;if((c|0)<0){break ea}x[31785]=0;O(540,n|0,c+T&65535);c=x[31785];x[31785]=0;if((c|0)!=1){break ea}}g=N()|0;break Q}f=f+1|0;continue}break}if(!d){break ba}fa:{while(1){ga:{x[31785]=0;d=P(543,b|0,e+108|0)|0;c=x[31785];x[31785]=0;ha:{ia:{ja:{ka:{if((c|0)!=1){if(!d){break ba}x[31785]=0;S(188,e+68|0,b|0,y[e+111|0]);c=x[31785];x[31785]=0;if((c|0)==1){break ka}c=e+68|0;j=ic(e+88|0,c);ub(c);c=Cb(z[e+108>>1]);f=cm(c+h|0);w[e+68>>1]=f;if((c|0)==65535){break fa}g=x[n>>2];if(Xc(g,x[n+4>>2])>>>0<=f>>>0){break fa}m=65535;switch(y[e+110|0]-1|0){case 0:break ia;case 1:break ja;default:break ha}}g=N()|0;break Q}g=N()|0;break Q}x[31785]=0;f=R(276,j|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ga}x[31785]=0;d=P(544,H|0,e+68|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ga}w[d>>1]=f;g=x[n>>2];m=65534;f=z[e+68>>1]}ja=_b(g,f),ka=m,w[ja>>1]=ka}ub(j);continue}break}g=N()|0;ub(j);break Q}ub(j)}Wd(e+172|0);continue}}g=N()|0;break Q}g=N()|0;break z}g=N()|0;break f}g=N()|0;break z}g=N()|0;break Q}g=N()|0;break Q}g=N()|0;break Q}g=N()|0}kd(o);break z}kd(o);if(f){f=q>>>(F>>>1&1)|0;break O}vv(H);if(!g){break d}break N}d=Cb(z[e+844>>1]);h=y[e+847|0];s=h&64;c=y[e+848|0];ca=c&32;Z=(c&31)+1|0;ja=a,ka=jY(d,s>>>6|0,ca>>>5|0,Z),x[ja+480204>>2]=ka;ja=a,ka=Hd(y[e+849|0],1,32),x[ja+480196>>2]=ka;if(ca){x[a+480216>>2]=Z;x[a+480220>>2]=Z<<2}c=y[e+866|0];if(c){v[e+188|0]=c;v[e+128|0]=64;ja=a,ka=y[Ub(e+188|0,e+128|0)|0]<<2,x[ja+480200>>2]=ka}x[a+480228>>2]=f;x[a+480232>>2]=f;x[a+480208>>2]=x[a+480208>>2]&-3|(h^-1)>>>4&2;la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{c=$b(x[e+548>>2]);va:{if(!c){break va}x[31785]=0;d=P(152,b|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ua}if(!d){break va}c=x[e+552>>2];x[31785]=0;S(273,b|0,ha|0,$b(c)|0);c=x[31785];x[31785]=0;if((c|0)==1){break ua}if(y[fa|0]<2){break va}x[31785]=0;S(261,e+56|0,28,ha|0);c=x[31785];x[31785]=0;if((c|0)==1){break ua}c=e+56|0;gp(n,c);tb(c)}wa:{if($b(x[e+520>>2])>>>0<2){break wa}c=x[e+516>>2];x[31785]=0;d=P(152,b|0,$b(c)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ua}if(!d){break wa}c=x[e+520>>2];x[31785]=0;V(339,M|0,b|0,$b(c)-1|0,4);c=x[31785];x[31785]=0;if((c|0)==1){break ua}}c=$b(x[e+560>>2]);if(!c){break la}x[31785]=0;d=P(152,b|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ua}if(!d){break la}d=x[b+8>>2];c=x[b>>2];x[31785]=0;d=U(153,c|0,d|0,12)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ua}if(!d){break la}x[31785]=0;P(186,b|0,6)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ua}x[31785]=0;d=R(276,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ua}if((d|0)!=1){break la}x[31785]=0;j=R(284,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break sa}if(!j){break la}d=x[b+8>>2];c=x[b>>2];x[31785]=0;d=U(153,c|0,d|0,j|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break sa}if(d){break ta}break la}g=N()|0;break z}f=DG(e+188|0,M);x[31785]=0;V(339,M|0,b|0,j|0,4);c=x[31785];x[31785]=0;if((c|0)==1){break na}if(!yd(x[e+192>>2],y[e+199|0])){x[31785]=0;d=U(545,e+32|0,2,13)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ra}x[31785]=0;S(546,e+128|0,f|0,d|0);c=x[31785];x[31785]=0;if((c|0)==1){break qa}x[31785]=0;S(547,e+44|0,e+128|0,M|0);c=x[31785];x[31785]=0;if((c|0)==1){break pa}c=e+44|0;yb(M,c);tb(c);tb(e+128|0);tb(d)}tb(f);break la}g=N()|0;break z}g=N()|0;break ma}g=N()|0;break oa}g=N()|0;tb(e+128|0)}tb(d);break ma}g=N()|0}tb(f);break z}xa:{if(t>>>0<2){break xa}g=0;if(!$b(x[e+572>>2])){break xa}while(1){if(z[E>>1]<=g>>>0){break xa}c=x[e+572>>2];x[31785]=0;d=P(152,b|0,$b(c)+(g<<2)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break A}ya:{if(!d){break ya}x[31785]=0;d=R(284,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break A}x[31785]=0;d=P(152,b|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break A}m=0;f=0;if(!d){break ya}while(1){za:{d=x[b+8>>2];c=x[b>>2];x[31785]=0;d=U(153,c|0,d|0,8)|0;c=x[31785];x[31785]=0;Aa:{Ba:{Ca:{if((c|0)!=1){if(!d){break za}x[31785]=0;O(548,b|0,e+188|0);c=x[31785];x[31785]=0;if((c|0)==1){break Ca}c=$b(x[e+188>>2]);if(!c){break za}switch((c&536870911)-1|0){case 1:break Aa;case 0:break Ba;default:continue}}g=N()|0;break z}g=N()|0;break z}m=$b(x[e+192>>2]);continue}f=$b(x[e+192>>2]);continue}break}if(!m|!f){break ya}x[31785]=0;d=P(152,b|0,m|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break B}if(!d){break ya}x[31785]=0;S(428,b|0,((g<<5)+a|0)+480289|0,f|0);c=x[31785];x[31785]=0;if((c|0)==1){break B}}g=g+1|0;continue}}c=z[e+584>>1];x[31785]=0;K=Cb(c);O(226,L|0,K+T&65535);c=x[31785];x[31785]=0;if((c|0)==1){break C}B=h&16;o=T&65535;W=0;Da:{Ea:{while(1){if((K|0)==(W|0)){ja=e,ka=Yi(x[H>>2]),x[ja+128>>2]=ka;d=Jf(H);while(1){c=x[e+128>>2];if(!Vg(c,d)){g=1;c=$b(x[e+504>>2]);if(!c){break x}x[31785]=0;d=P(152,b|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break C}if(!d){break x}T=T+K|0;vv(H);break N}j=Xo(c);h=Ze(j);Fa:{Ga:{Ha:{Ia:{f=z[j>>1];if(!f){f=0;break Ia}c=f-1&65535;if(!$i(n,c)){break Ia}x[31785]=0;f=P(371,n|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Fa}break Ha}if(z[h>>1]==(f+1|0)){break Ga}x[31785]=0;f=P(370,L|0,1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Fa}if((f|0)==65535){break Ga}ja=_b(x[n>>2],z[j>>1]),ka=f,w[ja>>1]=ka}c=Vb(x[L>>2],f);we(c,qn(Ue(Le(e+188|0,12,Rv(z[h>>1])),x[c+12>>2]-1|0)));K=(K&65535)>>>0>f>>>0?K:f+1|0}Yg(e+128|0);continue}break}g=N()|0;break z}Ja:{Ka:{if(!G){break Ka}c=y[e+908|0]|y[e+909|0]<<8|(y[e+910|0]<<16|y[e+911|0]<<24);x[31785]=0;d=P(152,b|0,$b(c)+(W<<2)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Ea}if(!d){break Ka}x[31785]=0;d=R(284,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Ea}x[31785]=0;d=P(152,b|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Ea}if(!d){break Ka}_=Fb(e+68|0);x[31785]=0;j=v[e+846|0];$=R(171,e+12|0)|0;c=x[31785];x[31785]=0;La:{Ma:{if((c|0)!=1){C=j+48|0;da=y[e+891|0];if(da){break Ma}x[31785]=0;O(549,b|0,e+188|0);c=x[31785];x[31785]=0;if((c|0)==1){break Ja}w[e+172>>1]=y[e+188|0];X=y[e+189|0]+1|0;break La}g=N()|0;break D}x[31785]=0;O(550,b|0,e+176|0);c=x[31785];x[31785]=0;Na:{Oa:{if((c|0)!=1){h=Cb(z[e+176>>1]);w[e+172>>1]=h;X=Cb(z[e+178>>1])+1|0;c=$b(z[e+180>>1]|z[e+182>>1]<<16);if(!c){break Na}f=x[b+8>>2];x[31785]=0;P(152,b|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break E}x[31785]=0;O(551,b|0,e+188|0);c=x[31785];x[31785]=0;if((c|0)==1){break E}c=y[e+192|0]|y[e+193|0]<<8|(y[e+194|0]<<16|y[e+195|0]<<24);x[31785]=0;d=P(152,b|0,$b(c)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break E}if(!d){break Oa}c=y[e+196|0]|y[e+197|0]<<8|(y[e+198|0]<<16|y[e+199|0]<<24);x[31785]=0;S(273,b|0,_|0,$b(c)|0);c=x[31785];x[31785]=0;if((c|0)!=1){break Oa}break E}break E}c=$b(y[e+204|0]|y[e+205|0]<<8|(y[e+206|0]<<16|y[e+207|0]<<24));Pa:{if(!c){break Pa}x[31785]=0;d=P(152,b|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break E}if(!d){break Pa}x[31785]=0;d=R(284,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break E}x[31785]=0;d=P(152,b|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break E}if(!d){break Pa}x[31785]=0;S(188,e+88|0,b|0,D(h,X)|0);c=x[31785];x[31785]=0;if((c|0)==1){break E}d=e+88|0;c=ic(e+128|0,d);hd($,c);ub(c);ub(d)}x[31785]=0;P(152,b|0,f|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break E}}C=da>>>0>2?j+24|0:C}x[31785]=0;f=o+W|0;d=U(199,L|0,f&65535,X|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break E}Qa:{if(!d){break Qa}c=x[L>>2];x[31785]=0;I=Vb(c,f);O(286,I|0,_|0);c=x[31785];x[31785]=0;if((c|0)==1){break Da}Pf(e+172|0,z[E>>1]);t=X-1|0;c=0;F=z[e+172>>1];Ra:while(1){if((c|0)==(X|0)){break Qa}d=c+1|0;q=c-1|0;g=0;f=gd(x[I>>2],x[x[I+48>>2]+12>>2],c,0);while(1){ea=g&65535;if(F>>>0<=ea>>>0){c=d;continue Ra}fD(e+128|0,y[f+3|0],f+5|0);Sa:{if(!da){x[31785]=0;O(552,e+188|0,b|0);h=x[31785];x[31785]=0;if((h|0)!=1){r=y[e+188|0];A=e+188|0;h=Ic(A);v[f+1|0]=r>>>3&16|y[h|0]>>>4|r>>>1&32;j=y[h|0];ja=f,ka=y[Ze(A)|0],v[ja+5|0]=ka;h=r&63;k=h?h+C|0:0;m=j&15;break Sa}break E}x[31785]=0;O(360,e+188|0,b|0);h=x[31785];x[31785]=0;Ta:{Ua:{if((h|0)!=1){h=e+188|0;u=Ic(h);r=Ze(h);A=cj(h);x[31785]=0;j=R(200,$|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break E}v[f+4|0]=j;j=y[e+188|0];h=j&127;if(!h){break Ua}k=h+C|0;break Ta}break E}k=0;if((j|0)!=128){break Ta}v[f|0]=254}v[f+1|0]=y[u|0]&63;m=y[r|0];v[f+5|0]=y[A|0]}if(k-1>>>0<=119){v[f|0]=k}r=(k|0)>84;k=e+188|0;A=(s|0)!=0;j=(ca|0)!=0;h=(B|0)!=0;l=fb-16|0;fb=l;v[f+3|0]=0;Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{u=m&255;switch(u-4|0){case 4:case 10:break Wa;case 42:break Ya;case 37:break Za;case 28:break _a;case 27:break $a;case 26:break ab;case 25:break bb;case 24:break cb;case 23:break db;case 22:break eb;case 21:break fb;case 20:break gb;case 18:break hb;case 17:break ib;case 16:break jb;case 14:break kb;case 13:break lb;case 12:break mb;case 11:break nb;case 9:break ob;case 8:break pb;case 5:break qb;case 0:break rb;default:break Xa}}v[f+3|0]=5;j=y[f+5|0];v[l+15|0]=j>>>3;v[l+14|0]=15;h=y[Ub(l+15|0,l+14|0)|0];v[l+13|0]=j<<1&30;v[l+12|0]=15;ja=f,ka=y[Ub(l+13|0,l+12|0)|0]|h<<4,v[ja+5|0]=ka;break Wa}if((y[f+5|0]-1&255)>>>0>19){break Wa}v[f+3|0]=16;break Wa}v[f+3|0]=13;j=y[f+5|0];sb:{if(!h){if(j>>>0>152){break sb}v[f+5|0]=D((j&240)>>>4|0,10)+(j&15);break Wa}v[f+5|0]=(j&127)+1>>>1;break Wa}v[f+3|0]=0;break Wa}v[f+3|0]=11;break Wa}h=y[f+5|0];if(!h){v[f+3|0]=14;break Wa}if(h>>>0>240){break Wa}v[f+3|0]=17;if(h>>>0<=2){v[f+5|0]=112;break Wa}h=sD(+(jY(h,A,j,Z)>>>0)/1e4);if(h>>>0<=255){v[f+5|0]=h;break Wa}v[f+5|0]=h>>>8;v[l+11|0]=h;ae(k,34,l+11|0);break Va}v[f+3|0]=31;v[f+5|0]=y[f+5|0]|128;break Wa}v[f+3|0]=19;v[l+10|0]=15;ja=f,ka=y[Ub(f+5|0,l+10|0)|0]|16,v[ja+5|0]=ka;break Wa}v[f+3|0]=19;v[l+9|0]=15;ja=f,ka=y[Ub(f+5|0,l+9|0)|0]|32,v[ja+5|0]=ka;break Wa}v[f+3|0]=5;h=y[f+5|0];v[l+8|0]=(h>>>4|0)+1;v[l+7|0]=15;ja=f,ka=h&15|y[Ub(l+8|0,l+7|0)|0]<<4,v[ja+5|0]=ka;break Wa}v[f+3|0]=19;v[f+5|0]=y[f+5|0]&15|80;break Wa}v[f+3|0]=19;v[l+6|0]=15;ja=f,ka=y[Ub(f+5|0,l+6|0)|0]|96,v[ja+5|0]=ka;break Wa}v[f+3|0]=19;v[l+5|0]=15;ja=f,ka=y[Ub(f+5|0,l+5|0)|0]|192,v[ja+5|0]=ka;break Wa}v[f+3|0]=10;break Wa}v[f+3|0]=19;v[l+4|0]=15;ja=f,ka=y[Ub(f+5|0,l+4|0)|0]|160,v[ja+5|0]=ka;break Wa}v[f+3|0]=19;v[l+3|0]=15;ja=f,ka=y[Ub(f+5|0,l+3|0)|0]|176,v[ja+5|0]=ka;break Wa}h=y[f+5|0]-1<<24>>24;if((h|0)<0){break Wa}v[f+5|0]=h;v[f+3|0]=31;break Wa}v[f+3|0]=14;break Wa}v[f+3|0]=19;v[l+2|0]=15;ja=f,ka=y[Ub(f+5|0,l+2|0)|0]|224,v[ja+5|0]=ka;break Wa}h=y[f+5|0];if(h>>>0>=16){v[f+3|0]=19;v[f+5|0]=h>>>4|208;break Wa}if(!h){break Wa}v[f+3|0]=19;v[f+5|0]=h|144;break Wa}if(y[f+5|0]|y[f+4|0]){break Wa}if(!zd(y[f|0])){break Wa}v[f+5|0]=159;v[f+3|0]=20;break Wa}h=y[f+4|0];if(!h){break Wa}v[f+3|0]=44;ja=f,ka=ej(Bc(((y[f+5|0]<<8&65280)>>>0)/(h>>>0)|0,0)),v[ja+5|0]=ka;break Wa}h=y[f+5|0];if((h+16&255)>>>0>32){break Wa}v[f+3|0]=9;ja=f,ka=Zg(((h^128)<<3)-896|0),v[ja+5|0]=ka;break Wa}if(u>>>0>15){break Wa}Mf(f,u,y[f+5|0])}v[l+1|0]=0;fD(k,0,l+1|0)}fb=l+16|0;tb:{if(y[e+128|0]!=34){break tb}if(!y[f+3|0]){h=z[e+128>>1];v[f+3|0]=h;v[f+5|0]=h>>>8;break tb}if(!c){break tb}ja=gd(x[I>>2],x[x[I+48>>2]+12>>2],q,ea),ka=255,v[ja+5|0]=ka}A=r&ga;ub:{if(!y[e+188|0]){break ub}if(c>>>0<t>>>0){j=gd(x[I>>2],x[x[I+48>>2]+12>>2],d,ea);h=z[e+188>>1];v[j+3|0]=h;v[j+5|0]=h>>>8;break ub}v[f+5|0]=255}J=A|J;f=f+6|0;g=g+1|0;continue}}}ub($);tb(_)}W=W+1|0;continue}break}break E}g=N()|0;break z}break E}i=i+1|0;continue}}g=N()|0;break f}g=N()|0;ub($)}tb(_);break z}g=N()|0;break z}g=N()|0;break z}g=N()|0}vv(H);break f}g=0}vv(H);f=0;if(!g){break c}}ak(ba,0);f=1;vb:{if(J&1){break vb}while(1){b=f&65535;if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=0;break vb}c=((b<<2)+a|0)+900380|0;b=x[c>>2];if(b){Db(xv(b))}x[c>>2]=0;f=f+1|0;continue}}wb:{if(!ia){break wb}x[31785]=0;c=P(1,e+188|0,16577)|0;b=x[31785];x[31785]=0;xb:{if((b|0)!=1){b=x[a+1298472>>2];x[31785]=0;S(389,b|0,2,c|0);b=x[31785];x[31785]=0;if((b|0)==1){break xb}tb(c);break wb}g=N()|0;break f}g=N()|0;tb(c);break f}k=22485;yb:{zb:{switch(y[e+891|0]){case 0:k=z[E>>1]>4?17488:17474;break yb;case 1:k=17456;break yb;case 2:k=17438;break yb;case 3:break zb;default:break yb}}k=17411}x[31785]=0;O(553,e+88|0,17010);b=x[31785];x[31785]=0;Ab:{Bb:{Cb:{if((b|0)!=1){x[31785]=0;S(554,e+128|0,e+88|0,e+891|0);b=x[31785];x[31785]=0;if((b|0)==1){break Cb}b=e+128|0;yb(a+1298344|0,b);tb(b);Eb(e+88|0);x[31785]=0;c=P(1,b|0,12727)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Bb}yb(a+1298356|0,c);tb(c);x[31785]=0;O(133,a+1298368|0,k|0);b=x[31785];x[31785]=0;if((b|0)==1){break Ab}ja=a+1298404|0,ka=x[Gc(e+88|0,28)>>2],x[ja>>2]=ka;f=1;break c}g=N()|0;break f}g=N()|0;Eb(e+88|0);break f}g=N()|0;break f}g=N()|0;break f}g=N()|0;break f}g=N()|0;break f}g=N()|0;break f}C=1;if((d|0)!=7){break m}f=k+108|0;d=zC(f);while(1){if((d|0)!=(f|0)){ja=f,ka=bm(y[f|0]-24|0),v[ja|0]=ka;f=f+1|0;continue}break}m=0}J=1;break l}m=0;Db:{if(F|(o|0)<0){break Db}j=k+108|0;g=7;Eb:while(1){if((g|0)==10){break Db}h=D(g,12);i=D(g,-12)+72|0;f=0;while(1)if((f|0)==12){g=g+1|0;continue Eb}else{d=xb(j,f+h|0);v[d|0]=i+y[d|0];f=f+1|0;continue}}}}x[31785]=0;O(555,aa|0,e+188|0);d=x[31785];x[31785]=0;if((d|0)!=1){Fb:{d=y[e+192|0];if((d-1&255)>>>0<=15){v[k+31|0]=d;J=1}d=y[e+193|0];if(d-1<<24>>24>=0){v[k+30|0]=d}f=0;Gb:{while(1){if((f|0)==(C|0)){if(!q){break j}if((o|0)>=0){break Gb}break j}x[31785]=0;i=D(f+t|0,104)+a|0;O(282,i+484380|0,8);d=x[31785];x[31785]=0;if((d|0)!=1){v[e+128|0]=y[e+194|0];v[e+68|0]=64;ja=i+484410|0,ka=y[Ub(e+128|0,e+68|0)|0]<<2,w[ja>>1]=ka;v[i+484416|0]=y[e+195|0];f=f+1|0;continue}break}break k}j=ad(e+128|0,8,1,1,0);i=Cb(z[e+190>>1]);g=Cb(z[e+188>>1]);d=x[G>>2];x[31785]=0;k=R(157,d|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){d=ve(w[e+92>>1]);if(d&16){ed(j,16);k=k>>>1|0}if(d&32){mp(j,3);k=k>>>1|0}if(d&64){ug(j,2)}k=m?(k>>>0)/((-1<<C^-1)>>>0)|0:k;m=g+i|0;f=0;while(1){if((f|0)==(C|0)){break j}h=D(f+t|0,104)+a|0;d=h+484380|0;x[d>>2]=k;x[31785]=0;U(218,j|0,d|0,G|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break Fb}g=g<<1;m=m<<1;if(i>>>0>=2){x[h+484388>>2]=m;x[h+484384>>2]=g;d=h+484414|0;w[d>>1]=z[d>>1]|2}f=f+1|0;k=k<<1;continue}}}}}g=N()|0;ub(G);break f}ub(G);B=B+1|0;s=s+C|0;k=z[a+480192>>1];continue}}g=N()|0;break e}g=N()|0;break e}g=N()|0}sc(Y)}ub(aa);Q(g|0);p()}f=0}sc(Y)}ub(aa)}fb=e+944|0;return f|0}function joa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,C=E(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ca=0,da=0,ea=E(0),fa=0,ga=0,ia=0,ja=0,ka=0,la=0;e=fb-608|0;fb=e;xc(b);a:{b:{c:{if(!yi(b,e+600|0)){break c}if(!aW(e+600|0)){break c}if((fp(b)|0)>=0){break c}if(!c){d=1;break c}Bd(a,16777216);d=a+480208|0;x[d>>2]=x[d>>2]|1681e4;cr(e+256|0,32);f=x[e+268>>2];d=a+1074320|0;x[d>>2]=x[e+264>>2];x[d+4>>2]=f;d=x[e+260>>2];x[a+1074312>>2]=x[e+256>>2];x[a+1074316>>2]=d;Yf(a+1074312|0,38);q=Nb(e+588|0);r=Nb(e+576|0);u=Nb(e+564|0);l=Nb(e+552|0);Eh(b,4);i=a+480190|0;K=c&1;J=a+1298332|0;s=2500;I=!(c&2);G=a+1298472|0;d:{e:{f:{while(1){c=x[b+8>>2];d=x[b>>2];x[31785]=0;c=U(153,d|0,c|0,4)|0;d=x[31785];x[31785]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){x[31785]=0;c=R(715,b|0)|0;d=x[31785];x[31785]=0;o:{if((d|0)==1){break o}m=4;d=0;p:{q:{r:{switch(c+21|0){case 20:x[31785]=0;c=R(284,b|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){d=c&65535;if(z[a+480188>>1]|d-1>>>0>126){continue}w[a+480188>>1]=c;ka=a,la=Xb(512/(d>>>0)|0,16,128),x[ka+480228>>2]=la;continue}c=N()|0;break a;case 19:x[31785]=0;M=R(284,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break o}if(M>>>0<=1024){continue}break m;case 16:x[31785]=0;c=R(284,b|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){if((c&65535)==4){continue}break m}c=N()|0;break a;case 15:x[31785]=0;c=R(284,b|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){x[e+256>>2]=c;x[e+152>>2]=800;ka=a,la=Xe(+A[Gb(e+256|0,e+152|0)>>2]*1.24*1e4),x[ka+480204>>2]=la;continue}c=N()|0;break a;case 31:x[31785]=0;c=R(284,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break o}Z=1;s=Hd(c,0,1e4);continue;case 32:case 33:x[31785]=0;c=R(284,b|0)|0;d=x[31785];x[31785]=0;s:{t:{if((d|0)!=1){Z=1;if(!c){continue}x[31785]=0;d=P(1,e+540|0,12636)|0;c=x[31785];x[31785]=0;if((c|0)==1){break t}c=x[G>>2];x[31785]=0;S(389,c|0,2,d|0);c=x[31785];x[31785]=0;if((c|0)==1){break s}tb(d);continue}c=N()|0;break a}c=N()|0;break a}c=N()|0;tb(d);break a;case 14:x[31785]=0;P(186,b|0,4)|0;c=x[31785];x[31785]=0;if((c|0)==1){break o}g=!z[i>>1]|g;continue;case 11:if(!K){break q}if(!mc(x[q>>2],x[q+4>>2])){break q}x[31785]=0;O(716,e+256|0,b|0);c=x[31785];x[31785]=0;if((c|0)!=1){if(x[q>>2]){IX(q);c=x[q>>2];Po(q);Db(c);ka=Ab(q),la=0,x[ka>>2]=la;x[q>>2]=0;x[q+4>>2]=0}c=e+256|0;x[q>>2]=x[c>>2];x[q+4>>2]=x[c+4>>2];d=Ab(c);ka=Ab(q),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Ui(c);continue}c=N()|0;break a;case 3:case 4:case 10:f=Ph(x[l>>2],x[l+4>>2]);d=z[i>>1];if(f>>>0<=d>>>0){continue}if((g|I)&1){break q}if(!si(d)){break q}d=d+1|0;w[i>>1]=d;t=Nb(e+528|0);x[31785]=0;k=R(171,e+508|0)|0;g=x[31785];x[31785]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}x[31785]=0;c=R(284,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break u}x[31785]=0;S(188,e+152|0,b|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break u}c=e+152|0;g=ic(e+256|0,c);hd(k,g);ub(g);break g}c=N()|0;break d}x[31785]=0;O(717,e+256|0,b|0);c=x[31785];x[31785]=0;x:{if((c|0)!=1){c=e+256|0;g=pn(t,c);dc(c);le(e+480|0,x[g>>2],x[e+532>>2]);c=Jd(e+472|0);x[31785]=0;g=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=g;c=dg(330,e+488|0,x[e+480>>2],x[e+484>>2],e+16|0);g=x[31785];x[31785]=0;if((g|0)==1){break x}hd(k,c);break g}c=N()|0;break e}c=N()|0;break e}x[31785]=0;O(718,e+256|0,b|0);c=x[31785];x[31785]=0;y:{if((c|0)!=1){c=e+256|0;g=pn(t,c);dc(c);le(e+440|0,x[g>>2],x[e+532>>2]);c=Jd(e+432|0);x[31785]=0;g=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=g;c=dg(330,e+452|0,x[e+440>>2],x[e+444>>2],e+8|0);g=x[31785];x[31785]=0;if((g|0)==1){break y}hd(k,c);break g}c=N()|0;break e}c=N()|0;break e}c=N()|0;break e;case 9:c=z[i>>1];if(!si(c)){continue}w[i>>1]=c+1;continue;case 8:if(!K){break q}if(!mc(x[u>>2],x[u+4>>2])){break q}x[31785]=0;O(719,e+256|0,b|0);c=x[31785];x[31785]=0;if((c|0)!=1){c=e+256|0;$V(u,c);sc(c);continue}c=N()|0;break a;case 7:if(!mc(x[l>>2],x[l+4>>2])){break q}x[31785]=0;O(720,e+256|0,b|0);c=x[31785];x[31785]=0;if((c|0)!=1){if(x[l>>2]){vV(l);c=x[l>>2];_B(l);Db(c);ka=Ab(l),la=0,x[ka>>2]=la;x[l>>2]=0;x[l+4>>2]=0}c=e+256|0;x[l>>2]=x[c>>2];x[l+4>>2]=x[c+4>>2];d=Ab(c);ka=Ab(l),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;cv(c);continue}c=N()|0;break a;case 6:if(!K){break q}if(!mc(x[r>>2],x[r+4>>2])){break q}x[31785]=0;O(721,e+256|0,b|0);c=x[31785];x[31785]=0;if((c|0)!=1){if(x[r>>2]){AV(r);c=x[r>>2];Su(r);Db(c);ka=Ab(r),la=0,x[ka>>2]=la;x[r>>2]=0;x[r+4>>2]=0}c=e+256|0;x[r>>2]=x[c>>2];x[r+4>>2]=x[c+4>>2];d=Ab(c);ka=Ab(r),la=x[d>>2],x[ka>>2]=la;x[d>>2]=0;x[c>>2]=0;x[c+4>>2]=0;cn(c);continue}c=N()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}x[31785]=0;O(722,e+256|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break n}z:{c=x[e+256>>2];d=x[e+260>>2];if(mc(c,d)){break z}x[31785]=0;V(346,J|0,c|0,Sc(c,d)|0,1);c=x[31785];x[31785]=0;if((c|0)!=1){break z}c=N()|0;dc(e+256|0);break a}dc(e+256|0);continue}x[31785]=0;m=R(284,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break o}}x[31785]=0;P(186,b|0,m|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){continue}}c=N()|0;break a}d=0;if(!z[a+480188>>1]|!M){break m}b=x[l>>2];c=x[l+4>>2];if(mc(b,c)){break m}if(K){if(mc(x[q>>2],x[q+4>>2])){break m}if(mc(x[u>>2],x[u+4>>2])){break m}if(mc(x[r>>2],x[r+4>>2])){break m}}b=Ph(b,c);if(b>>>0>=256){x[31785]=0;O(723,l|0,255);b=x[31785];x[31785]=0;if((b|0)==1){break b}b=Ph(x[l>>2],x[l+4>>2])}w[a+480192>>1]=b;m=a+480190|0;n=a+480192|0;ka=m,la=z[se(i,n)>>1],w[ka>>1]=la;if(g&1){x[31785]=0;b=P(1,e+528|0,16666)|0;c=x[31785];x[31785]=0;if((c|0)==1){break h}c=x[a+1298472>>2];x[31785]=0;S(389,c|0,2,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break i}tb(b)}g=0;A:while(1){if((g|0)!=2){d=1;while(1){h=d&65535;if(h>>>0>z[n>>1]){g=g+1|0;continue A}B:{f=an(x[l>>2],h-1|0);if(!y[f|0]|y[f+128|0]<<24>>24<0){break B}if((_u(f)|0)==((g|0)!=1|0)){break B}C:{D:{E:{c=0;F:{if(!_u(f)){break F}if(Cb(y[f+6|0]|y[f+7|0]<<8)){break F}if(Cb(y[f+14|0]|y[f+15|0]<<8)>>>0>20){break F}c=(Cb(y[f+18|0]|y[f+19|0]<<8)|0)==4}G:{H:{if(c){c=y[f+23|0];b=y[f+140|0];x[31785]=0;b=ha(724,f|0,a|0,(b&2)>>>1|0,(D(h,104)+a|0)+484380|0,s&65535)|0;k=x[31785];x[31785]=0;I:{J:{if((k|0)!=1){if(!b){break I}x[31785]=0;b=P(37,e+384|0,10765)|0;k=x[31785];x[31785]=0;if((k|0)==1){break J}zc(((h<<5)+a|0)+946304|0,b);tb(b);k=x[l>>2];b=d;if(Ph(k,x[l+4>>2])>>>0<=c>>>0){break G}ka=f,la=y[f+143|0]+y[an(k,c)+143|0]|0,v[ka+143|0]=la;break H}c=N()|0;break a}c=N()|0;break a}b=c+1|0;break G}c=0;K:{if(!_u(f)){break K}if((Cb(y[f+6|0]|y[f+7|0]<<8)|0)!=1){break K}if((Cb(y[f+14|0]|y[f+15|0]<<8)|0)!=2){break K}c=(Cb(y[f+18|0]|y[f+19|0]<<8)|0)==10}b=d;if(!c){break G}QV(e+256|0,f);b=Cb(y[e+276|0]|y[e+277|0]<<8);if(b>>>0>=z[i>>1]){break H}x[31785]=0;c=R(713,e+152|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break E}k=y[e+292|0]|y[e+293|0]<<8;o=z[m>>1];x[31785]=0;t=D(b,104);b=a+484380|0;k=Cb(k);b=ba(725,e+256|0,(t+b|0)+104|0,(k>>>0<o>>>0?(b+D(k,104)|0)+104|0:c)|0,b+D(h,104)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break D}if(!b){break H}x[31785]=0;b=P(37,e+140|0,11274)|0;c=x[31785];x[31785]=0;if((c|0)==1){break C}zc(((h<<5)+a|0)+946304|0,b);tb(b);v[f+139|0]=y[f+139|0]+12}b=d}x[31785]=0;b=b&65535;c=U(254,a|0,h|0,b|0)|0;h=x[31785];x[31785]=0;if((h|0)!=1){if(!c|b>>>0>z[i>>1]){break B}x[31785]=0;V(726,f|0,c|0,(D(b,104)+a|0)+484380|0,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){break B}}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}c=N()|0;break a}d=d+1|0;continue}}break}J=lg(e+128|0);t=lg(e+116|0);b=oc(x[u>>2],x[u+4>>2]);_=D(z[a+480188>>1],M);$=cm((b>>>0)/(_>>>0)|0);x[31785]=0;X=a+484344|0;O(226,X|0,$|0);b=x[31785];x[31785]=0;if((b|0)==1){break k}aa=a+484376|0;gj(Wb(x[a+484360>>2],y[aa|0]));b=z[a+480188>>1];x[31785]=0;G=P(727,e+104|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}ka=e,la=vb(x[r>>2]),x[ka+52>>2]=la;fa=a+902204|0;ga=vb(x[r+4>>2]);ia=a+480208|0;while(1){L:{M:{N:{k=x[e+52>>2];if(!Ib(k,ga)){break N}b=ve((y[k+6|0]|y[k+7|0]<<8)<<16>>16);if((b|0)==1){break L}if((b&65535)==65535){break N}g=Cb(y[k|0]|y[k+1|0]<<8);b=x[q>>2];f=x[q+4>>2];c=Hg(b,f);if(g>>>0>=c>>>0){break L}d=Cb(y[k+2|0]|y[k+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(Hg(b,f)<<5)|0;x[e+256>>2]=b;x[e+260>>2]=c-b>>5;b=x[e+256>>2];gc(e+76|0,b+(Cb(y[k|0]|y[k+1|0]<<8)<<5)|0,Cb(y[k+2|0]|y[k+3|0]<<8));O:{I=Wb(x[a+484360>>2],y[aa|0]);if(mc(x[I>>2],x[I+4>>2])){break O}x[31785]=0;O(540,I|0,65534);b=x[31785];x[31785]=0;if((b|0)!=1){break O}break M}ka=e,la=vb(x[e+76>>2]),x[ka+40>>2]=la;b=fb-16|0;fb=b;ja=x[zb(b+12|0,x[e+76>>2]+(x[e+80>>2]<<5)|0)>>2];fb=b+16|0;while(1){i=x[e+40>>2];if(!Ib(i,ja)){break L}b=ve(ve((y[k+8|0]|y[k+9|0]<<8)<<16>>16)+ve((y[i+16|0]|y[i+17|0]<<8)<<16>>16)<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8;b=$d(J);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!Uu(i,d)){c=1;if(!Uu(d,i)){break P}b=b+4|0}b=x[b>>2];continue}break}Q:{R:{S:{if(c){x[31785]=0;b=P(728,J|0,i|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break M}F=z[b>>1];break S}F=0;if(!K){break S}b=y[i+12|0]|y[i+13|0]<<8;x[31785]=0;F=P(370,X|0,Cb(b)|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break M}if((F|0)==65535){break L}x[31785]=0;b=P(728,J|0,i|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break M}w[b>>1]=F;if(Cb(y[i+8|0]|y[i+9|0]<<8)>>>0>=$>>>0){break R}if(Cb(y[i+10|0]|y[i+11|0]<<8)>>>0>=M>>>0){break R}n=Cb(y[i+14|0]|y[i+15|0]<<8);c=Ek(vb(x[u>>2]),D(Cb(y[i+8|0]|y[i+9|0]<<8),_));b=z[a+480188>>1];ka=e,la=Ek(c,D(b,Cb(y[i+10|0]|y[i+11|0]<<8))),x[ka+28>>2]=la;T=0;x[e+100>>2]=0;o=Jg(e- -64|0);T:while(1){U:{d=Cb(y[i+12|0]|y[i+13|0]<<8);c=Vb(x[X>>2],F);if(d>>>0<=T>>>0){break U}m=0;Y=gd(x[c>>2],x[x[c+48>>2]+12>>2],T,0);c=0;while(1){if((b&65535)>>>0<=m>>>0){T=T+1|0;continue T}b=vb(x[u+4>>2]);d=x[e+28>>2];h=Ib(d,b)?d:e+100|0;b=vb(x[u+4>>2]);if(Ib(x[e+28>>2],b)){YV(e+28|0)}d=Y+D(m,6)|0;g=y[h+1|0];b=(g>>>0>=85?-1:g+25|0)<<24>>24;s=0;f=x[l>>2];L=Ph(f,x[l+4>>2]);H=y[h+3|0];V:{if(L>>>0<=H>>>0){break V}s=H+1|0;if(v[an(f,H)+142|0]&1|(b|0)<0){break V}b=bm(ve((y[i+16|0]|y[i+17|0]<<8)<<16>>16)+b<<24>>24)}W:{if(!y[d|0]|!(y[h|0]|(g|0)!=255|H|y[h+2|0])){break W}g=y[d+1|0];if(!g|g>>>0>L>>>0){break W}if(y[an(f,g-1|0)+132|0]!=2){break W}No(d)}f=bv(x[G>>2],m);X:{Y:{if(!(c&1)){g=y[h|0];break Y}c=y[o|0]|y[o+1|0]<<8|(y[o+2|0]<<16|y[o+3|0]<<24);v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;c=y[o+4|0]|y[o+5|0]<<8;v[d+4|0]=c;v[d+5|0]=c>>>8;Z:{if(y[d+3|0]){break Z}g=y[f+21|0];c=y[bv(x[G>>2],m-1|0)+21|0];if((g|0)==(c|0)){break Z}v[d+3|0]=21;v[f+21|0]=c;v[d+5|0]=c}c=0;g=y[h|0];if(!(g-24>>>0<2|(g|0)==9|!g&(y[h+2|0]+7&255)>>>0<2)){break X}}_:{$:{aa:{ba:{ca:{da:{switch(g|0){case 5:c=y[f+17|0];break ca;case 0:ea:{c=y[h+2|0];if(c>>>0>=201){g=0;fa:{switch(c-242|0){case 11:v[d+4|0]=1;v[d+2|0]=14;v[f+16|0]=0;break $;case 9:if(!y[d|0]){v[d|0]=y[f+17|0]}v[d+4|0]=1;v[d+2|0]=15;break $;case 8:if((n&255)>>>0<2){break $}n=n-1|0;break aa;case 7:if((n&255)==255){n=255;break $}n=n+1|0;break aa;case 6:v[f+17|0]=b;if(y[f+18|0]!=(s&255)){break $}v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;w[f+32>>1]=0;x[f+8>>2]=0;break $;case 5:v[d+5|0]=242;v[d+3|0]=2;break $;case 4:v[d+5|0]=242;v[d+3|0]=3;break $;case 3:v[d+5|0]=244;v[d+3|0]=2;break $;case 2:v[d+5|0]=244;v[d+3|0]=3;break $;case 1:v[d+5|0]=248;v[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}v[d+5|0]=248;v[d+3|0]=3;break $}g=0;L=v[h+1|0];if((L|0)<0&c>>>0>99){break $}if((L|0)>=0){v[f+17|0]=b;v[d|0]=b;v[f+18|0]=s;v[d+1|0]=s;w[f+32>>1]=0;x[f+8>>2]=0;c=y[h+2|0]}b=c&255;if(!b){break $}ka=f,la=Zl(+(b>>>0)*.64),v[ka+19|0]=la;j=B[f>>2];x[f>>2]=0;g=j!=E(0);break $}v[d+4|0]=0;v[d+2|0]=14;v[f+16|0]=1;break $;case 1:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(.0333000011742115);break _;case 2:x[f+4>>2]=0;B[f>>2]=E(y[h+2|0])*E(-.0333000011742115);break _;case 12:v[e+256|0]=15;v[e+96|0]=y[h+3|0]>>>3;b=y[Ub(e+256|0,e+96|0)|0];v[e+256|0]=15;v[e+96|0]=y[h+2|0]>>>3;ka=f,la=y[Ub(e+256|0,e+96|0)|0]|b<<4,v[ka+24|0]=la;break _;case 3:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(.0333000011742115);break _;case 4:x[f+12>>2]=0;b=y[h+2|0];w[f+32>>1]=0;B[f+8>>2]=E(b>>>0)*E(-.0333000011742115);break _;case 15:if(!y[h+2|0]|(b|0)<0){break _}g=b-y[f+17|0]<<5;c=g>>31;c=(c^g)-c|0;x[e+256>>2]=c;v[f+17|0]=b;x[f+8>>2]=0;v[d|0]=b;v[d+3|0]=4;b=Zg((c>>>0)/(y[h+2|0]<<1>>>0)|0);v[d+5|0]=b;v[f+27|0]=b;x[e+96>>2]=D(b,(n&255)-1|0);ka=f,la=c-x[pd(e+256|0,e+96|0)>>2]|0,w[ka+32>>1]=la;break _;case 13:v[e+256|0]=15;v[e+96|0]=y[h+3|0]>>>3;b=y[Ub(e+256|0,e+96|0)|0];v[e+256|0]=15;v[e+96|0]=y[h+2|0];ka=f,la=y[Ub(e+256|0,e+96|0)|0]|b<<4,v[ka+23|0]=la;break _;case 18:b=y[h+2|0]+y[f+17|0]&255;b=b?b>>>0>=120?120:b:1;v[f+17|0]=b;v[d|0]=b;v[d+5|0]=255;v[d+3|0]=4;break ba;case 23:case 24:case 25:b=$d(t);while(1){ga:{c=0;if(!b){break ga}g=b+13|0;if(!Wu(h,g)){c=1;if(!Wu(g,h)){break ga}b=b+4|0}b=x[b>>2];continue}break};if(c){v[d+3|0]=31;x[31785]=0;b=P(729,t|0,h|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break M}v[d+5|0]=y[b|0];break _}b=x[Ab(t)>>2];if(b>>>0>127){break _}x[e+92>>2]=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);c=Me(fa,b&255);g=x[ia>>2];x[31785]=0;x[e+24>>2]=x[e+92>>2];c=U(730,e+24|0,c|0,g|0)|0;g=x[31785];x[31785]=0;ha:{if((g|0)==1){break ha}if(!c){break _}v[d+3|0]=31;x[31785]=0;c=P(729,t|0,h|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break ha}b=b|-128;v[c|0]=b;v[d+5|0]=b;ca=(y[h|0]&254)==24|ca;break _}break M;case 16:if(!y[h+2|0]){break _}v[d+3|0]=15;x[e+256>>2]=15;x[e+96>>2]=y[h+3|0]+1;ka=d,la=x[pd(e+256|0,e+96|0)>>2],v[ka+5|0]=la;w[f+30>>1]=D(y[h+2|0],y[h+3|0]+1|0);break _;case 9:v[d+3|0]=16;b=y[h+2|0];n=b?b:4;v[d+5|0]=n;break _;case 19:ia:{b=y[h+1|0];switch(b|0){case 0:case 4:break ia;default:break _}}g=128;g=(b|0)==4?y[h+3|0]:g;v[e+91|0]=g;v[e+256|0]=y[h+2|0];v[e+96|0]=100;b=e+256|0;s=e+96|0;c=y[Ub(b,s)|0];x[e+256>>2]=128;x[e+96>>2]=256-(g&255);g=x[pd(b,s)>>2];v[e+256|0]=128;b=y[Ub(b,e+91|0)|0];g=(D(c,g)|0)/128|0;s=g&255;if((s|0)!=y[f+20|0]){v[f+20|0]=g;v[d+3|0]=21;g=Bc(((D(s,y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=g;v[d+5|0]=g}if(y[h+1|0]!=4|(z[a+480188>>1]-1|0)<=(m|0)){break _}g=m+1|0;h=bv(x[G>>2],g);b=D(b,c)>>>7|0;if(y[h+20|0]==(b&255)){break _}v[h+20|0]=b;b=Y+D(g,6)|0;v[b+3|0]=21;c=Bc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);v[f+21|0]=c;v[b+5|0]=c;break _;case 10:case 11:case 17:case 20:v[d+3|0]=0;break _;case 7:b=y[h+2|0];v[f+25|0]=0;v[f+26|0]=0;v[f+22|0]=b;break _;case 8:v[f+22|0]=y[f+22|0]+y[h+2|0];break _;case 14:v[f+25|0]=y[h+3|0];v[f+26|0]=y[h+2|0];break _;case 6:break da;default:break _}}v[f+18|0]=s;v[f+17|0]=b;v[d+1|0]=s;c=b}v[d|0]=c;if((b|0)>=0){v[f+18|0]=s;v[d+1|0]=s}if(y[h|0]==5){v[d+4|0]=1;v[d+2|0]=11}b=y[f+26|0];c=y[f+22|0];if(!(b|(c|y[h+2|0]))){break ba}if(b){da=(Ti(+z[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{da=0}v[d+3|0]=44;ka=d,la=Zl(da+ +(c+y[h+2|0]|0)),v[ka+5|0]=la}w[f+32>>1]=0;break _}v[d+5|0]=n;v[d+3|0]=16}b=Bc(((D(y[f+20|0],y[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!g&y[f+21|0]==(b&255))){v[f+21|0]=b;v[d+5|0]=b;v[d+3|0]=21}if(m&1|v[h+1|0]<=0|(z[a+480188>>1]-1|0)<=(m|0)){break _}b=x[l>>2];if(Ph(b,x[l+4>>2])>>>0<=H>>>0){break _}if(y[an(b,H)+132|0]!=1){break _}g=m+1|0;b=Y+D(g,6)|0;c=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[d+4|0]|y[d+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;v[b+1|0]=y[b+1|0]+1;b=bv(x[G>>2],g);v[b+19|0]=y[f+19|0];B[b>>2]=B[f>>2];B[b+4>>2]=B[f+4>>2];B[b+8>>2]=B[f+8>>2];B[b+12>>2]=B[f+12>>2];w[b+30>>1]=z[f+30>>1]}ja:{if(y[d|0]){v[f+16|0]=0;break ja}c=0;if(y[f+16|0]){break X}}ka:{if(!z[f+30>>1]){break ka}b=n&255;w[e+256>>1]=b;c=f+30|0;ka=c,la=z[se(c,e+256|0)>>1]-b|0,w[ka>>1]=la;if(y[d+3|0]){break ka}v[d+3|0]=15;v[d+5|0]=0}j=B[f>>2];la:{if(j==E(0)){break la}b=n&255;j=E(E(j*E(b>>>0))+B[f+4>>2]);B[f+4>>2]=j;if(y[d+3|0]){break la}ma:{na:{oa:{pa:{if(b>>>0>=2){g=b-1|0;C=E(g|0);if(!(C<=j)){break pa}v[e+256|0]=15;ka=e,la=xh(E(j/C)),v[ka+96|0]=la;b=y[Ub(e+256|0,e+96|0)|0];B[f+4>>2]=j-E(D(b,g)|0);v[d+3|0]=22;c=b<<4;break ma}if(!(j>=E(1))){break oa}break na}if(j>=E(1)){break na}if(!(j<=E(1-b|0))){break oa}v[e+256|0]=15;ka=e,la=xh(E(E(-j)/C)),v[ka+96|0]=la;c=y[Ub(e+256|0,e+96|0)|0];B[f+4>>2]=j+E(D(g,c)|0);v[d+3|0]=22;break ma}if(!(j<=E(-1))){break la}v[e+256|0]=14;ka=e,la=xh(E(-j)),v[ka+96|0]=la;b=y[Ub(e+256|0,e+96|0)|0];B[f+4>>2]=j+E(b>>>0);v[d+3|0]=22;c=b|-16;break ma}v[e+256|0]=15;ka=e,la=xh(j),v[ka+96|0]=la;b=y[Ub(e+256|0,e+96|0)|0];B[f+4>>2]=j-E(b>>>0);v[d+3|0]=22;c=b<<4|15}v[d+5|0]=c}j=B[f+8>>2];qa:{if(j==E(0)){break qa}b=n&255;j=E(E(j*E(b>>>0))+B[f+12>>2]);B[f+12>>2]=j;ra:{if(!y[d+3|0]){sa:{ta:{if(b>>>0>=2){c=b-1|0;C=E(c|0);if(!(C<=j)){break ta}v[e+256|0]=223;ka=e,la=xh(E(j/C)),v[ka+96|0]=la;b=y[Ub(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(D(b,c)|0);v[d+3|0]=2;v[d+5|0]=b;break qa}if(!(j>=E(1))){break sa}break ra}if(j>=E(1)){break ra}if(!(E(1-b|0)>=j)){break sa}v[e+256|0]=223;ka=e,la=xh(E(E(-j)/C)),v[ka+96|0]=la;b=y[Ub(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(D(b,c)|0);v[d+3|0]=3;v[d+5|0]=b;break qa}if(!(j<=E(-1))){break qa}v[e+256|0]=14;ka=e,la=xh(E(-j)),v[ka+96|0]=la;b=y[Ub(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(b>>>0);v[d+3|0]=3;v[d+5|0]=b|240;break qa}if(y[d+2|0]|b>>>0<2){break qa}ea=E(j*E(.25));c=b-1|0;C=E(c|0);if(ea>=C){v[e+256|0]=9;ka=e,la=xh(E(j/C))>>>2|0,v[ka+96|0]=la;b=y[Ub(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(D(b,c)<<2);v[d+2|0]=12;v[d+4|0]=b;break qa}if(!(ea<=E(1-b|0))){break qa}v[e+256|0]=9;ka=e,la=xh(E(E(-j)/C))>>>2|0,v[ka+96|0]=la;b=y[Ub(e+256|0,e+96|0)|0];B[f+12>>2]=j+E(D(b,c)<<2);v[d+2|0]=13;v[d+4|0]=b;break qa}v[e+256|0]=15;ka=e,la=xh(j),v[ka+96|0]=la;b=y[Ub(e+256|0,e+96|0)|0];B[f+12>>2]=j-E(b>>>0);v[d+3|0]=2;v[d+5|0]=b|240}ua:{va:{wa:{xa:{ya:{za:{Aa:{b=y[d+3|0];switch(b|0){case 4:break ua;case 0:break Aa;default:break za}}Ba:{b=y[f+23|0];if(!b){b=y[f+24|0];if(b){break Ba}if(!z[f+32>>1]){break ua}c=f+32|0;break ya}v[d+3|0]=5;v[d+5|0]=b;if(!z[f+32>>1]){break ua}break xa}v[d+3|0]=8;v[d+5|0]=b;if(z[f+32>>1]){break xa}break ua}if(!z[f+32>>1]){break ua}c=f+32|0;if(b){break wa}}v[d+3|0]=4;break va}c=f+32|0}v[d+2|0]=11}w[e+256>>1]=D(y[f+27|0],(n&255)-1|0);ka=f,la=z[f+32>>1]-z[Mc(c,e+256|0)>>1]|0,w[ka+32>>1]=la}w[f+28>>1]=z[f+28>>1]+D(y[f+25|0],n&255)&1023;c=0;if(m&1){break X}b=y[f+18|0];if(!b){break X}g=x[l>>2];if(Ph(g,x[l+4>>2])>>>0<b>>>0){break X}g=an(g,b-1|0);if(!(y[g+142|0]&4)){break X}b=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[o|0]=b;v[o+1|0]=b>>>8;v[o+2|0]=b>>>16;v[o+3|0]=b>>>24;b=y[d+4|0]|y[d+5|0]<<8;v[o+4|0]=b;v[o+5|0]=b>>>8;c=1;b=y[e+65|0];if(!b|y[g+132|0]!=1){break X}v[e+65|0]=b+1}m=m+1|0;b=z[a+480188>>1];continue}}break}we(c,Vh(Ue(Le(e+256|0,16,Cb(y[i+14|0]|y[i+15|0]<<8)&255),0)))}b=dm(x[I>>2],x[I+4>>2]);ka=e,la=Cb(y[i+4|0]|y[i+5|0]<<8),w[ka+256>>1]=la;w[e+64>>1]=1;c=z[se(e+256|0,e- -64|0)>>1];x[31785]=0;V(731,I|0,b|0,c|0,F&65535);b=x[31785];x[31785]=0;if((b|0)==1){break Q}b=ve((y[k+8|0]|y[k+9|0]<<8)<<16>>16);b=ve(ve((y[i+16|0]|y[i+17|0]<<8)<<16>>16)-b<<16>>16);v[i+16|0]=b;v[i+17|0]=b>>>8}av(e+40|0);continue}break}break M}d=ca&1;if(d){g=a+906300|0;b=rd(g,0);x[31785]=0;W(289,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break M}x[b+16>>2]=1299020115;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[e+256>>2]=0;f=b+48|0;c=e+256|0;C$(b+32|0,f,c);x[31785]=0;c=P(37,c|0,9576)|0;h=x[31785];x[31785]=0;if((h|0)==1){break M}cE(f,c);tb(c);x[31785]=0;c=P(37,e+76|0,9569)|0;f=x[31785];x[31785]=0;if((f|0)==1){break M}cw(b+80|0,c);tb(c);x[31785]=0;b=P(37,e- -64|0,9561)|0;c=x[31785];x[31785]=0;if((c|0)==1){break M}cE(rd(g,1)+48|0,b);tb(b)}b=0;while(1){if(z[a+480188>>1]>b>>>0){LD(a,b&65535);c=(b<<5)+a|0;v[c+480288|0]=d;w[c+480284>>1]=b<<8&256;b=b+1|0;continue}break}x[31785]=0;b=P(1,e+52|0,12186)|0;c=x[31785];x[31785]=0;Ca:{Da:{Ea:{if((c|0)!=1){yb(a+1298344|0,b);tb(b);x[31785]=0;b=P(1,e+40|0,12404)|0;c=x[31785];x[31785]=0;if((c|0)==1){break M}yb(a+1298356|0,b);tb(b);if(Z){break Ea}x[31785]=0;b=P(1,e+28|0,12186)|0;c=x[31785];x[31785]=0;if((c|0)==1){break M}break Da}break M}if(Ph(x[l>>2],x[l+4>>2])>>>0<=128){x[31785]=0;b=P(1,e+28|0,9318)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break Da}break M}x[31785]=0;b=P(1,e+28|0,14961)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Ca}}yb(a+1298368|0,b);tb(b);ka=a+1298404|0,la=x[Gc(e+100|0,28)>>2],x[ka>>2]=la;XV(G);KV(t);JV(J);d=1;break m}}c=N()|0;XV(G);break j}Kq(e+52|0);continue}}c=N()|0;break a}c=N()|0;break a}cv(l);sc(u);cn(r);Ui(q);break c}c=N()|0;break j}c=N()|0}KV(t);JV(J);break a}c=N()|0;tb(b);break a}c=N()|0;break a}ub(c);x[31785]=0;c=d&65535;d=U(732,a|0,c|0,k|0)|0;g=x[31785];x[31785]=0;Fa:{Ga:{Ha:{Ia:{if((g|0)==1){break Ia}if(d){break Fa}x[31785]=0;d=U(733,a|0,c|0,k|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31785]=0;d=U(734,a|0,c|0,k|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31785]=0;d=P(735,(D(c,104)+a|0)+484380|0,k|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Ia}if(d){break Fa}x[31785]=0;d=P(1,e+420|0,16372)|0;g=x[31785];x[31785]=0;if((g|0)==1){break Ha}g=x[G>>2];x[31785]=0;S(389,g|0,2,d|0);g=x[31785];x[31785]=0;if((g|0)==1){break Ga}tb(d);break Fa}c=N()|0;break e}c=N()|0;break e}c=N()|0;tb(d);break e}Ja:{Ka:{La:{F=D(c,104)+a|0;if(y[F+484414|0]&64){d=z[i>>1];if(si(d)){break La}}d=x[l>>2];if(Ph(d,x[l+4>>2])>>>0<=c>>>0){break Ka}if(y[an(d,c)+132|0]!=2){break Ka}c=z[i>>1];if(!si(c)){break Ka}w[i>>1]=c+1;break Ka}c=d+1|0;w[i>>1]=c;H=D(c&65535,104)+a|0;o=H+484380|0;h=F+484380|0;d=x[h>>2];g=x[h+20>>2];Ma:{if(!ge(d,g)){break Ma}f=z[h+34>>1];if((h|0)==(o|0)|(Xd(f)|0)!=2){break Ma}c=(h|0)==(o|0);if(!(ge(x[o>>2],x[o+20>>2])?c:1)){break Ma}ge(x[h>>2],x[h+20>>2]);if(!c){g=Xu(d,Cn(f))}f=x[h+20>>2];if(!(f?g:0)){if(!c){QB(g)}break Ma}Na:{Oa:{switch(Cn(z[h+34>>1])-1|0){case 1:d=g;c=f;m=x[h+20>>2];n=x[h>>2];while(1){if(n){w[d>>1]=z[m>>1];w[c>>1]=z[m+2>>1];m=m+4|0;c=c+2|0;d=d+2|0;n=n-1|0;continue}break};break Na;case 0:break Oa;default:break Na}}d=g;c=f;m=x[h+20>>2];n=x[h>>2];while(1){if(n){v[d|0]=y[m|0];v[c|0]=y[m+1|0];m=m+2|0;c=c+1|0;d=d+1|0;n=n-1|0;continue}break}}d=Oo(o,h);w[d+34>>1]=z[d+34>>1]&65471;x[o+20>>2]=g;g=Oo(h,h);w[g+34>>1]=z[g+34>>1]&65471;x[h+20>>2]=f;f=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(f|0)){h=x[c+104>>2];if(!((h|0)!=(d|0)&(g|0)!=(h|0))){x[c+88>>2]=x[c+88>>2]&-65}c=c+872|0;continue}break}Mj(d,a);Mj(g,a)}x[31785]=0;c=P(37,e+408|0,6340)|0;d=x[31785];x[31785]=0;if((d|0)==1){break Ja}ye(H+484423|0,c);tb(c);x[31785]=0;c=P(37,e+396|0,6243)|0;d=x[31785];x[31785]=0;if((d|0)==1){break f}ye(F+484423|0,c);tb(c)}ub(k);dc(t);g=0;continue}break}c=N()|0;break e}c=N()|0}ub(k)}dc(t);break a}fb=e+608|0;return d|0}c=N()|0}cv(l);sc(u);cn(r);Ui(q);Q(c|0);p()}function qv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,q=0,r=0,s=0,t=0,u=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,R=0,T=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0,da=0,ea=0,fa=0,ia=0,ka=0,la=0,ma=0,na=0,oa=E(0),pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=E(0);h=fb-192|0;fb=h;Z=Nb(a);s=h+160|0;v[s+26|0]=0;w[s+24>>1]=0;x[s+16>>2]=0;x[s+20>>2]=-1;x[s+8>>2]=-1;x[s+12>>2]=-1;x[s>>2]=0;x[s+4>>2]=0;ia=x[d+16>>2];a=y[d+6|0];pa=b+484360|0;i=x[pa>>2];qa=(Aa=a,Ba=y[b+484376|0],Ca=Kj(i,x[b+484364>>2])>>>0>a>>>0,Ca?Aa:Ba);a=qa&255;K=Sj(i,a);x[31785]=0;t=P(606,h+128|0,b|0)|0;i=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{if((i|0)!=1){l=x[t+4>>2];x[31785]=0;L=U(607,h+92|0,b|0,a|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break g}ca=c&7;g=x[d>>2];a=z[d+4>>1];i=Xc(x[K>>2],x[K+4>>2]);while(1){f=a&65535;if(f>>>0>=i>>>0){break f}if($i(K,f)){break f}a=a+1|0;g=0;continue}}a=N()|0;break d}a=N()|0;break e}x[d>>2]=g;w[d+4>>1]=a;x[l+52>>2]=g;M=l+48|0;x[M>>2]=g;x[s+16>>2]=g;w[l+74>>1]=a;w[l+72>>1]=a;w[s+24>>1]=a;ra=Jd(h+84|0);h:{if((ca|0)!=7){break h}a=fb-16|0;fb=a;i=a+8|0;Kb(i,ra,1);Uo(i);fb=a+16|0;if((ia|0)!=2){break h}a=x[K>>2];f=Xc(a,x[K+4>>2]);i=z[d+12>>1];if(f>>>0<=i>>>0){break h}f=x[b+484344>>2];r=x[b+484348>>2];a=z[_b(a,i)>>1];if(!Ge(f,r,a)){break h}i=Vb(f,a);f=x[d+8>>2];if(A[i+12>>2]<=f>>>0){break h}a=0;m=gd(x[i>>2],x[x[i+48>>2]+12>>2],f,0);i=z[b+480188>>1];f=x[t+8>>2];r=z[b+480192>>1];while(1){if((a|0)==(i|0)){break h}i:{j:{k:{l:{e=y[m|0];switch(e-253|0){case 1:case 2:break j;case 0:break l;default:break k}}if(r){break j}}if(!zd(e)){break i}if(Hl(y[m+2|0],y[m+3|0])){break i}}Aa=Re(f,a),Ba=-1,x[Aa>>2]=Ba}m=m+6|0;a=a+1|0;continue}}_=c&1;if(_){oT(l+223860|0)}R=l+74|0;va=l+223872|0;T=l+80|0;xa=b+901692|0;ya=b+902204|0;da=l+44|0;ka=l+223860|0;$=l+20|0;J=b+1074312|0;sa=l+616|0;ea=32768;Y=b+480188|0;I=b+480180|0;la=b+484348|0;za=l+223884|0;ta=(ca|0)!=7;ma=b+480192|0;r=0;m:{n:{o:{p:{q:{r:{s:{t:{u:while(1){ua=C[d+8>>3];o(+ua);i=j(1)|0;a=j(0)|0;q=x[d+16>>2];f=a;v:{w:{x:{y:{while(1){nT(h+24|0,x[I>>2],z[Y>>1],l,F&1);k=y[h+24|0];if((q|0)==3&C[t+24>>3]>=ua){break y}a=65535;e=x[K>>2];g=Xc(e,x[K+4>>2]);m=z[l+72>>1];if(g>>>0>m>>>0){a=z[_b(e,m)>>1]}w[l+70>>1]=a;g=x[b+484344>>2];e=x[la>>2];n=a&65535;if(!(Ge(g,e,n)|(n|0)==65535|(q|0)!=2)&(m|0)==(i&65535)){break y}z:{while(1){a=a&65535;if(pg(g,e)>>>0>a>>>0){break z}m=z[l+72>>1];A:{B:{if((a|0)!=65535){n=x[K>>2];u=Xc(n,x[K+4>>2]);if(m>>>0<u>>>0){break B}}a=z[K+28>>1];if((m|0)==(a|0)){break z}n=x[K>>2];u=Xc(n,x[K+4>>2]);break A}a=m+1|0}w[l+72>>1]=a;m=65535;G=u;u=a&65535;if(G>>>0>u>>>0){m=z[_b(n,u)>>1]}w[l+74>>1]=a;w[l+70>>1]=m;C:{if(!Ge(g,e,m&65535)){e=uq(h+24|0,sa);x[31785]=0;a=ha(608,L|0,a&65535,0,e|0,(k|0)!=0|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break q}if(a){break C}g=x[b+484344>>2];e=x[la>>2]}a=z[l+70>>1];continue}break}if(ia>>>0<=1){a=z[l+72>>1];x[s+8>>2]=0;w[s+20>>1]=a}if(!q){break z}if(!Eu(L,R,M)){break z}C[s>>3]=C[t+24>>3];x[31785]=0;O(609,Z|0,s|0);a=x[31785];x[31785]=0;if((a|0)==1){break r}x[s+16>>2]=x[M>>2];w[s+24>>1]=z[R>>1];x[31785]=0;W(610,t|0);a=x[31785];x[31785]=0;if((a|0)==1){break r}a=z[l+74>>1];w[l+72>>1]=a;Aa=l,Ba=z[_b(x[K>>2],a)>>1],w[Aa+70>>1]=Ba;x[l+52>>2]=x[l+48>>2]}if(z[R>>1]==65535){break n}a=x[b+484344>>2];e=z[l+70>>1];if(!Ge(a,x[la>>2],e)){a=z[l+72>>1];if((a|0)==z[K+28>>1]){if(!q){break o}if(!Eu(L,R,M)){break p}C[s>>3]=C[t+24>>3];x[31785]=0;O(609,Z|0,s|0);a=x[31785];x[31785]=0;if((a|0)==1){break r}x[s+16>>2]=x[M>>2];w[s+24>>1]=z[R>>1];x[31785]=0;W(610,t|0);a=x[31785];x[31785]=0;if((a|0)==1){break r}x[l+52>>2]=x[l+48>>2];continue}w[R>>1]=a+1;continue}break}g=x[M>>2];if(g>>>0>=A[Vb(a,e)+12>>2]){x[M>>2]=0;g=0}if((q|0)!=2){break x}if(z[l+72>>1]!=(i&65535)|(f|0)!=(g|0)){break w}}q=1;v[s+26|0]=1;break n}a=0;if((q|0)==3){break v}}a=0;if(A[L+28>>2]<ea>>>0){break v}x[t+24>>2]=0;x[t+28>>2]=2146435072;x[L+28>>2]=0;ea=ea>>>(ea>>>0>256)|0;g=x[M>>2];a=1}i=z[l+72>>1];f=uq(h+24|0,sa);x[31785]=0;i=ha(608,L|0,i|0,g|0,f|0,(k|0)!=0|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break t}if((a|i)==1){if(ia>>>0<=1){w[s+20>>1]=z[l+72>>1];x[s+8>>2]=x[l+48>>2]}if(!q){break o}if(!Eu(L,R,M)){break p}C[s>>3]=C[t+24>>3];x[31785]=0;O(609,Z|0,s|0);a=x[31785];x[31785]=0;if((a|0)==1){break s}x[s+16>>2]=x[M>>2];w[s+24>>1]=z[R>>1];x[31785]=0;W(610,t|0);a=x[31785];x[31785]=0;if((a|0)==1){break s}x[l+52>>2]=x[l+48>>2];continue}w[s+22>>1]=z[l+72>>1];x[s+12>>2]=x[l+48>>2];mT(b,l,0);m=x[l+48>>2];i=Vb(x[b+484344>>2],z[l+70>>1]);if(m>>>0>=A[i+12>>2]){x[M>>2]=0;m=0}if(k){continue}a=0;m=gd(x[i>>2],x[x[i+48>>2]+12>>2],m,0);Kb(h+24|0,J,77);g=Hb(x[x[h+24>>2]>>2],x[h+28>>2]);D:{while(1){if(z[Y>>1]>a>>>0){E:{if(!(!mB(m)&(!g|!(y[((a<<5)+b|0)+480281|0]&4)))){No((l+D(a,872)|0)+1404|0);break E}if(Sg(y[m|0])){F:{if(!Ad(y[za|0])){break F}i=y[m+1|0];if(i-251>>>0<5|!i){break F}e=y[m+5|0];k=y[m+3|0];n=Hj(y[m+2|0],y[m+4|0]);f=h+24|0;v[f|0]=i-1;x[f+4>>2]=n&65535;x[31785]=0;i=P(611,va|0,f|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break D}Aa=i,Da=E(E(Hj(k,e)>>>0)/E(999)),B[Aa>>2]=Da}No((l+D(a,872)|0)+1404|0);break E}i=l+D(a,872)|0;f=i+1408|0;e=y[m+4|0]|y[m+5|0]<<8;v[f|0]=e;v[f+1|0]=e>>>8;f=i+1404|0;e=y[m|0]|y[m+1|0]<<8|(y[m+2|0]<<16|y[m+3|0]<<24);v[f|0]=e;v[f+1|0]=e>>>8;v[f+2|0]=e>>>16;v[f+3|0]=e>>>24;G:{H:{I:{J:{switch(y[m+3|0]-16|0){case 0:e=y[m+5|0];break I;case 3:break G;case 4:break H;case 1:break J;default:break E}}Kb(h+24|0,J,5);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break E}e=y[m+5|0];if(!e){break E}}kT(b,l,e&255);break E}f=i+1409|0;e=y[f|0];K:{if(!(e|!(x[I>>2]&16777250))){v[f|0]=y[i+1449|0];break K}v[i+1449|0]=e}i=y[m+5|0];f=i&240;if((f|0)!=224){if((f|0)!=96){break E}x[l+24>>2]=x[l+24>>2]+(i&15);break E}if(x[$>>2]){break E}i=i&15;if(i?0:y[I|0]&2){break E}x[$>>2]=i+1;break E}i=y[m+5|0];if((i&240)!=224){break E}x[$>>2]=(i&15)+1}m=m+6|0;a=a+1|0;continue}break}i=Fl(l);x[h+24>>2]=1;a=x[_c($,h+24|0)>>2];w[l+68>>1]=65535;x[l+60>>2]=-1;x[l+64>>2]=-1;na=i-1|0;a=i-a|0;X=D(a,1e4);m=0;while(1){L:{M:{N:{O:{P:{if(z[Y>>1]<=m>>>0){if(x[I>>2]!=4|x[l+40>>2]!=65535){break P}w[l+74>>1]=z[l+72>>1];x[l+52>>2]=x[l+48>>2];continue u}k=l+D(m,872)|0;q=k+1404|0;if(mB(q)){break L}n=k+616|0;fa=k+1409|0;e=y[fa|0];ba=k+1407|0;u=y[ba|0];if(!_){break N}G=y[q|0];f=G;g=k+1405|0;H=y[g|0];if(H){v[k+1415|0]=0;v[k+1419|0]=H;Aa=Re(x[t+8>>2],m),Ba=255,v[Aa+5|0]=Ba;f=y[q|0]}Q:{if(!zd(f)){break Q}v[k+1415|0]=G;SU(n);if(!ta){if(x[Re(x[t+8>>2],m)>>2]!=-1){break Q}}H=k+1272|0;f=y[k+1419|0];f=x[(f?f>>>0>z[ma>>1]?H:((f<<2)+b|0)+900380|0:H)>>2];if(!f){break Q}H=y[f+21|0];if(Cd(H)){Aa=k+1453|0,Ba=Sh(H),v[Aa|0]=Ba}f=y[f+22|0];if(!Cd(f)){break Q}Aa=k+1454|0,Ba=Sh(f),v[Aa|0]=Ba}R:{if(!(zd(y[q|0])|y[g|0])){break R}H=k+1419|0;g=y[H|0];S:{if(!g){g=0;break S}if(z[ma>>1]<g>>>0){break S}f=x[((g<<2)+b|0)+900380>>2];if(!f|!(v[f+15|0]&1)){break S}Fq(n,x[f+8>>2],b);g=y[H|0]}f=br(b,G,g&255);if(!f){break R}f=D(f,104)+b|0;if(!(y[f+484414|0]&32)){break R}Fq(n,z[f+484408>>1],b)}T:{U:{V:{f=y[k+1406|0];switch(f-1|0){case 1:break N;case 2:case 3:break U;case 0:break V;default:break T}}Aa=Re(x[t+8>>2],m),Ba=y[k+1408|0],v[Aa+5|0]=Ba;break N}f=y[k+1408|0];if(!f){break N}v[k+1450|0]=f;break N}if((f|0)==11){break O}break N}x[l+32>>2]=x[b+480216>>2];a=Vb(x[b+484344>>2],z[l+70>>1]);f=x[a+16>>2];if(jT(f,x[a+20>>2])){x[l+32>>2]=f}f=iT(b,l);a=D(f,i);C[t+24>>3]=C[t+24>>3]+ +(a>>>0)/+A[b+24620>>2];x[l>>2]=a+x[l>>2];W:{X:{Y:{if(ta){break Y}m=0;na=(r|0)!=0&(f|0)!=(r|0);while(1){if(z[Y>>1]<=m>>>0){break Y}F=Re(x[t+8>>2],m);Z:{if(x[F>>2]==-1){break Z}n=l+D(m,872)|0;G=n+1404|0;X=x[n+1316>>2];if(!X){if(mB(G)){break Z}}u=n+1409|0;q=y[u|0];e=Hl(y[G+2|0],y[G+3|0]);if(y[n+1405|0]){x[n+1276>>2]=0}k=n+616|0;a=q&15;g=0;_:{if(!zd(y[G|0])){break _}if(e&y[F+4|0]!=0){lB(h+24|0,b,k,X,0);g=x[h+28>>2];x[n+624>>2]=x[h+24>>2];x[n+628>>2]=g}v[n+1418|0]=y[n+1415|0];X=n+1308|0;fa=x[X>>2];g=y[n+1419|0];if(g){Eo(b,k,g,e,1,1)}g=y[G|0];x[31785]=0;ga(612,b|0,k|0,g|0,e|0,1,0,65535);g=x[31785];x[31785]=0;if((g|0)==1){break X}q=q>>>4|0;hT(b,k);gT(x[I>>2],z[Y>>1],l,m&65535);ba=Re(x[t+8>>2],m);v[ba+4|0]=1;F=y[n+1407|0];$:{if(!((y[u|0]&240)!=208|(F-19&255)>>>0>1)){g=a;if(a>>>0<i>>>0){break $}}g=(F|0)==33?i>>>0>q>>>0?q:0:0}H=x[$>>2];if(!(!(x[I>>2]&16777250)|(!g|H>>>0<2))){g=D(H-1|0,x[l+24>>2]+x[l+40>>2]|0)+g|0}if(!e){x[ba>>2]=0}aa:{if((F|0)==9){break aa}ba:{if((F|0)!=19){if((F|0)!=20|(q|0)!=8){break ba}break aa}if((q|0)==8){break aa}}if(y[n+1406|0]!=2){break _}}x[X>>2]=fa}ca:{if(!zd(y[G|0])){Kb(h+24|0,J,114);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break ca}}da:{ea:{fa:{ga:{e=y[n+1407|0];switch(e-42|0){case 1:break da;case 0:break ea;case 2:break fa;default:break ga}}if((e|0)!=10){break da}e=z[l+70>>1];q=x[l+48>>2];x[31785]=0;aa(613,b|0,k|0,m&65535,q|0,e|0);e=x[31785];x[31785]=0;if((e|0)!=1){break ca}break W}q=sua(y[u|0],0,x[n+692>>2],0);e=hb;F=e>>>8|0;Do(b,k,Bc((e&255)<<24|q>>>8,F));break ca}if(!x[n+720>>2]){break da}x[31785]=0;V(614,t|0,m&65535,r|0,-1);e=x[31785];x[31785]=0;if((e|0)==1){break W}eT(k,y[u|0]);g=x[l+40>>2]-1|0;break ca}if(y[n+1406|0]!=15){break ca}q=x[n+720>>2];if(!q){break ca}e=y[n+1408|0];if(e>>>0>9){break ca}ha:{if(!e){e=x[n+1280>>2];break ha}e=x[wb(q+68|0,e-1|0)>>2];x[n+1280>>2]=e}Do(b,k,e)}ia:{ja:{ka:{switch(y[G|0]-253|0){case 0:if(z[ma>>1]){break ja}break;case 1:case 2:break ja;default:break ka}}e=y[n+1407|0];if(!((y[u|0]&240)!=192|(e-19&255)>>>0>1)&a>>>0<i>>>0){break ja}q=0;F=e&255;if((F|0)==33&(a|0)!=0&i>>>0>a+g>>>0){break ja}if((F|0)!=25){break ia}}e=y[n+1407|0];q=1}H=n+1304|0;la:{ma:{na:{a=e&255;if((a|0)!=46){if((a|0)!=13){break na}F=y[u|0]<<2;break ma}F=y[u|0];break ma}if(y[n+1406|0]!=1){break la}F=y[n+1408|0]<<2}x[H>>2]=F}F=n+1407|0;oa:{pa:{qa:{if(!x[n+720>>2]|a>>>0>46|q){break qa}Kb(h+24|0,ra,a);if(Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break pa}e=y[F|0];if((e|0)!=19){break qa}a=y[u|0]&240;if((a|0)==16){break pa}e=19;if((a|0)==32){break pa}}if(!q){break oa}}TU(k);Aa=Re(x[t+8>>2],m),Ba=0,x[Aa>>2]=Ba;break Z}if(na){x[31785]=0;V(614,t|0,m&65535,r|0,-1);a=x[31785];x[31785]=0;if((a|0)==1){break W}e=y[F|0]}ra:{sa:{ta:{ua:{va:{a=e&255;if(a-6>>>0>=2){wa:{switch(a-19|0){case 1:break ua;case 0:break va;default:break wa}}if(a-35>>>0<2){break sa}if((a|0)==45){break ta}if((a|0)!=11){break ra}}if(!y[u|0]&x[I>>2]==1){break ra}a=n+1467|0;e=0;while(1){if((e|0)==(i|0)){break ra}v[a|0]=!e|y[a|0]&254;Co(b,k,y[u|0]);e=e+1|0;continue}}e=y[u|0];a=e&15;if(!(a|x[I>>2]&1048580)){break ra}q=n+1467|0;v[q|0]=y[q|0]|1;e=e&240;if((e|0)!=176){if((e|0)!=160){break ra}Bo(b,k,a,0);break ra}Ao(b,k,a,0);break ra}xa:{ya:{za:{a=y[u|0];switch(a-158|0){case 1:break ya;case 0:break za;default:break xa}}x[31785]=0;V(614,t|0,m&65535,r|0,-1);a=x[31785];x[31785]=0;if((a|0)==1){break W}x[n+704>>2]=x[n+704>>2]&-129;break ra}x[31785]=0;V(614,t|0,m&65535,r|0,-1);a=x[31785];x[31785]=0;if((a|0)==1){break W}a=x[n+704>>2];x[n+704>>2]=a|128;if(x[k+4>>2]){break ra}e=x[n+692>>2];if(!e){break ra}if(!(Aa=zd(y[G|0]),Ba=1,Ca=a&2,Ca?Aa:Ba)){break ra}x[k>>2]=-1;x[k+4>>2]=e-1;break ra}if((a&240)!=112|a>>>0<115){break ra}QU(k,a,x[I>>2]);break ra}dT(k,y[u|0]);break ra}x[31785]=0;a=m&65535;V(614,t|0,a|0,r|0,-1);e=x[31785];x[31785]=0;if((e|0)==1){break W}Aa=n+1390|0,Ba=cT(b,z[l+70>>1],x[l+48>>2],a),w[Aa>>1]=Ba}e=n+1467|0;a=y[e|0]|1;v[e|0]=a;Aa:{Ba:{Ca:{Da:{Ea:{q=n+1406|0;switch(y[q|0]-3|0){case 11:break Ba;case 0:case 1:break Ca;case 3:break Da;case 2:break Ea;default:break Aa}}a=y[n+1408|0];Kb(h+24|0,J,41);Bo(b,k,a,Hb(x[x[h+24>>2]>>2],x[h+28>>2]));break Aa}a=y[n+1408|0];Kb(h+24|0,J,41);Ao(b,k,a,Hb(x[x[h+24>>2]>>2],x[h+28>>2]));break Aa}a=y[n+1408|0];Fa:{if(a){break Fa}Kb(h+24|0,J,41);a=0;if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break Fa}a=y[n+1450|0];if(!a){break Aa}}n=y[q|0]==3?a<<4:a;a=0;while(1){if((a|0)==(i|0)){break Aa}v[e|0]=!a|y[e|0]&254;Co(b,k,n&255);a=a+1|0;continue}}k=y[n+1408|0];if(k>>>0>1){break Aa}v[e|0]=a&247|!k<<3}if(y[e|0]&8){break Z}a=1;Ga:{Ha:{Ia:{e=y[G+3|0];if(e>>>0>28){break Ia}k=1<<e;if(k&92){break Ga}if(!(k&268959744)){break Ia}if((y[G+5|0]-16&255)>>>0<32){break Ga}break Ha}if(e-38>>>0<4){break Ga}}a=(y[G+2|0]-11&255)>>>0<3}if(a){e=Re(x[t+8>>2],m);a=x[e>>2];x[e>>2]=a+i;x[31785]=0;V(614,t|0,m&65535,f|0,a+g|0);a=x[31785];x[31785]=0;if((a|0)!=1){break Z}a=N()|0;break m}a=Re(x[t+8>>2],m);x[a>>2]=x[a>>2]+(i-g|0)}m=m+1|0;continue}}F=bT(b,l,K,0);r=f;continue u}a=N()|0;break m}a=N()|0;break m}f=y[k+1408|0];if(!f){break N}g=h+24|0;jB(g,b,y[q+3|0],f,0);w[k+1384>>1]=z[h+24>>1];if(y[Ze(g)|0]){break M}}Ja:{Ka:{La:{Ma:{Na:{switch(u-12|0){case 0:aT(b,l,m&65535);break Ja;case 2:f=$S(b,l,m&65535,e);if((f|0)==-1){break Ja}x[l+60>>2]=f;break Ja;case 5:Kb(h+24|0,J,5);if(Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break Ja}g=D(zo(b,z[l+70>>1],x[l+48>>2],m&65535,0),1e4);x[h+56>>2]=g;Oa:{if(!_|!(x[I>>2]&16777250)){break Oa}if(g>>>0>=1e4){v[k+1451|0]=(g>>>0)/1e4;break Oa}g=D(y[k+1451|0],1e4);x[h+56>>2]=g}f=x[b+8>>2];if(g>>>0>=32e4){x[h+24>>2]=D(x[f+24>>2],1e4);Aa=da,Ba=x[Gb(h+56|0,h+24|0)>>2],x[Aa>>2]=Ba;break Ja}q=x[da>>2];G=(g>>>0)/1e4|0;H=D(X,G&15);g=q-H|0;x[da>>2]=(G&240)==16?q+H|0:g>>>0<=q>>>0?g:0;g=x[f+20>>2];f=x[f+24>>2];Kb(h+24|0,J,8);vp(da,D(g,1e4),Hb(x[x[h+24>>2]>>2],x[h+28>>2])?255e4:D(f,1e4));break Ja;case 8:Pa:{switch((e&240)-144>>>4|0){case 0:if(e>>>0>145){break Ja}x[k+704>>2]=x[k+704>>2]&-257|((e|0)==145)<<8;break Ja;case 1:v[k+1452|0]=e&15;break Ja;case 2:break Ma;case 6:break Pa;default:break Ja}}v[k+1460|0]=e&15;break Ja;case 1:case 3:case 4:case 6:break Ja;case 7:break Na;default:break Ka}}f=e&240;if((f|0)==240){break La}if((f|0)!=96){break Ja}}hB(b,l,m&65535,e&15);break Ja}v[k+1460|0]=e&15;break Ja}if((u|0)!=28|(e&240)!=160){break Ja}Kb(h+24|0,J,58);if(Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break Ja}v[k+1452|0]=e&15}if(!_){break L}Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{switch(u-2|0){case 0:if(!e){break Qa}Kb(h+24|0,J,90);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){v[k+1428|0]=e}v[k+1427|0]=e;break M;case 1:if(!e){break Qa}Kb(h+24|0,J,90);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){v[k+1427|0]=e}v[k+1428|0]=e;break M;case 2:if(!e){break Qa}w[k+1384>>1]=e;break M;case 8:if(!e){break Qa}x[k+1280>>2]=e<<8;break M;case 4:case 9:if(!e){break Qa}v[k+1425|0]=e;break M;case 11:Aa=Re(x[t+8>>2],m),Ba=e,v[Aa+5|0]=Ba;break M;case 44:Aa=Re(x[t+8>>2],m),Ba=e+3>>>2|0,v[Aa+5|0]=Ba;break M;case 21:f=x[I>>2];e=e<<(!(f&59593760)&e<<24>>24>=0);g=e&255;if(g>>>0<=128){x[T>>2]=g<<1;break M}if(f&16777250){break M}x[T>>2]=256;break M;case 22:Kb(h+24|0,J,9);Za:{if(Hb(x[x[h+24>>2]>>2],x[h+28>>2])){f=k+1433|0;if(e){v[f|0]=e;break Za}e=y[f|0];break Za}if(e){v[l+1433|0]=e;break Za}e=y[l+1433|0]}f=e&15;g=e&255;_a:{if(!((f|0)!=15|g>>>0<16)){e=(e&240)>>>4<<!(x[I>>2]&59593760);f=x[T>>2]+(e<<1)|0;break _a}g=g&240;if(!(!f|(g|0)!=240)){e=f<<(x[I>>2]&59593760?1:2);f=x[T>>2]-e|0;break _a}if(g){e=(e>>>3&30)<<!(x[I>>2]&59593760);f=x[T>>2]+D(a,e)|0;break _a}e=f<<(x[I>>2]&59593760?1:2);f=x[T>>2]-D(a,e)|0}x[T>>2]=f;Ee(T,0,256);break M;case 19:if(e>>>0>64){break M}x[k+1364>>2]=e;break M;case 20:f=k+1432|0;$a:{if(e){v[f|0]=e;break $a}e=y[f|0]}u=k+1364|0;f=x[u>>2];g=e&15;q=e&255;ab:{if(!((g|0)!=15|q>>>0<16)){x[h+24>>2]=f+(q>>>4|0);break ab}if(!(!g|(q&240)!=240)){x[h+24>>2]=f-g;break ab}if(g){x[h+24>>2]=f-D(a,g);break ab}x[h+24>>2]=f+D(a,q>>>4|0)}Ee(h+24|0,0,64);x[u>>2]=x[h+24>>2];break M;case 7:Xm(b,n,e,8);break M;case 29:case 30:break Ra;case 25:break Sa;case 6:break Ta;case 24:break Ua;case 3:break Va;case 5:break Wa;case 18:break Xa;case 17:break Ya;default:break M}}if(e>>>0>15){break Xa}f=(e&1)<<14;q=z[Y>>1];g=0;while(1){if((g|0)==(q|0)){break Xa}u=l+D(g,872)|0;x[u+704>>2]=(f|x[u+704>>2]&-16385)^16384;g=g+1|0;continue}}if((e&240)!=128){break M}Xm(b,n,e&15,4);break M}if(e){v[k+1425|0]=e}e=0}El(n,e);break M}_S(b,n,e);break M}ZS(n,e);break M}YS(n,e);break M}bb:{if(e<<24>>24>=0){f=Me(xa,y[k+1460|0]);break bb}f=Me(ya,e&127)}g=y[fa|0];x[31785]=0;ja(615,b|0,l|0,m&65535,0,f|0,g|0);f=x[31785];x[31785]=0;if((f|0)!=1){break M}a=N()|0;break m}e=0}cb:{db:{switch(y[k+1406|0]-2|0){case 0:Xm(b,n,y[k+1408|0],6);break cb;case 5:Kb(h+24|0,J,53);f=y[k+1408|0];if(Hb(x[x[h+24>>2]>>2],x[h+28>>2])){v[k+1439|0]=f&15;break cb}El(n,f<<4);break cb;case 6:break db;default:break cb}}El(n,y[k+1408|0])}eb:{fb:{gb:{hb:{ib:{f=y[ba|0];switch(f-5|0){case 1:break eb;case 3:break gb;case 0:case 2:break hb;default:break ib}}switch(f-26|0){case 1:break fb;case 0:break hb;default:break eb}}jb:{if(x[I>>2]&16777248){f=i;if(!(y[b+480208|0]&4)){break jb}}f=a}g=y[k+1439|0];Kb(h+24|0,J,21);k=k+1435|0;q=y[k|0];f=D(f,g);Aa=k,Ba=(Hb(x[x[h+24>>2]>>2],x[h+28>>2])?f<<2:f)+q|0,v[Aa|0]=Ba;break eb}kb:{if(x[I>>2]&16777248){f=i;if(!(y[b+480208|0]&4)){break kb}}f=a}g=y[k+1442|0];Kb(h+24|0,J,21);k=k+1436|0;q=y[k|0];f=D(f,g);Aa=k,Ba=(Hb(x[x[h+24>>2]>>2],x[h+28>>2])?f<<2:f)+q|0,v[Aa|0]=Ba;break eb}f=k+1437|0;v[f|0]=y[f|0]+D(na,y[k+1445|0]);WS(b,n)}Kb(h+24|0,J,78);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break L}f=e&255;if(!f){break L}VS(n,f)}m=m+1|0;continue}}break}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}q=1;break n}q=0}lb:{if((ca|0)!=7){break lb}a=0;d=b+480188|0;while(1){if(z[d>>1]<=a>>>0){break lb}mb:{if(x[Re(x[t+8>>2],a)>>2]==-1){break mb}x[31785]=0;V(614,t|0,a&65535,r|0,-1);i=x[31785];x[31785]=0;if((i|0)!=1){break mb}a=N()|0;break m}a=a+1|0;continue}}if(y[s+26|0]){w[s+20>>1]=z[l+72>>1];x[s+8>>2]=x[l+48>>2]}C[s>>3]=C[t+24>>3];x[31785]=0;O(609,Z|0,s|0);a=x[31785];x[31785]=0;if((a|0)!=1){if(!_){break a}if(!(q?y[s+26|0]:1)){break c}f=XA(h+56|0);if(Ad(y[ka+24|0])){JS(f,ka)}gB(ka);a=yc(b+1074376|0,l,614);r=0;while(1){if((r|0)==256){pn(a+223848|0,l+223848|0);d=a+223860|0;r=y[d+24|0];i=l+223860|0;nb:{if((Ad(y[i+24|0])|0)==(r|0)){if(!r){break nb}r=ec(d);tu(d,x[r>>2]);x[d>>2]=x[i>>2];x[d+4>>2]=x[i+4>>2];x[d+8>>2]=x[i+8>>2];ob:{if(!x[Ab(d)>>2]){x[d>>2]=r;break ob}x[x[r>>2]+8>>2]=r;r=ec(i);x[i>>2]=r;x[r>>2]=0;Aa=Ab(i),Ba=0,x[Aa>>2]=Ba}d=d+12|0;r=ec(d);su(d,x[r>>2]);i=i+12|0;x[d>>2]=x[i>>2];x[d+4>>2]=x[i+4>>2];x[d+8>>2]=x[i+8>>2];pb:{if(!x[Ab(d)>>2]){x[d>>2]=r;break pb}x[x[r>>2]+8>>2]=r;d=ec(i);x[i>>2]=d;x[d>>2]=0;Aa=Ab(i),Ba=0,x[Aa>>2]=Ba}break nb}if(r){gB(d);break nb}JS(d,i)}}else{d=D(r,872);sq((d+a|0)+616|0,(d+l|0)+616|0);r=r+1|0;continue}break}fB(a);a=0;x[b+1074400>>2]=0;v[b+1074476|0]=1;d=b+1074392|0;x[d>>2]=-2;x[d+4>>2]=0;x[b+1074428>>2]=x[b+1074424>>2];qb:{rb:{d=x[b+1298300>>2];if(!xd(d)){break rb}x[31785]=0;W(616,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){break rb}break qb}while(1){if(z[b+480188>>1]<=a>>>0){a=sC(h+24|0);Aa=h,Ba=Yi(x[f+12>>2]),x[Aa+20>>2]=Ba;i=b+906300|0;g=Jf(f+12|0);while(1){d=x[h+20>>2];if(!Vg(d,g)){sb:{g=250;d=a;tb:{while(1){if(g>>>0>=32){if(x[a>>2]){a=1;break tb}else{g=g-32|0;a=a+4|0;continue}}break}a=(x[d+28>>2]&67108863)!=0}if(!a){break sb}a=0;while(1){if((a|0)==250){break sb}Kb(h+12|0,d,a);ub:{if(!Hb(x[x[h+12>>2]>>2],x[h+16>>2])){break ub}r=x[rd(i,a)>>2];e=x[x[r>>2]+180>>2];x[31785]=0;W(e|0,r|0);r=x[31785];x[31785]=0;if((r|0)!=1){break ub}break qb}a=a+1|0;continue}}Aa=h,Ba=Yi(x[f>>2]),x[Aa+12>>2]=Ba;a=Jf(f);while(1){d=x[h+12>>2];if(Vg(d,a)){d=qd(d);oa=B[ec(d)>>2];Aa=rd(i,y[d|0]),Da=oa,B[Aa+144>>2]=Da;Yg(h+12|0);continue}else{tq(f);break b}}}r=qd(d);k=Ab(r);vb:{e=y[r|0];d=x[rd(i,e)>>2];if(d){Kb(h+12|0,a,e);if(!Hb(x[x[h+12>>2]>>2],x[h+16>>2])){x[31785]=0;P(617,a|0,e|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break vb}e=x[x[d>>2]+176>>2];x[31785]=0;O(e|0,d|0,-1);e=x[31785];x[31785]=0;if((e|0)==1){break vb}}oa=B[k>>2];r=x[r+4>>2];e=x[x[d>>2]+44>>2];x[31785]=0;wa(e|0,d|0,r|0,E(oa));d=x[31785];x[31785]=0;if((d|0)==1){break vb}}Yg(h+20|0);continue}break}break qb}d=D(a,872)+b|0;i=y[d+1075791|0];if(i){v[d+1075794|0]=i}d=Re(x[t+8>>2],a);if(!((ca|0)==7|y[d+5|0]==255)){v[h+24|0]=64;Aa=(D(a,872)+b|0)+1075680|0,Ba=y[Ub(d+5|0,h+24|0)|0]<<2,x[Aa>>2]=Ba}wb:{i=D(a,872)+b|0;d=x[i+1075096>>2];xb:{if(!d|!(y[d+35|0]&2)){break xb}r=x[b+1298300>>2];if(!xd(r)){break xb}x[31785]=0;g=r;r=a&65535;S(618,g|0,r|0,d+68|0);d=x[31785];x[31785]=0;if((d|0)==1){break wb}d=x[b+1298300>>2];x[31785]=0;S(619,d|0,r|0,1);d=x[31785];x[31785]=0;if((d|0)==1){break wb}}x[i+1075008>>2]=0;a=a+1|0;continue}break}}a=N()|0;tq(f);break m}a=N()|0}xu(L)}US(t)}Ui(Z);Q(a|0);p()}if((c|0)==3){break b}x[b+1074416>>2]=x[b+480196>>2];x[b+1074420>>2]=x[b+480204>>2];x[b+1074456>>2]=x[b+480200>>2]}a=qa&255;if((a|0)==y[b+484376|0]){break a}ak(pa,a)}if(c&9){a=b+1298264|0;if(x[a>>2]){LT(a);b=x[a>>2];el(a);Db(b);Aa=Ab(a),Ba=0,x[Aa>>2]=Ba;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[L>>2];x[a+4>>2]=x[L+4>>2];b=Ab(L);Aa=Ab(a),Ba=x[b>>2],x[Aa>>2]=Ba;x[b>>2]=0;x[L>>2]=0;x[L+4>>2]=0;a=a+12|0;c=ec(a);yq(a,x[c>>2]);b=L+12|0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];yb:{if(!x[Ab(a)>>2]){x[a>>2]=c;break yb}x[x[c>>2]+8>>2]=c;a=ec(b);x[b>>2]=a;x[a>>2]=0;Aa=Ab(b),Ba=0,x[Aa>>2]=Ba}}xu(L);US(t);fb=h+192|0}function bY(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0,r=E(0),s=E(0),t=0,u=0,C=0,F=0,G=0,H=0,I=E(0),J=E(0),K=0,L=E(0),M=E(0),N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=E(0),$=E(0),aa=0,ba=0,ca=E(0),da=E(0),ea=E(0),fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0;ba=fb-16|0;fb=ba;a:{if(x[a+1420>>2]>=0){x[f>>2]=0;P=x[a+1420>>2];d=(P|0)>0?P:0;while(1){if((d|0)!=(h|0)){x[(D(h,20)+a|0)+1436>>2]=0;h=h+1|0;continue}break}b:{c:{d:{if((P|0)>3){break d}h=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{k=b+d|0;if(y[k|0]!=79){break f}if(Ob(k,126164,4)){break f}g=d+26|0;if((g|0)>=(c|0)){break e}l=d+27|0;i=b+g|0;f=y[i|0];if((l+f|0)>=(c|0)){break e}j=f+27|0;h=0;e=0;while(1)if((e|0)==(f|0)){e=0;while(1){f=22;if((h|0)!=22){e=$y(e,y[(d+h|0)+b|0]);h=h+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;e=$y(e,0);continue}break}x[a+1420>>2]=P+1;f=D(P,20)+a|0;x[f+1432>>2]=e;x[f+1428>>2]=j-26;x[f+1424>>2]=y[k+22|0]|y[k+23|0]<<8|(y[k+24|0]<<16|y[k+25|0]<<24);e=y[(g+y[i|0]|0)+b|0]==255?-1:y[k+6|0]|y[k+7|0]<<8|(y[k+8|0]<<16|y[k+9|0]<<24);x[f+1436>>2]=g;x[f+1440>>2]=e;P=x[a+1420>>2];if((P|0)!=4){break f}P=4;break d}else{j=y[(e+l|0)+b|0]+j|0;e=e+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(P|0)?d:P;while(1){if((d|0)==(i|0)){break b}h=0;f=D(d,20)+a|0;n=f+1428|0;k=x[n>>2];l=x[f+1436>>2];j=c-l|0;g=(j|0)>(k|0)?k:j;S=(g|0)>0?g:0;o=f+1432|0;e=x[o>>2];while(1){if((h|0)!=(S|0)){e=$y(e,y[(h+l|0)+b|0]);h=h+1|0;continue}break}x[n>>2]=k-g;x[o>>2]=e;if((j|0)>=(k|0)){h=e;e=f+1424|0;if((h|0)==x[e>>2]){x[a+1380>>2]=-1;x[a+992>>2]=0;x[a+1420>>2]=-1;b=x[(D(d,20)+a|0)+1440>>2];x[a+1060>>2]=b;x[a+1064>>2]=(b|0)!=-1;h=g+l|0;break c}f=P-1|0;x[a+1420>>2]=f;f=D(f,20)+a|0;x[e+16>>2]=x[f+1440>>2];h=f+1432|0;k=x[h+4>>2];x[e+8>>2]=x[h>>2];x[e+12>>2]=k;f=f+1424|0;h=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=h;P=x[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=h}break a}x[a+100>>2]=0;x[a+32>>2]=b;x[a+40>>2]=b+c;if(!GL(a)){x[f>>2]=0;c=0;break a}ha=fb-16|0;fb=ha;ja=ba+4|0;x[a+1504>>2]=0;x[a+1508>>2]=0;h:{if(x[a+96>>2]){break h}i:{j:{k:{if(x[a+1380>>2]!=-1){break k}c=df(a);if(x[a+96>>2]){break i}if((c|0)!=79){break j}if((df(a)|0)!=103){break j}if((df(a)|0)!=103){break j}if((df(a)|0)!=83){break j}if(!FL(a)){break i}if(!(v[a+1375|0]&1)){break k}v[a+1376|0]=0;x[a+1384>>2]=0;fc(a,32);break i}k=Yy(a);break i}fc(a,30)}if(!k){break h}if(qc(a,1)){fc(a,35);break h}l:{m:{if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){c=qc(a,Fm(x[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=x[a+408>>2]){break h}x[ha+12>>2]=c;j=D(c,6)+a|0;if(!y[j+412|0]){h=x[a+112>>2];k=h>>1;break m}h=x[a+116>>2];k=h>>1;c=qc(a,1);l=qc(a,1);if(c|!y[j+412|0]){break m}x[ja>>2]=h-x[a+112>>2]>>2;c=x[a+112>>2]+h>>2;break l}_(6345,13279,3152,10773);p()}x[ja>>2]=0;c=k}x[ha+8>>2]=c;n:{if(!(!y[j+412|0]|l)){c=D(h,3);x[ba+8>>2]=c-x[a+112>>2]>>2;h=c+x[a+112>>2]>>2;break n}x[ba+8>>2]=k}x[ha+4>>2]=h;h=1}if(h){S=x[ja>>2];la=x[ba+8>>2];ka=x[ha+4>>2];N=fb-2368|0;fb=N;G=x[a+404>>2];oa=D(x[ha+12>>2],6)+a|0;C=y[oa+413|0];Q=G+D(C,40)|0;V=x[((y[oa+412|0]<<2)+a|0)+104>>2];fa=V>>1;ra=0-fa|0;o:{while(1){c=x[a+4>>2];if((c|0)>(g|0)){c=y[(x[Q+4>>2]+D(g,3)|0)+2|0];O=(N+1344|0)+(g<<2)|0;x[O>>2]=0;h=y[(c+Q|0)+9|0];if(z[((h<<1)+a|0)+132>>1]){k=x[a+260>>2];p:{q:{if(!qc(a,1)){break q}c=2;j=x[((g<<2)+a|0)+996>>2];k=k+D(h,1596)|0;F=x[(y[k+1588|0]<<2)+89372>>2];h=Fm(F)-1|0;ta=j,ua=qc(a,h),w[ta>>1]=ua;ta=j,ua=qc(a,h),w[ta+2>>1]=ua;H=k+82|0;W=k+65|0;T=k+49|0;R=k+33|0;K=k+1|0;t=0;while(1){if(y[k|0]>t>>>0){o=y[t+K|0];u=y[o+T|0];i=-1<<u;n=y[o+R|0];r:{if(!u){l=0;break r}h=x[a+124>>2]+D(y[o+W|0],2096)|0;if(x[a+1396>>2]<=9){tl(a)}l=x[a+1392>>2];X=w[(h+((l&1023)<<1)|0)+36>>1];s:{if((X|0)>=0){q=l;X=X&65535;l=y[X+x[h+8>>2]|0];x[a+1392>>2]=q>>>l;l=x[a+1396>>2]-l|0;x[a+1396>>2]=(l|0)>0?l:0;l=(l|0)<0?-1:X;break s}l=Em(a,h)}if(!y[h+23|0]){break r}l=x[x[h+2088>>2]+(l<<2)>>2]}X=i^-1;h=c+n|0;while(1){if((c|0)!=(h|0)){n=0;i=w[(H+(o<<4)|0)+((l&X)<<1)>>1];t:{if((i|0)<0){break t}i=x[a+124>>2]+D(i&65535,2096)|0;if(x[a+1396>>2]<=9){tl(a)}n=x[a+1392>>2];Y=w[(i+((n&1023)<<1)|0)+36>>1];u:{if((Y|0)>=0){q=n;Y=Y&65535;n=y[Y+x[i+8>>2]|0];x[a+1392>>2]=q>>>n;n=x[a+1396>>2]-n|0;x[a+1396>>2]=(n|0)>0?n:0;n=(n|0)<0?-1:Y;break u}n=Em(a,i)}if(!y[i+23|0]){break t}n=x[x[i+2088>>2]+(n<<2)>>2]}l=l>>u;w[j+(c<<1)>>1]=n;c=c+1|0;continue}break}t=t+1|0;c=h;continue}break}if(x[a+1396>>2]==-1){break q}w[N+320>>1]=257;h=k+338|0;t=k+1088|0;c=2;while(1){n=x[k+1592>>2];if((n|0)<=(c|0)){c=0;while(1){if((c|0)>=(n|0)){break p}if(!y[(N+320|0)+c|0]){w[j+(c<<1)>>1]=65535;n=x[k+1592>>2]}c=c+1|0;continue}}else{l=c<<1;n=l+t|0;u=y[n|0];o=u<<1;i=z[o+h>>1];O=y[n+1|0];H=O<<1;W=w[j+o>>1];n=w[H+j>>1]-W|0;o=n>>31;i=(D((n^o)-o|0,z[h+l>>1]-i|0)|0)/(z[h+H>>1]-i|0)|0;n=W+((n|0)<0?0-i|0:i)|0;H=j+l|0;i=z[H>>1];v:{w:{if(i){l=N+320|0;v[l+O|0]=1;v[l+u|0]=1;v[c+l|0]=1;l=i<<16>>16;o=F-n|0;if((l|0)>=((n|0)>(o|0)?o:n)<<1){if((n|0)<(o|0)){break v}n=F+(i^-1)|0;break w}if(l&1){n=n-(l+1>>>1|0)|0;break w}n=(l>>1)+n|0;break w}v[(N+320|0)+c|0]=0}w[H>>1]=n}c=c+1|0;continue}}}x[O>>2]=1}g=g+1|0;continue}else{fc(a,21);c=0;break o}}break}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){yc(N+320|0,N+1344|0,c<<2);k=z[Q>>1];c=0;while(1){if((c|0)==(k|0)){X=G+D(C,40)|0}else{g=x[Q+4>>2]+D(c,3)|0;h=y[g+1|0];n=N+1344|0;g=n+(y[g|0]<<2)|0;if(!(x[(h<<2)+n>>2]?x[g>>2]:0)){x[(N+1344|0)+(h<<2)>>2]=0;x[g>>2]=0}c=c+1|0;continue}break}l=0;while(1){x:{if(y[X+8|0]>l>>>0){n=0;c=x[a+4>>2];g=(c|0)>0?c:0;c=0;while(1){if((c|0)==(g|0)){break x}if(y[(x[Q+4>>2]+D(c,3)|0)+2|0]==(l|0)){j=n+N|0;k=c<<2;y:{if(x[k+(N+1344|0)>>2]){k=0;h=1;break y}k=x[(a+k|0)+800>>2];h=0}v[j|0]=h;x[(N+256|0)+(n<<2)>>2]=k;n=n+1|0}c=c+1|0;continue}}if(!(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0)){g=(fa|0)>0?fa:0;h=z[Q>>1];k=a+800|0;z:while(1){if((h|0)<=0){O=fa<<2;n=0;c=0;while(1){l=x[a+4>>2];if((l|0)<=(c|0)){while(1){if((n|0)<(l|0)){O=y[oa+412|0];Q=V>>1;h=Q<<2;X=x[a+92>>2];F=V>>3;W=V>>2;k=x[((n<<2)+a|0)+800>>2];c=Q<<2;u=k+c|0;A:{if(x[a+80>>2]){l=ho(a,h);break A}l=Ed(h)}h=(l+c|0)-8|0;j=x[((O<<2)+a|0)+1068>>2];i=j;c=k;while(1){if((c|0)!=(u|0)){B[h+4>>2]=E(B[c>>2]*B[i>>2])-E(B[i+4>>2]*B[c+8>>2]);B[h>>2]=E(B[c>>2]*B[i+4>>2])+E(B[c+8>>2]*B[i>>2]);c=c+16|0;i=i+8|0;h=h-8|0;continue}break}c=((Q<<2)+k|0)-12|0;while(1){if(h>>>0>=l>>>0){B[h+4>>2]=E(B[c>>2]*B[i+4>>2])-E(B[c+8>>2]*B[i>>2]);B[h>>2]=E(E(-B[c+8>>2])*B[i+4>>2])-E(B[i>>2]*B[c>>2]);c=c-16|0;i=i+8|0;h=h-8|0;continue}break}c=W<<2;t=c+k|0;h=c+l|0;i=(j+(Q<<2)|0)-32|0;c=l;g=k;while(1){if(i>>>0>=j>>>0){m=B[c>>2];r=B[h>>2];s=B[h+4>>2];I=B[c+4>>2];B[t+4>>2]=s+I;B[t>>2]=B[h>>2]+B[c>>2];s=E(s-I);m=E(r-m);B[g+4>>2]=E(s*B[i+16>>2])-E(B[i+20>>2]*m);B[g>>2]=E(m*B[i+16>>2])+E(s*B[i+20>>2]);m=B[c+8>>2];r=B[h+8>>2];s=B[h+12>>2];I=B[c+12>>2];B[t+12>>2]=s+I;B[t+8>>2]=B[h+8>>2]+B[c+8>>2];s=E(s-I);m=E(r-m);B[g+12>>2]=E(s*B[i>>2])-E(B[i+4>>2]*m);B[g+8>>2]=E(m*B[i>>2])+E(s*B[i+4>>2]);c=c+16|0;h=h+16|0;g=g+16|0;t=t+16|0;i=i-32|0;continue}break}h=Fm(V);c=V>>4;o=Q-1|0;g=0-F|0;CL(c,k,o,g,j);CL(c,k,o-W|0,g,j);H=V>>5;c=0-c|0;Zp(H,k,o,c,j,16);Zp(H,k,o-F|0,c,j,16);Zp(H,k,o-(F<<1)|0,c,j,16);Zp(H,k,o+D(F,-3)|0,c,j,16);c=h-4>>1;t=(c|0)<=2?2:c;c=2;while(1){B:{C:{D:{if((c|0)==(t|0)){Y=h-7|0;break D}i=0;g=2<<c;g=(g|0)>0?g:0;F=8<<c;C=V>>c+4;G=V>>c+2;T=0-(G>>1)|0;while(1){if((g|0)==(i|0)){break C}Zp(C,k,o-D(i,G)|0,T,j,F);i=i+1|0;continue}}while(1){E:{if((t|0)<(Y|0)){ma=32<<t;F=2<<t;T=8<<t;i=V>>t+6;aa=V>>t+2;ga=0-(aa>>1)|0;h=o;c=j;while(1){if((i|0)<=0){break E}g=F;C=(h<<2)+k|0;G=C+(ga<<2)|0;R=D(T,12)+c|0;m=B[R>>2];K=(T<<3)+c|0;r=B[K>>2];q=(T<<2)+c|0;s=B[q>>2];I=B[R+4>>2];L=B[K+4>>2];Z=B[q+4>>2];$=B[c+4>>2];ea=B[c>>2];R=0-aa<<2;while(1){if((g|0)>0){K=G-4|0;M=B[K>>2];ca=B[C>>2];da=B[G>>2];B[C>>2]=ca+da;q=C-4|0;J=B[q>>2];B[q>>2]=J+B[K>>2];J=E(J-M);M=E(ca-da);B[K>>2]=E(J*ea)+E($*M);B[G>>2]=E(M*ea)-E($*J);K=G-12|0;ca=B[K>>2];q=C-8|0;J=B[q>>2];U=q;q=G-8|0;da=B[q>>2];B[U>>2]=J+da;U=C-12|0;M=B[U>>2];B[U>>2]=M+B[K>>2];M=E(M-ca);J=E(J-da);B[K>>2]=E(M*s)+E(Z*J);B[q>>2]=E(J*s)-E(Z*M);K=G-20|0;ca=B[K>>2];q=C-16|0;J=B[q>>2];U=q;q=G-16|0;da=B[q>>2];B[U>>2]=J+da;U=C-20|0;M=B[U>>2];B[U>>2]=M+B[K>>2];M=E(M-ca);J=E(J-da);B[K>>2]=E(M*r)+E(L*J);B[q>>2]=E(J*r)-E(L*M);K=G-28|0;ca=B[K>>2];q=C-24|0;J=B[q>>2];U=q;q=G-24|0;da=B[q>>2];B[U>>2]=J+da;U=C-28|0;M=B[U>>2];B[U>>2]=M+B[K>>2];M=E(M-ca);J=E(J-da);B[K>>2]=E(M*m)+E(I*J);B[q>>2]=E(J*m)-E(I*M);g=g-1|0;G=G+R|0;C=C+R|0;continue}break}i=i-1|0;h=h-8|0;c=(ma<<2)+c|0;continue}}c=(o<<2)+k|0;g=c-(H<<6)|0;m=B[j+(V>>3<<2)>>2];ea=E(-m);while(1){if(c>>>0>g>>>0){L=B[c>>2];h=c-32|0;Z=B[h>>2];B[c>>2]=L+Z;j=c-4|0;r=B[j>>2];q=j;j=c-36|0;$=B[j>>2];B[q>>2]=r+$;i=c-8|0;s=B[i>>2];q=i;i=c-40|0;J=B[i>>2];B[q>>2]=s+J;o=c-12|0;I=B[o>>2];q=o;o=c-44|0;M=B[o>>2];B[q>>2]=I+M;B[h>>2]=L-Z;B[j>>2]=r-$;j=c-16|0;r=B[j>>2];q=j;j=c-48|0;ca=B[j>>2];B[q>>2]=r+ca;s=E(s-J);I=E(I-M);B[i>>2]=m*E(s+I);B[o>>2]=m*E(I-s);i=c-28|0;s=B[i>>2];o=c-60|0;I=B[o>>2];F=c-24|0;L=B[F>>2];t=c-56|0;Z=B[t>>2];C=c-20|0;$=B[C>>2];q=C;C=c-52|0;J=B[C>>2];B[q>>2]=$+J;B[F>>2]=L+Z;B[i>>2]=s+I;B[j>>2]=$-J;B[C>>2]=-E(r-ca);r=E(s-I);s=E(L-Z);B[t>>2]=m*E(r-s);B[o>>2]=E(s+r)*ea;BL(c);BL(h);c=c+-64|0;continue}break}o=Q-4|0;h=l+(o<<2)|0;i=(l+(W<<2)|0)-16|0;c=x[((O<<2)+a|0)+1100>>2];while(1){if(i>>>0>=l>>>0){g=(z[c>>1]<<2)+k|0;B[h+12>>2]=B[g>>2];B[h+8>>2]=B[g+4>>2];B[i+12>>2]=B[g+8>>2];B[i+8>>2]=B[g+12>>2];g=(z[c+2>>1]<<2)+k|0;B[h+4>>2]=B[g>>2];B[h>>2]=B[g+4>>2];B[i+4>>2]=B[g+8>>2];B[i>>2]=B[g+12>>2];c=c+4|0;h=h-16|0;i=i-16|0;continue}break}c=x[((O<<2)+a|0)+1084>>2];i=l;h=i+(Q<<2)|0;j=h;while(1){g=j-16|0;if(g>>>0>i>>>0){m=B[i+4>>2];F=j-4|0;r=B[F>>2];s=E(m-r);I=B[c+4>>2];m=E(m+r);r=B[i>>2];t=j-8|0;L=B[t>>2];Z=E(r-L);$=B[c>>2];ea=E(E(I*m)-E(Z*$));B[i+4>>2]=s+ea;r=E(r+L);m=E(E(I*Z)+E(m*$));B[i>>2]=r+m;B[F>>2]=ea-s;B[t>>2]=r-m;m=B[i+8>>2];r=B[g>>2];s=E(m+r);I=B[c+12>>2];m=E(m-r);r=B[i+12>>2];j=j-12|0;L=B[j>>2];Z=E(r+L);$=B[c+8>>2];ea=E(E(I*m)+E(Z*$));B[i+8>>2]=s+ea;r=E(r-L);m=E(E(I*Z)-E(m*$));B[i+12>>2]=r+m;B[g>>2]=s-ea;B[j>>2]=m-r;i=i+16|0;c=c+16|0;j=g;continue}break}i=x[((O<<2)+a|0)+1076>>2]+(Q<<2)|0;c=(o<<2)+k|0;j=((V<<2)+k|0)-16|0;while(1){g=h-32|0;if(g>>>0>=l>>>0){m=B[h-8>>2];r=B[i-4>>2];s=B[i-8>>2];I=B[h-4>>2];L=E(E(m*r)-E(s*I));B[k>>2]=L;B[c+12>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u>>2]=m;B[j+12>>2]=m;m=B[h-16>>2];r=B[i-12>>2];s=B[i-16>>2];I=B[h-12>>2];L=E(E(m*r)-E(s*I));B[k+4>>2]=L;B[c+8>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u+4>>2]=m;B[j+8>>2]=m;m=B[h-24>>2];r=B[i-20>>2];s=B[i-24>>2];I=B[h-20>>2];L=E(E(m*r)-E(s*I));B[k+8>>2]=L;B[c+4>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u+8>>2]=m;B[j+4>>2]=m;m=B[g>>2];r=B[i-28>>2];i=i-32|0;s=B[i>>2];I=B[h-28>>2];L=E(E(m*r)-E(s*I));B[k+12>>2]=L;B[c>>2]=-L;m=E(E(s*E(-m))-E(r*I));B[u+12>>2]=m;B[j>>2]=m;j=j-16|0;c=c-16|0;u=u+16|0;k=k+16|0;h=g;continue}break}if(!x[a+80>>2]){Db(l)}x[a+92>>2]=X;break B}t=t+1|0;continue}}c=c+1|0;continue}break}n=n+1|0;l=x[a+4>>2];continue}break}}else{h=c<<2;k=h+a|0;i=x[k+800>>2];F:{if(x[h+(N+320|0)>>2]){Tb(i,0,O);break F}G=x[k+996>>2];G:{h=y[(y[(x[Q+4>>2]+D(c,3)|0)+2|0]+Q|0)+9|0];if(!z[((h<<1)+a|0)+132>>1]){fc(a,21);break G}o=V>>1;F=x[a+260>>2]+D(h,1596)|0;H=F+338|0;W=F+838|0;k=D(y[F+1588|0],w[G>>1]);t=1;h=0;while(1){if(x[F+1592>>2]>(t|0)){g=y[t+W|0]<<1;l=w[g+G>>1];if((l|0)>=0){j=D(y[F+1588|0],l&65535);l=z[g+H>>1];if((l|0)!=(h|0)){g=j-k|0;u=l-h|0;C=(g|0)/(u|0)|0;H:{T=(l|0)<(o|0)?l:o;if((T|0)<=(h|0)){break H}q=g;g=g>>31;R=C>>31;R=((q^g)-g|0)-D(u,(R^C)-R|0)|0;K=g|1;g=i+(h<<2)|0;B[g>>2]=B[((k&255)<<2)+89392>>2]*B[g>>2];T=T-1|0;g=0;while(1){if((h|0)==(T|0)){break H}h=h+1|0;X=i+(h<<2)|0;g=g+R|0;Y=(g|0)<(u|0);k=(k+C|0)+(Y?0:K)|0;B[X>>2]=B[((k&255)<<2)+89392>>2]*B[X>>2];g=g-(Y?0:u)|0;continue}}h=l}k=j}t=t+1|0;continue}break}if((h|0)>=(o|0)){break G}k=(k<<2)+89392|0;while(1){if((h|0)==(o|0)){break G}g=i+(h<<2)|0;B[g>>2]=B[k>>2]*B[g>>2];h=h+1|0;continue}}}c=c+1|0;continue}break}EL(a);I:{if(y[a+1377|0]){x[a+1060>>2]=ra;v[a+1377|0]=0;x[a+1064>>2]=1;x[a+1412>>2]=V-ka;break I}c=x[a+1412>>2];if(!c){break I}h=la-S|0;if((h|0)<=(c|0)){x[a+1412>>2]=c-h;x[ja>>2]=la;S=la;break I}S=c+S|0;x[ja>>2]=S;x[a+1412>>2]=0}c=x[a+1064>>2];J:{K:{L:{M:{if(x[a+1388>>2]==x[a+1404>>2]){N:{if(!c|!(y[a+1375|0]&4)){break N}c=x[a+1408>>2];h=x[a+1060>>2];if(c>>>0>=h+(ka-S|0)>>>0){break N}h=c-h|0;c=(c>>>0>=h>>>0?h:0)+S|0;c=(c|0)<(ka|0)?c:ka;x[ba+12>>2]=c;x[a+1060>>2]=c+x[a+1060>>2];break K}x[a+1064>>2]=1;c=x[a+1408>>2]+(S-fa|0)|0;break M}if(!c){break L}c=x[a+1060>>2]}x[a+1060>>2]=c+(la-S|0)}if(x[a+84>>2]!=x[a+92>>2]?x[a+80>>2]:0){break J}x[ba+12>>2]=ka}c=1;break o}_(6345,13279,3451,5654);p()}h=h-1|0;c=x[Q+4>>2]+D(h,3)|0;l=x[k+(y[c+1|0]<<2)>>2];j=x[k+(y[c|0]<<2)>>2];c=0;while(1){if((c|0)==(g|0)){continue z}i=c<<2;n=i+l|0;s=B[n>>2];i=i+j|0;m=B[i>>2];O:{if(m>E(0)){if(s>E(0)){r=E(m-s);break O}r=m;m=E(m+s);break O}if(s>E(0)){r=E(m+s);break O}r=m;m=E(m-s)}B[i>>2]=m;B[n>>2]=r;c=c+1|0;continue}}}_(6345,13279,3335,5654);p()}W=N+256|0;i=0;t=fb-16|0;fb=t;u=x[a+4>>2];G=x[a+396>>2];C=y[(l+X|0)+24|0];F=G+D(C,24)|0;h=x[F+4>>2];Y=z[((C<<1)+a|0)+268>>1];c=fa<<((Y|0)==2);g=c>>>0>h>>>0?h:c;h=x[F>>2];O=(g-(c>>>0>h>>>0?h:c)>>>0)/A[F+8>>2]|0;k=O<<2;c=D(u,k+4|0);K=x[x[a+124>>2]+D(y[F+13|0],2096)>>2];U=x[a+92>>2];P:{if(x[a+80>>2]){h=ho(a,c);u=x[a+4>>2];break P}h=Ed(c)}o=(n|0)>0?n:0;H=fa<<2;g=0;c=(u|0)>0?u:0;j=(u<<2)+h|0;while(1){if((c|0)!=(g|0)){x[(g<<2)+h>>2]=j;g=g+1|0;j=j+k|0;continue}break}k=h;c=0;while(1){if((c|0)!=(o|0)){if(!y[c+N|0]){Tb(x[W+(c<<2)>>2],0,H)}c=c+1|0;continue}break}Q:{if(!((n|0)==1|(Y|0)!=2)){c=0;while(1){R:{if((c|0)!=(o|0)){if(y[c+N|0]){break R}}else{c=o}if((c|0)==(n|0)){break Q}u=G+D(C,24)|0;C=(n|0)!=2;G=(n|0)<3;while(1){if((i|0)==8){break Q}S:{if(!C){h=0;j=0;while(1){if((j|0)>=(O|0)){break S}c=x[F>>2]+D(x[F+8>>2],j)|0;x[t+12>>2]=c&1;x[t+8>>2]=c>>1;c=0;if(!i){o=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){tl(a)}g=x[a+1392>>2];H=w[(o+((g&1023)<<1)|0)+36>>1];T:{if((H|0)>=0){q=g;H=H&65535;g=y[H+x[o+8>>2]|0];x[a+1392>>2]=q>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:H;break T}g=Em(a,o)}g=y[o+23|0]?x[x[o+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[k>>2]+(h<<2)>>2]=x[x[u+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(j|0)>=(O|0))){g=x[F+8>>2];o=w[(x[u+20>>2]+(y[x[x[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];U:{if((o|0)>=0){if(!DL(a,x[a+124>>2]+D(o&65535,2096)|0,W,2,t+12|0,t+8|0,fa,g)){break Q}j=j+1|0;break U}j=j+1|0;g=x[F>>2]+D(g,j)|0;x[t+8>>2]=g>>1;x[t+12>>2]=g&1}c=c+1|0;continue}break}h=h+1|0;continue}}if(G){break S}h=0;j=0;while(1){if((j|0)>=(O|0)){break S}g=x[F>>2]+D(x[F+8>>2],j)|0;c=(g|0)/(n|0)|0;x[t+12>>2]=g-D(c,n);x[t+8>>2]=c;c=0;if(!i){o=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){tl(a)}g=x[a+1392>>2];H=w[(o+((g&1023)<<1)|0)+36>>1];V:{if((H|0)>=0){q=g;H=H&65535;g=y[H+x[o+8>>2]|0];x[a+1392>>2]=q>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:H;break V}g=Em(a,o)}g=y[o+23|0]?x[x[o+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[k>>2]+(h<<2)>>2]=x[x[u+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(j|0)>=(O|0))){g=x[F+8>>2];o=w[(x[u+20>>2]+(y[x[x[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(i<<1)>>1];W:{if((o|0)>=0){if(!DL(a,x[a+124>>2]+D(o&65535,2096)|0,W,n,t+12|0,t+8|0,fa,g)){break Q}j=j+1|0;break W}j=j+1|0;g=x[F>>2]+D(g,j)|0;o=(g|0)/(n|0)|0;x[t+8>>2]=o;x[t+12>>2]=g-D(n,o)}c=c+1|0;continue}break}h=h+1|0;continue}}i=i+1|0;continue}}c=c+1|0;continue}}ma=G+D(C,24)|0;n=0;while(1){if((n|0)==8){break Q}i=0;T=0;X:while(1){if((i|0)<(O|0)){h=0;c=0;Y:{if(n){break Y}while(1){if((c|0)==(o|0)){break Y}if(!y[c+N|0]){j=x[a+124>>2]+D(y[F+13|0],2096)|0;if(x[a+1396>>2]<=9){tl(a)}g=x[a+1392>>2];u=w[(j+((g&1023)<<1)|0)+36>>1];Z:{if((u|0)>=0){q=g;u=u&65535;g=y[u+x[j+8>>2]|0];x[a+1392>>2]=q>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;g=(g|0)<0?-1:u;break Z}g=Em(a,j)}g=y[j+23|0]?x[x[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}x[x[k+(c<<2)>>2]+(T<<2)>>2]=x[x[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((h|0)>=(K|0)){break $}c=0;if((i|0)>=(O|0)){break $}while(1){if((c|0)==(o|0)){break _}aa:{if(y[c+N|0]){break aa}g=c<<2;j=w[(x[ma+20>>2]+(y[x[x[g+k>>2]+(T<<2)>>2]+h|0]<<4)|0)+(n<<1)>>1];if((j|0)<0){break aa}G=x[a+124>>2]+D(j&65535,2096)|0;aa=x[g+W>>2];R=x[F+8>>2];H=x[F>>2]+D(R,i)|0;ba:{ca:{if(Y){u=0;while(1){g=1;if((u|0)>=(R|0)){break ba}ga=aa+(H<<2)|0;g=R-u|0;C=0;m=E(0);da:{q=AL(a,G);if((q|0)<0){break da}j=x[G>>2];g=(g|0)>(j|0)?j:g;q=D(j,q);if(y[G+22|0]){j=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(j|0)){break da}ia=ga+(j<<2)|0;m=E(m+B[x[G+28>>2]+(j+q<<2)>>2]);B[ia>>2]=B[ia>>2]+m;j=j+1|0;m=E(m+B[G+12>>2]);continue}}j=0;g=(g|0)>0?g:0;C=1;while(1){if((g|0)==(j|0)){break da}ia=ga+(j<<2)|0;B[ia>>2]=B[ia>>2]+E(B[x[G+28>>2]+(j+q<<2)>>2]+E(0));j=j+1|0;continue}}if(!C){break ca}g=x[G>>2];H=g+H|0;u=g+u|0;continue}}u=0;ga=(R|0)/x[G>>2]|0;q=(ga|0)>0?ga:0;ia=aa+(H<<2)|0;g=1;while(1){if((u|0)==(q|0)){break ba}j=u+H|0;C=u<<2;u=u+1|0;sa=C+ia|0;aa=R-j|0;j=0;m=E(0);ea:{na=AL(a,G);if((na|0)<0){break ea}C=0;j=x[G>>2];aa=(j|0)<(aa|0)?j:aa;aa=(aa|0)>0?aa:0;na=D(j,na);j=1;while(1){if((C|0)==(aa|0)){break ea}qa=sa+(D(C,ga)<<2)|0;r=E(m+B[x[G+28>>2]+(C+na<<2)>>2]);B[qa>>2]=B[qa>>2]+r;m=y[G+22|0]?r:m;C=C+1|0;continue}}if(j){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}}T=T+1|0;continue X}i=i+1|0;h=h+1|0;continue}}break}n=n+1|0;continue}}if(!x[a+80>>2]){Db(k)}x[a+92>>2]=U;fb=t+16|0;l=l+1|0;continue}}_(6345,13279,3302,5654);p()}fb=N+2368|0}else{c=0}fb=ha+16|0;if(!c){fa:{ga:{ha:{c=x[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}x[a+100>>2]=0;while(1){if((Lh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}if(x[a+992>>2]){break fa}x[a+100>>2]=0;while(1){if((Lh(a)|0)!=-1&!x[a+96>>2]){continue}break}x[f>>2]=0;c=x[a+32>>2]-b|0;break a}x[a+1420>>2]=0;x[a+992>>2]=0;x[a+1504>>2]=0;x[a+1508>>2]=0;x[a+1412>>2]=0;x[a+1416>>2]=0;v[a+1377|0]=0;x[a+1064>>2]=0;x[a+100>>2]=c;x[f>>2]=0;c=1;break a}g=x[ba+12>>2];j=x[ba+4>>2];k=x[ba+8>>2];ia:{ja:{l=x[a+992>>2];if(l){h=l<<1;ka:{if((h|0)==x[a+112>>2]){c=a+1092|0}else{c=0;if((h|0)!=x[a+116>>2]){break ka}c=a+1096|0}c=x[c>>2]}if(!c){break ja}n=(l|0)>0?l:0;while(1){if(x[a+4>>2]>(P|0)){i=(P<<2)+a|0;h=0;while(1){if((h|0)!=(n|0)){S=x[i+800>>2]+(h+j<<2)|0;q=S;m=B[S>>2];S=h<<2;B[q>>2]=E(m*B[S+c>>2])+E(B[S+x[i+928>>2]>>2]*B[c+(l+(h^-1)<<2)>>2]);h=h+1|0;continue}break}P=P+1|0;continue}break}P=x[a+992>>2]}x[a+992>>2]=g-k;l=(g|0)<(k|0);i=(l?k:g)-k|0;while(1){if(x[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;h=0;while(1){if((h|0)!=(i|0)){B[x[c+928>>2]+(h<<2)>>2]=B[x[c+800>>2]+(h+k<<2)>>2];h=h+1|0;continue}break}pa=pa+1|0;continue}break}if(!P){break ja}c=(l?g:k)-j|0;x[a+1416>>2]=c+x[a+1416>>2];break ia}c=0}h=c;c=0;k=x[a+4>>2];g=(k|0)>0?k:0;while(1){if((c|0)!=(g|0)){l=(c<<2)+a|0;x[l+864>>2]=x[l+800>>2]+(j<<2);c=c+1|0;continue}break}if(d){x[d>>2]=k}x[f>>2]=h;x[e>>2]=a+864;c=x[a+32>>2]-b|0}fb=ba+16|0;return c}function Cpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=fb-1728|0;fb=d;xc(b);f=fb-16|0;fb=f;h=d+1602|0;wX(f+8|0,h);g=x[f+12>>2];l=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){Yb(l,x[f+12>>2])}fb=f+16|0;b=(b|0)==(g|0);if(!b){vX(h)}a:{if(!b){break a}if(!xX(d+1602|0)){break a}if(!Mb(x[l>>2],x[l+8>>2],Bc(256,0))){break a}b:{if(!c){break b}Bd(a,1048576);ag(a);b=fb-16|0;fb=b;e=uc(b+4|0,4250);Yc(d+1344|0,e);tb(e);fb=b+16|0;b=y[d+1610|0]|y[d+1611|0]<<8;x[d+144>>2]=b>>>8;x[31785]=0;x[d+12>>2]=b&255;O(448,d+72|0,d+12|0);b=x[31785];x[31785]=0;c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){x[31785]=0;V(434,d+256|0,d+1344|0,d+144|0,d+72|0);b=x[31785];x[31785]=0;if((b|0)==1){break i}b=d+256|0;yb(a+1298344|0,b);tb(b);tb(d+72|0);e=d+1344|0;Eb(e);f=uc(b,15294);yb(a+1298356|0,f);tb(f);Te(e,2,d+1612|0);Xv(b,22,e);yb(a+1298368|0,b);tb(b);H=a+1298404|0,I=x[Gc(b,22)>>2],x[H>>2]=I;uC(e,2,d+1644|0);Ec(b,e);yb(a+1298308|0,b);tb(b);w[a+480188>>1]=y[d+1714|0]|y[d+1715|0]<<8;f=y[d+1718|0];x[a+480204>>2]=125e4;x[a+480208>>2]=32792;H=a,I=Hd(f,1,31),x[H+480196>>2]=I;w[a+480192>>1]=y[d+1724|0]|y[d+1725|0]<<8;w[a+480190>>1]=y[d+1726|0]|y[d+1727|0]<<8;f=Hd(y[d+1719|0],1,32);x[a+480216>>2]=f;x[a+480228>>2]=96;x[a+480232>>2]=48;x[a+480220>>2]=f<<2;sw(l,e);f=a+484360|0;g=a+484376|0;Dr(Wb(x[f>>2],y[g|0]),e,y[d+1708|0]|y[d+1709|0]<<8,65535,65535);_e(Wb(x[f>>2],y[g|0]),y[d+1710|0]|y[d+1711|0]<<8);r=eh(l);ce(b,l,r?274:0);C=ic(d+1324|0,b);ub(b);x[31785]=0;b=R(154,l|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break g}x[31785]=0;S(188,d+256|0,l|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break g}b=d+256|0;t=ic(d+1304|0,b);ub(b);b=a+480188|0;o=z[b>>1];if(r){w[b>>1]=o+8}B=c&1;if(!B){break f}x[31785]=0;O(226,a+484344|0,y[d+1712|0]|y[d+1713|0]<<8);b=x[31785];x[31785]=0;if((b|0)!=1){break f}g=N()|0;break e}g=N()|0;break h}g=N()|0;tb(d+72|0)}Eb(d+1344|0);break c}g=N()|0;break d}n=a+484344|0;E=a+480188|0;g=0;j:{k:{while(1){l:{m:{n:{o:{p:{q:{if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=s>>>0){b=y[d+1716|0]|y[d+1717|0]<<8;if((b-2&65535)>>>0>=4998){break o}if(!(g&1)){break q}h=0;b=Fc(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break p}x[31785]=0;b=R(192,l|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break j}x[d+12>>2]=b;x[31785]=0;b=R(154,l|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break k}x[31785]=0;S(188,d+72|0,l|0,b+1&-2);b=x[31785];x[31785]=0;if((b|0)==1){break k}b=d+72|0;j=ic(d+256|0,b);ub(b);vc(d+12|0,1024);if(!B){break m}m=x[d+12>>2];if(!m){break m}x[31785]=0;b=U(199,n|0,s&65535,m|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){if(!b){break m}k=0;e=0;if(v[d+1720|0]&1){break n}r:while(1){if((k|0)==(m|0)){break m}b=Vb(x[n>>2],s);Ve(d+72|0,x[b>>2],x[x[b+48>>2]+12>>2],k);e=0;while(1){if((e|0)==(o|0)){k=k+1|0;continue r}x[31785]=0;O(626,j|0,d+144|0);b=x[31785];x[31785]=0;if((b|0)!=1){g=uX(Vc(x[d+72>>2],e),d+144|0)|g;e=e+1|0;continue}break}break}break l}break l}h=2;b=Xe(2646e3/+(D(b,D(x[a+480216>>2],x[a+480196>>2]))>>>0)*1e4)}v[a+480224|0]=h;x[a+480204>>2]=b}h=a+480188|0;b=z[h>>1];x[31785]=0;v[d+256|0]=0;s=U(627,d+1292|0,b|0,d+256|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){k=a+1298320|0;m=a+1298332|0;q=a+484348|0;j=0;s:{t:{u:{v:{w:{x:{while(1){b=x[t+8>>2];e=x[t>>2];x[31785]=0;b=U(153,e|0,b|0,8)|0;e=x[31785];x[31785]=0;y:{if((e|0)!=1){if(b){break y}b=a+906300|0;h=x[s>>2];k=0;m=a+480188|0;while(1){f=z[m>>1];if(f>>>0<=k>>>0){x[d+248>>2]=0;x[d+252>>2]=0;x[d+240>>2]=0;x[d+244>>2]=0;x[d+232>>2]=0;x[d+236>>2]=0;x[d+224>>2]=0;x[d+228>>2]=0;z:{A:{if(!r){break A}e=0;x[31785]=0;O(628,C|0,d+256|0);b=x[31785];x[31785]=0;if((b|0)==1){break z}while(1){if((e|0)==8){e=0;x[31785]=0;k=P(217,d+212|0,z[d+256>>1])|0;b=x[31785];x[31785]=0;if((b|0)!=1){B:{C:{D:{E:{while(1){if(z[d+256>>1]<=e>>>0){x[31785]=0;m=U(629,d+200|0,y[d+1712|0]|y[d+1713|0]<<8,25532)|0;b=x[31785];x[31785]=0;if((b|0)==1){break C}q=a+484376|0;r=a+484348|0;B=a+480188|0;f=0;break D}x[31785]=0;b=R(192,l|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){x[31785]=0;S(188,d+144|0,l|0,b<<5);b=x[31785];x[31785]=0;if((b|0)==1){break E}f=d+144|0;b=ic(d+72|0,f);hd($g(x[k>>2],e),b);ub(b);e=e+1|0;ub(f);continue}break}g=N()|0;break B}g=N()|0;break B}while(1){if((y[d+1708|0]|y[d+1709|0]<<8)>>>0<=f>>>0){kd(m);Qc(k);break A}F:{g=d+f|0;e=y[g+274|0];if(e>>>0>=z[d+256>>1]){break F}b=z[_b(x[Wb(x[a+484360>>2],y[q|0])>>2],f)>>1];if(b>>>0>=(y[d+1712|0]|y[d+1713|0]<<8)>>>0){break F}G:{h=_b(x[m>>2],b);i=z[h>>1];H:{if((i|0)==65535){w[h>>1]=e;break H}if((e|0)==(i|0)){break H}x[31785]=0;e=P(630,n|0,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break G}if((e|0)==65535){break H}H=_b(x[Wb(x[a+484360>>2],y[q|0])>>2],f),I=e,w[H>>1]=I;b=e}if(!Ge(x[a+484344>>2],x[r>>2],b)){break F}i=$g(x[k>>2],y[g+274|0]);xc(i);e=x[i>>2];x[31785]=0;e=R(157,e|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break G}E=e>>>5|0;h=0;I:while(1){e=Vb(x[n>>2],b);if(A[e+12>>2]<=h>>>0){break F}g=0;e=gd(x[e>>2],x[x[e+48>>2]+12>>2],h,z[B>>1]-8&65535);while(1){if((g|0)==8){h=h+1|0;continue I}v[e|0]=0;v[e+1|0]=0;v[e+2|0]=0;v[e+3|0]=0;v[e+4|0]=0;v[e+5|0]=0;J:{if(h>>>0>=E>>>0){break J}x[31785]=0;P(631,i|0,d+72|0)|0;u=x[31785];x[31785]=0;if((u|0)==1){break G}if(v[d+72|0]>=0){break J}v[e|0]=61;v[e+1|0]=y[(d+240|0)+(g<<1)|0];u=y[d+72|0]&31;v[d+144|0]=u;if(u){If(d+144|0,15);v[e+3|0]=20;v[e+5|0]=y[d+144|0]|208}v[e+2|0]=1;v[e+4|0]=y[d+73|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=N()|0;kd(m);break B}f=f+1|0;continue}}g=N()|0}Qc(k);break s}g=N()|0;break s}f=e<<1;g=f+(d+240|0)|0;b=z[a+480192>>1]+1&65535;h=z[x[a+8>>2]+58>>1];while(1){K:{L:{k=b&65535;if(k>>>0<=h>>>0){if(x[((k<<2)+a|0)+900380>>2]){break L}}else{b=65535}b=b&65535;break K}b=b+1|0;continue}break}w[g>>1]=b;h=f+(d+224|0)|0;f=z[(d+f|0)+258>>1];w[h>>1]=f;M:{if((b|0)!=65535){x[31785]=0;b=U(254,a|0,b|0,f+1&65535)|0;f=x[31785];x[31785]=0;N:{O:{if((f|0)!=1){if(!b){break M}x[31785]=0;O(291,d+144|0,4495);f=x[31785];x[31785]=0;if((f|0)==1){break O}x[31785]=0;x[d+12>>2]=e+1;S(632,d+72|0,d+144|0,d+12|0);f=x[31785];x[31785]=0;if((f|0)==1){break N}f=b+492|0;b=d+72|0;zc(f,b);tb(b);Eb(d+144|0);break M}g=N()|0;break s}g=N()|0;break s}g=N()|0;Eb(d+144|0);break s}w[g>>1]=0}e=e+1|0;continue}}P:{Q:{b=y[d+1720|0]|y[d+1721|0]<<8|(y[d+1722|0]<<16|y[d+1723|0]<<24);if(!(b&2)){break Q}b=(((b&8?z[a+480188>>1]:o)&65535)+((y[d+1610|0]|y[d+1611|0]<<8)>>>0>591?j:0)|0)+(b>>>4&1)|0;f=0;R:while(1){e=0;if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=f>>>0){break Q}while(1){S:{if((b|0)!=(e|0)){g=x[l+8>>2];h=x[l>>2];x[31785]=0;g=U(153,h|0,g|0,4)|0;h=x[31785];x[31785]=0;if((h|0)==1){break P}if(g){break S}}f=f+1|0;continue R}x[31785]=0;O(633,y[d+1610|0]|y[d+1611|0]<<8,l|0);g=x[31785];x[31785]=0;if((g|0)==1){break P}e=e+1|0;continue}}}x[31785]=0;k=P(217,d+188|0,255)|0;b=x[31785];x[31785]=0;if((b|0)!=1){q=a+480208|0;f=0;while(1){T:{b=f;U:{if((b|0)==255){n=sC(d+72|0);m=sC(d+144|0);g=0;while(1){V:{W:{X:{if((g|0)==256){h=0;break X}x[31785]=0;O(634,l|0,d+256|0);b=x[31785];x[31785]=0;if((b|0)==1){break W}x[31785]=0;b=R(154,l|0)|0;e=x[31785];x[31785]=0;Y:{Z:{_:{if((e|0)!=1){x[31785]=0;S(188,d+12|0,l|0,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break _}e=d+12|0;j=ic(d+52|0,e);ub(e);if((y[d+1726|0]|y[d+1727|0]<<8)>>>0>g>>>0){e=d+40|0;Te(e,2,d+256|0);x[31785]=0;O(221,d+12|0,e|0);e=x[31785];x[31785]=0;if((e|0)==1){break Y}e=d+12|0;zc(((g<<5)+a|0)+946336|0,e);tb(e)}if(!b){break V}if((y[d+1726|0]|y[d+1727|0]<<8)>>>0>g>>>0){break Z}break V}g=N()|0;break U}g=N()|0;break U}x[31785]=0;b=D(g+1|0,104)+a|0;e=b+484380|0;O(282,e|0,32);f=x[31785];x[31785]=0;$:{aa:{ba:{if((f|0)!=1){np(e);x[31785]=0;O(635,j|0,d+12|0);f=x[31785];x[31785]=0;if((f|0)==1){break Y}f=x[d+12>>2];x[e>>2]=f;x[b+484404>>2]=x[d+16>>2];if(y[d+20|0]>=2){h=b+484414|0;w[h>>1]=z[h>>1]|1;f=f>>>1|0;x[e>>2]=f}if(y[d+21|0]>=2){h=b+484414|0;w[h>>1]=z[h>>1]|64;x[e>>2]=f>>>1}h=2;switch(y[d+23|0]-1|0){case 0:break aa;case 1:break ba;default:break $}}break Y}h=6}e=b+484414|0;w[e>>1]=z[e>>1]|h}x[b+484384>>2]=x[d+24>>2];x[b+484388>>2]=x[d+28>>2];w[b+484410>>1]=z[d+32>>1]>>>7;e=y[d+34|0];ca:{if((e|0)==128){e=b+484414|0;f=z[e>>1]|256;w[e>>1]=f;break ca}w[b+484408>>1]=(e<<24>>24)+128;f=z[b+484414>>1]}h=b+484414|0;w[h>>1]=f|32;v[b+484416|0]=y[d+35|0];e=y[d+22|0];if(e&2){b=d+40|0;Kb(b,m,g);Uo(b);e=y[d+22|0]}if(e&5){w[h>>1]=z[h>>1]|16384}if(!(e&8)){break V}b=d+40|0;Kb(b,n,g);Uo(b);e=0;while(1){if((e|0)==8){break V}b=e<<1;da:{if(z[b+(d+224|0)>>1]!=(g|0)){break da}b=x[((z[b+(d+240|0)>>1]<<2)+a|0)+900380>>2];if(!b){break da}v[b+14|0]=0}e=e+1|0;continue}}g=N()|0;ub(j);break U}while(1){ea:{fa:{if((y[d+1724|0]|y[d+1725|0]<<8)>>>0<=h>>>0){if(!(c&2)){break fa}e=a+1298404|0;f=a+1298472|0;g=0;ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{while(1){if(z[a+480190>>1]<=g>>>0){break fa}g=g+1|0;c=D(g,104)+a|0;h=c+484380|0;b=c+484416|0;_l(h,(+(v[b|0]-49|0)+ +v[c+484417|0]*-.0078125)/-12);w[b>>1]=0;b=z[c+484414>>1];if(!(b&16384)){b=ad(d+256|0,b&1?16:8,b&64?3:1,0,11);x[31785]=0;U(218,b|0,h|0,l|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}g=N()|0;break U}x[31785]=0;h=R(154,l|0)|0;b=x[31785];x[31785]=0;oa:{if((b|0)==1){break oa}x[31785]=0;P(186,l|0,12)|0;b=x[31785];x[31785]=0;if((b|0)==1){break oa}b=Fb(d+256|0);x[31785]=0;S(273,l|0,b|0,h|0);h=x[31785];x[31785]=0;if((h|0)==1){break na}ye(c+484423|0,b);x[31785]=0;O(387,d+52|0,16624);c=x[31785];x[31785]=0;if((c|0)==1){break ma}x[d+8>>2]=g;c=x[e>>2];x[31785]=0;S(636,d+40|0,c|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break la}x[31785]=0;V(434,d+12|0,d+52|0,d+8|0,d+40|0);c=x[31785];x[31785]=0;if((c|0)==1){break ka}c=x[f>>2];x[31785]=0;S(389,c|0,2,d+12|0);c=x[31785];x[31785]=0;if((c|0)==1){break ja}tb(d+12|0);tb(d+40|0);Eb(d+52|0);tb(b);continue}break}g=N()|0;break U}g=N()|0;break ga}g=N()|0;break ga}g=N()|0;break ha}g=N()|0;break ia}g=N()|0;tb(d+12|0)}tb(d+40|0)}Eb(d+52|0)}tb(b);break U}b=x[$g(x[k>>2],h)>>2];x[31785]=0;b=R(157,b|0)|0;e=x[31785];x[31785]=0;pa:{qa:{if((e|0)!=1){if(!b){h=h+1|0;continue}b=$g(x[k>>2],h);xc(b);x[31785]=0;O(637,b|0,d+256|0);b=x[31785];x[31785]=0;if((b|0)==1){break qa}j=Nb(d+12|0);x[31785]=0;S(638,l|0,j|0,z[d+256>>1]);b=x[31785];x[31785]=0;if((b|0)==1){break pa}h=h+1|0;b=x[((h<<2)+a|0)+900380>>2];if(!b|y[b+34|0]){break ea}x[b+4>>2]=32;e=0;yv(b,0);q=b+108|0;i=b+236|0;while(1){if((e|0)==96){break ea}f=y[(d+e|0)+258|0];ra:{if(f>>>0>=z[d+256>>1]){break ra}o=Re(x[j>>2],f);f=y[o|0];g=f+1|0;r=e+12|0;H=_b(i,r),I=g,w[H>>1]=I;if(f>>>0>=z[a+480190>>1]){break ra}f=D(g,104)+a|0;v[f+484418|0]=y[d+354|0]&3;v[f+484419|0]=y[d+355|0];v[f+484420|0]=y[d+356|0];v[f+484421|0]=y[d+357|0];w[f+484412>>1]=y[o+1|0]<<1;v[f+484417|0]=y[o+2|0];f=g-1|0;Kb(d+52|0,n,f);if(Hb(x[x[d+52>>2]>>2],x[d+56>>2])){v[b+14|0]=0}Kb(d+52|0,m,f);if(!Hb(x[x[d+52>>2]>>2],x[d+56>>2])){break ra}H=xb(q,r),I=61,v[H|0]=I}e=e+1|0;continue}}g=N()|0;break U}g=N()|0;break U}g=N()|0;ze(j);break U}Qc(k);dc(s);ub(t);ub(C);break b}ze(j);continue}}g=N()|0;break U}ub(j);g=g+1|0;continue}}x[31785]=0;O(634,l|0,d+144|0);e=x[31785];x[31785]=0;sa:{ta:{ua:{va:{if((e|0)!=1){x[31785]=0;e=R(154,l|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break va}x[31785]=0;e=(e|0)==32?428:e;j=e?(y[d+1610|0]|y[d+1611|0]<<8)>>>0>513?e+4|0:e:e;S(188,d+72|0,l|0,j|0);e=x[31785];x[31785]=0;if((e|0)==1){break ua}g=d+72|0;e=ic(d+256|0,g);h=Fe(d+12|0,hd($g(x[k>>2],b),e));ub(e);f=b+1|0;ub(g);if(b>>>0>=(y[d+1724|0]|y[d+1725|0]<<8)>>>0){break T}x[31785]=0;b=f&65535;g=U(254,a|0,b|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break ta}break sa}g=N()|0;break U}g=N()|0;break U}g=N()|0;break U}if(!g){break T}b=d+72|0;Te(b,2,d+144|0);x[31785]=0;O(221,d+256|0,b|0);b=x[31785];x[31785]=0;wa:{if((b|0)!=1){b=d+256|0;zc(g+492|0,b);tb(b);if(!j){break T}x[31785]=0;O(637,h|0,d+256|0);b=x[31785];x[31785]=0;if((b|0)!=1){j=3;n=0;if((y[d+1610|0]|y[d+1611|0]<<8)>>>0<513){m=0;break wa}x[31785]=0;m=R(192,h|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break sa}if((y[d+1610|0]|y[d+1611|0]<<8)>>>0<514){break wa}x[31785]=0;j=R(154,h|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break wa}break sa}break sa}break sa}x[g>>2]=y[d+358|0]|y[d+359|0]<<8;v[g+16|0]=y[((y[d+360|0]|y[d+361|0]<<8)&3)+25534|0];v[g+17|0]=y[(y[d+361|0]&3)+25534|0];v[g+18|0]=y[((y[d+360|0]|y[d+361|0]<<8)>>>12&3)+25538|0];while(1){xa:{ya:{if((n|0)==4){if(!(v[g+60|0]&1|y[g+16|0]==3)){x[g>>2]=32767}gk(g,127,1);fk(g,0,1);if(!m){break T}x[31785]=0;O(639,h|0,d+72|0);b=x[31785];x[31785]=0;if((b|0)==1){break sa}if(m&2){gk(g,rD(x[q>>2],+((y[d+74|0]|y[d+75|0]<<8)>>>0)),1);fk(g,y[d+76|0],1)}v[g+25|0]=y[d+73|0]==1;if(!(m&4)){break T}v[g+31|0]=y[d+79|0]+1;b=v[d+80|0];v[g+34|0]=b+1;if((b|0)<0){v[g+30|0]=y[d+87|0]+1}if(!y[d+84|0]){break ya}j=g+108|0;e=0;while(1){if((e|0)==128){break ya}b=e+1|0;x[d+52>>2]=b+v[d+84|0];sX(d+52|0);n=x[d+52>>2];H=xb(j,e),I=n,v[H|0]=I;e=b;continue}}if(!(j&1)){break xa}x[31785]=0;O(640,h|0,d+72|0);b=x[31785];x[31785]=0;za:{if((b|0)!=1){b=Xh(g,y[n+25542|0]);Aa:{if((n|0)!=3){e=y[d+72|0];o=y[b+12|0]&-17;break Aa}e=y[d+72|0];o=e<<4&16|y[b+12|0]&-17}v[b+12|0]=e>>>1&2|(e<<1&4|(o&248|e&1));v[d+52|0]=y[d+73|0];v[d+40|0]=16;e=y[Ub(d+52|0,d+40|0)|0];x[31785]=0;O(296,b|0,e|0);e=x[31785];x[31785]=0;if((e|0)==1){break za}e=y[d+74|0];v[b+15|0]=e;v[b+16|0]=e;v[b+13|0]=y[d+75|0];v[b+14|0]=y[d+76|0];e=0;o=x[b>>2];i=Od(o,x[b+4>>2]);while(1){if((e|0)==(i|0)){break xa}r=wb(o,e);b=(d+72|0)+(e<<2)|0;w[r>>1]=y[b+8|0]|y[b+9|0]<<8;H=r,I=Hd(y[b+10|0]|y[b+11|0]<<8,0,64),v[H+2|0]=I;e=e+1|0;continue}}break sa}break sa}yv(g,0);break T}n=n+1|0;j=j>>>1|0;continue}}g=N()|0;ub(h)}Qc(k);break s}ub(h);continue}}g=N()|0;break s}g=N()|0;break s}g=N()|0;break s}else{e=v[xb(h,k)|0];Ba:{if((e|0)<=(k|0)|(e|0)>=(f|0)){break Ba}e=y[((e<<5)+a|0)+480288|0];if(!e){break Ba}f=((k<<5)+a|0)+480288|0;g=y[f|0];if(!g){v[f|0]=e;break Ba}g=g-1|0;while(1){f=g&255;g=km(x[rd(b,f)+28>>2]);f=rd(b,f);if((g|0)==255){e=e-1&255;x[f+28>>2]=e>>>0<250?e+128|0:0}else{g=km(x[f+28>>2]);continue}break}}k=k+1|0;continue}}}g=N()|0;break s}x[31785]=0;f=R(154,t|0)|0;b=x[31785];x[31785]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((b|0)!=1){x[31785]=0;b=R(154,t|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Ka}x[31785]=0;S(188,d+256|0,t|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break Ka}e=d+256|0;b=ic(d+72|0,e);ub(e);if((f|0)==4674381){break Ga}if((f|0)==5068115){break Fa}if((f|0)==726487106){break Ja}if((f|0)==844387158){break Ea}e=0;if((f|0)==1280004692){break Ia}if((f|0)==1314144592){break Ha}if((f|0)!=1397445204){break Da}x[31785]=0;e=R(192,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break u}e=e>>>0<256?48:e>>>8|0;x[a+480228>>2]=e;x[a+480232>>2]=e>>>1;e=0;while(1){if(z[h>>1]<=e>>>0){break Da}x[31785]=0;f=P(641,b|0,d+256|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break x}if(f){w[((e<<5)+a|0)+480286>>1]=z[d+256>>1]>>>10;H=xb(x[s>>2],e),I=y[d+259|0],v[H|0]=I}e=e+1|0;continue}}g=N()|0;break s}g=N()|0;break s}if(g&1){break Da}v[a+480224|0]=2;x[31785]=0;F=+ia(642,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break Ca}if(!(F>1e-8)){break Da}H=a,I=Xe(2646e3/(F*+(D(x[a+480216>>2],x[a+480196>>2])>>>0))*1e4),x[H+480204>>2]=I;break Da}while(1){La:{if(z[h>>1]<=e>>>0){break Da}f=x[b>>2];x[31785]=0;f=U(153,f|0,x[d+80>>2],1)|0;i=x[31785];x[31785]=0;if((i|0)==1){break w}if(!f){break Da}f=Fb(d+256|0);x[31785]=0;S(361,b|0,f|0,-1);i=x[31785];x[31785]=0;if((i|0)!=1){i=d+12|0;rg(i,3,Jb(f),Wc(x[d+260>>2],y[d+267|0]));x[31785]=0;O(221,d+144|0,i|0);i=x[31785];x[31785]=0;if((i|0)==1){break La}i=d+144|0;fm(((e<<5)+a|0)+480289|0,i);tb(i);tb(f);e=e+1|0;continue}}break}g=N()|0;tb(f);break t}while(1){if((y[d+1712|0]|y[d+1713|0]<<8)>>>0<=e>>>0){break Da}f=x[b>>2];x[31785]=0;f=U(153,f|0,x[d+80>>2],1)|0;i=x[31785];x[31785]=0;if((i|0)==1){break v}if(!f){break Da}if(!tn(x[a+484344>>2],x[q>>2],e&65535)){break Da}f=Fb(d+256|0);x[31785]=0;S(361,b|0,f|0,-1);i=x[31785];x[31785]=0;Ma:{if((i|0)==1){break Ma}i=x[n>>2];x[31785]=0;O(286,Vb(i,e)|0,f|0);i=x[31785];x[31785]=0;if((i|0)==1){break Ma}tb(f);e=e+1|0;continue}break}g=N()|0;tb(f);break t}x[31785]=0;P(186,b|0,1)|0;e=x[31785];x[31785]=0;if((e|0)==1){break u}x[31785]=0;e=R(205,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break u}x[31785]=0;V(339,m|0,b|0,e|0,2);e=x[31785];x[31785]=0;if((e|0)!=1){break Da}break u}x[31785]=0;P(643,b|0,d+12|0)|0;e=x[31785];x[31785]=0;Na:{if((e|0)!=1){e=Fb(d+256|0);x[31785]=0;S(361,b|0,e|0,-1);f=x[31785];x[31785]=0;if((f|0)==1){break Na}if(er(e,12703)){x[31785]=0;S(261,d+144|0,22,e|0);f=x[31785];x[31785]=0;if((f|0)==1){break Na}f=d+144|0;yb(k,f);tb(f)}tb(e);break Da}g=N()|0;break t}g=N()|0;tb(e);break t}x[31785]=0;j=R(154,b|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break u}}ub(b);continue}break}g=N()|0;break t}g=N()|0;break t}g=N()|0;break t}g=N()|0;break t}g=N()|0}ub(b)}dc(s);break e}g=N()|0;break e}while(1){b=x[j>>2];x[31785]=0;b=U(153,b|0,x[d+264>>2],1)|0;f=x[31785];x[31785]=0;Oa:{if((f|0)!=1){if(!b){break m}x[31785]=0;h=R(200,j|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}q=0;if((h|0)!=255){break Oa}x[31785]=0;q=R(200,j|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){x[31785]=0;h=R(200,j|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break Oa}}break l}break l}if(h&127){b=Vb(x[n>>2],s);f=gd(x[b>>2],x[x[b+48>>2]+12>>2],e,k&65535);lE(d+72|0);if(h&1){x[31785]=0;b=R(200,j|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break l}v[d+72|0]=b}if(h&2){x[31785]=0;b=R(200,j|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break l}v[d+73|0]=b}if(h&4){x[31785]=0;b=R(200,j|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break l}v[d+74|0]=b}if(h&8){x[31785]=0;b=R(200,j|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break l}v[d+75|0]=b}if(h&16){x[31785]=0;b=R(200,j|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break l}v[d+76|0]=b}if(h&32){x[31785]=0;b=R(200,j|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break l}v[d+77|0]=b}if(h&64){x[31785]=0;b=R(200,j|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break l}v[d+78|0]=b}u=uX(f,d+72|0);x[d+144>>2]=q;x[d+52>>2]=m+(e^-1);G=x[Gb(d+144|0,d+52|0)>>2];h=0;b=f;while(1){if((h|0)!=(G|0)){b=D(z[E>>1],6)+b|0;i=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[b|0]=i;v[b+1|0]=i>>>8;v[b+2|0]=i>>>16;v[b+3|0]=i>>>24;i=y[f+4|0]|y[f+5|0]<<8;v[b+4|0]=i;v[b+5|0]=i>>>8;h=h+1|0;continue}break}g=g|u}e=(e+q|0)+1|0;while(1){if(e>>>0>=m>>>0){k=k+1|0;e=e-m|0;continue}break}if(o>>>0>(k&65535)>>>0){continue}break}}ub(j);s=s+1|0;continue}break}g=N()|0;ub(j);break e}g=N()|0;break e}g=N()|0}ub(t)}ub(C)}Q(g|0);p()}e=1}fb=d+1728|0;return e|0}function xsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0;d=fb-1120|0;fb=d;xc(b);e=fb-16|0;fb=e;r=d+884|0;TZ(e+8|0,r);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Yb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){SZ(r)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(!e){break o}if(!VZ(d+884|0)){break o}if(!Mb(x[b>>2],x[b+8>>2],Bc(UZ(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)),hb))){break o}if(!c){f=1;break o}Bd(a,16777216);ag(a);e=a+480208|0;x[e>>2]=x[e>>2]|16809984;e=d+448|0;cr(e,32);g=x[d+460>>2];f=a+1074320|0;x[f>>2]=x[d+456>>2];x[f+4>>2]=g;f=x[d+452>>2];x[a+1074312>>2]=x[d+448>>2];x[a+1074316>>2]=f;Lb(Lb(a+1074312|0,57,y[d+887|0]>5),114,1);f=bp(d+840|0);E=f,F=Hd(y[d+1084|0],1,31),x[E+8>>2]=F;E=f,F=Hd(y[d+1085|0],1,12),x[E+4>>2]=F;E=f,F=Cb(y[d+1086|0]|y[d+1087|0]<<8),x[E>>2]=F;VD(a+1298412|0,f);w[a+480188>>1]=32;f=d+36|0;RZ(f,3,d+1088|0);Xv(e,1,f);yb(a+1298368|0,e);tb(e);p:{if(y[d+887|0]<=5){cg(d+36|0,3944);break p}e=fb-16|0;fb=e;f=uc(e+4|0,4013);Yc(d+36|0,f);tb(f);fb=e+16|0}x[31785]=0;S(374,d+448|0,d+36|0,y[d+887|0]);e=x[31785];x[31785]=0;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((e|0)!=1){e=d+448|0;yb(a+1298344|0,e);tb(e);f=d+36|0;Eb(f);g=uc(e,15298);yb(a+1298356|0,g);tb(g);E=a+1298404|0,F=x[Gc(e,26)>>2],x[E>>2]=F;Te(f,3,d+892|0);Ec(e,f);yb(a+1298308|0,e);tb(e);x[a+480228>>2]=256;x[a+480200>>2]=384/(z[a+480188>>1]+3>>>0);G:{if(y[d+887|0]>5){break G}E=d,F=Cb(y[d+1112|0]|y[d+1113|0]<<8),w[E+448>>1]=F;w[d+36>>1]=1;e=d+448|0;f=d+36|0;E=a,F=z[se(e,f)>>1],x[E+480196>>2]=F;E=d,F=Cb(y[d+1114|0]|y[d+1115|0]<<8),w[E+448>>1]=F;w[d+36>>1]=1;E=a,F=D(z[se(e,f)>>1],1e4),x[E+480204>>2]=F;E=d,F=Bc(((Cb(y[d+1116|0]|y[d+1117|0]<<8)<<8)+2047>>>0)/4095|0,0),x[E+448>>2]=F;x[d+36>>2]=256;E=a,F=x[Gb(e,f)>>2],x[E+480200>>2]=F;E=d,F=Cb(y[d+1118|0]|y[d+1119|0]<<8),w[E+448>>1]=F;Pf(e,127);f=0;e=z[d+448>>1];while(1){if((e|0)==(f|0)){break G}E=d,F=Bc(((Qk(b)<<8)+2047>>>0)/4095|0,0),w[E+36>>1]=F;w[d+344>>1]=256;E=((f<<5)+a|0)+480284|0,F=z[Mc(d+36|0,d+344|0)>>1],w[E>>1]=F;f=f+1|0;continue}}bd(b,$b(y[d+888|0]|y[d+889|0]<<8|(y[d+890|0]<<16|y[d+891|0]<<24)));r=Fe(d+820|0,b);x[31785]=0;O(379,d+808|0,r|0);b=x[31785];x[31785]=0;H:{I:{J:{K:{L:{if((b|0)!=1){x[31785]=0;S(380,d+448|0,d+808|0,1346458707);b=x[31785];x[31785]=0;if((b|0)==1){break H}x[31785]=0;b=U(153,x[d+448>>2],x[d+456>>2],2)|0;e=x[31785];x[31785]=0;if((e|0)==1){break K}if(!b){break I}x[31785]=0;b=R(276,d+448|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break K}if((b-1&65535)>>>0>126){break I}w[a+480188>>1]=b;b=d+448|0;ub(b);x[31785]=0;S(380,b|0,d+808|0,1397706311);b=x[31785];x[31785]=0;if((b|0)!=1){break L}a=N()|0;break c}a=N()|0;break b}x[31785]=0;b=U(153,x[d+448>>2],x[d+456>>2],2)|0;e=x[31785];x[31785]=0;if((e|0)==1){break E}if(!b){break I}x[31785]=0;b=R(276,d+448|0)|0;e=x[31785];x[31785]=0;M:{if((e|0)==1){break M}w[d+36>>1]=b;b=y[a+484376|0];e=x[a+484360>>2];x[31785]=0;f=R(276,d+448|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break M}_e(Wb(e,b),f);x[31785]=0;b=R(205,d+448|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break M}Pf(d+36|0,cm(b>>>1|0));b=y[a+484376|0];e=x[a+484360>>2];x[31785]=0;S(279,Wb(e,b)|0,d+448|0,z[d+36>>1]);b=x[31785];x[31785]=0;if((b|0)!=1){break J}}break E}a=N()|0;ub(d+448|0);break c}b=d+448|0;ub(b);x[31785]=0;S(380,b|0,d+808|0,1480806221);b=x[31785];x[31785]=0;if((b|0)==1){break F}x[31785]=0;b=U(153,x[d+448>>2],x[d+456>>2],3)|0;e=x[31785];x[31785]=0;if((e|0)!=1){if(b){break D}b=160;while(1){N:{f=b;if(!b){f=0;break N}b=f-1|0;if(y[(d+b|0)+924|0]==32){continue}}break}x[31785]=0;V(346,a+1298332|0,d+924|0,f|0,4);b=x[31785];x[31785]=0;if((b|0)!=1){break C}break B}break B}ub(d+448|0);f=0;break q}a=N()|0;break c}a=N()|0;Eb(d+36|0);break a}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}x[31785]=0;b=R(276,d+448|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){x[31785]=0;V(339,a+1298332|0,d+448|0,b|0,4);b=x[31785];x[31785]=0;if((b|0)!=1){break C}}break B}b=d+448|0;ub(b);x[31785]=0;S(380,b|0,d+808|0,1413697073);b=x[31785];x[31785]=0;if((b|0)==1){break A}x[31785]=0;b=R(200,d+448|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break y}if(b){break z}x[31785]=0;b=P(152,d+448|0,2648)|0;e=x[31785];x[31785]=0;if((e|0)==1){break y}if(!b){break z}f=0;x[31785]=0;b=R(284,d+448|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break y}while(1){if((f|0)==32){break z}e=((f<<5)+a|0)+480280|0;x[e>>2]=x[e>>2]&-1025|!(b>>>f&1)<<10;f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+448|0;ub(b);x[31785]=0;S(380,b|0,d+808|0,1413697074);b=x[31785];x[31785]=0;if((b|0)==1){break x}x[31785]=0;b=U(153,x[d+448>>2],x[d+456>>2],12)|0;e=x[31785];x[31785]=0;if((e|0)==1){break w}O:{if(!b){break O}x[31785]=0;O(381,d+36|0,d+448|0);b=x[31785];x[31785]=0;if((b|0)==1){break w}b=d+36|0;e=Ze(b);f=ec(b);g=QZ(b);h=Ab(b);n=PZ(b);b=D(Hd(Cb(y[e|0]|y[e+1|0]<<8),32,999),1e4);e=sua(Cb(y[f|0]|y[f+1|0]<<8),0,1e4,0);f=hb;e=e+32768|0;f=e>>>0<32768?f+1|0:f;E=a,F=((Bc((f&65535)<<16|e>>>16,f>>>16|0)>>>0)%1e4|0)+b|0,x[E+480204>>2]=F;E=a,F=Hd(Cb(y[g|0]|y[g+1|0]<<8),1,255),x[E+480196>>2]=F;b=16/(Hd(Cb(y[n|0]|y[n+1|0]<<8),1,16)>>>0)|0;x[a+480216>>2]=b;E=a,F=D(Hd(Cb(y[h|0]|y[h+1|0]<<8),1,16),b),x[E+480220>>2]=F;if(!Cb(z[d+36>>1])){break O}x[31785]=0;b=R(276,d+448|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break w}e=a+480208|0;x[e>>2]=x[e>>2]&-17|!b<<4}b=d+448|0;ub(b);x[31785]=0;S(380,b|0,d+808|0,1414942540);b=x[31785];x[31785]=0;if((b|0)==1){break v}x[31785]=0;b=U(153,x[d+448>>2],x[d+456>>2],2)|0;e=x[31785];x[31785]=0;if((e|0)==1){break t}if(!b){break u}x[31785]=0;b=R(276,d+448|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break t}w[d+36>>1]=b;w[d+344>>1]=z[a+480188>>1];b=z[Mc(d+36|0,d+344|0)>>1];f=0;while(1){if((b|0)==(f|0)){break u}x[31785]=0;e=R(276,d+448|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break t}w[d+36>>1]=e;w[d+344>>1]=4096;E=((f<<5)+a|0)+480286|0,F=z[Mc(d+36|0,d+344|0)>>1]>>>6&255,w[E>>1]=F;f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}ub(d+448|0);x[31785]=0;S(380,d+36|0,d+808|0,1296652368);b=x[31785];x[31785]=0;if((b|0)==1){break s}x[31785]=0;b=U(153,x[d+36>>2],x[d+44>>2],56)|0;e=x[31785];x[31785]=0;if((e|0)==1){break d}if(!b){break r}x[31785]=0;O(382,d+36|0,d+448|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}if((Cb(y[d+482|0]|y[d+483|0]<<8)|0)!=4){break r}if((Cb(y[d+496|0]|y[d+497|0]<<8)|0)!=257){break r}E=d,F=Cb(y[d+488|0]|y[d+489|0]<<8),w[E+344>>1]=F;w[d+796>>1]=16384;e=z[Mc(d+344|0,d+796|0)>>1];b=e>>>24|0;f=(e<<8)+2048|0;b=f>>>0<2048?b+1|0:b;E=a,F=Bc((b&4095)<<20|f>>>12,b>>>12|0),x[E+480200>>2]=F;h=a+480188|0;f=0;while(1){if(Cb(y[d+486|0]|y[d+487|0]<<8)>>>0<=(f&65535)>>>0){break r}x[31785]=0;O(383,d+36|0,d+344|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}P:{if(y[d+344|0]){break P}b=Cb(y[d+346|0]|y[d+347|0]<<8);if(b>>>0>=z[h>>1]){break P}b=(b<<5)+a|0;E=b+480284|0,F=Bc(((Cb(y[d+350|0]|y[d+351|0]<<8)<<8)+2047>>>0)/4095|0,0),w[E>>1]=F;i=b+480286|0;e=Cb(y[d+348|0]|y[d+349|0]<<8);b=e>>>26|0;g=(e<<6)+2048|0;b=g>>>0<2048?b+1|0:b;E=i,F=Bc((b&4095)<<20|g>>>12,b>>>12|0)&255,w[E>>1]=F}f=f+1|0;continue}}a=N()|0;ub(d+448|0);break c}a=N()|0;break c}b=d+36|0;ub(b);x[31785]=0;S(384,b|0,d+808|0,1396788530);b=x[31785];x[31785]=0;if((b|0)==1){break e}E=d,F=vb(x[d+36>>2]),x[E+760>>2]=F;f=c&2;h=d+450|0;n=vb(x[d+40>>2]);g=a+480190|0;j=a+1298472|0;Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{while(1){e=x[d+760>>2];if(!Ib(e,n)){b=d+36|0;Qc(b);x[31785]=0;S(384,b|0,d+808|0,1396788560);b=x[31785];x[31785]=0;if((b|0)==1){break f}E=d,F=vb(x[d+36>>2]),x[E+784>>2]=F;h=d+450|0;n=vb(x[d+40>>2]);e=a+480190|0;break Q}x[31785]=0;b=P(385,e|0,d+448|0)|0;m=x[31785];x[31785]=0;if((m|0)==1){break S}_:{$:{if(!b){break $}b=Cb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break $}if(Cb(z[d+496>>1])>>>0>1){break $}if(Cb(z[d+478>>1])>>>0>1){break $}if(b>>>0>z[g>>1]){w[g>>1]=b}x[31785]=0;m=D(b,104)+a|0;b=m+484380|0;O(386,d+448|0,b|0);i=x[31785];x[31785]=0;aa:{ba:{ca:{if((i|0)==1){break ca}i=d+796|0;_i(i,3,h);x[31785]=0;O(221,d+344|0,i|0);i=x[31785];x[31785]=0;if((i|0)==1){break ba}i=d+344|0;zc(((Cb(z[d+448>>1])<<5)+a|0)+946304|0,i);tb(i);if(!f){break $}i=z[d+522>>1]|z[d+524>>1]<<16;x[31785]=0;i=P(152,e|0,$b(i)-8|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break ca}if(!i){break $}if(Cb(z[d+478>>1])){break aa}i=d+344|0;ad(i,(Cb(y[d+480|0]|y[d+481|0]<<8)|0)==8?8:16,(Cb(y[d+484|0]|y[d+485|0]<<8)|0)==1?1:2,!Cb(y[d+482|0]|y[d+483|0]<<8),0);x[31785]=0;U(218,i|0,b|0,e|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break aa}a=N()|0;break R}a=N()|0;break R}a=N()|0;break R}b=Fb(d+344|0);i=z[d+498>>1];x[31785]=0;S(273,e|0,b|0,Cb(i)|0);e=x[31785];x[31785]=0;if((e|0)==1){break U}ye(m+484423|0,b);if((Cb(z[d+478>>1])|0)==1){x[31785]=0;O(387,d+784|0,16624);e=x[31785];x[31785]=0;if((e|0)==1){break _}x[31785]=0;S(261,d+772|0,0,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break Z}x[31785]=0;V(388,d+796|0,d+784|0,z[d+448>>1],d+772|0);e=x[31785];x[31785]=0;if((e|0)==1){break Y}e=x[j>>2];x[31785]=0;S(389,e|0,2,d+796|0);e=x[31785];x[31785]=0;if((e|0)==1){break X}tb(d+796|0);tb(d+772|0);Eb(d+784|0)}tb(b)}Xf(d+760|0);continue}break}a=N()|0;break T}a=N()|0;break V}a=N()|0;break W}a=N()|0;tb(d+796|0)}tb(d+772|0)}Eb(d+784|0);break T}a=N()|0}tb(b);break R}a=N()|0}Qc(d+36|0);break c}da:{while(1){ea:{g=x[d+784>>2];if(!Ib(g,n)){Qc(d+36|0);x[31785]=0;S(384,d+796|0,d+808|0,1447382614);b=x[31785];x[31785]=0;if((b|0)!=1){break da}a=N()|0;break c}x[31785]=0;b=P(390,g|0,d+448|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break ea}fa:{ga:{if(!b){break ga}b=Cb(z[d+448>>1]);if((b-4e3&65535)>>>0<61537){break ga}if(Cb(z[d+502>>1])){break ga}if(b>>>0>z[e>>1]){w[e>>1]=b}x[31785]=0;b=(D(b,104)+a|0)+484380|0;O(391,d+448|0,b|0);j=x[31785];x[31785]=0;if((j|0)==1){break ea}j=d+796|0;_i(j,3,h);x[31785]=0;O(221,d+344|0,j|0);j=x[31785];x[31785]=0;if((j|0)==1){break ea}j=d+344|0;zc(((Cb(z[d+448>>1])<<5)+a|0)+946304|0,j);tb(j);if(!f){break ga}j=z[d+478>>1];m=d+344|0;ad(m,(Cb(z[d+482>>1])|0)==8?8:16,Cb(j)&1?2:1,1,0);x[31785]=0;U(218,m|0,b|0,g|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break fa}}Xf(d+784|0);continue}}break}a=N()|0;Qc(d+36|0);break c}x[31785]=0;S(384,d+784|0,d+808|0,1413828182);b=x[31785];x[31785]=0;if((b|0)==1){break h}x[31785]=0;S(384,d+772|0,d+808|0,1346719318);b=x[31785];x[31785]=0;if((b|0)==1){break j}x[31785]=0;S(384,d+760|0,d+808|0,1229869908);b=x[31785];x[31785]=0;if((b|0)==1){break l}E=d,F=vb(x[d+760>>2]),x[E+12>>2]=F;n=d+394|0;j=d+346|0;m=d+450|0;i=vb(x[d+764>>2]);k=a+480190|0;u=a+480208|0;while(1){ha:{ia:{ja:{ka:{g=x[d+12>>2];if(!Ib(g,i)){Qc(d+760|0);x[31785]=0;S(384,d+344|0,d+808|0,1346458692);b=x[31785];x[31785]=0;if((b|0)!=1){break ka}a=N()|0;break k}x[31785]=0;b=P(392,g|0,d+448|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break n}if(!b){break ha}if(Cb(z[d+478>>1])){break ha}b=z[d+448>>1];x[31785]=0;e=U(254,a|0,Cb(b)|0,0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break n}if(!e){break ha}b=Cb(z[d+448>>1]);if(b>>>0>z[a+480192>>1]){w[a+480192>>1]=b}b=d+344|0;_i(b,3,m);x[31785]=0;O(221,d+36|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break ja}b=d+36|0;zc(e+492|0,b);tb(b);v[e+33|0]=2;if((ve(w[d+482>>1])|0)>0){v[e+15|0]=y[e+15|0]|1;f=ve(w[d+482>>1]);b=f>>>24|0;h=(f<<8&-256)+2047|0;f=b&255;E=e,F=Bc(uua(h,h>>>0<2047?f+1|0:f,4095,0),hb),x[E+8>>2]=F}h=e+108|0;l=e+236|0;b=0;while(1){la:{x[d+36>>2]=128;x[d+344>>2]=128;f=b&255;if(f>>>0>=A[Gb(d+36|0,d+344|0)>>2]){x[31785]=0;O(393,d+36|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break la}E=d,F=Yi(x[d+36>>2]),x[E+344>>2]=F;b=Jf(d+36|0);f=z[k>>1];h=z[d+480>>1];while(1){l=x[d+344>>2];if(Ib(l,b)){l=z[Xo(l)>>1];if(f>>>0>(l-1&65535)>>>0){E=(D(l,104)+a|0)+484410|0,F=Cb(h),w[E>>1]=F}Yg(d+344|0);continue}break}Hv(d+36|0);gk(e,127,1);fk(e,0,1);b=Cb(z[d+498>>1]);if(!b){x[e>>2]=0;b=z[d+484>>1];x[31785]=0;V(394,e|0,0,Cb(b)|0,d+796|0);b=x[31785];x[31785]=0;if((b|0)==1){break n}b=z[d+488>>1];x[31785]=0;V(394,e|0,1,Cb(b)|0,d+772|0);b=x[31785];x[31785]=0;if((b|0)==1){break n}b=z[d+486>>1];x[31785]=0;V(394,e|0,2,Cb(b)|0,d+784|0);b=x[31785];x[31785]=0;if((b|0)!=1){break ha}break n}x[31785]=0;S(395,g|0,d+344|0,((b|0)==1?98:102)|0);b=x[31785];x[31785]=0;ma:{na:{oa:{if((b|0)!=1){b=Cb(z[d+344>>1]);h=b&1;if(!h){break ia}f=b&24;if(f){break oa}f=0;break na}a=N()|0;break m}if((f|0)!=8){break ma}f=1}v[e+25|0]=f}pa:{qa:{ra:{sa:{if(!(b&2)){break sa}x[31785]=0;b=U(396,d+332|0,j|0,24)|0;f=x[31785];x[31785]=0;if((f|0)==1){break ra}x[31785]=0;t=+ia(397,b|0);f=x[31785];x[31785]=0;if((f|0)==1){break qa}tb(b);if(!(t>20)){break sa}gk(e,rD(x[u>>2],t),1)}if(Cb(z[d+344>>1])&4){break pa}break ia}a=N()|0;break m}a=N()|0;tb(b);break m}x[31785]=0;b=U(396,d+320|0,n|0,24)|0;f=x[31785];x[31785]=0;ta:{if((f|0)!=1){x[31785]=0;t=+ia(397,b|0);f=x[31785];x[31785]=0;if((f|0)==1){break ta}tb(b);fk(e,Zl(t*127/24),1);break ia}a=N()|0;break m}a=N()|0;tb(b);break m}else{o=(d+448|0)+(f<<1)|0;q=y[o+52|0];E=_b(l,f),F=q,w[E>>1]=F;q=xb(h,f);o=bm(v[o+53|0]+y[q|0]|0);E=xb(h,f),F=o,v[E|0]=F;b=b+1|0;continue}}break}a=N()|0;break m}b=x[d+348>>2];e=x[d+344>>2];x[31785]=0;h=a+484344|0;O(226,h|0,Lf(e,b)&65535);b=x[31785];x[31785]=0;ua:{if((b|0)!=1){x[d+32>>2]=x[a+480204>>2];x[d+28>>2]=x[a+480196>>2];E=d,F=vb(x[d+344>>2]),x[E+24>>2]=F;u=c&1;l=vb(x[d+348>>2]);o=a+480188|0;while(1){va:{wa:{xa:{ya:{za:{Aa:{c=x[d+24>>2];if(!Ib(c,l)){x[31785]=0;S(380,d+36|0,d+808|0,1414414669);b=x[31785];x[31785]=0;if((b|0)!=1){break Aa}a=N()|0;break ua}if(!u){break va}b=x[c+8>>2];e=x[c>>2];x[31785]=0;b=U(153,e|0,b|0,24)|0;e=x[31785];x[31785]=0;if((e|0)==1){break za}if(!b){break va}x[31785]=0;n=R(276,c|0)|0;b=x[31785];x[31785]=0;Ba:{Ca:{Da:{Ea:{if((b|0)!=1){v[d+464|0]=0;x[d+456>>2]=0;x[d+460>>2]=0;x[d+448>>2]=0;x[d+452>>2]=0;x[31785]=0;O(398,c|0,d+448|0);b=x[31785];x[31785]=0;if((b|0)==1){break Ea}x[31785]=0;i=R(276,c|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Da}x[31785]=0;j=R(276,c|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Ca}x[31785]=0;m=R(276,c|0)|0;b=x[31785];x[31785]=0;Fa:{if((b|0)==1){break Fa}b=x[c+8>>2];e=x[c>>2];x[31785]=0;b=U(153,e|0,b|0,D(D(j,m),5)|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Fa}if(!(b&i>>>0<2)){break va}x[31785]=0;b=U(199,h|0,n|0,j|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Fa}if(!b){break va}b=x[h>>2];x[31785]=0;O(399,Vb(b,n)|0,d+448|0);b=x[31785];x[31785]=0;if((b|0)!=1){break Ba}}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}a=N()|0;break ua}v[d+12|0]=0;b=ae(d+36|0,0,d+12|0);x[31785]=0;e=U(375,d+760|0,m|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break wa}g=0;Ga:while(1){if((g|0)==(j|0)){kd(e);break va}b=Vb(x[h>>2],n);Ve(d+36|0,x[b>>2],x[x[b+48>>2]+12>>2],g);f=0;while(1){if((f|0)==(m|0)){g=g+1|0;continue Ga}b=Jg(d+12|0);if(z[o>>1]>f>>>0){b=Vc(x[d+36>>2],f)}x[31785]=0;O(400,c|0,d|0);k=x[31785];x[31785]=0;Ha:{if((k|0)==1){break Ha}k=y[d|0];if((k-1&255)>>>0<=119){k=k+1|0;v[b|0]=k;E=_b(x[e>>2],f),F=k,v[E|0]=F}k=y[d+1|0];if(k){v[b+1|0]=k;E=_b(x[e>>2],f),F=k,v[E+1|0]=F}k=y[d+4|0];if(k){v[b+2|0]=1;v[b+4|0]=i?k-16|0:k>>>2|0}k=y[d+887|0];q=y[d+3|0];B=y[d+2|0];s=_b(x[e>>2],f);C=y[s+1|0];s=y[s|0];x[31785]=0;ya(377,a|0,b|0,B|0,q|0,k|0,s|0,C|0,d+32|0,d+28|0);b=x[31785];x[31785]=0;if((b|0)==1){break Ha}f=f+1|0;continue}break}break}a=N()|0;kd(e);break ua}x[31785]=0;b=U(153,x[d+36>>2],x[d+44>>2],38)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(!b){break xa}x[31785]=0;b=R(276,d+36|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ya}c=d+452|0;e=a+480188|0;f=0;Ia:{while(1){if(b>>>0<=(f&65535)>>>0){break xa}x[31785]=0;g=U(153,x[d+36>>2],x[d+44>>2],36)|0;h=x[31785];x[31785]=0;Ja:{if((h|0)!=1){if(g){break Ja}break xa}break ya}x[31785]=0;O(401,d+36|0,d+448|0);g=x[31785];x[31785]=0;if((g|0)!=1){Ka:{if(Cb(z[d+448>>1])){break Ka}if(Cb(z[d+450>>1])>>>0>=z[e>>1]){break Ka}Te(d,3,c);x[31785]=0;O(221,d+12|0,d|0);g=x[31785];x[31785]=0;if((g|0)==1){break Ia}g=d+12|0;fm(((Cb(z[d+450>>1])<<5)+a|0)+480289|0,g);tb(g)}f=f+1|0;continue}break}break ya}break ya}break ya}a=N()|0;break ua}a=N()|0;ub(d+36|0);break ua}ub(d+36|0);Qc(d+344|0);Qc(d+772|0);Qc(d+784|0);Qc(d+796|0);f=1;break q}a=N()|0;break ua}Xf(d+24|0);continue}}a=N()|0}Qc(d+344|0);break k}a=N()|0;break m}f=0;while(1){if(y[d+445|0]<=f>>>0){break ha}x[31785]=0;O(402,g|0,d+36|0);b=x[31785];x[31785]=0;La:{Ma:{if((b|0)!=1){x[d>>2]=33620480;E=d,F=(Cb(z[d+484>>1])|0)!=0,v[E+32|0]=F;E=d,F=(Cb(z[d+486>>1])|0)!=0,v[E+33|0]=F;E=d,F=(Cb(z[d+488>>1])|0)!=0,v[E+34|0]=F;E=d,F=h&(Cb(z[d+490>>1])|0)!=0,v[E+35|0]=F;if(!y[(d+32|0)+f|0]|f>>>0>3){break La}b=(f|0)!=3;if(!b&(v[e+100|0]&1)){break La}x[31785]=0;l=y[d+f|0];S(403,d+36|0,e|0,l|0);o=x[31785];x[31785]=0;if((o|0)==1){break Ma}if(!b){v[e+100|0]=y[e+100|0]|16}Na:{switch(l|0){case 0:if(Cb(y[d+48|0]|y[d+49|0]<<8)&1){b=Cb(y[d+46|0]|y[d+47|0]<<8)&32767}else{b=0}x[e>>2]=b;break La;case 2:break Na;default:break La}}if(!(Cb(y[d+48|0]|y[d+49|0]<<8)&2)){break La}E=d,F=Cb(y[d+42|0]|y[d+43|0]<<8),w[E+28>>1]=F;w[d+24>>1]=1;b=z[se(d+28|0,d+24|0)>>1];l=ej(Bc(((Cb(y[d+38|0]|y[d+39|0]<<8)<<6|48)>>>0)/100|0,0));E=d,F=Cb(y[d+40|0]|y[d+41|0]<<8),w[E+28>>1]=F;w[d+24>>1]=1;o=Zg(256/z[se(d+28|0,d+24|0)>>1]|0);q=z[d+448>>1];B=y[d+44|0]|y[d+45|0]<<8;x[31785]=0;s=Cb(q);q=Cb(B);ja(404,a|0,s|0,y[(q>>>0<6?q:0)+25200|0],255/(b>>>0)|0,l|0,o|0);b=x[31785];x[31785]=0;if((b|0)!=1){break La}a=N()|0;break m}a=N()|0;break m}a=N()|0;break m}f=f+1|0;continue}}Xf(d+12|0);continue}}fe(d+808|0);ub(r)}fb=d+1120|0;return f|0}a=N()|0}Qc(d+760|0);break k}a=N()|0}Qc(d+772|0);break i}a=N()|0}Qc(d+784|0);break g}a=N()|0}Qc(d+796|0);break c}a=N()|0;break c}a=N()|0;break c}a=N()|0;ub(d+36|0)}fe(d+808|0)}ub(r)}Q(a|0);p()}function bja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,P=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0,Z=0,$=0,aa=0,ba=0,ca=0,da=0;l=fb-1168|0;fb=l;xc(b);a:{if(!$r(b,l+1144|0)){break a}if(!eR(l+1144|0)){break a}if((y[l+1152|0]|y[l+1153|0]<<8|(y[l+1154|0]<<16|y[l+1155|0]<<24))!=(hh(x[b>>2])|0)){break a}if((y[l+1160|0]|y[l+1161|0]<<8|(y[l+1162|0]<<16|y[l+1163|0]<<24))!=(jf(b)|0)){break a}if(!c){d=1;break a}f=l+1088|0;Tb(f,0,56);e=-2;b:{if(!f){break b}x[f+44>>2]=0;x[f+48>>2]=0;x[f+52>>2]=0;x[f+20>>2]=0;x[f+24>>2]=0;x[f+8>>2]=0;g=x[f+32>>2];if(!g){x[f+32>>2]=1175;g=1175}if(!x[f+36>>2]){x[f+36>>2]=1176}g=ib[g|0](x[f+40>>2],1,43784)|0;e=-4;if(!g){break b}x[f+28>>2]=g;x[g+43780>>2]=1;x[g+10992>>2]=0;x[g+10996>>2]=0;x[g>>2]=0;x[g+11008>>2]=15;x[g+11e3>>2]=1;x[g+11004>>2]=0;e=0}if(e){break a}d=y[l+1160|0]|y[l+1161|0]<<8|(y[l+1162|0]<<16|y[l+1163|0]<<24);x[l+1084>>2]=d;K=y[l+1164|0]|y[l+1165|0]<<8|(y[l+1166|0]<<16|y[l+1167|0]<<24);T=nZ(l+1072|0,K);c:{d:{while(1){if(!(!d|!K|(i|0)==1)){x[l+32>>2]=1024;d=l+32|0;V=x[Gb(d,l+1084|0)>>2];i=gc(l+40|0,l+48|0,V);f=x[i>>2];i=x[i+4>>2];x[31785]=0;Rn(162,d,b,f,i);d=x[31785];x[31785]=0;if((d|0)==1){break d}g=l+48|0;i=g;d=V;f=aa^-1;while(1){if(d>>>0<4){while(1){if(d){f=x[(((y[i|0]^f)&255)<<2)+79808>>2]^f>>>8;d=d-1|0;i=i+1|0;continue}break}aa=f^-1}else{f=x[(((y[i|0]^f)&255)<<2)+79808>>2]^f>>>8;f=f>>>8^x[(((f^y[i+1|0])&255)<<2)+79808>>2];f=f>>>8^x[(((f^y[i+2|0])&255)<<2)+79808>>2];f=f>>>8^x[(((f^y[i+3|0])&255)<<2)+79808>>2];d=d-4|0;i=i+4|0;continue}break}x[l+1092>>2]=V;x[l+1088>>2]=g;x[l+1104>>2]=K;x[l+1100>>2]=x[T>>2]+ba;B=fb-16|0;fb=B;i=-2;q=l+1088|0;e:{if(!q){break e}h=x[q+28>>2];if(!h){break e}da=x[q+4>>2];x[h+11e3>>2]=0;f:{if(x[h+43780>>2]<0){break f}if(x[h+11004>>2]){break e}f=x[h+11008>>2];i=0;x[h+11004>>2]=0;d=x[h+10996>>2];if(!d){X=(f|0)>0?11:10;I=h+11012|0;g=x[q+4>>2];f=x[h+10992>>2];while(1){x[B+12>>2]=g;x[B+8>>2]=32768-f;F=x[q>>2];d=0;g=0;C=0;E=0;J=0;L=0;W=0;M=0;Y=0;Z=fb-144|0;fb=Z;g:{h:{O=f+I|0;if(O>>>0>=I>>>0){G=x[B+8>>2]+O|0;r=G-I|0;$=(I^-1)+G|0;if(!(r&$)){break h}}x[B+8>>2]=0;x[B+12>>2]=0;o=-3;break g}n=x[B+12>>2];t=n+F|0;P=x[h+60>>2];s=x[h+40>>2];i=x[h+36>>2];u=x[h+32>>2];f=x[h+56>>2];e=x[h+4>>2];o=-1;m=O;k=F;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{j=x[h>>2];switch(j|0){case 36:break k;case 39:break m;case 10:break n;case 35:break o;case 17:break p;case 21:break q;case 34:break r;case 2:break w;case 53:break A;case 26:break C;case 25:break D;case 24:break E;case 23:break F;case 18:break G;case 16:break H;case 14:break I;case 51:break L;case 6:break M;case 3:break N;case 37:break O;case 42:break P;case 41:break Q;case 32:break R;case 27:break S;case 11:break T;case 38:break U;case 9:break V;case 52:break W;case 7:break X;case 5:break Y;case 1:break Z;case 0:break _;default:break j}}x[h+28>>2]=1;f=0;x[h+8>>2]=0;x[h+12>>2]=0;x[h+16>>2]=1;s=0;i=0;u=0;e=0;if(X&1){break Z}break v}if((n|0)<=0){o=1;x[h>>2]=1;break i}x[h+8>>2]=y[F|0];k=F+1|0;break w}if((n|0)<=0){break x}W=e+8|0;k=F+1|0;f=y[F|0]<<e|f;d=2;break u}d=4;break u}M=f;break K}d=7;break u}d=8;break u}C=i;break J}E=f;break B}o=1;if((n|0)<=0){break y}e=e+8|0;k=F+1|0;break t}g=i;d=e;break z}j=2;break s}j=37;break k}d=1;break u}d=3;break u}d=5;break u}d=6;break u}d=9;break u}d=10;break u}d=11;break u}d=12;break u}d=13;break u}d=14;break u}d=15;break u}d=16;break u}d=17;break u}d=18;break u}j=1;break s}x[h>>2]=32;break i}x[h>>2]=5;o=1;break i}if(k>>>0>=t>>>0){x[h>>2]=2;o=1;break i}d=y[k|0];x[h+12>>2]=d;n=1;i=x[h+8>>2];if(!(((d|i<<8)>>>0)%31|d&32)){n=(i&15)!=8}k=k+1|0;j=36;d=256<<(i>>>4);if(d>>>0>32768|d>>>0>r>>>0){break l}i=0;if(n){break l}}d=0}$:while(1){aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{switch(d|0){case 0:if(e>>>0>2){break Ga}d=1;continue;case 4:break Da;case 3:break Ea;case 2:break Fa;case 1:break Ha;case 9:break la;case 10:break ma;case 11:break na;case 12:break oa;case 13:break pa;case 14:break qa;case 15:break ra;case 16:break sa;case 17:break ta;case 8:break za;case 7:break Aa;case 6:break Ba;case 5:break Ca;default:break ua}}while(1){if(k>>>0>=t>>>0){x[h>>2]=3;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;if(e>>>0<3){continue}break}}d=f&7;x[h+20>>2]=d;g=d>>>1|0;x[h+24>>2]=g;e=e-3|0;f=f>>>3|0;if(d>>>0>=2){break ya}W=e;break va}e=W&-8;f=f>>>(W&7)|0;i=0;d=0;break xa}while(1){if(k>>>0>=t>>>0){x[h>>2]=6;o=1;break i}f=y[k|0]<<e|f;d=e>>>0>4294967287;k=k+1|0;e=e+8|0;if(d){continue}break}d=1;break xa}if(k>>>0>=t>>>0){x[h>>2]=7;o=1;break i}v[(h+i|0)+10528|0]=y[k|0];k=k+1|0;d=2;break xa}while(1){if(k>>>0>=t>>>0){x[h>>2]=51;o=1;break i}f=y[k|0]<<e|f;d=e>>>0>4294967287;k=k+1|0;e=e+8|0;if(d){continue}break}break da}if(m>>>0<G>>>0){v[m|0]=u;i=i-1|0;m=m+1|0;f=M;break ea}o=2;j=52;f=M;break k}if(m>>>0<G>>>0){break wa}o=2;j=9;break k}if(k>>>0<t>>>0){d=G-m|0;g=t-k|0;d=d>>>0<g>>>0?d:g;d=d>>>0<i>>>0?d:i;i=i-d|0;m=yc(m,k,d)+d|0;k=d+k|0;break ca}x[h>>2]=38;o=1;break i}C=0;Ia:{switch(g-1|0){case 0:x[h+44>>2]=288;x[h+48>>2]=32;d=h+3552|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h+3560|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h+3568|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h+3576|0;x[d>>2]=84215045;x[d+4>>2]=84215045;d=h- -64|0;g=0;while(1){j=144;if((g|0)==144){while(1){g=256;if((j|0)==256){while(1){j=280;if((g|0)==280){while(1){if((j|0)==288){break ia}v[d|0]=8;j=j+1|0;d=d+1|0;continue}}else{v[d|0]=7;g=g+1|0;d=d+1|0;continue}}}else{v[d|0]=9;j=j+1|0;d=d+1|0;continue}}}else{v[d|0]=8;g=g+1|0;d=d+1|0;continue}};case 2:break n;default:break Ia}}d=0;break ka}while(1){Ja:{Ka:{La:{Ma:{Na:{Oa:{switch(d|0){case 0:if(i>>>0>3){break Na}if(!e){e=0;break Ma}if(e>>>0>7){break Ka}d=3;continue $;case 1:v[(h+i|0)+10528|0]=f;e=e-8|0;f=f>>>8|0;break Ja;default:break Oa}}i=i+1|0;break La}i=z[h+10528>>1];if((i|0)==(z[h+10530>>1]^65535)){break ea}break m}d=4;continue $}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(m>>>0<G>>>0){v[m|0]=y[(P-u&$)+I|0];m=m+1|0;P=P+1|0;d=7;break fa}o=2;j=53;break k}while(1){if(k>>>0>=t>>>0){x[h>>2]=27;o=1;f=E;break i}E=y[k|0]<<e|E;k=k+1|0;e=e+8|0;if(s>>>0>e>>>0){continue}break}d=6;break fa}if(k>>>0>=t>>>0){x[h>>2]=26;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;d=4;if(e>>>0<15){break fa}d=5;break fa}while(1){if(k>>>0>=t>>>0){x[h>>2]=25;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;if(s>>>0>e>>>0){continue}break}d=3;break fa}if(m>>>0>=G>>>0){o=2;j=24;break k}v[m|0]=i;m=m+1|0;break ga}if(k>>>0>=t>>>0){x[h>>2]=23;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;d=0;if(e>>>0<15){break fa}d=1;break fa}while(1){if(k>>>0>=t>>>0){x[h>>2]=18;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;if(s>>>0>e>>>0){continue}break}Y=u-16|0;d=3;break ha}if(k>>>0>=t>>>0){x[h>>2]=16;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;d=1;if(e>>>0<15){break ha}d=2;break ha}while(1){if(k>>>0>=t>>>0){x[h>>2]=14;o=1;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;if(e>>>0<3){continue}break}d=1;break ja}d=C+22466|0;while(1){if(k>>>0>=t>>>0){x[h>>2]=11;o=1;i=C;break i}f=y[k|0]<<e|f;k=k+1|0;e=e+8|0;L=v[d|0];if(e>>>0<L>>>0){continue}break}d=1}while(1){Pa:{Qa:{Ra:{if(!d){if(C>>>0>2){break Ra}L=v[C+22466|0];if(L>>>0<=e>>>0){break Pa}d=9;continue $}d=C<<2;x[(d+h|0)+44>>2]=x[d+81344>>2]+((-1<<L^-1)&f);C=C+1|0;e=e-L|0;f=f>>>L|0;break Qa}i=0;Tb(h+7040|0,0,288);d=0;break ja}d=0;continue}d=1;continue}}while(1){Sa:{Ta:{Ua:{if(!d){if(A[h+52>>2]<=i>>>0){break Ua}if(e>>>0>2){break Sa}d=10;continue $}v[(y[i+81360|0]+h|0)+7040|0]=f&7;i=i+1|0;e=e-3|0;f=f>>>3|0;break Ta}x[h+52>>2]=19;break ia}d=0;continue}d=1;continue}}J=x[h+24>>2];d=0}while(1){Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{switch(d|0){case 0:d=0;if((J|0)<0){break ga}R=Tb(Z,0,64);g=D(J,3488)+h|0;Tb(g+352|0,0,3200);ca=g- -64|0;H=x[h+24>>2];j=x[((H<<2)+h|0)+44>>2];while(1){if((d|0)!=(j|0)){g=(y[d+ca|0]<<2)+R|0;x[g>>2]=x[g>>2]+1;d=d+1|0;continue}break};x[R+64>>2]=0;x[R+68>>2]=0;r=0;d=1;g=0;while(1){if((d|0)!=16){n=d<<2;d=d+1|0;n=x[n+R>>2];g=n+g<<1;x[(R- -64|0)+(d<<2)>>2]=g;r=n+r|0;continue}break};S=0;n=-1;if((g|0)!=65536&r>>>0>=2){break o}while(1){if(j>>>0>S>>>0){r=y[S+ca|0];cb:{if(!r){break cb}d=(R- -64|0)+(r<<2)|0;g=x[d>>2];x[d>>2]=g+1;d=0;j=r;while(1){if(j){d=g&1|d<<1;g=g>>>1|0;j=j-1|0;continue}break}if(r>>>0<=10){g=1<<r;r=r<<9|S;j=D(J,3488)+h|0;while(1){if(d>>>0>1023){break cb}w[(j+(d<<1)|0)+352>>1]=r;d=d+g|0;continue}}H=D(J,3488)+h|0;g=H+((d&1023)<<1)|0;j=w[g+352>>1];db:{if(j){g=n;n=j;break db}w[g+352>>1]=n;g=n-2|0}d=d>>>9|0;while(1){d=d>>>1|0;j=d&1;if(r>>>0>=12){j=(H+(j+(n^-1)<<1)|0)+2400|0;n=w[j>>1];if(!n){w[j>>1]=g;n=g;g=g-2|0}r=r-1|0;continue}break}w[((D(J,3488)+h|0)+(j+(n^-1)<<1)|0)+2400>>1]=S;n=g}S=S+1|0;H=x[h+24>>2];j=x[((H<<2)+h|0)+44>>2];continue}break};d=0;if((H|0)!=2){break Wa}break _a;case 1:d=w[(((f&1023)<<1)+h|0)+7328>>1];eb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break eb}break Za}if(e>>>0<11){break eb}j=10;while(1){d=w[(((f>>>j&1)+(d^-1)<<1)+h|0)+9376>>1];if((d|0)<0){g=j+2|0;j=j+1|0;if(e>>>0>=g>>>0){continue}}break}if((d|0)>=0){break Za}}d=11;continue $;case 2:j=w[(((f&1023)<<1)+h|0)+7328>>1];if((j|0)>=0){break ab}d=10;while(1){g=f>>>d|0;d=d+1|0;j=w[(((g&1)+(j^-1)<<1)+h|0)+9376>>1];if((j|0)<0){continue}break};u=j&65535;break $a;default:break bb}}d=v[Y+18664|0]+((-1<<s^-1)&f)|0;e=e-s|0;f=f>>>s|0;g=h+i|0;Tb(g+10532|0,(u|0)==16?y[g+10531|0]:0,d);d=d+i|0;break _a}d=j>>>9|0;u=j&511}e=e-d|0;f=f>>>d|0;if(u>>>0>15){break Ya}v[(h+i|0)+10532|0]=u;d=i+1|0}g=x[h+48>>2];i=x[h+44>>2];n=g+i|0;if(n>>>0<=d>>>0){break Xa}if(e>>>0<=14){if((t-k|0)<=1){i=d;d=1;continue}f=y[k|0]<<e|y[k+1|0]<<e+8|f;k=k+2|0;e=e+16|0}i=d}d=2;continue}if(!((u|0)!=16|i)){i=0;u=16;break p}Y=u-16|0;s=v[u+22446|0];if(s>>>0<=e>>>0){break Va}d=12;continue $}if((d|0)!=(n|0)){i=d;break q}n=h+10532|0;yc(h- -64|0,n,i);yc(h+3552|0,i+n|0,g);H=x[h+24>>2];i=d}J=H-1|0;x[h+24>>2]=J;d=0;continue}d=3;continue}}d=2}fb:while(1){gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{switch(d|0){case 0:d=w[(((f&1023)<<1)+h|0)+352>>1];wb:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break wb}break gb}if(e>>>0<11){break wb}j=10;while(1){d=w[(((f>>>j&1)+(d^-1)<<1)+h|0)+2400>>1];if((d|0)<0){g=j+2|0;j=j+1|0;if(e>>>0>=g>>>0){continue}}break}if((d|0)>=0){break gb}}d=13;continue $;case 1:j=w[(((f&1023)<<1)+h|0)+352>>1];if((j|0)>=0){break ub}d=10;while(1){i=f>>>d|0;d=d+1|0;j=w[(((i&1)+(j^-1)<<1)+h|0)+2400>>1];if((j|0)<0){continue}break};i=j&65535;break tb;case 3:break jb;case 4:break kb;case 5:break pb;case 6:break qb;case 2:break vb;default:break rb}}while(1){d=t-k|0;if(!((G-m|0)>1&(d|0)>=4)){if(e>>>0>14){break gb}if((d|0)<=1){d=0;continue fb}f=y[k|0]<<e|y[k+1|0]<<e+8|f;e=e+16|0;k=k+2|0;break gb}if(!(e>>>0>14)){f=(y[k|0]|y[k+1|0]<<8)<<e|f;k=k+2|0;e=e+16|0}r=e;i=w[(((f&1023)<<1)+h|0)+352>>1];xb:{if((i|0)<0){d=10;while(1){g=f>>>d|0;d=d+1|0;i=w[(((g&1)+(i^-1)<<1)+h|0)+2400>>1];if((i|0)<0){continue}break}i=i&65535;break xb}d=i>>>9|0}e=r-d|0;f=f>>>d|0;if(i&256){break sb}if(!(e>>>0>14)){f=(y[k|0]|y[k+1|0]<<8)<<e|f;k=k+2|0;e=e+16|0}r=e;j=w[(((f&1023)<<1)+h|0)+352>>1];yb:{if((j|0)<0){d=10;while(1){g=f>>>d|0;d=d+1|0;j=w[(((g&1)+(j^-1)<<1)+h|0)+2400>>1];if((j|0)<0){continue}break}j=j&65535;break yb}d=j>>>9|0}v[m|0]=i;e=r-d|0;f=f>>>d|0;if(!(j&256)){v[m+1|0]=j;m=m+2|0;continue}break}m=m+1|0;i=j;break sb}d=j>>>9|0;i=j&511}e=e-d|0;f=f>>>d|0;if(i>>>0>255){break sb}d=14;continue $}g=i&511;i=256;if((g|0)==256){break ba}d=g-257<<2;i=x[d+80832>>2];s=0;if(g-285>>>0<4294967276){break ib}s=x[d+80960>>2];if(s>>>0>e>>>0){d=15;continue $}d=3;continue}if(!i){i=-1;break nb}i=i-1|0;d=18;continue $}e=e-s|0;f=E>>>s|0;u=((-1<<s^-1)&E)+u|0;break ob}j=w[(((f&1023)<<1)+h|0)+3840>>1];zb:{if((j|0)<0){d=10;while(1){g=f>>>d|0;d=d+1|0;j=w[(((g&1)+(j^-1)<<1)+h|0)+5888>>1];if((j|0)<0){continue}break}g=j&65535;break zb}d=j>>>9|0;g=j&511}e=e-d|0;E=f>>>d|0;d=g<<2;u=x[d+81088>>2];s=0;if(g-30>>>0<4294967270){f=E;break ob}s=x[d+81216>>2];if(s>>>0<=e>>>0){break mb}d=17;continue $}P=m-I|0;d=(P-u&$)+I|0;if((d>>>0<m>>>0?m:d)+i>>>0>G>>>0){break lb}while(1){if(i>>>0>=3){v[m|0]=y[d|0];v[m+1|0]=y[d+1|0];v[m+2|0]=y[d+2|0];i=i-3|0;d=d+3|0;m=m+3|0;continue}break}if(!i){i=0;break nb}v[m|0]=y[d|0];if((i|0)!=1){v[m+1|0]=y[d+1|0]}m=i+m|0}d=2;continue}d=6;continue}d=7;continue}d=w[(((f&1023)<<1)+h|0)+3840>>1];Ab:{if((d|0)>=0){if(d>>>0<512|d>>>9>>>0>e>>>0){break Ab}break hb}if(e>>>0<11){break Ab}j=10;while(1){d=w[(((f>>>j&1)+(d^-1)<<1)+h|0)+5888>>1];if((d|0)<0){g=j+2|0;j=j+1|0;if(e>>>0>=g>>>0){continue}}break}if((d|0)>=0){break hb}}d=16;continue $}e=e-s|0;i=((-1<<s^-1)&f)+i|0;f=f>>>s|0}if(e>>>0>14){break hb}if((t-k|0)<=1){d=4;continue}f=y[k|0]<<e|y[k+1|0]<<e+8|f;e=e+16|0;k=k+2|0}d=5;continue}d=1;continue}}if(!i|!e){break ca}if(e>>>0>7){break da}d=5;continue}e=e-8|0;M=f>>>8|0;u=f&255;d=6;continue}if(i){break aa}i=0}if(v[h+20|0]&1){break t}d=0;continue}d=7;continue}}f=0;d=e>>>3|0;g=k-F|0;g=k>>>0>=g>>>0?g:0;d=d>>>0<g>>>0?d:g;if((e&-8)==d<<3){k=k-d|0;g=0;d=0;e=0;if(!(X&1)){break r}j=0;break s}_(6894,13257,2797,6904);p()}while(1){Bb:{Cb:{Db:{Eb:{Fb:{switch(j|0){case 0:if(g>>>0>3){i=g;e=d;break r}e=0;if(!d){i=g;break Bb}if(d>>>0>7){break Eb}j=1;continue;case 1:break Fb;default:break Db}}while(1){if(k>>>0>=t>>>0){x[h>>2]=41;o=1;i=g;e=d;break i}f=y[k|0]<<d|f;n=d>>>0>4294967287;k=k+1|0;d=d+8|0;if(n){continue}break}}j=f&255;f=f>>>8|0;d=d-8|0;break Cb}if(k>>>0>=t>>>0){x[h>>2]=42;o=1;break i}j=y[k|0];k=k+1|0;g=i;d=e}x[h+16>>2]=x[h+16>>2]<<8|j;g=g+1|0;j=0;continue}j=2;continue}}o=0;j=34;break k}j=21;break k}j=17;break k}j=35;break k}j=10;break k}j=39;break k}i=1}x[h>>2]=j}d=e>>>3|0;g=k-F|0;g=k>>>0>=g>>>0?g:0;d=d>>>0<g>>>0?d:g;k=k-d|0;e=e-(d<<3)|0}x[h+4>>2]=e;x[h+60>>2]=P;x[h+40>>2]=s;x[h+36>>2]=i;x[h+32>>2]=u;x[h+56>>2]=(((e&63)>>>0<32?-1<<e:0)^-1)&f;x[B+12>>2]=k-F;e=m-O|0;x[B+8>>2]=e;if((o|0)<0){break g}k=(e>>>0)%5552|0;d=x[h+28>>2];f=d>>>16|0;j=d&65535;while(1){g=0;if(e){d=O;while(1){if((g|7)>>>0<k>>>0){i=y[d|0]+j|0;n=i+y[d+1|0]|0;r=n+y[d+2|0]|0;E=r+y[d+3|0]|0;M=E+y[d+4|0]|0;C=M+y[d+5|0]|0;m=C+y[d+6|0]|0;j=m+y[d+7|0]|0;f=j+(m+(C+(M+(E+(r+(n+(f+i|0)|0)|0)|0)|0)|0)|0)|0;d=d+8|0;g=g+8|0;continue}break}g=k&8184;while(1){if((k|0)!=(g|0)){g=g+1|0;j=y[d|0]+j|0;f=j+f|0;d=d+1|0;continue}break}e=e-k|0;f=(f>>>0)%65521|0;j=(j>>>0)%65521|0;O=k+O|0;k=5552;continue}break}d=f<<16|j;x[h+28>>2]=d;if(o){break g}o=0;if(!(X&1)){break g}o=(d|0)!=x[h+16>>2]?-2:0}fb=Z+144|0;x[h+43780>>2]=o;d=x[B+12>>2];x[q>>2]=d+x[q>>2];x[q+4>>2]=x[q+4>>2]-d;x[q+8>>2]=d+x[q+8>>2];x[q+48>>2]=x[h+28>>2];d=x[B+8>>2];x[h+10996>>2]=d;i=x[q+16>>2];d=d>>>0<i>>>0?d:i;yc(x[q+12>>2],x[h+10992>>2]+I|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];e=x[h+10996>>2];x[h+10996>>2]=e-d;f=d+x[h+10992>>2]&32767;x[h+10992>>2]=f;if((o|0)<0){break f}if(!((o|0)!=1|da)){i=-5;break e}if(o){i=0;g=x[q+4>>2];if(!g|!x[q+16>>2]){break e}if((d|0)==(e|0)){continue}break e}break}i=(d|0)==(e|0);break e}f=x[q+16>>2];d=d>>>0<f>>>0?d:f;yc(x[q+12>>2],(x[h+10992>>2]+h|0)+11012|0,d);x[q+12>>2]=d+x[q+12>>2];x[q+16>>2]=x[q+16>>2]-d;x[q+20>>2]=d+x[q+20>>2];f=x[h+10996>>2];x[h+10996>>2]=f-d;x[h+10992>>2]=d+x[h+10992>>2]&32767;if(x[h+43780>>2]){break e}i=(d|0)==(f|0);break e}i=-3}fb=B+16|0;d=x[l+1084>>2]-V|0;x[l+1084>>2]=d;g=K+ba|0;K=x[l+1104>>2];ba=g-K|0;continue}break}b=l+1088|0;Gb:{if(!b){break Gb}d=x[b+28>>2];if(!d){break Gb}ib[x[b+36>>2]](x[b+40>>2],d);x[b+28>>2]=0}d=0;Hb:{Ib:{if(!((y[l+1156|0]|y[l+1157|0]<<8|(y[l+1158|0]<<16|y[l+1159|0]<<24))!=(aa|0)|K|(i|0)!=1)){le(l+24|0,x[T>>2],x[T+4>>2]);b=Jd(l+16|0);x[31785]=0;d=x[b+4>>2];x[l+8>>2]=x[b>>2];x[l+12>>2]=d;b=dg(558,l+48|0,x[l+24>>2],x[l+28>>2],l+8|0);d=x[31785];x[31785]=0;if((d|0)==1){break Ib}x[31785]=0;d=U(920,a|0,b|0,c|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break Hb}ub(b)}dc(T);break a}a=N()|0;break c}a=N()|0;ub(b);break c}a=N()|0}dc(T);Q(a|0);p()}fb=l+1168|0;return d|0}function bqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=E(0),A=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=E(0),M=E(0),O=0,P=0,S=0,V=0,W=0,Z=0,_=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=E(0),ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=E(0);n=fb-96|0;fb=n;xc(c);a:{while(1){b:{if(!Mb(x[c>>2],x[c+8>>2],4)){break b}d=n+76|0;g=fb-16|0;fb=g;c:{if(!Mb(x[c>>2],x[c+8>>2],3)){F=0;while(1){if((F|0)!=3){Wh(d+F|0);F=F+1|0;continue}break}break c}Qw(g+8|0,d);md(g,c,x[g+8>>2],x[g+12>>2])}fb=g+16|0;d:{e:{if(!Ob(d,15183,3)){d=n+32|0;g=fb-16|0;fb=g;f:{if(!Mb(x[c>>2],x[c+8>>2],7)){F=0;while(1){if((F|0)!=7){Wh(d+F|0);F=F+1|0;continue}break}break f}ur(g+8|0,d);md(g,c,x[g+8>>2],x[g+12>>2])}fb=g+16|0;F=0;g=3;while(1){if((g|0)==7){break d}d=v[(n+32|0)+g|0];if((d|0)<0){break e}g=g+1|0;F=d&255|F<<7;continue}}g:{if(Ob(n+76|0,14329,3)){break g}if(!LX(c,13668)){break g}Yb(c,Mg(c)+16|0);continue}if(!Ob(n+76|0,28830,3)){continue}if(!Ob(n+76|0,28834,3)){continue}if(!y[n+76|0]){Eh(c,2);continue}if(XU(n+76|0)){break b}}g=0;break a}Yb(c,F);continue}break}xc(c);g=n+76|0;bD(g,c);V=x[n+76>>2];c=Se(g);O=Nb(n- -64|0);x[31785]=0;aa=R(595,n+60|0)|0;g=x[31785];x[31785]=0;h:{i:{j:{if((g|0)!=1){wB(Tb(x[aa>>2],0,6668));x[n+48>>2]=0;x[n+52>>2]=0;x[n+40>>2]=0;x[n+44>>2]=0;x[n+32>>2]=0;x[n+36>>2]=0;x[31785]=0;ba=R(596,n+20|0)|0;g=x[31785];x[31785]=0;k:{if((g|0)!=1){F=0;while(1){G=x[aa>>2];e=Fc(V,ca);W=x[ba>>2];d=0;m=0;r=fb-17152|0;fb=r;x[r+17148>>2]=0;l:{m:{n:{if(y[G+6152|0]!=255|(e|0)<5){break n}if(!aq(G+6152|0,c)){break n}g=ez(y[c+1|0],y[c+2|0],x[G+6148>>2])+$p(c)|0;x[r+17148>>2]=g;if((e|0)==(g|0)){g=e;break m}o:{if((e|0)>=(g+4|0)){if(aq(c,c+g|0)){break o}}x[r+17148>>2]=0;break n}if(g){break m}}h=c;A=Tb(G,0,6668)+6148|0;q=r+17148|0;s=e-4|0;I=(s|0)>0?s:0;while(1){p:{q:{r:{s:{if((m|0)==(I|0)){m=e;break s}if(!ML(h)){break q}j=ez(y[h+1|0],y[h+2|0],x[A>>2]);g=j+$p(h)|0;i=4;k=m+4|0;t:{while(1){if(!(i>>>0>2303|j)){if((s|0)<=((i<<1)+m|0)){break t}j=0;l=h+i|0;u:{if(!aq(h,l)){break u}f=i-$p(h)|0;o=$p(l)+f|0;if((e|0)<(o+(i+k|0)|0)){break u}if(!aq(h,l+o|0)){break u}x[A>>2]=f;j=f;g=i}i=i+1|0;continue}break}if(!j|(e|0)<(g+m|0)){break t}k=e-m|0;i=0;f=0;while(1){v:{w:{if((f|0)!=10){l=(f|0)!=0;K=i;i=h+i|0;i=(K+ez(y[i+1|0],y[i+2|0],j)|0)+$p(i)|0;if((k|0)<(i+4|0)){break v}if(aq(h,h+i|0)){break w}l=0}else{l=1}break v}f=f+1|0;continue}break}if(!l){break t}d=g;break s}if((e|0)!=(g|0)|m){break r}m=0;d=e}x[q>>2]=d;d=m;break p}x[A>>2]=0}h=h+1|0;m=m+1|0;continue}break}g=x[r+17148>>2];if((e|0)>=(d+g|0)?g:0){break m}x[n+32>>2]=d;o=0;break l}C=c+d|0;x[G+6152>>2]=y[C|0]|y[C+1|0]<<8|(y[C+2|0]<<16|y[C+3|0]<<24);x[n+36>>2]=d;x[n+32>>2]=d+g;x[n+40>>2]=y[C+3|0]>191?1:2;ra=n,sa=QL(y[C+1|0],y[C+2|0]),x[ra+44>>2]=sa;x[n+48>>2]=4-(y[C+1|0]>>>1&3);ra=n,sa=dz(y[C+1|0],y[C+2|0]),x[ra+52>>2]=sa;if(!W){o=cz(y[C+1|0]);break l}OL(r+17136|0,C+4|0,g-4|0);if(!(v[C+1|0]&1)){re(r+17136|0,16)}x:{if(x[n+48>>2]==3){o=0;d=r+17136|0;ia=r+3728|0;g=ia;h=0;e=y[C+1|0];f=D((e>>>3&1)+(e>>>4&1)|0,3)+(y[C+2|0]>>>2&3)|0;f=f-((f|0)!=0)|0;m=y[C+3|0]>191?1:2;y:{if(e&8){j=re(d,9);m=m<<1;h=re(d,m+7|0);break y}j=re(d,m|8)>>>m|0}e=D(f,40);A=e+81680|0;s=e+82e3|0;q=D(f,23)+81488|0;f=-1;l=0;z:{while(1){e=y[C+3|0];I=re(d,12);w[g+4>>1]=I;i=re(d,9);w[g+6>>1]=i;if((i&65535)>>>0>288){break z}i=e>>>0>191?h<<4:h;ra=g,sa=re(d,8),v[ra+10|0]=sa;e=re(d,y[C+1|0]&8?4:9);v[g+13|0]=22;v[g+14|0]=0;x[g>>2]=q;w[g+8>>1]=e;A:{if(re(d,1)){e=re(d,2);v[g+11|0]=e;if(!(e&255)){break z}e=re(d,1);w[g+18>>1]=65287;v[g+12|0]=e;if(y[g+11|0]==2){B:{if(!(e&255)){x[g>>2]=A;v[g+18|0]=8;h=0;e=39;break B}x[g>>2]=s;h=y[C+1|0]&8?8:6;e=30}v[g+14|0]=e;v[g+13|0]=h;i=i&3855}e=re(d,10);ra=g,sa=re(d,3),v[ra+21|0]=sa;ra=g,sa=re(d,3),v[ra+22|0]=sa;ra=g,sa=re(d,3),v[ra+23|0]=sa;h=e<<5;break A}v[g+11|0]=0;v[g+12|0]=0;h=re(d,15);ra=g,sa=re(d,4),v[ra+18|0]=sa;e=re(d,3);v[g+20|0]=255;v[g+19|0]=e}v[g+17|0]=h&31;v[g+15|0]=h>>>10;v[g+16|0]=h>>>5&31;l=(I&65535)+l|0;C:{if(y[C+1|0]&8){e=re(d,1);break C}e=z[g+8>>1]>499}v[g+24|0]=e;ra=g,sa=re(d,1),v[ra+25|0]=sa;e=re(d,1);v[g+27|0]=i>>>12&15;v[g+26|0]=e;g=g+28|0;h=i<<4;m=m-1|0;if(m){continue}break}f=(x[d+4>>2]+l|0)>(x[d+8>>2]+(j<<3)|0)?-1:j}if(!((f|0)<0|x[r+17140>>2]>x[r+17144>>2])){g=r+17136|0;i=x[g+4>>2];m=x[g+8>>2];h=r+900|0;d=x[G+6144>>2];e=d-f|0;d=(d|0)<(f|0)?d:f;e=yc(h+12|0,(((e|0)>0?e:0)+G|0)+6156|0,d);j=x[g>>2]+(x[g+4>>2]/8|0)|0;g=(m-i|0)/8|0;yc(d+e|0,j,g);OL(h,e,d+g|0);D:{g=x[G+6144>>2]>=(f|0);if(!g){break D}ma=G+2304|0;na=r+8608|0;oa=r+3840|0;while(1){if((y[C+1|0]&8?2:1)>>>0<=o>>>0){break D}pa=Tb(oa,0,4608);e=x[n+40>>2];m=D(D(e,o),28)+ia|0;d=0;ja=(e|0)>0?e:0;A=r+900|0;I=A+7548|0;Z=G+6152|0;while(1){if((d|0)!=(ja|0)){i=D(d,28)+m|0;K=z[i+4>>1];S=x[A+4>>2];t=(A+D(d,39)|0)+16156|0;e=I;s=d;f=fb-48|0;fb=f;d=i;J=y[d+25|0];H=D(!y[d+13|0]+(y[d+14|0]!=0)|0,28)+82320|0;E:{if(y[Z+1|0]&8){j=y[d+27|0];i=y[z[d+8>>1]+82416|0];h=i&3;v[f+47|0]=h;v[f+46|0]=h;i=i>>>2|0;v[f+45|0]=i;v[f+44|0]=i;break E}i=(y[Z+3|0]&16)>>>4&(s|0)!=0;k=i?12:0;h=z[d+8>>1]>>>i|0;while(1){if((h|0)>=0){j=3;i=1;while(1){if((j|0)>=0){l=y[(j+k|0)+82432|0];v[(f+44|0)+j|0]=((h|0)/(i|0)|0)%(l|0);j=j-1|0;i=D(i,l);continue}break}k=k+4|0;h=h-i|0;continue}break}H=k+H|0;j=-16}i=f;da=f+44|0;h=0;while(1){F:{G:{H:{if((h|0)==4){break H}q=y[h+H|0];if(!q){break H}if(j&8){yc(i,t,q);break G}k=y[h+da|0];if(!k){Tb(i,0,q);Tb(t,0,q);break G}ea=(j|0)>=0?-1:-1<<k^-1;l=0;while(1){if((l|0)==(q|0)){break G}P=re(A,k);v[l+t|0]=(P|0)==(ea|0)?-1:P;v[i+l|0]=P;l=l+1|0;continue}}v[i+2|0]=0;v[i|0]=0;v[i+1|0]=0;break F}j=j<<1;h=h+1|0;i=i+q|0;t=q+t|0;continue}break}I:{i=y[d+14|0];if(i){h=2-J|0;l=y[d+23|0]<<h;q=y[d+22|0]<<h;k=y[d+21|0]<<h;t=y[d+13|0];j=0;while(1){if(j>>>0>=i>>>0){break I}h=f+(j+t|0)|0;v[h|0]=k+y[h|0];v[h+1|0]=q+y[h+1|0];v[h+2|0]=l+y[h+2|0];j=j+3|0;continue}}if(!y[d+24|0]){break I}j=0;while(1){if((j|0)==10){break I}h=f+j|0;v[h+11|0]=y[h+11|0]+y[j+82456|0];j=j+1|0;continue}}h=J+1|0;j=0;u=bz(E(2048),((((y[Z+3|0]&224)==96)<<1)-y[d+10|0]|0)+258|0);while(1){if(y[d+13|0]+(i&255)>>>0>j>>>0){ra=e+(j<<2)|0,ta=bz(u,y[f+j|0]<<h),B[ra>>2]=ta;j=j+1|0;i=y[d+14|0];continue}break}fb=f+48|0;l=(A+D(s,2304)|0)+2940|0;j=e;da=K+S|0;u=E(0);i=x[A+4>>2];e=x[A>>2]+((i|0)/8|0)|0;f=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);f=(f<<24|(f&65280)<<8|(f>>>8&65280|f>>>24))<<(i&7);k=i|-8;t=e+4|0;q=d;H=x[d>>2];J=z[d+6>>1];e=0;while(1){J:{K:{if((J|0)>0){i=e+1|0;e=e+q|0;d=y[e+15|0];ea=(w[(d<<1)+86880>>1]<<1)+82496|0;P=y[e+18|0];if(d>>>0>=16){fa=y[d+86944|0];qa=32-fa|0;while(1){ga=y[H|0]>>>1|0;ha=(J|0)<(ga|0)?J:ga;u=B[j>>2];while(1){e=f>>>27|0;d=5;while(1){e=w[ea+(e<<1)>>1];if((e|0)<0){f=f<<d;h=e&7;e=(f>>>32-h|0)-(e>>3)|0;k=d+k|0;d=h;continue}break}h=e&65535;d=h>>>8|0;k=d+k|0;f=f<<d;d=0;while(1){if((d|0)!=2){K=h&15;L:{if((K|0)==15){k=k+fa|0;e=f<<fa;while(1){if((k|0)>=0){e=y[t|0]<<k|e;t=t+1|0;k=k-8|0;continue}break}K=(f>>>qa|0)+15|0;f=K;M:{if((f|0)<=128){L=B[(f<<2)+87040>>2];break M}ka=f>>>0<1024;f=ka?f<<3:f;S=f<<1&64;M=E(E((f&63)-S|0)/E(S+(f&-64)|0));L=E((ka?E(16):E(256))*E(E(E(M*E(E(M*E(.2222222238779068))+E(1.3333333730697632)))+E(1))*B[(f+S>>6<<2)+87040>>2]))}L=E(E(u*L)*E(e>>31|1));break L}e=f;L=E(u*B[(((e>>>27&16|K)^16)<<2)+86976>>2])}B[l>>2]=L;h=h>>>4|0;l=l+4|0;d=d+1|0;f=(K|0)!=0;k=f+k|0;f=e<<f;continue}break}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}ha=ha-1|0;if(ha){continue}break}j=j+4|0;H=H+1|0;J=J-ga|0;if((J|0)<=0){break K}d=(P|0)>0;P=P-1|0;if(d){continue}break}break K}while(1){S=y[H|0]>>>1|0;K=(J|0)<(S|0)?J:S;u=B[j>>2];while(1){e=f>>>27|0;d=5;while(1){e=w[ea+(e<<1)>>1];if((e|0)<0){f=f<<d;h=e&7;e=(f>>>32-h|0)-(e>>3)|0;k=d+k|0;d=h;continue}break}d=e&65535;e=d>>>8|0;k=e+k|0;f=f<<e;e=0;while(1){if((e|0)!=2){h=d&15;B[l>>2]=u*B[(((h|f>>>27&16)^16)<<2)+86976>>2];d=d>>>4|0;l=l+4|0;e=e+1|0;h=(h|0)!=0;k=h+k|0;f=f<<h;continue}break}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}K=K-1|0;if(K){continue}break}j=j+4|0;H=H+1|0;J=J-S|0;if((J|0)<=0){break K}d=(P|0)>0;P=P-1|0;if(d){continue}break}break K}d=1-J|0;while(1){N:{i=y[q+26|0]?86864:86832;e=y[i+(f>>>28|0)|0];if(!(e&8)){e=y[i+((f<<4>>>32-(e&3))+(e>>>3)|0)|0]}i=e&7;k=i+k|0;if((da|0)<((k+(t-x[A>>2]<<3)|0)-24|0)){break N}d=d-1|0;if(!d){d=y[H|0];if(d>>>0<2){break N}H=H+1|0;u=B[j>>2];j=j+4|0;d=d>>>1|0}f=f<<i;if(e>>>0>=128){B[l>>2]=(f|0)<0?E(-u):u;k=k+1|0;f=f<<1}if(e&64){B[l+4>>2]=(f|0)<0?E(-u):u;k=k+1|0;f=f<<1}d=d-1|0;if(!d){d=y[H|0];if(d>>>0<2){break N}H=H+1|0;u=B[j>>2];j=j+4|0;d=d>>>1|0}if(e&32){B[l+8>>2]=(f|0)<0?E(-u):u;k=k+1|0;f=f<<1}if(e&16){B[l+12>>2]=(f|0)<0?E(-u):u;k=k+1|0;f=f<<1}while(1){if((k|0)>=0){f=y[t|0]<<k|f;t=t+1|0;k=k-8|0;continue}break}l=l+16|0;continue}break}x[A+4>>2]=da;break J}e=i;continue}break}d=s+1|0;continue}break}d=y[G+6155|0];O:{if(d&16){s=A+16195|0;d=0;l=fb-16|0;fb=l;i=A+2940|0;j=i+2304|0;I=x[m>>2];k=y[m+14|0];t=y[m+13|0];q=k+t|0;e=l+4|0;x[e+8>>2]=-1;x[e>>2]=-1;x[e+4>>2]=-1;while(1){if((d|0)!=(q|0)){H=d+I|0;h=y[H|0];f=0;P:{while(1){if(f>>>0>=h>>>0){break P}J=f<<2;if(B[J+j>>2]==E(0)){f=f+2|0;if(B[(J|4)+j>>2]==E(0)){continue}}break}x[e+((d>>>0)%3<<2)>>2]=d;h=y[H|0]}d=d+1|0;j=(h<<2)+j|0;continue}break}if(t){d=x[l+4>>2];e=x[l+8>>2];d=(d|0)>(e|0)?d:e;e=x[l+12>>2];d=(d|0)>(e|0)?d:e;x[l+12>>2]=d;x[l+8>>2]=d;x[l+4>>2]=d}e=k?3:1;h=q-e|0;d=0;while(1){if((d|0)!=(e|0)){j=d+h|0;f=j-e|0;if((f|0)<=x[(l+4|0)+(d<<2)>>2]){f=y[Z+1|0]<<28>>31&3}else{f=y[f+s|0]}v[j+s|0]=f;d=d+1|0;continue}break}h=x[m>>2];q=l+4|0;I=w[m+36>>1]&1;j=0;k=y[Z+1|0]&8?7:64;while(1){t=h+j|0;e=y[t|0];if(e){f=y[Z+3|0]&32;Q:{R:{if(x[q+((j>>>0)%3<<2)>>2]>=(j|0)){break R}d=y[j+s|0];if(d>>>0>=k>>>0){break R}L=f?E(1.4142135381698608):E(1);S:{if(y[Z+1|0]&8){d=d<<3;u=B[d+87572>>2];M=B[d+87568>>2];break S}M=bz(E(1),d+1>>>1<<I);d=d&1;u=d?E(1):M;M=d?M:E(1)}M=E(L*M);L=E(L*u);d=0;while(1){if((d|0)!=(e|0)){f=(d<<2)+i|0;u=B[f>>2];B[f+2304>>2]=u*L;B[f>>2]=u*M;d=d+1|0;continue}break}break Q}if(!f){break Q}LL(i,e)}j=j+1|0;i=(y[t|0]<<2)+i|0;continue}break}fb=l+16|0;break O}if((d&224)!=96){break O}LL(A+2940|0,576)}i=A+7708|0;d=0;while(1){if((d|0)!=(ja|0)){e=y[G+6153|0];s=(y[m+12|0]!=0)<<1<<((D((e>>>3&1)+(e>>>4&1)|0,3)+(y[G+6154|0]>>>2&3)|0)==2);l=(A+D(d,2304)|0)+2940|0;j=l;if(y[m+14|0]){h=x[m>>2]+y[m+13|0]|0;t=((A+D(d,2304)|0)+D(s,72)|0)+2940|0;e=t;f=i;while(1){q=y[h|0];if(q){k=q<<1;I=0;while(1){if((q|0)!=(I|0)){B[f>>2]=B[e>>2];B[f+4>>2]=B[(q<<2)+e>>2];B[f+8>>2]=B[(k<<2)+e>>2];e=e+4|0;I=I+1|0;f=f+12|0;continue}break}h=h+3|0;e=(k<<2)+e|0;continue}break}yc(t,i,f-i|0);f=s-1|0}else{f=31}while(1){e=0;if((f|0)>0){while(1){if((e|0)!=8){h=e<<2;q=h+j|0;u=B[q+72>>2];M=B[h+87632>>2];L=B[h+87664>>2];h=(17-e<<2)+j|0;la=B[h>>2];B[q+72>>2]=E(u*M)-E(L*la);B[h>>2]=E(u*L)+E(la*M);e=e+1|0;continue}break}j=j+72|0;f=f-1|0;continue}break}e=l;f=D(d,1152)+G|0;h=y[m+11|0];if(s){KL(e,f,87696,s);f=D(s,36)+f|0;e=D(s,72)+e|0}T:{if((h|0)==2){j=32-s|0;h=fb-80|0;fb=h;q=h|8;I=h|4;while(1){if((j|0)>0){s=yc(h,e,72);k=x[f+20>>2];x[e+16>>2]=x[f+16>>2];x[e+20>>2]=k;k=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=k;k=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=k;K=s;s=f+24|0;az(K,e+24|0,s);az(I,e+48|0,s);az(q,f,s);e=e+72|0;f=f+36|0;j=j-1|0;continue}break}fb=h+80|0;break T}KL(e,f,D((h|0)==3,72)+87696|0,32-s|0)}h=0;j=l+72|0;while(1){e=1;if(h>>>0<=31){while(1){if(e>>>0<=17){f=(e<<2)+j|0;B[f>>2]=-B[f>>2];e=e+2|0;continue}break}j=j+144|0;h=h+2|0;continue}break}m=m+28|0;d=d+1|0;continue}break}NL(ma,pa,18,x[n+40>>2],W,na);o=o+1|0;W=D(x[n+40>>2],1152)+W|0;continue}}e=r+900|0;i=x[e+8>>2]>>>3|0;m=x[e+4>>2]+7>>>3|0;d=i-m|0;f=(d|0)>=511?511:d;if((d|0)>0){ai(G+6156|0,(e+(d>>>0>511?i-511|0:m)|0)+12|0,f)}x[G+6144>>2]=f;break x}wB(G);break l}h=r+17136|0;o=0;m=0;j=0;e=r;d=0;U:{V:{W:{g=y[C+3|0];i=g>>>6|0;switch(i-1|0){case 2:break U;case 0:break W;default:break V}}d=(g>>>2&12)+4|0;break U}d=32}g=y[C+1|0];X:{if((g&6)==6){g=32;f=89100;break X}if(!(g&8)){g=30;f=89103;break X}l=y[C+2|0];f=l>>>2&3;g=dz(g,l)>>>((i|0)!=3)|0;g=g?g:192;if(g>>>0<=55){g=(f|0)==2?12:8;f=89124;break X}g=g>>>0<=95?27:(f|0)!=1?30:27;f=89112}v[e+768|0]=g;v[e+769|0]=(d|0)<(g|0)?d:g;g=f;i=89008;while(1){d=y[e+768|0];if(o>>>0>=d>>>0){o=0;while(1){f=d<<1&510;if(f>>>0>o>>>0){f=e+o|0;Y:{if(!y[f+770|0]){g=6;break Y}g=2;if((y[C+1|0]&6)==6){break Y}g=re(h,2);d=y[e+768|0]}v[f+834|0]=g;o=o+1|0;continue}break}m=e+770|0;i=e+834|0;g=0;j=f;while(1){if((g|0)!=(j|0)){l=y[m|0];f=l?19>>>y[g+i|0]&3|4:0;m=m+1|0;l=D(l,3)-6|0;u=E(0);d=4;while(1){if(d){if(d&f){A=re(h,6);s=(A|0)/3|0;u=E(B[(l+(D(s,-3)+A|0)<<2)+89136>>2]*E(2097152>>>s|0))}B[e>>2]=u;d=d>>>1|0;e=e+4|0;continue}break}g=g+1|0;continue}break}o=y[r+769|0];g=y[r+768|0];g=g>>>0<o>>>0?o:g;while(1){if((g|0)!=(o|0)){v[((o<<1)+r|0)+771|0]=0;o=o+1|0;continue}break}}else{if((j|0)==(o|0)){i=y[g|0]+89008|0;j=y[g+2|0]+o|0;m=y[g+1|0];g=g+3|0}f=o<<1;d=y[re(h,m)+i|0];v[(f+e|0)+770|0]=d;l=y[e+769|0];if(l>>>0>o>>>0){d=y[re(h,m)+i|0];l=y[e+769|0]}v[((f|1)+e|0)+770|0]=l?d:0;o=o+1|0;continue}break}g=0;e=Tb(r+3840|0,0,4608);I=G+2304|0;k=r+8608|0;o=0;Z:{while(1){if((o|0)==3){break Z}C=e+(g<<2)|0;A=r+17136|0;h=0;l=x[n+48>>2]|1;s=(l|0)>0?l:0;f=576;while(1){if((h|0)!=4){m=C+(D(h,l)<<2)|0;i=0;while(1){if(y[r+768|0]<<1>>>0>i>>>0){_:{j=y[(i+r|0)+770|0];if(!j){break _}if(j>>>0<=16){q=(-1<<j-1)+1|0;d=0;while(1){if((d|0)==(s|0)){break _}ra=(d<<2)+m|0,ta=E(re(A,j)+q|0),B[ra>>2]=ta;d=d+1|0;continue}}d=2<<j-17;j=re(A,(d-(d>>>3|0)|0)+3|0);t=d>>>1|0;q=d|1;d=0;while(1){if((d|0)==(s|0)){break _}K=j;j=(j>>>0)/(q>>>0)|0;B[(d<<2)+m>>2]=K-(t+D(q,j)|0)|0;d=d+1|0;continue}}i=i+1|0;m=(f<<2)+m|0;f=18-f|0;continue}break}h=h+1|0;continue}break}g=(l<<2)+g|0;if((g|0)==12){d=(o<<2)+r|0;g=e;f=y[r+769|0];i=e+D(f,72)|0;yc(i+2304|0,i,D(y[r+768|0]-f|0,72));m=0;while(1){if(y[r+768|0]>m>>>0){h=0;while(1){if((h|0)!=12){f=(h<<2)+g|0;B[f>>2]=B[d>>2]*B[f>>2];f=f+2304|0;B[f>>2]=B[d+12>>2]*B[f>>2];h=h+1|0;continue}break}d=d+24|0;g=g+72|0;m=m+1|0;continue}break}NL(I,e,12,x[n+40>>2],W,k);Tb(e,0,4608);W=D(x[n+40>>2],768)+W|0;g=0}o=o+1|0;if(x[r+17140>>2]<=x[r+17144>>2]){continue}break}wB(G);o=0;break l}g=1}o=D(cz(y[G+6153|0]),g)}fb=r+17152|0;g=x[n+32>>2];if((g|0)<0|!g){break h}d=x[n+44>>2];if((d|0)!=(_|0)?_:0){break h}g=x[n+40>>2];if((g|0)!=(F|0)?F:0){break h}if(g-3>>>0<4294967294|(d|0)<=0){break i}x[n+16>>2]=0;ra=n,sa=Fc(V,ca),x[ra+12>>2]=sa;F=x[bk(n+32|0,n+16|0,n+12|0)>>2];x[n+16>>2]=0;ra=n,sa=Fc(V,ca),x[ra+12>>2]=sa;e=x[bk(n+32|0,n+16|0,n+12|0)>>2];i=e>>31;$:{if(!o){break $}f=x[ba>>2];x[31785]=0;U(597,O|0,f|0,f+(D(g,o)<<1)|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){break $}c=T(125240)|0;if((gb|0)==($(125240)|0)){Y(c|0)|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;F=g;_=d;if((c|0)!=1){break h}c=N()|0}kd(ba);break k}if((Xc(x[O>>2],x[O+4>>2])>>>0)/(g>>>0)>>>0>268435456){break i}c=c+F|0;_=d;F=g;d=ca-(i+(e>>>0>V>>>0)|0)|0;ca=d;V=V-e|0;if(!!V&(d|0)>=0|(d|0)>0){continue}break}break h}c=N()|0}yT(aa);break j}c=N()|0}kd(O);Jc(n+76|0);Q(c|0);p()}F=g;_=d}g=0;aa:{if(!_|!F){break aa}c=x[O>>2];d=x[O+4>>2];if(mc(c,d)){break aa}if((Xc(c,d)>>>0)/(F>>>0)>>>0>268435456){break aa}Du(a,b);b=D(b,104)+a|0;a=b+484380|0;ra=a,sa=(Xc(x[O>>2],x[O+4>>2])>>>0)/(F>>>0)|0,x[ra>>2]=sa;g=b+484414|0;c=z[g>>1];w[g>>1]=(F|0)==2?c|65:c&65470|1;Bh(a);c=b+484400|0;g=ge(x[a>>2],x[c>>2]);if(!g){break aa}g=vb(x[O>>2]);d=vb(x[O+4>>2]);b=fb-16|0;fb=b;GU(b+8|0,g,d,x[c>>2]);fb=b+16|0;g=ge(x[a>>2],x[a+20>>2])}kd(ba);yT(aa);kd(O);Jc(n+76|0)}fb=n+96|0;return g|0}function LC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=E(0),u=0,C=0,G=0,H=0,I=E(0),K=0,L=0,M=0,N=0,O=E(0);s=fb-1520|0;fb=s;e=s+8|0;M=Tb(e,0,1512),N=-1,x[M+1420>>2]=N;v[s+56|0]=1;x[s+48>>2]=a+b;x[s+40>>2]=a;m=fb-1024|0;fb=m;v[e+1377|0]=1;a:{if(!wt(e)){break a}b=y[e+1375|0];if(!(b&2)){fc(e,34);break a}if(b&4){fc(e,34);break a}if(b&1){fc(e,34);break a}if(x[e+1116>>2]!=1){fc(e,34);break a}b=y[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!Zy(e,m+1018|0,6)|y[m+1018|0]!=102|(y[m+1019|0]!=105|y[m+1020|0]!=115)){break b}if(y[m+1021|0]!=104|y[m+1022|0]!=101|y[m+1023|0]!=97){break b}if((df(e)|0)!=100){break b}if(df(e)){break b}fc(e,38);break a}fc(e,34);break a}if((df(e)|0)!=1){fc(e,34);break a}if(!Zy(e,m+1018|0,6)){fc(e,10);break a}if(!Xy(m+1018|0)){fc(e,34);break a}if(wj(e)){fc(e,34);break a}b=df(e);x[e+4>>2]=b;if(!b){fc(e,34);break a}if(b>>>0>=17){fc(e,5);break a}b=wj(e);x[e>>2]=b;if(!b){fc(e,34);break a}wj(e);wj(e);wj(e);b=df(e);j=b>>>4|0;x[e+116>>2]=1<<j;g=b&15;x[e+112>>2]=1<<g;if(g-14>>>0<=4294967287){fc(e,20);break a}if(b+32<<24>>24>=0){fc(e,20);break a}c:{if(g>>>0>j>>>0){fc(e,20);break c}if(!(df(e)&1)){fc(e,34);break c}if(!wt(e)){break a}if(!Yy(e)){break a}if(!_y(e)){break a}if((Lh(e)|0)==3){while(1){if((f|0)!=6){M=(m+1018|0)+f|0,N=Lh(e),v[M|0]=N;f=f+1|0;continue}break}if(!Xy(m+1018|0)){fc(e,20);break c}b=Wy(e);f=qe(e,b+1|0);x[e+20>>2]=f;if(f){f=0;g=(b|0)>0?b:0;while(1){if((f|0)!=(g|0)){j=Lh(e);v[x[e+20>>2]+f|0]=j;f=f+1|0;continue}break}v[b+x[e+20>>2]|0]=0;b=Wy(e);x[e+28>>2]=0;x[e+24>>2]=b;d:{if((b|0)<=0){break d}b=qe(e,b<<2);x[e+28>>2]=b;if(b){break d}fc(e,3);break c}while(1){e:{f:{if(x[e+24>>2]>(h|0)){b=Wy(e);f=qe(e,b+1|0);g=h<<2;x[g+x[e+28>>2]>>2]=f;if(!x[g+x[e+28>>2]>>2]){break f}f=0;j=(b|0)>0?b:0;while(1){if((f|0)==(j|0)){break e}i=Lh(e);v[x[g+x[e+28>>2]>>2]+f|0]=i;f=f+1|0;continue}}if(!(Lh(e)&1)){fc(e,20);break c}yL(e,y[e+1376|0]);v[e+1376|0]=0;while(1){b=_y(e);yL(e,b);v[e+1376|0]=0;if(b){continue}break}f=0;if(!Yy(e)){break a}if(!GL(e)){if(x[e+100>>2]!=21){break a}x[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){j=b<<24;g=0;while(1){if((g|0)!=8){j=j>>31&79764919^j<<1;g=g+1|0;continue}break}x[(b<<2)+496032>>2]=j;b=b+1|0;continue}break}if((Lh(e)|0)==5){while(1){if((f|0)!=6){M=(m+1018|0)+f|0,N=Lh(e),v[M|0]=N;f=f+1|0;continue}break}if(!Xy(m+1018|0)){fc(e,20);break c}b=qc(e,8)+1|0;x[e+120>>2]=b;b=qe(e,D(b,2096));x[e+124>>2]=b;if(!b){fc(e,3);break c}Tb(b,0,D(x[e+120>>2],2096));g:{h:{while(1){i:{if(x[e+120>>2]>(C|0)){b=x[e+124>>2];if((qc(e,8)&255)!=66){fc(e,20);break c}if((qc(e,8)&255)!=67){fc(e,20);break c}if((qc(e,8)&255)!=86){fc(e,20);break c}g=b+D(C,2096)|0;M=g,N=qc(e,8)&255|qc(e,8)<<8,x[M>>2]=N;M=g,N=qc(e,8)&255|(qc(e,8)<<8&65280|qc(e,8)<<16),x[M+4>>2]=N;n=g+4|0;f=0;k=qc(e,1);if(!k){f=qc(e,1)}v[g+23|0]=f;h=x[n>>2];if(x[g>>2]){b=h;break i}b=0;if(!h){break i}fc(e,20);break c}b=qc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!qc(e,16)){continue}break}fc(e,20);break c}b=qc(e,6)+1|0;x[e+128>>2]=b;b=qe(e,D(b,1596));x[e+260>>2]=b;k:{if(b){C=0;k=0;l:while(1){if(x[e+128>>2]<=(k|0)){break k}b=qc(e,16);w[((k<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){fc(e,20);break c}if(!b){b=x[e+260>>2]+D(k,1596)|0;M=b,N=qc(e,8),v[M|0]=N;M=b,N=qc(e,16),w[M+2>>1]=N;M=b,N=qc(e,16),w[M+4>>1]=N;M=b,N=qc(e,6),v[M+6|0]=N;M=b,N=qc(e,8),v[M+7|0]=N;j=qc(e,4)+1|0;v[b+8|0]=j;h=b+9|0;f=0;while(1){if((j&255)>>>0>f>>>0){M=f+h|0,N=qc(e,8),v[M|0]=N;f=f+1|0;j=y[b+8|0];continue}break}fc(e,4);break c}f=x[e+260>>2]+D(k,1596)|0;b=qc(e,5);v[f|0]=b;n=f+1|0;j=0;g=-1;while(1)if((b&255)>>>0<=j>>>0){h=g+1|0;g=f+82|0;i=f+65|0;o=f+49|0;l=f+33|0;b=0;m:{while(1){if((b|0)!=(h|0)){M=b+l|0,N=qc(e,3)+1|0,v[M|0]=N;r=b+o|0;q=qc(e,2);v[r|0]=q;j=0;if(q&255){q=qc(e,8);v[b+i|0]=q;if(x[e+120>>2]<=(q&255)){break m}}while(1){if(1<<y[r|0]>(j|0)){q=qc(e,8)-1|0;w[(g+(b<<4)|0)+(j<<1)>>1]=q;j=j+1|0;if(x[e+120>>2]>q<<16>>16){continue}break m}break}b=b+1|0;continue}break}g=2;M=f,N=qc(e,2)+1|0,v[M+1588|0]=N;b=qc(e,4);x[f+1592>>2]=2;h=0;w[f+338>>1]=0;v[f+1589|0]=b;w[f+340>>1]=1<<b;b=f+338|0;i=0;while(1){if(y[f|0]>i>>>0){o=l+y[i+n|0]|0;j=0;while(1){if(y[o|0]>j>>>0){g=qc(e,y[f+1589|0]);w[b+(x[f+1592>>2]<<1)>>1]=g;g=x[f+1592>>2]+1|0;x[f+1592>>2]=g;j=j+1|0;continue}break}i=i+1|0;continue}break}while(1){if((g|0)>(h|0)){g=z[b+(h<<1)>>1];j=(m+16|0)+(h<<2)|0;w[j+2>>1]=h;w[j>>1]=g;h=h+1|0;g=x[f+1592>>2];continue}break}xL(m+16|0,g,1177);g=x[f+1592>>2];h=((g|0)<=1?1:g)-1|0;j=0;while(1){if((h|0)==(j|0)){h=f+838|0;j=0;while(1)if((g|0)<=(j|0)){r=f+1088|0;j=2;while(1){if((g|0)>(j|0)){x[m+12>>2]=0;x[m+8>>2]=0;g=0;q=(j|0)>0?j:0;i=b+(j<<1)|0;n=65536;l=-1;while(1){if((g|0)!=(q|0)){o=b+(g<<1)|0;h=z[o>>1];if(!((l|0)>=(h|0)|z[i>>1]<=h>>>0)){x[m+12>>2]=g;h=z[o>>1];l=h}if(!((h|0)>=(n|0)|z[i>>1]>=h>>>0)){x[m+8>>2]=g;n=z[o>>1]}g=g+1|0;continue}break}h=r+(j<<1)|0;v[h|0]=x[m+12>>2];v[h+1|0]=x[m+8>>2];j=j+1|0;g=x[f+1592>>2];continue}break}C=(g|0)>(C|0)?g:C;k=k+1|0;continue l}else{v[h+j|0]=y[((m+16|0)+(j<<2)|0)+2|0];j=j+1|0;g=x[f+1592>>2];continue}}i=m+16|0;l=z[i+(j<<2)>>1];j=j+1|0;if((l|0)!=z[i+(j<<2)>>1]){continue}break}}fc(e,20);break c}else{b=qc(e,4);v[j+n|0]=b;b=b&255;g=(b|0)>(g|0)?b:g;j=j+1|0;b=y[f|0];continue}}}fc(e,3);break c}b=qc(e,6)+1|0;x[e+264>>2]=b;b=qe(e,D(b,24));x[e+396>>2]=b;if(!b){fc(e,3);break c}k=0;Tb(b,0,D(x[e+264>>2],24));n:{o:{while(1){if(x[e+264>>2]>(k|0)){b=x[e+396>>2];f=qc(e,16);w[((k<<1)+e|0)+268>>1]=f;g=20;if((f&65535)>>>0>2){break n}i=b+D(k,24)|0;M=i,N=qc(e,24),x[M>>2]=N;b=qc(e,24);x[i+4>>2]=b;if(b>>>0<A[i>>2]){break n}M=i,N=qc(e,24)+1|0,x[M+8>>2]=N;M=i,N=qc(e,6)+1|0,v[M+12|0]=N;b=qc(e,8);v[i+13|0]=b;if(x[e+120>>2]<=(b&255)){break n}f=0;while(1){b=y[i+12|0];if(b>>>0>f>>>0){h=(m+16|0)+f|0;b=qc(e,3);if(qc(e,1)){l=qc(e,5)}else{l=0}v[h|0]=b+(l<<3);f=f+1|0;continue}break}b=qe(e,b<<4);x[i+20>>2]=b;if(!b){break o}h=0;while(1){if(y[i+12|0]>h>>>0){b=y[(m+16|0)+h|0];f=0;while(1){if((f|0)!=8){p:{if(b>>>f&1){j=qc(e,8);l=f<<1;n=h<<4;w[l+(n+x[i+20>>2]|0)>>1]=j;if(x[e+120>>2]<=w[l+(n+x[i+20>>2]|0)>>1]){break n}break p}w[(x[i+20>>2]+(h<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}h=h+1|0;continue}break}f=qe(e,x[(x[e+124>>2]+D(y[i+13|0],2096)|0)+4>>2]<<2);x[i+16>>2]=f;if(!f){break o}b=0;Tb(f,0,x[(x[e+124>>2]+D(y[i+13|0],2096)|0)+4>>2]<<2);while(1){f=x[e+124>>2]+D(y[i+13|0],2096)|0;if(x[f+4>>2]>(b|0)){f=x[f>>2];g=qe(e,f);h=b<<2;x[h+x[i+16>>2]>>2]=g;j=b;if(!x[h+x[i+16>>2]>>2]){break o}while(1){if((f|0)>0){f=f-1|0;v[f+x[h+x[i+16>>2]>>2]|0]=(j|0)%y[i+12|0];j=(j|0)/y[i+12|0]|0;continue}break}b=b+1|0;continue}break}k=k+1|0;continue}break}b=qc(e,6)+1|0;x[e+400>>2]=b;b=qe(e,D(b,40));x[e+404>>2]=b;if(!b){fc(e,3);break c}Tb(b,0,D(x[e+400>>2],40));i=0;while(1){if(x[e+400>>2]>(i|0)){b=x[e+404>>2];if(qc(e,16)){fc(e,20);break c}h=b+D(i,40)|0;b=qe(e,D(x[e+4>>2],3));x[h+4>>2]=b;if(!b){fc(e,3);break c}if(qc(e,1)){b=qc(e,4)+1|0}else{b=1}v[h+8|0]=b;q:{if(qc(e,1)){b=qc(e,8)+1|0;w[h>>1]=b;f=0;g=x[e+4>>2];if((g|0)<(b&65535)){fc(e,20);break c}while(1){if(z[h>>1]<=f>>>0){break q}g=qc(e,Fm(g-1|0));b=D(f,3);v[b+x[h+4>>2]|0]=g;g=qc(e,Fm(x[e+4>>2]-1|0));v[(b+x[h+4>>2]|0)+1|0]=g;g=x[e+4>>2];b=b+x[h+4>>2]|0;j=y[b|0];if((g|0)<=(j|0)){fc(e,20);break c}b=y[b+1|0];if((b|0)>=(g|0)){fc(e,20);break c}f=f+1|0;if((b|0)!=(j|0)){continue}break}fc(e,20);break c}w[h>>1]=0}if(qc(e,2)){fc(e,20);break c}g=0;b=0;f=0;r:{if(y[h+8|0]>=2){while(1){if(x[e+4>>2]<=(b|0)){break r}f=qc(e,4);j=D(b,3);v[(j+x[h+4>>2]|0)+2|0]=f;b=b+1|0;if(y[(j+x[h+4>>2]|0)+2|0]<y[h+8|0]){continue}break}fc(e,20);break c}while(1){if(x[e+4>>2]<=(f|0)){break r}v[(x[h+4>>2]+D(f,3)|0)+2|0]=0;f=f+1|0;continue}}s:{while(1){if(y[h+8|0]<=g>>>0){break s}qc(e,8);b=g+h|0;M=b,N=qc(e,8),v[M+9|0]=N;f=qc(e,8);v[b+24|0]=f;if(x[e+128>>2]<=y[b+9|0]){fc(e,20);break c}g=g+1|0;if(x[e+264>>2]>(f&255)){continue}break}fc(e,20);break c}i=i+1|0;continue}break}M=e,N=qc(e,6)+1|0,x[M+408>>2]=N;f=e+412|0;j=0;t:{while(1){if(x[e+408>>2]<=(j|0)){break t}b=f+D(j,6)|0;M=b,N=qc(e,1),v[M|0]=N;M=b,N=qc(e,16),w[M+2>>1]=N;M=b,N=qc(e,16),w[M+4>>1]=N;h=qc(e,8);v[b+1|0]=h;if(z[b+2>>1]){fc(e,20);break c}if(z[b+4>>1]){fc(e,20);break c}j=j+1|0;if(x[e+400>>2]>(h&255)){continue}break}fc(e,20);break c}EL(e);x[e+992>>2]=0;h=C<<1;f=0;while(1){if(x[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=qe(e,x[e+116>>2]<<2),x[M+800>>2]=N;M=b,N=qe(e,x[e+116>>2]<<1&2147483646),x[M+928>>2]=N;g=qe(e,h);x[b+996>>2]=g;j=x[b+800>>2];if(g?!j|!x[b+928>>2]:1){fc(e,3);break c}Tb(j,0,x[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!wL(e,0,x[e+112>>2])){break a}if(!wL(e,1,x[e+116>>2])){break a}x[e+104>>2]=x[e+112>>2];h=x[e+116>>2];x[e+108>>2]=h;b=x[e+264>>2];i=(b|0)>0?b:0;b=(h|0)/2|0;g=0;while(1){if((f|0)!=(i|0)){j=x[e+396>>2]+D(f,24)|0;k=x[j+4>>2];l=b>>>0>k>>>0?k:b;k=x[j>>2];j=(l-(b>>>0>k>>>0?k:b)>>>0)/A[j+8>>2]|0;g=(g|0)<(j|0)?j:g;f=f+1|0;continue}break}b=h<<1&2147483646;f=D(x[e+4>>2],(g<<2)+4|0);b=b>>>0>f>>>0?b:f;x[e+12>>2]=b;u:{v:{if(!x[e+80>>2]){break v}f=x[e+92>>2];if((f|0)!=x[e+84>>2]){break u}if(f>>>0>=(b+x[e+88>>2]|0)+1512>>>0){break v}fc(e,3);break c}w:{if(x[e+1380>>2]==-1){x[e+52>>2]=y[e+48|0]?0:x[e+32>>2]-x[e+36>>2]|0;break w}x[e+52>>2]=0}f=1;break a}_(7364,13279,4196,8849);p()}g=3}fc(e,g);break c}x:{if(f&255){j=ho(e,b);break x}j=qe(e,b);x[g+8>>2]=j}if(!j){fc(e,3);break c}i=0;y:{if(!k){f=0;while(1){b=x[n>>2];if((f|0)>=(b|0)){break y}z:{A:{if(y[g+23|0]){if(!qc(e,1)){break A}}b=qc(e,5)+1|0;v[f+j|0]=b;if((b&255)!=32){i=i+1|0;break z}fc(e,20);break c}v[f+j|0]=255}f=f+1|0;continue}}h=qc(e,5);f=0;while(1){b=x[n>>2];if((f|0)>=(b|0)){break y}k=qc(e,Fm(b-f|0));h=h+1|0;if((h|0)>=32){fc(e,20);break c}b=f+k|0;if((b|0)>x[n>>2]){fc(e,20);break c}else{Tb(f+j|0,h,k);f=b;continue}}}B:{C:{D:{if(y[g+23|0]){if(b>>2>(i|0)){break D}if(x[e+16>>2]<(b|0)){x[e+16>>2]=b;b=x[n>>2]}b=qe(e,b);x[g+8>>2]=b;if(!b){fc(e,3);break c}yc(b,j,x[n>>2]);vj(e,j,x[n>>2]);j=x[g+8>>2];v[g+23|0]=0;b=x[n>>2]}h=0;i=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(i|0)){h=((y[f+j|0]-11&255)>>>0<244)+h|0;f=f+1|0;continue}break}x[g+2092>>2]=h;b=qe(e,b<<2);x[g+32>>2]=b;if(b){k=g+2092|0;f=0;break C}fc(e,3);break c}x[g+2092>>2]=i;k=g+2092|0;E:{if(!i){f=0;h=0;break E}b=qe(e,i);x[g+8>>2]=b;if(!b){fc(e,3);break c}b=ho(e,x[k>>2]<<2);x[g+32>>2]=b;if(!b){fc(e,3);break c}f=ho(e,x[k>>2]<<2);if(!f){break B}b=x[n>>2];h=x[k>>2]}b=(h<<3)+b|0;if(b>>>0<=A[e+16>>2]){break C}x[e+16>>2]=b}l=x[n>>2];b=0;h=fb-128|0;fb=h;o=Tb(h,0,128);h=(l|0)>0?l:0;while(1){F:{G:{if((b|0)!=(h|0)){if(y[b+j|0]==255){break G}h=b}if((h|0)==(l|0)){b=1;if(!x[g+2092>>2]){break F}_(15940,13279,1103,7608);p()}b=h+j|0;i=y[b|0];if(i>>>0<32){uL(g,0,h,0,i,f);r=1;i=y[b|0]+1|0;b=1;H:{while(1){if((b|0)==(i|0)){I:while(1){J:{b=1;h=h+1|0;if((l|0)<=(h|0)){break F}G=h+j|0;i=y[G|0];if((i|0)==255){continue}b=i;if(b>>>0>=32){break J}while(1){if((b|0)<=0){b=0;break F}H=o+(b<<2)|0;q=x[H>>2];if(!q){b=b-1|0;continue}break}x[H>>2]=0;uL(g,Dm(q),h,r,i,f);r=r+1|0;i=y[G|0];if((i|0)==(b|0)){continue}while(1){if((b|0)>=(i|0)){continue I}G=o+(i<<2)|0;if(x[G>>2]){break H}x[G>>2]=q+(1<<32-i);i=i-1|0;continue}}break}}else{x[o+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}_(15387,13279,1118,7608);p()}_(15984,13279,1133,7608);p()}_(15394,13279,1104,7608);p()}b=b+1|0;continue}break}fb=o+128|0;if(!b){if(y[g+23|0]){vj(e,f,0)}fc(e,20);break c}b=x[k>>2];if(b){b=qe(e,(b<<2)+4|0);x[g+2084>>2]=b;if(!b){fc(e,3);break c}b=qe(e,(x[k>>2]<<2)+4|0);x[g+2088>>2]=b;if(!b){fc(e,3);break c}x[g+2088>>2]=b+4;x[b>>2]=-1;b=0;h=0;i=0;K:{L:{M:{if(y[g+23|0]){while(1){h=x[g+2092>>2];if((h|0)<=(b|0)){break M}h=b<<2;M=h+x[g+2084>>2]|0,N=Dm(x[h+x[g+32>>2]>>2]),x[M>>2]=N;b=b+1|0;continue}}while(1){if(x[g+4>>2]>(b|0)){if(Vy(y[g+23|0],y[b+j|0])){M=x[g+2084>>2]+(h<<2)|0,N=Dm(x[x[g+32>>2]+(b<<2)>>2]),x[M>>2]=N;h=h+1|0}b=b+1|0;continue}break}if(x[g+2092>>2]!=(h|0)){break L}}xL(x[g+2084>>2],h,1178);x[x[g+2084>>2]+(x[g+2092>>2]<<2)>>2]=-1;b=x[g+(y[g+23|0]?2092:4)>>2];G=(b|0)>0?b:0;N:{while(1){if((i|0)!=(G|0)){b=y[g+23|0];O:{if(!b){l=y[i+j|0];b=Vy(0,l);break O}l=y[x[(i<<2)+f>>2]+j|0];b=Vy(b,l)}P:{if(!b){break P}H=i<<2;o=Dm(x[H+x[g+32>>2]>>2]);b=x[g+2092>>2];h=0;while(1){if((b|0)>=2){r=b>>>1|0;K=r+h|0;q=o>>>0<A[x[g+2084>>2]+(K<<2)>>2];b=q?r:b-r|0;h=q?h:K;continue}break}b=h<<2;if((o|0)!=x[b+x[g+2084>>2]>>2]){break N}if(y[g+23|0]){x[b+x[g+2088>>2]>>2]=x[f+H>>2];v[x[g+8>>2]+h|0]=l;break P}x[b+x[g+2088>>2]>>2]=i}i=i+1|0;continue}break}break K}_(12320,13279,1230,9992);p()}_(7549,13279,1200,9992);p()}}if(y[g+23|0]){vj(e,f,x[k>>2]<<2);vj(e,x[g+32>>2],x[k>>2]<<2);vj(e,j,x[n>>2]);x[g+32>>2]=0}i=g;b=0;f=0;while(1){if((b|0)!=1024){w[(i+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=x[i+(y[i+23|0]?2092:4)>>2];b=(b|0)>=32767?32767:b;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){Q:{if(y[x[i+8>>2]+f|0]>10){break Q}R:{if(y[i+23|0]){b=Dm(x[x[i+2084>>2]+(f<<2)>>2]);break R}b=x[x[i+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break Q}w[(i+(b<<1)|0)+36>>1]=f;b=(1<<y[x[i+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=qc(e,4);v[i+21|0]=b;b=b&255;if(b>>>0>=3){fc(e,20);break c}if(b){M=i,O=vL(qc(e,32)),B[M+12>>2]=O;M=i,O=vL(qc(e,32)),B[M+16>>2]=O;M=i,N=qc(e,4)+1|0,v[M+20|0]=N;M=i,N=qc(e,1),v[M+22|0]=N;h=x[i>>2];f=x[n>>2];S:{if(y[i+21|0]==1){u=J(Ps(+E(E(Xp(+E(f|0)))/E(h|0))));T:{if(F(u)<2147483648){b=~~u;break T}b=-2147483648}u=+(h|0);L=J(nk(+E(E(b|0)+E(1)),u));U:{if(F(L)<2147483648){h=~~L;break U}h=-2147483648}b=((h|0)<=(f|0))+b|0;t=E(b|0);if(nk(+E(t+E(1)),u)<=+(f|0)){f=-1}else{u=J(nk(+t,u));V:{if(F(u)<2147483648){h=~~u;break V}h=-2147483648}f=(h|0)>(f|0)?-1:b}if((f|0)>=0){break S}fc(e,20);break c}f=D(f,h)}x[i+24>>2]=f;if(!f){fc(e,20);break c}l=ho(e,f<<1);if(!l){break h}f=0;while(1){j=x[i+24>>2];if((j|0)>(f|0)){b=qc(e,y[i+20|0]);if((b|0)==-1){vj(e,l,x[i+24>>2]<<1);fc(e,20);break c}else{w[l+(f<<1)>>1]=b;f=f+1|0;continue}}break}W:{X:{if(y[i+21|0]==1){o=y[i+23|0];Y:{if(o){f=x[k>>2];if(f){break Y}break W}f=x[n>>2]}b=qe(e,D(x[i>>2],f)<<2);x[i+28>>2]=b;if(!b){vj(e,l,x[i+24>>2]<<1);fc(e,3);break c}h=0;b=x[(o?k:n)>>2];n=(b|0)>0?b:0;r=i+2088|0;t=E(0);while(1){if((h|0)==(n|0)){break X}g=h;g=o?x[x[r>>2]+(g<<2)>>2]:g;j=x[i>>2];f=0;b=1;while(1){if((f|0)<(j|0)){I=E(t+E(E(E(z[l+(((g>>>0)/(b>>>0)>>>0)%A[i+24>>2]<<1)>>1])*B[i+16>>2])+B[i+12>>2]));B[x[i+28>>2]+(D(h,j)+f<<2)>>2]=I;t=y[i+22|0]?I:t;f=f+1|0;j=x[i>>2];if((f|0)>=(j|0)){continue}k=x[i+24>>2];sua(k,0,b,0);if(hb){vj(e,l,k<<1);fc(e,20);break c}else{b=D(b,k);continue}}break}h=h+1|0;continue}}b=qe(e,j<<2);x[i+28>>2]=b;if(!b){break g}f=0;t=E(0);while(1){j=x[i+24>>2];if((j|0)<=(f|0)){break W}I=E(t+E(E(E(z[l+(f<<1)>>1])*B[i+16>>2])+B[i+12>>2]));B[x[i+28>>2]+(f<<2)>>2]=I;t=y[i+22|0]?I:t;f=f+1|0;continue}}v[i+21|0]=2;j=x[i+24>>2]}vj(e,l,j<<1)}C=C+1|0;continue}break}fc(e,3);break c}fc(e,3);break c}vj(e,l,x[i+24>>2]<<1);fc(e,3);break c}fc(e,20);break c}fc(e,3);break c}v[b+x[x[e+28>>2]+(h<<2)>>2]|0]=0;h=h+1|0;continue}}fc(e,3);break c}fc(e,20)}f=0}fb=m+1024|0;Z:{_:{if(!f){x[d>>2]=x[s+104>>2]?1:x[s+108>>2];break _}b=qe(s+8|0,1512);if(b){M=c,N=x[yc(b,s+8|0,1512)+32>>2]-a|0,x[M>>2]=N;x[d>>2]=0;break Z}}HL(s+8|0);b=0}fb=s+1520|0;return b}function vK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,w=0,z=0,B=0,C=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;r=fb-48|0;fb=r;a:{if(c>>>0<=2){c=c<<2;I=x[c+95964>>2];J=x[c+95952>>2];while(1){c=x[b+4>>2];b:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break b}c=ud(b)}if(pl(c)){continue}break}n=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}n=(c|0)==45?-1:1;c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break c}c=ud(b)}e:{f:{while(1){if(v[g+4972|0]==(c|32)){g:{if(g>>>0>6){break g}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break g}c=ud(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){x[b+4>>2]=x[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}l=fb-16|0;fb=l;h=(q(E(E(n|0)*E(Infinity))),j(2));b=h&2147483647;h:{if(b-8388608>>>0<=2130706431){c=b;b=b>>>7|0;c=c<<25;d=b+1065353216|0;break h}c=h<<25;d=h>>>7|2147418112;if(b>>>0>=2139095040){break h}c=0;d=0;if(!b){break h}c=b;b=G(b);Vf(l,c,0,0,0,b+81|0);k=x[l>>2];i=x[l+4>>2];c=x[l+8>>2];d=x[l+12>>2]^65536|16265-b<<16}x[r>>2]=k;x[r+4>>2]=i;x[r+8>>2]=c;x[r+12>>2]=h&-2147483648|d;fb=l+16|0;k=x[r+8>>2];i=x[r+12>>2];h=x[r>>2];m=x[r+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(v[g+9988|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break l}c=ud(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=x[b+4>>2];o:{if((g|0)!=x[b+104>>2]){x[b+4>>2]=g+1;g=y[g|0];break o}g=ud(b)}if((g&-33)==88){g=d;c=0;f=fb-432|0;fb=f;p:{q:{d=x[b+4>>2];if((d|0)!=x[b+104>>2]){x[b+4>>2]=d+1;c=y[d|0];break q}d=0;break p}d=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!d){c=ud(b);break y}if((c|0)!=48){m=1073676288;if((c|0)==46){break w}break v}d=x[b+4>>2];if((d|0)==x[b+104>>2]){break x}o=1;x[b+4>>2]=d+1;c=y[d|0]}d=1;continue}o=1;break s}c=x[b+4>>2];z:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break z}c=ud(b)}if((c|0)==48){break u}e=1}break t}while(1){c=s;s=c-1|0;t=t-!c|0;e=1;c=x[b+4>>2];A:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break A}c=ud(b)}if((c|0)==48){continue}break}o=1}while(1){K=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|K-97>>>0<6)){d=c;break r}d=46;if((c|0)!=46){break C}if(e){break r}e=1;s=k;t=i;break B}c=(c|0)>57?K-87|0:M;D:{if((i|0)<=0&k>>>0<=7|(i|0)<0){w=c+(w<<4)|0;break D}if(!i&k>>>0<=28){jh(f+48|0,c);Rd(f+32|0,F,H,h,m,0,0,0,1073414144);F=x[f+32>>2];H=x[f+36>>2];h=x[f+40>>2];m=x[f+44>>2];Rd(f+16|0,x[f+48>>2],x[f+52>>2],x[f+56>>2],x[f+60>>2],F,H,h,m);Qg(f,x[f+16>>2],x[f+20>>2],x[f+24>>2],x[f+28>>2],l,p,B,C);B=x[f+8>>2];C=x[f+12>>2];l=x[f>>2];p=x[f+4>>2];break D}if(!c|u){break D}Rd(f+80|0,F,H,h,m,0,0,0,1073610752);Qg(f- -64|0,x[f+80>>2],x[f+84>>2],x[f+88>>2],x[f+92>>2],l,p,B,C);B=x[f+72>>2];C=x[f+76>>2];u=1;l=x[f+64>>2];p=x[f+68>>2]}k=k+1|0;i=k?i:i+1|0;o=1}c=x[b+4>>2];if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0]}else{c=ud(b)}continue}}d=0;continue}break}E:{if(!o){c=x[b+116>>2];F:{G:{if((c|0)>0|(c|0)>=0){c=x[b+4>>2];x[b+4>>2]=c-1;if(!g){break G}x[b+4>>2]=c-2;if(!e){break F}x[b+4>>2]=c-3;break F}if(g){break F}}Fi(b,0,0)}ij(f+96|0,+(n|0)*0);l=x[f+96>>2];p=x[f+100>>2];c=x[f+108>>2];b=x[f+104>>2];break E}if((i|0)<=0&k>>>0<=7|(i|0)<0){h=k;m=i;while(1){w=w<<4;h=h+1|0;m=h?m:m+1|0;if((h|0)!=8|m){continue}break}}H:{I:{J:{if((d&-33)==80){h=uK(b,g);c=hb;m=c;if(h|(c|0)!=-2147483648){break H}if(g){c=x[b+116>>2];if((c|0)>0|(c|0)>=0){break J}break I}l=0;p=0;Fi(b,0,0);c=0;b=0;break E}h=0;m=0;if(x[b+116>>2]<0){break H}}x[b+4>>2]=x[b+4>>2]-1}h=0;m=0}if(!w){ij(f+112|0,+(n|0)*0);l=x[f+112>>2];p=x[f+116>>2];c=x[f+124>>2];b=x[f+120>>2];break E}b=e?s:k;i=(e?t:i)<<2|b>>>30;c=h+(b<<2)|0;b=i+m|0;k=c-32|0;i=(c>>>0<h>>>0?b+1|0:b)-(c>>>0<32)|0;b=i;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){x[31660]=68;jh(f+160|0,n);Rd(f+144|0,x[f+160>>2],x[f+164>>2],x[f+168>>2],x[f+172>>2],-1,-1,-1,2147418111);Rd(f+128|0,x[f+144>>2],x[f+148>>2],x[f+152>>2],x[f+156>>2],-1,-1,-1,2147418111);l=x[f+128>>2];p=x[f+132>>2];c=x[f+140>>2];b=x[f+136>>2];break E}b=I-226|0;c=b>>31;if((i|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(i|0)){if((w|0)>=0){while(1){Qg(f+416|0,l,p,B,C,0,0,0,-1073807360);b=oU(l,p,B,C,1073610752);c=(b|0)>=0;b=c;Qg(f+400|0,l,p,B,C,b?x[f+416>>2]:l,b?x[f+420>>2]:p,b?x[f+424>>2]:B,b?x[f+428>>2]:C);b=k;k=b-1|0;i=i-!b|0;B=x[f+408>>2];C=x[f+412>>2];l=x[f+400>>2];p=x[f+404>>2];w=c|w<<1;if((w|0)>=0){continue}break}}b=i-((I>>31)+(k>>>0<I>>>0)|0)|0;c=(k-I|0)+32|0;b=c>>>0<32?b+1|0:b;c=c>>>0<J>>>0&(b|0)<=0|(b|0)<0?(c|0)>0?c:0:J;K:{if((c|0)>=113){jh(f+384|0,n);s=x[f+392>>2];t=x[f+396>>2];F=x[f+384>>2];H=x[f+388>>2];h=0;b=0;break K}ij(f+352|0,mk(1,144-c|0));jh(f+336|0,n);F=x[f+336>>2];H=x[f+340>>2];s=x[f+344>>2];t=x[f+348>>2];xK(f+368|0,x[f+352>>2],x[f+356>>2],x[f+360>>2],x[f+364>>2],F,H,s,t);z=x[f+376>>2];L=x[f+380>>2];h=x[f+372>>2];b=x[f+368>>2]}d=!(w&1)&((_m(l,p,B,C,0,0,0,0)|0)!=0&(c|0)<32);Mn(f+320|0,d+w|0);Rd(f+304|0,F,H,s,t,x[f+320>>2],x[f+324>>2],x[f+328>>2],x[f+332>>2]);c=b;Qg(f+272|0,x[f+304>>2],x[f+308>>2],x[f+312>>2],x[f+316>>2],b,h,z,L);b=d;Rd(f+288|0,F,H,s,t,b?0:l,b?0:p,b?0:B,b?0:C);Qg(f+256|0,x[f+288>>2],x[f+292>>2],x[f+296>>2],x[f+300>>2],x[f+272>>2],x[f+276>>2],x[f+280>>2],x[f+284>>2]);Ry(f+240|0,x[f+256>>2],x[f+260>>2],x[f+264>>2],x[f+268>>2],c,h,z,L);b=x[f+240>>2];d=x[f+244>>2];c=x[f+248>>2];h=x[f+252>>2];if(!_m(b,d,c,h,0,0,0,0)){x[31660]=68}wK(f+224|0,b,d,c,h,k);l=x[f+224>>2];p=x[f+228>>2];c=x[f+236>>2];b=x[f+232>>2];break E}x[31660]=68;jh(f+208|0,n);Rd(f+192|0,x[f+208>>2],x[f+212>>2],x[f+216>>2],x[f+220>>2],0,0,0,65536);Rd(f+176|0,x[f+192>>2],x[f+196>>2],x[f+200>>2],x[f+204>>2],0,0,0,65536);l=x[f+176>>2];p=x[f+180>>2];c=x[f+188>>2];b=x[f+184>>2]}x[r+16>>2]=l;x[r+20>>2]=p;x[r+24>>2]=b;x[r+28>>2]=c;fb=f+432|0;k=x[r+24>>2];i=x[r+28>>2];h=x[r+16>>2];m=x[r+20>>2];break a}if(x[b+116>>2]<0){break n}x[b+4>>2]=x[b+4>>2]-1}g=b;z=n;f=d;b=0;n=0;e=fb-8976|0;fb=e;L=0-I|0;K=L-J|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}c=x[g+4>>2];if((c|0)==x[g+104>>2]){break N}x[g+4>>2]=c+1;c=y[c|0];break M}}else{b=x[g+4>>2];if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0]}else{c=ud(g)}b=1;continue}break}c=ud(g)}o=1;if((c|0)!=48){break L}while(1){b=k;k=b-1|0;i=i-!b|0;b=x[g+4>>2];O:{if((b|0)!=x[g+104>>2]){x[g+4>>2]=b+1;c=y[b|0];break O}c=ud(g)}if((c|0)==48){continue}break}b=1}x[e+784>>2]=0;P:{Q:{d=(c|0)==46;l=c-48|0;R:{S:{T:{if(d|l>>>0<=9){while(1){U:{if(d&1){if(!o){k=h;i=m;o=1;break U}d=!b;break T}h=h+1|0;m=h?m:m+1|0;if((n|0)<=2044){w=(c|0)==48?w:h;b=(e+784|0)+(n<<2)|0;if(u){l=(D(x[b>>2],10)+c|0)-48|0}x[b>>2]=l;b=1;d=u+1|0;c=(d|0)==9;u=c?0:d;n=c+n|0;break U}if((c|0)==48){break U}x[e+8960>>2]=x[e+8960>>2]|1;w=18396}c=x[g+4>>2];V:{if((c|0)!=x[g+104>>2]){x[g+4>>2]=c+1;c=y[c|0];break V}c=ud(g)}d=(c|0)==46;l=c-48|0;if(d|l>>>0<10){continue}break}}k=o?k:h;i=o?i:m;if(!(!b|(c&-33)!=69)){l=uK(g,f);b=hb;p=b;W:{if(l|(b|0)!=-2147483648){break W}if(!f){break R}l=0;p=0;if(x[g+116>>2]<0){break W}x[g+4>>2]=x[g+4>>2]-1}i=i+p|0;k=k+l|0;i=k>>>0<l>>>0?i+1|0:i;break Q}d=!b;if((c|0)<0){break S}}if(x[g+116>>2]<0){break S}x[g+4>>2]=x[g+4>>2]-1}if(!d){break Q}x[31660]=28}h=0;m=0;Fi(g,0,0);c=0;b=0;break P}b=x[e+784>>2];if(!b){ij(e,+(z|0)*0);h=x[e>>2];m=x[e+4>>2];c=x[e+12>>2];b=x[e+8>>2];break P}if(!((h|0)!=(k|0)|(i|0)!=(m|0)|(h>>>0>9&(m|0)>=0|(m|0)>0)|(b>>>J|0?(J|0)<=30:0))){jh(e+48|0,z);Mn(e+32|0,b);Rd(e+16|0,x[e+48>>2],x[e+52>>2],x[e+56>>2],x[e+60>>2],x[e+32>>2],x[e+36>>2],x[e+40>>2],x[e+44>>2]);h=x[e+16>>2];m=x[e+20>>2];c=x[e+28>>2];b=x[e+24>>2];break P}if(k>>>0>L>>>1>>>0&(i|0)>=0|(i|0)>0){x[31660]=68;jh(e+96|0,z);Rd(e+80|0,x[e+96>>2],x[e+100>>2],x[e+104>>2],x[e+108>>2],-1,-1,-1,2147418111);Rd(e- -64|0,x[e+80>>2],x[e+84>>2],x[e+88>>2],x[e+92>>2],-1,-1,-1,2147418111);h=x[e+64>>2];m=x[e+68>>2];c=x[e+76>>2];b=x[e+72>>2];break P}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(i|0)<=(b|0)|(b|0)>(i|0)){x[31660]=68;jh(e+144|0,z);Rd(e+128|0,x[e+144>>2],x[e+148>>2],x[e+152>>2],x[e+156>>2],0,0,0,65536);Rd(e+112|0,x[e+128>>2],x[e+132>>2],x[e+136>>2],x[e+140>>2],0,0,0,65536);h=x[e+112>>2];m=x[e+116>>2];c=x[e+124>>2];b=x[e+120>>2];break P}if(u){if((u|0)<=8){b=(e+784|0)+(n<<2)|0;g=x[b>>2];while(1){g=D(g,10);u=u+1|0;if((u|0)!=9){continue}break}x[b>>2]=g}n=n+1|0}o=k;X:{if((k|0)<(w|0)|(w|0)>8|(k|0)>17){break X}if((o|0)==9){jh(e+192|0,z);Mn(e+176|0,x[e+784>>2]);Rd(e+160|0,x[e+192>>2],x[e+196>>2],x[e+200>>2],x[e+204>>2],x[e+176>>2],x[e+180>>2],x[e+184>>2],x[e+188>>2]);h=x[e+160>>2];m=x[e+164>>2];c=x[e+172>>2];b=x[e+168>>2];break P}if((o|0)<=8){jh(e+272|0,z);Mn(e+256|0,x[e+784>>2]);Rd(e+240|0,x[e+272>>2],x[e+276>>2],x[e+280>>2],x[e+284>>2],x[e+256>>2],x[e+260>>2],x[e+264>>2],x[e+268>>2]);jh(e+224|0,x[(0-o<<2)+95952>>2]);GQ(e+208|0,x[e+240>>2],x[e+244>>2],x[e+248>>2],x[e+252>>2],x[e+224>>2],x[e+228>>2],x[e+232>>2],x[e+236>>2]);h=x[e+208>>2];m=x[e+212>>2];c=x[e+220>>2];b=x[e+216>>2];break P}b=(J+D(o,-3)|0)+27|0;c=x[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break X}jh(e+352|0,z);Mn(e+336|0,c);Rd(e+320|0,x[e+352>>2],x[e+356>>2],x[e+360>>2],x[e+364>>2],x[e+336>>2],x[e+340>>2],x[e+344>>2],x[e+348>>2]);jh(e+304|0,x[(o<<2)+95880>>2]);Rd(e+288|0,x[e+320>>2],x[e+324>>2],x[e+328>>2],x[e+332>>2],x[e+304>>2],x[e+308>>2],x[e+312>>2],x[e+316>>2]);h=x[e+288>>2];m=x[e+292>>2];c=x[e+300>>2];b=x[e+296>>2];break P}while(1){c=n;n=c-1|0;if(!x[(e+784|0)+(n<<2)>>2]){continue}break}b=(o|0)%9|0;Y:{if(!b){u=0;d=0;break Y}u=0;b=(o|0)<0?b+9|0:b;Z:{if(!c){d=0;c=0;break Z}k=x[(0-b<<2)+95952>>2];i=1e9/(k|0)|0;l=0;g=0;d=0;while(1){h=l;l=(e+784|0)+(g<<2)|0;m=x[l>>2];n=(m>>>0)/(k>>>0)|0;h=h+n|0;x[l>>2]=h;h=!h&(d|0)==(g|0);d=h?d+1&2047:d;o=h?o-9|0:o;l=D(i,m-D(k,n)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!l){break Z}x[(e+784|0)+(c<<2)>>2]=l;c=c+1|0}o=(o-b|0)+9|0}while(1){g=(e+784|0)+(d<<2)|0;f=(o|0)<36;_:{while(1){$:{if(f){break $}if((o|0)!=36){break _}if(A[g>>2]<=10384592){break $}o=36;break _}n=c+2047|0;l=0;b=c;while(1){c=b;h=n&2047;n=(e+784|0)+(h<<2)|0;b=x[n>>2];m=b>>>3|0;k=l;l=b<<29;k=k+l|0;b=m;i=k>>>0<l>>>0?b+1|0:b;if(!i&k>>>0<1000000001){l=0}else{l=uua(k,i,1e9,0);b=sua(l,hb,-1e9,-1);k=b+k|0}x[n>>2]=k;b=(h|0)!=(c-1&2047)?c:(d|0)==(h|0)?c:k?c:h;n=h-1|0;if((d|0)!=(h|0)){continue}break}u=u-29|0;if(!l){continue}break}d=d-1&2047;if((d|0)==(b|0)){k=e+784|0;c=k+((b+2046&2047)<<2)|0;i=c;m=x[c>>2];c=b-1&2047;x[i>>2]=m|x[k+(c<<2)>>2]}o=o+9|0;x[(e+784|0)+(d<<2)>>2]=l;continue}break}aa:{ba:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(o|0)>45?9:1;ca:{while(1){b=d;g=0;da:{while(1){ea:{d=b+g&2047;if((d|0)==(c|0)){break ea}d=x[(e+784|0)+(d<<2)>>2];i=x[(g<<2)+95904>>2];if(d>>>0<i>>>0){break ea}if(d>>>0>i>>>0){break da}g=g+1|0;if((g|0)!=4){continue}}break}if((o|0)!=36){break da}k=0;i=0;g=0;h=0;m=0;while(1){d=b+g&2047;if((d|0)==(c|0)){c=c+1&2047;x[((c<<2)+e|0)+780>>2]=0}Mn(e+768|0,x[(e+784|0)+(d<<2)>>2]);Rd(e+752|0,k,i,h,m,0,0,1342177280,1075633366);Qg(e+736|0,x[e+752>>2],x[e+756>>2],x[e+760>>2],x[e+764>>2],x[e+768>>2],x[e+772>>2],x[e+776>>2],x[e+780>>2]);h=x[e+744>>2];m=x[e+748>>2];k=x[e+736>>2];i=x[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}jh(e+720|0,z);Rd(e+704|0,k,i,h,m,x[e+720>>2],x[e+724>>2],x[e+728>>2],x[e+732>>2]);h=x[e+712>>2];m=x[e+716>>2];k=0;i=0;l=x[e+704>>2];p=x[e+708>>2];f=u+113|0;n=f-I|0;o=(n|0)<(J|0);d=o?(n|0)>0?n:0:J;if((d|0)<=112){break ca}break aa}u=h+u|0;d=c;if((b|0)==(c|0)){continue}break}m=1e9>>>h|0;n=-1<<h^-1;g=0;d=b;while(1){i=g;g=(e+784|0)+(b<<2)|0;f=x[g>>2];i=i+(f>>>h|0)|0;x[g>>2]=i;i=!i&(b|0)==(d|0);d=i?d+1&2047:d;o=i?o-9|0:o;g=D(m,f&n);b=b+1&2047;if((c|0)!=(b|0)){continue}break}if(!g){continue}if((d|0)!=(k|0)){x[(e+784|0)+(c<<2)>>2]=g;c=k;continue ba}x[l>>2]=x[l>>2]|1;continue}break}break}ij(e+656|0,mk(1,225-d|0));xK(e+688|0,x[e+656>>2],x[e+660>>2],x[e+664>>2],x[e+668>>2],l,p,h,m);F=x[e+696>>2];H=x[e+700>>2];B=x[e+688>>2];C=x[e+692>>2];ij(e+640|0,mk(1,113-d|0));gQ(e+672|0,l,p,h,m,x[e+640>>2],x[e+644>>2],x[e+648>>2],x[e+652>>2]);k=x[e+672>>2];i=x[e+676>>2];s=x[e+680>>2];t=x[e+684>>2];Ry(e+624|0,l,p,h,m,k,i,s,t);Qg(e+608|0,B,C,F,H,x[e+624>>2],x[e+628>>2],x[e+632>>2],x[e+636>>2]);h=x[e+616>>2];m=x[e+620>>2];l=x[e+608>>2];p=x[e+612>>2]}g=b+4&2047;fa:{if((g|0)==(c|0)){break fa}g=x[(e+784|0)+(g<<2)>>2];ga:{if(g>>>0<=499999999){if(!g&(b+5&2047)==(c|0)){break ga}ij(e+496|0,+(z|0)*.25);Qg(e+480|0,k,i,s,t,x[e+496>>2],x[e+500>>2],x[e+504>>2],x[e+508>>2]);s=x[e+488>>2];t=x[e+492>>2];k=x[e+480>>2];i=x[e+484>>2];break ga}if((g|0)!=5e8){ij(e+592|0,+(z|0)*.75);Qg(e+576|0,k,i,s,t,x[e+592>>2],x[e+596>>2],x[e+600>>2],x[e+604>>2]);s=x[e+584>>2];t=x[e+588>>2];k=x[e+576>>2];i=x[e+580>>2];break ga}N=+(z|0);if((b+5&2047)==(c|0)){ij(e+528|0,N*.5);Qg(e+512|0,k,i,s,t,x[e+528>>2],x[e+532>>2],x[e+536>>2],x[e+540>>2]);s=x[e+520>>2];t=x[e+524>>2];k=x[e+512>>2];i=x[e+516>>2];break ga}ij(e+560|0,N*.75);Qg(e+544|0,k,i,s,t,x[e+560>>2],x[e+564>>2],x[e+568>>2],x[e+572>>2]);s=x[e+552>>2];t=x[e+556>>2];k=x[e+544>>2];i=x[e+548>>2]}if((d|0)>111){break fa}gQ(e+464|0,k,i,s,t,0,0,0,1073676288);if(_m(x[e+464>>2],x[e+468>>2],x[e+472>>2],x[e+476>>2],0,0,0,0)){break fa}Qg(e+448|0,k,i,s,t,0,0,0,1073676288);s=x[e+456>>2];t=x[e+460>>2];k=x[e+448>>2];i=x[e+452>>2]}Qg(e+432|0,l,p,h,m,k,i,s,t);Ry(e+416|0,x[e+432>>2],x[e+436>>2],x[e+440>>2],x[e+444>>2],B,C,F,H);h=x[e+424>>2];m=x[e+428>>2];l=x[e+416>>2];p=x[e+420>>2];ha:{if((K-2|0)>=(f&2147483647)){break ha}x[e+408>>2]=h;x[e+412>>2]=m&2147483647;x[e+400>>2]=l;x[e+404>>2]=p;Rd(e+384|0,l,p,h,m,0,0,0,1073610752);b=oU(x[e+400>>2],x[e+404>>2],x[e+408>>2],x[e+412>>2],1081081856);b=(b|0)>=0;h=b?x[e+392>>2]:h;m=b?x[e+396>>2]:m;l=b?x[e+384>>2]:l;p=b?x[e+388>>2]:p;u=b+u|0;if(!((_m(k,i,s,t,0,0,0,0)|0)!=0&(b?o&(d|0)!=(n|0):o))&(u+110|0)<=(K|0)){break ha}x[31660]=68}wK(e+368|0,l,p,h,m,u);h=x[e+368>>2];m=x[e+372>>2];c=x[e+380>>2];b=x[e+376>>2]}x[r+40>>2]=b;x[r+44>>2]=c;x[r+32>>2]=h;x[r+36>>2]=m;fb=e+8976|0;k=x[r+40>>2];i=x[r+44>>2];h=x[r+32>>2];m=x[r+36>>2];break a;case 3:break j;default:break m}}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}break i}ia:{c=x[b+4>>2];ja:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ja}c=ud(b)}if((c|0)==40){g=1;break ia}i=2147450880;if(x[b+116>>2]<0){break a}x[b+4>>2]=x[b+4>>2]-1;break a}while(1){c=x[b+4>>2];ka:{if((c|0)!=x[b+104>>2]){x[b+4>>2]=c+1;c=y[c|0];break ka}c=ud(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}i=2147450880;if((c|0)==41){break a}c=x[b+116>>2];if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}la:{if(d){if(g){break la}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){x[b+4>>2]=x[b+4>>2]-1}if(g){continue}break}break a}x[31660]=28;Fi(b,0,0)}i=0}x[a>>2]=h;x[a+4>>2]=m;x[a+8>>2]=k;x[a+12>>2]=i;fb=r+48|0}function Wqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0;d=fb-416|0;fb=d;xc(b);i=d+411|0;e=hE(b,i);if(!e){FY(i)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!e){break j}if(!GY(d+411|0)){break j}if(!c){B=1;break j}H=Fe(d+388|0,b);x[31785]=0;O(511,d+376|0,H|0);b=x[31785];x[31785]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((b|0)!=1){x[31785]=0;S(512,d+356|0,d+376|0,20041);b=x[31785];x[31785]=0;if((b|0)==1){break t}x[31785]=0;e=R(175,x[d+356>>2])|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}if(!e){break k}x[31785]=0;e=P(513,d+356|0,d+265|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}if(!e){break k}x[31785]=0;O(249,a|0,16384);b=x[31785];x[31785]=0;if((b|0)==1){break l}x[a+480208>>2]=8;x[31785]=0;e=U(269,a+1074312|0,9,1)|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}x[31785]=0;e=U(269,e|0,114,1)|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}x[31785]=0;e=P(270,e|0,21)|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}x[31785]=0;P(270,e|0,30)|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}x[31785]=0;e=P(1,d+252|0,8300)|0;b=x[31785];x[31785]=0;if((b|0)==1){break q}yb(a+1298344|0,e);tb(e);x[31785]=0;e=P(1,d+240|0,10761)|0;b=x[31785];x[31785]=0;if((b|0)==1){break p}yb(a+1298356|0,e);tb(e);x[31785]=0;g=P(1,d+228|0,18321)|0;b=x[31785];x[31785]=0;if((b|0)==1){break o}e=15220;b=y[d+415|0];switch(b-16|0){case 1:break m;case 0:break s;default:break r}}f=N()|0;break a}f=N()|0;break b}e=15201;break m}if(!b){break n}e=22485;break m}f=N()|0;break c}f=N()|0;break c}f=N()|0;break c}e=13343}x[31785]=0;i=P(1,d+216|0,e|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;S(2,d+192|0,g|0,i|0);b=x[31785];x[31785]=0;if((b|0)==1){break f}e=d+192|0;yb(a+1298368|0,e);tb(e);tb(i);tb(g);I=a+1298404|0,J=x[Gc(e,4)>>2],x[I>>2]=J;b=d+84|0;Te(b,3,d+265|0);x[31785]=0;O(221,e|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break g}e=d+192|0;yb(a+1298308|0,e);tb(e);b=d+84|0;Zj(b,3,d+297|0);x[31785]=0;S(372,e|0,4,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break h}b=d+192|0;yb(a+1298320|0,b);tb(b);x[a+480200>>2]=y[d+321|0]+1;I=a,J=Hd(y[d+322|0],1,255),x[I+480196>>2]=J;I=a,J=D(Hd(y[d+323|0],4,255),1e4),x[I+480204>>2]=J;i=x[a+484360>>2];e=a+484376|0;b=y[e|0];x[31785]=0;aa(351,Wb(i,b)|0,d+356|0,y[d+317|0]|y[d+318|0]<<8,65535,65535);b=x[31785];x[31785]=0;if((b|0)==1){break l}_e(Wb(x[a+484360>>2],y[e|0]),y[d+319|0]|y[d+320|0]<<8);w[a+480188>>1]=0;b=0;while(1){if((b|0)==32){x[31785]=0;S(512,d+192|0,d+376|0,17741);b=x[31785];x[31785]=0;if((b|0)!=1){b=d+192|0;i=hd(d+356|0,b);ub(b);b=x[i>>2];x[31785]=0;e=R(157,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}x[31785]=0;V(339,a+1298332|0,i|0,e|0,0);b=x[31785];x[31785]=0;if((b|0)==1){break l}x[31785]=0;S(512,d+192|0,d+376|0,21321);b=x[31785];x[31785]=0;if((b|0)!=1){b=d+192|0;j=hd(i,b);ub(b);b=x[j>>2];x[31785]=0;e=R(175,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}u:{v:{if(e){x[31785]=0;S(512,d+192|0,d+376|0,16723);b=x[31785];x[31785]=0;if((b|0)==1){break u}x[31785]=0;g=R(200,j|0)|0;b=x[31785];x[31785]=0;w:{if((b|0)!=1){i=c&2;G=a+480190|0;h=0;while(1){if(g>>>0<=(h&255)>>>0){break w}x[31785]=0;q=R(200,j|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break v}if(!q){break w}e=x[j+8>>2];b=x[j>>2];x[31785]=0;e=U(153,b|0,e|0,56)|0;b=x[31785];x[31785]=0;if((b|0)==1){break v}if(!e){break w}if(q>>>0>z[G>>1]){w[G>>1]=q}x[31785]=0;n=D(q,104)+a|0;k=n+484380|0;O(282,k|0,0);b=x[31785];x[31785]=0;if((b|0)==1){break v}Zo(k);x[31785]=0;S(320,j|0,((q<<5)+a|0)+946304|0,32);b=x[31785];x[31785]=0;if((b|0)==1){break v}x[31785]=0;O(323,j|0,n+484423|0);b=x[31785];x[31785]=0;if((b|0)==1){break v}x:{if(y[d+415|0]<=15){x[31785]=0;f=R(192,j|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break x}break v}x[31785]=0;f=R(154,j|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break v}}x[n+484404>>2]=f<<1;x[31785]=0;e=R(154,j|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break v}x[k>>2]=e;x[31785]=0;e=R(154,j|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break v}C=n+484384|0;x[C>>2]=e;x[31785]=0;e=R(154,j|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break v}m=n+484388|0;x[m>>2]=e;if(e){b=n+484414|0;w[b>>1]=z[b>>1]|2;x[m>>2]=e+x[C>>2]}x[31785]=0;e=R(200,j|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break v}if(y[d+415|0]<=15){w[n+484410>>1]=e}x[31785]=0;q=R(200,j|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break v}b=n+484414|0;e=z[b>>1];B=8;if(q&1){e=e|1;w[b>>1]=e;x[k>>2]=x[k>>2]>>>1;x[C>>2]=x[C>>2]>>>1;x[m>>2]=x[m>>2]>>>1;B=16}w[b>>1]=e&65531|q<<1&4;b=ad(d+84|0,B,1,0,((q&12)!=0)<<3);y:{if(!i){break y}x[31785]=0;U(218,b|0,k|0,d+192|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break y}break v}h=h+1|0;continue}}break v}ub(d+192|0)}x[31785]=0;S(512,d+192|0,d+376|0,18761);b=x[31785];x[31785]=0;z:{if((b|0)!=1){b=d+192|0;l=hd(j,b);ub(b);b=x[l>>2];x[31785]=0;e=R(175,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break l}if(!e){break z}r=Nb(d+84|0);u=Nb(d+180|0);s=Nb(d+168|0);x[31785]=0;S(512,d+148|0,d+376|0,17750);b=x[31785];x[31785]=0;A:{if((b|0)==1){break A}b=x[d+160>>2];x[d+56>>2]=x[d+156>>2];x[d+60>>2]=b;x[d- -64>>2]=x[d+164>>2];x[31785]=0;b=x[d+152>>2];x[d+48>>2]=x[d+148>>2];x[d+52>>2]=b;O(514,d+48|0,r|0);b=x[31785];x[31785]=0;if((b|0)==1){break A}x[31785]=0;S(512,d+128|0,d+376|0,17744);b=x[31785];x[31785]=0;if((b|0)==1){break A}b=x[d+140>>2];x[d+32>>2]=x[d+136>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+144>>2];x[31785]=0;b=x[d+132>>2];x[d+24>>2]=x[d+128>>2];x[d+28>>2]=b;O(514,d+24|0,u|0);b=x[31785];x[31785]=0;if((b|0)==1){break A}x[31785]=0;S(512,d+108|0,d+376|0,17734);b=x[31785];x[31785]=0;if((b|0)==1){break A}b=x[d+120>>2];x[d+8>>2]=x[d+116>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+124>>2];x[31785]=0;b=x[d+112>>2];x[d>>2]=x[d+108>>2];x[d+4>>2]=b;O(514,d|0,s|0);b=x[31785];x[31785]=0;if((b|0)==1){break A}x[31785]=0;n=R(200,l|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break A}k=a+480190|0;B=0;while(1){if(n>>>0<=(B&255)>>>0){Ro(s);Ro(u);Ro(r);break z}x[31785]=0;O(201,d+72|0,l|0);b=x[31785];x[31785]=0;B:{if((b|0)!=1){F=Ic(d+72|0);C:{D:{if(!y[d+72|0]){break D}i=x[l+8>>2];e=x[l>>2];b=y[F|0];x[31785]=0;e=U(153,e|0,i|0,D(b,14)+32|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break A}if(!e){break D}x[31785]=0;o=U(254,a|0,y[d+72|0],0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break A}if(o){break C}}b=y[F|0];x[31785]=0;P(186,l|0,D(b,14)+32|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break B}break A}x[31785]=0;S(320,l|0,o+492|0,32);b=x[31785];x[31785]=0;if((b|0)==1){break A}C=o+88|0;m=o+68|0;q=o+48|0;G=o+236|0;b=0;h=0;while(1){if(y[F|0]<=(h&255)>>>0){break B}x[31785]=0;O(515,l|0,d+192|0);e=x[31785];x[31785]=0;if((e|0)==1){break A}e=y[d+192|0];E:{if(!e|e>>>0>z[k>>1]){break E}if(y[d+193|0]>=129){v[d+193|0]=128}while(1){i=b&255;g=y[d+193|0];if(i>>>0>g>>>0){e=x[r+4>>2];b=x[r>>2];x[31785]=0;V(516,q|0,y[d+195|0],b|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break A}e=x[u+4>>2];b=x[u>>2];x[31785]=0;V(516,m|0,y[d+197|0],b|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break A}e=x[s+4>>2];b=x[s>>2];x[31785]=0;V(516,C|0,y[d+205|0],b|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break A}x[o>>2]=(y[d+198|0]|y[d+199|0]<<8)+1>>>1;e=y[d+192|0];F:{if(y[d+195|0]&64){w[(D(e,104)+a|0)+484410>>1]=y[d+194|0];break F}b=(D(e,104)+a|0)+484414|0;w[b>>1]=z[b>>1]|32768}w[d+106>>1]=y[d+196|0]<<1;w[d+104>>1]=254;t=D(e,104)+a|0;I=t+484408|0,J=z[Mc(d+106|0,d+104|0)>>1],w[I>>1]=J;v[t+484418|0]=y[(y[d+203|0]&3)+25268|0];e=t+484419|0;j=y[d+202|0];v[e|0]=j;i=y[d+201|0]+3>>>2|0;v[t+484420|0]=i;v[t+484421|0]=y[d+200|0];b=g+1|0;if(j){g=ej(Bc(((i<<8|j>>>1)>>>0)/(j>>>0)|0,0))}else{g=255}v[e|0]=g;if(!(y[d+197|0]&64)){break E}e=t+484414|0;w[e>>1]=z[e>>1]|32}else{e=y[d+192|0];I=_b(G,i),J=e,w[I>>1]=J;b=b+1|0;continue}break}}h=h+1|0;continue}}break A}B=B+1|0;continue}}f=N()|0;Ro(s);Ro(u);Ro(r);break c}f=N()|0;break c}B=1;o=Nb(d+180|0);G:{if(!(c&1)){break G}x[31785]=0;S(512,d+192|0,d+376|0,21076);b=x[31785];x[31785]=0;H:{I:{J:{K:{L:{M:{if((b|0)!=1){g=hd(l,d+192|0);b=x[g>>2];x[31785]=0;c=R(175,b|0)|0;b=x[31785];x[31785]=0;N:{O:{P:{if((b|0)!=1){ub(d+192|0);if(!c){break N}x[31785]=0;e=R(192,g|0)|0;c=x[31785];x[31785]=0;b=1;if((c|0)==1){break P}x[31785]=0;i=e+1|0;O(517,o|0,i|0);c=x[31785];x[31785]=0;if((c|0)==1){break P}while(1){if((b|0)==(i|0)){break N}x[31785]=0;e=R(192,g|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break O}x[31785]=0;S(188,d+84|0,g|0,e|0);c=x[31785];x[31785]=0;if((c|0)==1){break O}c=d+84|0;e=ic(d+192|0,c);hd($g(x[o>>2],b),e);ub(e);b=b+1|0;ub(c);continue}}f=N()|0;ub(d+192|0);break H}f=N()|0;break H}f=N()|0;break H}x[31785]=0;S(512,d+192|0,d+376|0,16720);b=x[31785];x[31785]=0;if((b|0)==1){break J}E=hd(g,d+192|0);b=x[E>>2];x[31785]=0;c=R(175,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break K}ub(d+192|0);if(!c){break M}x[31785]=0;F=R(200,E|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break I}c=0;Q:{R:{S:while(1){T:{if(F>>>0<=(c&65535)>>>0){x[31785]=0;P(152,E|0,1)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break T}break I}h=32;U:{if(y[d+415|0]<16){break U}x[31785]=0;O(518,E|0,d+192|0);b=x[31785];x[31785]=0;if((b|0)==1){break Q}h=y[d+192|0];if(h>>>0<=z[a+480188>>1]|h>>>0>32){break U}w[a+480188>>1]=h}b=0;while(1){g=b&65535;if(g>>>0>=h>>>0){c=c+1|0;continue S}x[31785]=0;i=R(192,E|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break R}if(!(!i|g>>>0>31|g>>>0<z[a+480188>>1])){w[a+480188>>1]=b+1}b=b+1|0;continue}}break}x[31785]=0;r=a+484344|0;O(226,r|0,F|0);b=x[31785];x[31785]=0;if((b|0)==1){break I}q=d+194|0;l=0;while(1){if((l|0)==(F|0)){break M}u=Fb(d+84|0);V:{if(y[d+415|0]<16){j=32;i=64;break V}x[31785]=0;O(518,E|0,d+192|0);b=x[31785];x[31785]=0;if((b|0)==1){break L}c=y[d+193|0];j=y[d+192|0];b=d+72|0;hf(b,q,16,3);x[31785]=0;O(221,d+168|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break L}b=d+168|0;yb(u,b);tb(b);i=c+1|0}x[31785]=0;c=U(199,r|0,l&65535,i|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break L}W:{if(!c){x[31785]=0;P(186,E|0,j<<1)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break W}break L}b=x[r>>2];x[31785]=0;O(286,Vb(b,l)|0,u|0);b=x[31785];x[31785]=0;if((b|0)==1){break L}G=i-1|0;n=0;while(1){s=n&65535;if(s>>>0>=j>>>0){break W}x[31785]=0;c=R(192,E|0)|0;b=x[31785];x[31785]=0;X:{if((b|0)!=1){if(!c){break X}b=x[o>>2];if(Lf(b,x[o+4>>2])>>>0<=c>>>0|s>>>0>=z[a+480188>>1]){break X}A=$g(b,c);xc(A);c=0;Y:while(1){e=c;if(i>>>0<=e>>>0){break X}c=x[A+8>>2];b=x[A>>2];x[31785]=0;c=U(153,b|0,c|0,1)|0;b=x[31785];x[31785]=0;Z:{_:{$:{aa:{ba:{if((b|0)!=1){if(!c){break X}b=Vb(x[r>>2],l);b=gd(x[b>>2],x[x[b+48>>2]+12>>2],e,s);x[31785]=0;g=R(200,A|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break L}k=g<<24>>24;f=(k&252)>>>2|0;switch((k&3)-1|0){case 2:break _;case 1:break $;case 0:break aa;default:break ba}}break L}c=(e+f|0)+1|0;continue}c=0;if(!e){continue}c=Vb(x[r>>2],l);h=gd(x[c>>2],x[x[c+48>>2]+12>>2],e-1|0,s);while(1){c=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[h+4|0]|y[h+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;c=e+1|0;if((e|0)==(G|0)){continue Y}b=D(z[a+480188>>1],6)+b|0;g=f&255;e=c;f=f-1|0;if(g){continue}break}continue}if(e>>>0<=f>>>0){break Z}c=Vb(x[r>>2],l);g=gd(x[c>>2],x[x[c+48>>2]+12>>2],f,s);c=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[b|0]=c;v[b+1|0]=c>>>8;v[b+2|0]=c>>>16;v[b+3|0]=c>>>24;c=y[g+4|0]|y[g+5|0]<<8;v[b+4|0]=c;v[b+5|0]=c>>>8;break Z}if(f&1){x[31785]=0;g=R(200,A|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break L}v[b|0]=g>>>0>120?-1:g}if(f&2){x[31785]=0;g=R(200,A|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break L}v[b+1|0]=g}c=0;h=0;ca:{if(f&4){x[31785]=0;h=R(200,A|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break ca}}t=0;if(f&8){x[31785]=0;g=R(200,A|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ca}t=g>>>4|0;c=g&15}C=0;m=0;if(f&16){x[31785]=0;m=R(200,A|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break ca}}if((k|0)<0){x[31785]=0;C=R(200,A|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break ca}}g=h;f=fb-16|0;fb=f;h=f+14|0;CY(h,c,m);k=Ic(h);c=f+12|0;CY(c,((t-1&255)>>>0<6?t+15|0:t)&255,C);m=Ic(c);da:{ea:{fa:{if(y[f+14|0]==10){h=y[m|0];c=y[k|0]&15;v[k|0]=c?-1:h;c=h|c<<8;h=y[f+12|0];if((h|0)!=10){break fa}h=0;v[f+12|0]=0;break fa}if(y[f+12|0]!=10){break ea}c=y[m|0]&15;v[m|0]=c?-1:0;c=c<<8;h=y[f+14|0]}if(c-256>>>0>4294967038){break ea}if(Uh(h)>>>0>=Uh(10)>>>0){break ea}v[b+5|0]=c;v[b+2|0]=15;v[b+3|0]=10;v[b+4|0]=c>>>8;break da}if(g){v[b+2|0]=1;v[b+4|0]=g+2>>>2}gw(f+14|0,k,f+12|0,m);c=y[f+12|0];ga:{ha:{h=y[f+14|0];if(h){if((h|0)==20|(h|0)!=(c&255)){break ha}c=h}break ga}if(!(c&255)){v[b+5|0]=y[k|0];v[b+3|0]=h;break da}if(!g){sn(f+10|0,b,h,y[k|0],c&255,y[m|0]);break da}if(Uh(h)>>>0>Uh(c&255)>>>0){v[b+5|0]=y[k|0];v[b+3|0]=h;break da}}v[b+5|0]=y[m|0];v[b+3|0]=c}fb=f+16|0;break Z}break L}c=e+1|0;continue}}break L}n=n+1|0;continue}}tb(u);l=l+1|0;continue}}f=N()|0;break H}f=N()|0;break H}f=N()|0;break H}x[31785]=0;S(512,d+192|0,d+376|0,20048);b=x[31785];x[31785]=0;ia:{ja:{if((b|0)!=1){i=hd(E,d+192|0);b=x[i>>2];x[31785]=0;c=R(175,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break ja}ub(d+192|0);if(!c){break G}e=a+484348|0;while(1){if(!pg(x[a+484344>>2],x[e>>2])){break G}c=x[i+8>>2];b=x[i>>2];x[31785]=0;c=U(153,b|0,c|0,16)|0;b=x[31785];x[31785]=0;if((b|0)==1){break ia}if(!c){break G}x[31785]=0;O(398,i|0,d+192|0);b=x[31785];x[31785]=0;if((b|0)!=1){b=x[a+484344>>2];x[31785]=0;O(399,Vb(b,0)|0,d+192|0);b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}f=N()|0;break H}f=N()|0;break H}f=N()|0;ub(d+192|0);break H}f=N()|0;break H}f=N()|0;tb(u);break H}f=N()|0;ub(d+192|0);break H}f=N()|0;break H}f=N()|0}Qc(o);break c}Qc(o);break k}f=N()|0;ub(d+192|0);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;break c}h=(b<<5)+a|0;g=h+480280|0;Ye(g);i=v[(b+d|0)+324|0];e=i<<1&254;w[h+480284>>1]=(e|0)==254?256:e;ka:{if((i|0)<0){x[g>>2]=x[g>>2]|1024;break ka}w[a+480188>>1]=b+1}x[31785]=0;O(519,d+356|0,h+480289|0);e=x[31785];x[31785]=0;if((e|0)==1){break i}b=b+1|0;continue}}f=N()|0;break c}ub(d+356|0);fe(d+376|0);ub(H)}fb=d+416|0;return B|0}f=N()|0;break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;tb(i);break d}f=N()|0}tb(g)}ub(d+356|0)}fe(d+376|0)}ub(H);Q(f|0);p()}function $sa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=fb-240|0;fb=d;xc(b);e=fb-16|0;fb=e;h=d+218|0;Nv(e+8|0,h);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);k=x[e+4>>2];if((k|0)==(g|0)){Yb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(k|0);if(!e){u_(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!v_(d+218|0)){break n}if(!c){f=1;break n}Bd(a,1024);ag(a);x[a+480208>>2]=x[a+480208>>2]|12;Yf(a+1074312|0,21);e=Cb(y[d+234|0]|y[d+235|0]<<8);if(e){x[a+480204>>2]=D(e,1e4)}e=Cb(y[d+232|0]|y[d+233|0]<<8);if(e){x[a+480196>>2]=e}if(!y[d+228|0]){Ch(a,1)}eE(b,a+1298308|0,$b(y[d+222|0]|y[d+223|0]<<8|(y[d+224|0]<<16|y[d+225|0]<<24))-14|0);b=Fe(d+112|0,b);x[31785]=0;O(349,d+204|0,b|0);e=x[31785];x[31785]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((e|0)!=1){ub(b);x[31785]=0;S(350,d+112|0,d+204|0,1395544366);b=x[31785];x[31785]=0;if((b|0)==1){break s}x[31785]=0;b=R(280,x[d+112>>2])|0;e=x[31785];x[31785]=0;if((e|0)==1){break y}if(!b){break r}x[31785]=0;b=R(276,d+112|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break y}x[31785]=0;e=R(276,d+112|0)|0;f=x[31785];x[31785]=0;A:{if((f|0)==1){break A}x[31785]=0;P(186,d+112|0,4)|0;f=x[31785];x[31785]=0;if((f|0)==1){break A}f=a+484376|0;g=y[f|0];h=x[a+484360>>2];x[31785]=0;aa(351,Wb(h,g)|0,d+112|0,b|0,65535,65535);b=x[31785];x[31785]=0;if((b|0)!=1){break z}}break y}e=N()|0;ub(b);break a}_e(Wb(x[a+484360>>2],y[f|0]),e);b=d+112|0;ub(b);x[31785]=0;S(350,b|0,d+204|0,1346458708);b=x[31785];x[31785]=0;if((b|0)==1){break x}x[31785]=0;e=R(280,x[d+112>>2])|0;b=x[31785];x[31785]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}x[31785]=0;e=R(276,d+112|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break w}w[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}x[31785]=0;b=R(276,d+112|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break w}x[31785]=0;O(226,a+484344|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break w}b=0;x[31785]=0;o=R(284,d+112|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break w}switch(o-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}e=N()|0;ub(d+112|0);break b}e=N()|0;break b}e=N()|0;ub(d+112|0);break b}if(o){break t}}b=1}ub(d+112|0);if(!b){break o}x[31785]=0;S(350,d+184|0,d+204|0,1398157625);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;b=R(280,x[d+184>>2])|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}if(!b){break q}x[31785]=0;P(186,d+184|0,2)|0;b=x[31785];x[31785]=0;if((b|0)==1){break c}x[31785]=0;b=R(284,d+184|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}H=a,I=Xe((+(b>>>0)*2.3283064365386963e-10+ +(A[a+480204>>2]/1e4>>>0))*1e4),x[H+480204>>2]=I;b=0;x[31785]=0;P(352,d+184|0,d+112|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}f=z[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){H=d,I=Cb(z[(d+112|0)+(b<<1)>>1]),x[H+48>>2]=I;x[d+32>>2]=180;e=x[pd(d+48|0,d+32|0)>>2]-90|0;h=e>>31<<7|e>>>25;H=((b<<5)+a|0)+480284|0,I=Fc(tua(e<<7|45,h,90,0),hb)+128|0,w[H>>1]=I;b=b+1|0;continue}else{B:{x[31785]=0;P(186,d+184|0,16)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break B}break c}}break}x[31785]=0;b=U(153,x[d+184>>2],x[d+192>>2],2)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}C:{if(b){x[31785]=0;b=R(276,d+184|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break C}w[d+48>>1]=b;w[d+32>>1]=256;H=a,I=z[Mc(d+48|0,d+32|0)>>1],x[H+480200>>2]=I}x[31785]=0;P(186,d+184|0,128)|0;b=x[31785];x[31785]=0;if((b|0)==1){break c}x[31785]=0;b=P(352,d+184|0,d+48|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){if(!b){break q}e=z[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){H=d,I=Cb(z[(d+48|0)+(b<<1)>>1]),x[H+32>>2]=I;x[d+20>>2]=128;H=((b<<5)+a|0)+480286|0,I=x[pd(d+32|0,d+20|0)>>2]/2&255,w[H>>1]=I;b=b+1|0;continue}else{x[a+480228>>2]=x[a+480228>>2]<<1;break q}}break c}break c}e=N()|0;break b}ub(d+112|0);break p}ub(d+184|0);x[31785]=0;S(350,d+112|0,d+204|0,1413830740);b=x[31785];x[31785]=0;D:{E:{if((b|0)!=1){x[31785]=0;b=R(280,x[d+112>>2])|0;e=x[31785];x[31785]=0;if((e|0)==1){break e}if(!b){break D}x[31785]=0;O(353,d+112|0,d+48|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}if((Cb(y[d+58|0]|y[d+59|0]<<8)|0)!=65535){break E}x[31785]=0;P(186,d+112|0,1)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break E}break e}e=N()|0;break b}x[31785]=0;b=R(205,d+112|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break e}x[31785]=0;V(339,a+1298332|0,d+112|0,b|0,2);b=x[31785];x[31785]=0;if((b|0)==1){break e}}ub(d+112|0);x[31785]=0;S(350,d+48|0,d+204|0,1229869908);b=x[31785];x[31785]=0;if((b|0)==1){break h}x[31785]=0;b=R(280,x[d+48>>2])|0;e=x[31785];x[31785]=0;if((e|0)==1){break l}F:{if(!b){break F}x[31785]=0;b=R(276,d+48|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break i}G:{H:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break H}x[31785]=0;e=U(153,x[d+48>>2],x[d+56>>2],D(f,(b>>>14&2)+50|0)|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break g}if(!e){break H}w[a+480190>>1]=f;g=a+480190|0;h=d+130|0;k=(b|0)>=0;b=1;I:{J:{K:{L:{while(1){if(f>>>0<(b&65535)>>>0){x[31785]=0;b=R(276,d+48|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){break I}break g}M:{if(k){q=b}else{x[31785]=0;e=R(276,d+48|0)|0;m=x[31785];x[31785]=0;if((m|0)==1){break M}q=e+1|0}w[d+20>>1]=q;x[31785]=0;O(354,d+48|0,d+112|0);e=x[31785];x[31785]=0;if((e|0)==1){break L}e=z[d+20>>1];if((e-4e3&65535)>>>0>=61537){H=a,I=z[se(g,d+20|0)>>1],w[H+480190>>1]=I;m=y[d+236|0]|y[d+237|0]<<8|(y[d+238|0]<<16|y[d+239|0]<<24);x[31785]=0;V(355,d+112|0,(D(e,104)+a|0)+484380|0,$b(m)|0,o|0);e=x[31785];x[31785]=0;if((e|0)==1){break K}e=d+32|0;im(e,2,h);x[31785]=0;O(221,d+184|0,e|0);e=x[31785];x[31785]=0;if((e|0)==1){break J}e=d+184|0;zc(((z[d+20>>1]<<5)+a|0)+946304|0,e);tb(e)}b=b+1|0;continue}break}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}e=N()|0;break f}if((b|0)!=4){break F}w[d+112>>1]=z[a+480190>>1];w[d+184>>1]=255;h=a+480192|0;b=d+184|0;H=h,I=z[Mc(d+112|0,b)>>1],w[H>>1]=I;x[31785]=0;S(350,b|0,d+204|0,1229278806);b=x[31785];x[31785]=0;if((b|0)==1){break j}N:while(1){O:{x[31785]=0;b=U(153,x[d+48>>2],x[d+56>>2],15)|0;e=x[31785];x[31785]=0;if((e|0)==1){break O}if(!b){break G}x[31785]=0;O(356,d+48|0,d+32|0);b=x[31785];x[31785]=0;if((b|0)==1){break k}b=Cb(z[d+32>>1]);if(b>>>0>=z[h>>1]){continue}e=D(b,104)+a|0;v[e+484524|0]=y[d+40|0];f=y[d+39|0];v[e+484523|0]=255;v[e+484525|0]=f;x[31785]=0;b=b+1&65535;e=U(254,a|0,b|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break k}if(!e){continue}H=d,I=Cb(y[d+37|0]|y[d+38|0]<<8),w[H+112>>1]=I;w[d+20>>1]=4095;H=e,I=z[Mc(d+112|0,d+20|0)>>1],x[H>>2]=I;b=y[d+35|0];if((b|0)==255){continue}x[31785]=0;b=P(152,d+184|0,D(b,34)+2|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break k}if(!b){continue}x[31785]=0;O(357,d+184|0,d+112|0);b=x[31785];x[31785]=0;if((b|0)==1){break k}v[e+60|0]=y[e+60|0]|1;b=z[d+112>>1];x[d+24>>2]=16;x[d+28>>2]=240;H=d,I=Cb(b),x[H+20>>2]=I;b=aE(d+20|0);x[31785]=0;O(296,e+48|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break k}g=x[e+52>>2];f=x[e+48>>2];b=0;while(1){k=Od(f,g);if(k>>>0<=b>>>0){b=y[d+36|0];if((b|0)!=255){v[e- -64|0]=b;v[e+63|0]=b;v[e+60|0]=y[e+60|0]|4}if(mc(f,g)){continue N}b=k-1|0;v[e+62|0]=b;v[e+61|0]=b;v[e+60|0]=y[e+60|0]|2;continue N}else{v[d+20|0]=64;k=(d+112|0)+(b<<1)|0;v[d+16|0]=y[k+2|0];m=Ub(d+20|0,d+16|0);i=wb(f,b);v[i+2|0]=y[m|0];w[i>>1]=y[k+3|0];b=b+1|0;continue}}}break}break k}ub(d+48|0);break p}ub(d+184|0)}ub(d+48|0);x[31785]=0;S(358,d+184|0,d+204|0,1145131092);b=x[31785];x[31785]=0;if((b|0)==1){break m}H=d,I=vb(x[d+184>>2]),x[H+20>>2]=I;m=a+484344|0;B=c&1;r=d+48|4;C=vb(x[d+188>>2]);s=(o|0)!=841887798;t=a+480188|0;E=(o|0)!=841887796;while(1){P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{g=x[d+20>>2];if(!Ib(g,C)){Qc(d+184|0);x[31785]=0;S(350,d+112|0,d+204|0,1346458702);b=x[31785];x[31785]=0;if((b|0)!=1){break aa}e=N()|0;break b}x[31785]=0;P(186,g|0,4)|0;b=x[31785];x[31785]=0;if((b|0)!=1){x[31785]=0;i=R(276,g|0)|0;b=x[31785];x[31785]=0;ba:{if((b|0)!=1){x[31785]=0;k=R(276,g|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break R}k=s?k:(k>>>0)/A[a+480196>>2]|0;if(!B|i>>>0>255){break P}x[31785]=0;b=U(199,m|0,i|0,k|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break R}if(b){break ba}break P}e=N()|0;break Q}if(!s){h=0;x[31785]=0;P(186,g|0,4)|0;b=x[31785];x[31785]=0;if((b|0)==1){break R}while(1){u=h&65535;if(u>>>0>=z[t>>1]){break P}x[31785]=0;b=R(276,g|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break $}x[31785]=0;S(188,d+48|0,g|0,b+(b&1)&65535);b=x[31785];x[31785]=0;if((b|0)==1){break S}b=d+48|0;f=ic(d+112|0,b);ub(b);x[d+48>>2]=0;x[d+52>>2]=0;e=0;ca:{while(1){b=x[f>>2];x[31785]=0;b=U(153,b|0,x[d+120>>2],6)|0;j=x[31785];x[31785]=0;if((j|0)==1){break ca}j=x[d+48>>2];if(b&j>>>0<k>>>0){b=Vb(x[m>>2],i);b=gd(x[b>>2],x[x[b+48>>2]+12>>2],j,u);x[31785]=0;O(359,d+32|0,f|0);j=x[31785];x[31785]=0;da:{ea:{if((j|0)!=1){j=d+32|0;l=Ic(j);F=Ze(j);G=cj(j);q=ec(j);n=v[d+32|0];if((n-1&255)>>>0>95){break ea}v[b|0]=n+13;if(!x[d+52>>2]){break da}v[b+3|0]=19;x[d+16>>2]=15;H=b,I=y[pd(r,d+16|0)|0]|208,v[H+5|0]=I;break da}break T}if((n|0)>=0){break da}if(x[d+52>>2]){v[b+3|0]=19;x[d+16>>2]=15;H=b,I=y[pd(r,d+16|0)|0]|192,v[H+5|0]=I;break da}v[b|0]=254}if(y[l|0]){v[b+2|0]=1;v[d+16|0]=64;H=b,I=y[Ub(l,d+16|0)|0],v[H+4|0]=I}l=y[F|0];if(l){v[b+1|0]=l}l=y[G|0];n=y[q|0];if(l|n){Mf(b,l,n)}j=v[j+5|0];b=j&255;l=d+48|0;if((j|0)<0){x[31785]=0;j=R(200,f|0)|0;n=x[31785];x[31785]=0;if((n|0)==1){break T}b=j|b<<8&32512}e=b+e|0;QD(l,e,x[a+480196>>2]);continue}break}ub(f);h=h+1|0;continue}break}break T}h=0;b=Vb(x[m>>2],i);b=gd(x[b>>2],x[x[b+48>>2]+12>>2],0,0);fa:while(1){f=0;if((h|0)==(k|0)){break P}while(1){if(z[t>>1]<=(f&65535)>>>0){h=h+1|0;continue fa}x[31785]=0;O(360,d+48|0,g|0);e=x[31785];x[31785]=0;if((e|0)!=1){v[d+16|0]=0;ga:{if(!E){e=x[d+48>>2];x[d+112>>2]=e;i=d+112|0;j=Ic(i);l=Ze(i);n=cj(i);if(e<<24>>24>0){v[b|0]=(D((e&240)>>>4|0,12)+(e&15)|0)+12}e=y[j|0];if(e>>>0>=4){v[b+2|0]=1;v[b+4|0]=(e>>>2|0)-1;e=y[j|0]}v[b+1|0]=e<<4&48|y[l|0]>>>4;i=y[l|0]&15;v[d+16|0]=i;e=y[n|0];v[b+5|0]=e;break ga}e=x[d+48>>2];x[d+12>>2]=e;x[d+8>>2]=e;e=d+32|0;Yo(e,d+8|0,b);i=d+112|0;GD(i,d+16|0,b+5|0);FD(i,e);e=xb(d+48|0,0);v[b+1|0]=y[b+1|0]|y[e|0]&48;e=y[b+5|0];i=y[d+16|0]}Mf(b,i,e&255);e=y[b+3|0];ha:{if(e>>>0>11){break ha}e=1<<e;ia:{if(!(e&2240)){if(!(e&12)){break ha}if(!y[b+5|0]){break ia}break ha}e=y[b+5|0];i=e&240;if(i){v[b+5|0]=i;break ha}if(e){break ha}}v[b+3|0]=0}b=b+6|0;f=f+1|0;continue}break}break}e=N()|0;break Q}e=N()|0;break Q}x[31785]=0;b=R(280,x[d+112>>2])|0;e=x[31785];x[31785]=0;ja:{ka:{la:{ma:{na:{if((e|0)!=1){if(b){f=Fb(d+48|0);e=a+484348|0;b=0;oa:{while(1){pa:{x[31785]=0;g=U(153,x[d+112>>2],x[d+120>>2],1)|0;h=x[31785];x[31785]=0;if((h|0)==1){break pa}if(!g){break oa}if(pg(x[a+484344>>2],x[e>>2])>>>0<=b>>>0){break oa}x[31785]=0;S(361,d+112|0,f|0,32);g=x[31785];x[31785]=0;if((g|0)==1){break pa}g=x[m>>2];x[31785]=0;O(286,Vb(g,b)|0,f|0);g=x[31785];x[31785]=0;if((g|0)==1){break pa}b=b+1|0;continue}break}e=N()|0;tb(f);break na}tb(f)}b=d+112|0;ub(b);x[31785]=0;S(350,b|0,d+204|0,1414679374);b=x[31785];x[31785]=0;if((b|0)==1){break ma}x[31785]=0;b=R(280,x[d+112>>2])|0;e=x[31785];x[31785]=0;if((e|0)==1){break V}if(!b){break ja}f=Fb(d+48|0);e=a+480188|0;b=0;while(1){x[31785]=0;g=U(153,x[d+112>>2],x[d+120>>2],1)|0;h=x[31785];x[31785]=0;if((h|0)==1){break la}if(!(g&z[e>>1]>b>>>0)){break ka}x[31785]=0;S(361,d+112|0,f|0,32);g=x[31785];x[31785]=0;if((g|0)==1){break la}fm(((b<<5)+a|0)+480289|0,f);b=b+1|0;continue}}e=N()|0}ub(d+112|0);break b}e=N()|0;break b}e=N()|0;tb(f);break U}tb(f)}b=d+112|0;ub(b);x[31785]=0;S(358,b|0,d+204|0,1145129300);b=x[31785];x[31785]=0;if((b|0)==1){break W}H=d,I=vb(x[d+112>>2]),x[H+48>>2]=I;e=c&2;f=vb(x[d+116>>2]);g=a+480190|0;qa:{ra:{sa:{ta:{ua:{va:{while(1){b=x[d+48>>2];if(!Ib(b,f)){Qc(d+112|0);b=Fb(d+48|0);if((o|0)!=841887798){break ua}x[31785]=0;c=P(1,d+112|0,9510)|0;e=x[31785];x[31785]=0;if((e|0)==1){break va}yb(b,c);tb(c);break ta}x[31785]=0;c=R(276,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break X}wa:{if(!(!e|c>>>0>=z[g>>1])){c=D(c,104)+a|0;h=z[c+484518>>1];h=ad(d+184|0,h&1?16:8,h&64?2:1,1,0);x[31785]=0;U(218,h|0,c+484484|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break wa}}Xf(d+48|0);continue}break}break X}e=N()|0;break Y}x[31785]=0;S(350,d+112|0,d+204|0,1447383635);c=x[31785];x[31785]=0;xa:{ya:{za:{Aa:{Ba:{if((c|0)!=1){x[31785]=0;c=R(280,x[d+112>>2])|0;e=x[31785];x[31785]=0;if((e|0)==1){break sa}if(!c){break ya}x[31785]=0;c=R(284,d+112|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Ba}x[31785]=0;O(271,d+32|0,4312);e=x[31785];x[31785]=0;if((e|0)==1){break Aa}x[d+20>>2]=c>>>4;x[31785]=0;x[d+16>>2]=c&15;V(362,d+184|0,d+32|0,d+20|0,d+16|0);c=x[31785];x[31785]=0;if((c|0)==1){break za}c=d+184|0;yb(b,c);tb(c);Eb(d+32|0);break xa}e=N()|0;break Y}e=N()|0;break Z}e=N()|0;break Z}e=N()|0;Eb(d+32|0);break Z}x[31785]=0;c=P(1,d+184|0,8529)|0;e=x[31785];x[31785]=0;if((e|0)==1){break _}yb(b,c);tb(c)}ub(d+112|0)}x[31785]=0;c=P(1,d+32|0,8529)|0;e=x[31785];x[31785]=0;if((e|0)==1){break ra}yb(a+1298344|0,c);tb(c);x[31785]=0;c=P(1,d+20|0,10143)|0;e=x[31785];x[31785]=0;if((e|0)==1){break qa}yb(a+1298356|0,c);tb(c);yb(a+1298368|0,b);H=a+1298404|0,I=x[Gc(d+16|0,28)>>2],x[H>>2]=I;tb(b);f=1;break o}e=N()|0;break Z}e=N()|0;break Y}e=N()|0;break Y}e=N()|0;break Q}e=N()|0}ub(d+112|0)}tb(b);break b}e=N()|0;Qc(d+112|0);break b}e=N()|0;break b}e=N()|0}ub(d+112|0);break b}e=N()|0;ub(f);break Q}e=N()|0;break Q}e=N()|0}Qc(d+184|0);break b}Xf(d+20|0);continue}}f=0}fe(d+204|0)}fb=d+240|0;return f|0}e=N()|0;break b}e=N()|0;break f}e=N()|0;ub(d+184|0);break f}e=N()|0;break f}e=N()|0;break f}e=N()|0;break b}e=N()|0}ub(d+48|0);break b}e=N()|0;ub(d+112|0);break b}e=N()|0;break b}e=N()|0;ub(d+184|0)}fe(d+204|0)}Q(e|0);p()}function $ta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;d=fb-416|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!yi(b,d+408|0)){break F}if(!J$(d+408|0)){break F}if(!c){o=1;break F}q=Fe(d+388|0,b);x[31785]=0;O(266,d+376|0,q|0);b=x[31785];x[31785]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){x[31785]=0;S(267,d+208|0,d+376|0,1229866575);b=x[31785];x[31785]=0;if((b|0)==1){break da}x[31785]=0;o=P(268,d+208|0,d+366|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break fa}ub(d+208|0);if(!o){break G}x[31785]=0;O(249,a|0,524288);b=x[31785];x[31785]=0;ga:{if((b|0)==1){break ga}ag(a);x[a+480208>>2]=12;C=a+480188|0,E=Hd(Cb(z[d+374>>1]),1,127),w[C>>1]=E;C=d,E=Cb(z[d+366>>1]),w[C+208>>1]=E;w[d+320>>1]=255;C=a+480192|0,E=z[Mc(d+208|0,d+320|0)>>1],w[C>>1]=E;C=d,E=Cb(z[d+368>>1]),w[C+208>>1]=E;w[d+320>>1]=3999;C=a+480190|0,E=z[Mc(d+208|0,d+320|0)>>1],w[C>>1]=E;x[31785]=0;b=U(269,a+1074312|0,6,1)|0;f=x[31785];x[31785]=0;if((f|0)==1){break ga}x[31785]=0;b=P(270,b|0,21)|0;f=x[31785];x[31785]=0;if((f|0)==1){break ga}x[31785]=0;P(270,b|0,13)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break ea}}b=N()|0;break b}b=N()|0;break a}b=N()|0;ub(d+208|0);break b}x[31785]=0;b=P(1,d+352|0,9302)|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}yb(a+1298344|0,b);tb(b);x[31785]=0;b=P(1,d+340|0,10327)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}yb(a+1298356|0,b);tb(b);x[31785]=0;O(271,d+320|0,4356);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;O(272,d+300|0,d+412|0);b=x[31785];x[31785]=0;if((b|0)==1){break g}x[31785]=0;O(272,d+264|0,d+413|0);b=x[31785];x[31785]=0;if((b|0)==1){break i}x[31785]=0;V(92,d+208|0,d+320|0,d+300|0,d+264|0);b=x[31785];x[31785]=0;if((b|0)==1){break j}b=d+208|0;yb(a+1298368|0,b);tb(b);tb(d+264|0);tb(d+300|0);f=d+320|0;Eb(f);C=a+1298404|0,E=x[Gc(b,28)>>2],x[C>>2]=E;x[31785]=0;S(267,f|0,d+376|0,1312902469);b=x[31785];x[31785]=0;if((b|0)==1){break k}x[31785]=0;b=R(157,x[d+320>>2])|0;f=x[31785];x[31785]=0;if((f|0)==1){break m}x[31785]=0;g=a+1298308|0;S(273,d+320|0,g|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break m}x[31785]=0;S(267,d+300|0,d+376|0,1397706311);b=x[31785];x[31785]=0;if((b|0)==1){break n}e=a+484360|0;f=a+484376|0;gj(Wb(x[e>>2],y[f|0]));h=Cb(z[d+370>>1]);m=a+1298319|0;i=a+1298312|0;while(1){ha:{if(h>>>0<=(j&65535)>>>0){break ha}x[31785]=0;b=U(153,x[d+300>>2],x[d+308>>2],46)|0;l=x[31785];x[31785]=0;ia:{if((l|0)!=1){if(!b){break ha}x[31785]=0;O(274,d+300|0,d+208|0);b=x[31785];x[31785]=0;if((b|0)!=1){if(!yd(x[i>>2],y[m|0])){break ia}x[31785]=0;O(275,g|0,d+208|0);b=x[31785];x[31785]=0;if((b|0)!=1){break ia}}b=N()|0;break o}b=N()|0;break o}x[31785]=0;l=R(276,d+300|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break ca}b=Wb(x[a+484360>>2],y[f|0]);if(!mc(x[b>>2],x[b+4>>2])){x[31785]=0;b=R(277,e|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break ca}if((b|0)==255){break ha}b=Wb(x[a+484360>>2],y[f|0])}x[31785]=0;O(278,d+288|0,d+208|0);k=x[31785];x[31785]=0;if((k|0)==1){break ca}k=b;b=d+288|0;gp(k,b);tb(b);b=y[f|0];k=x[a+484360>>2];x[31785]=0;S(279,Wb(k,b)|0,d+300|0,l|0);b=x[31785];x[31785]=0;if((b|0)==1){break ca}j=j+1|0;continue}break}ak(e,0);x[31785]=0;S(267,d+264|0,d+376|0,1229869908);b=x[31785];x[31785]=0;if((b|0)==1){break ba}x[31785]=0;b=R(280,x[d+264>>2])|0;f=x[31785];x[31785]=0;if((f|0)==1){break p}ja:{if(!b){break ja}e=a+480192|0;j=1;ka:{while(1){b=j&65535;if(b>>>0>z[e>>1]){x[31785]=0;S(267,d+188|0,d+376|0,1447382614);b=x[31785];x[31785]=0;if((b|0)!=1){break ka}break p}x[31785]=0;O(281,d+264|0,d+208|0);f=x[31785];x[31785]=0;if((f|0)==1){break p}f=y[d+238|0]|y[d+239|0]<<8;x[31785]=0;b=U(254,a|0,b|0,Cb(f)|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break p}la:{ma:{if(!b){break ma}if(Cb(y[d+238|0]|y[d+239|0]<<8)>>>0>3999){break ma}f=d+112|0;dE(f,2,d+208|0);x[31785]=0;O(221,d+132|0,f|0);f=x[31785];x[31785]=0;if((f|0)==1){break la}f=d+132|0;zc(b+492|0,f);tb(f);g=d+112|0;dE(g,2,d+208|0);x[31785]=0;O(221,f|0,g|0);f=x[31785];x[31785]=0;if((f|0)==1){break p}f=d+132|0;zc(((Cb(y[d+238|0]|y[d+239|0]<<8)<<5)+a|0)+946304|0,f);tb(f);x[b>>2]=0;C=b,E=ve((y[d+254|0]|y[d+255|0]<<8)<<16>>16)+128&65535,x[C+8>>2]=E;vc(b+8|0,256);v[b+15|0]=y[b+15|0]|1;b=y[d+238|0]|y[d+239|0]<<8;x[31785]=0;b=D(Cb(b),104)+a|0;O(282,b+484380|0,0);f=x[31785];x[31785]=0;if((f|0)==1){break p}C=d,E=Cb(y[d+240|0]|y[d+241|0]<<8),w[C+132>>1]=E;w[d+112>>1]=64;C=b+484410|0,E=z[Mc(d+132|0,d+112|0)>>1]<<2,w[C>>1]=E;g=b+484404|0;f=$b(y[d+242|0]|y[d+243|0]<<8|(y[d+244|0]<<16|y[d+245|0]<<24));h=sua(f,f>>31,8303,0);f=hb;h=h+4181|0;f=h>>>0<4181?f+1|0:f;C=g,E=Fc(tua(h,f,8363,0),hb),x[C>>2]=E;f=$b(y[d+250|0]|y[d+251|0]<<8|(y[d+252|0]<<16|y[d+253|0]<<24));if(!f){break ma}g=Cb(y[d+256|0]|y[d+257|0]<<8);if(!(g&3)){break ma}h=f;f=$b(y[d+246|0]|y[d+247|0]<<8|(y[d+248|0]<<16|y[d+249|0]<<24));x[b+484388>>2]=h+f;x[b+484384>>2]=f;b=b+484414|0;f=z[b>>1];w[b>>1]=f|2;if(!(g&2)){break ma}w[b>>1]=f|6}j=j+1|0;continue}break}break p}b=x[d+200>>2];x[d+32>>2]=x[d+196>>2];x[d+36>>2]=b;x[d+40>>2]=x[d+204>>2];x[31785]=0;b=x[d+192>>2];x[d+24>>2]=x[d+188>>2];x[d+28>>2]=b;V(283,d+24|0,0,a|0,0);b=x[31785];x[31785]=0;if((b|0)==1){break p}x[31785]=0;S(267,d+168|0,d+376|0,1346719318);b=x[31785];x[31785]=0;if((b|0)==1){break p}b=x[d+180>>2];x[d+8>>2]=x[d+176>>2];x[d+12>>2]=b;x[d+16>>2]=x[d+184>>2];x[31785]=0;b=x[d+172>>2];x[d>>2]=x[d+168>>2];x[d+4>>2]=b;V(283,d|0,1,a|0,y[d+412|0]>2|0);b=x[31785];x[31785]=0;if((b|0)==1){break p}b=z[a+480192>>1]+1&65535;e=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(e|0)){break ja}f=x[((b<<2)+a|0)+900380>>2];if(!(!f|v[f+60|0]&1)){x[f>>2]=32767}b=b+1|0;continue}}ub(d+264|0);x[31785]=0;S(267,d+208|0,d+376|0,1346458708);b=x[31785];x[31785]=0;if((b|0)==1){break q}x[31785]=0;b=R(175,x[d+208>>2])|0;f=x[31785];x[31785]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){x[31785]=0;S(267,d+264|0,d+376|0,1347305805);b=x[31785];x[31785]=0;if((b|0)==1){break t}x[31785]=0;P(186,d+264|0,1)|0;b=x[31785];x[31785]=0;if((b|0)==1){break v}b=z[d+372>>1];x[31785]=0;k=a+484344|0;O(226,k|0,Cb(b)|0);b=x[31785];x[31785]=0;if((b|0)==1){break v}l=Nb(d+152|0);t=a+480188|0;f=0;m=0;while(1){if(Cb(z[d+372>>1])>>>0<=f>>>0){kd(l);g=m;ub(d+264|0);if(!(c&4)){break $}e=0;if(!u){break aa}f=z[a+480188>>1];b=0;e=1;while(1){if((b|0)==(f|0)){break aa}h=(b<<5)+a|0;v[h+480288|0]=1;h=h+480280|0;x[h>>2]=x[h>>2]|67108864;b=b+1|0;continue}}x[31785]=0;b=R(276,d+208|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break x}x[31785]=0;e=R(284,d+208|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break y}x[31785]=0;S(188,d+112|0,d+208|0,e|0);e=x[31785];x[31785]=0;if((e|0)==1){break z}e=d+112|0;i=ic(d+132|0,e);ub(e);x[31785]=0;e=U(199,k|0,f&65535,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break B}na:{if(e){n=Fb(d+100|0);x[31785]=0;O(285,d+264|0,n|0);e=x[31785];x[31785]=0;if((e|0)==1){break C}e=x[k>>2];x[31785]=0;O(286,Vb(e,f)|0,n|0);e=x[31785];x[31785]=0;if((e|0)==1){break C}j=0;e=Vb(x[k>>2],f);Ve(d+88|0,x[e>>2],x[x[e+48>>2]+12>>2],0);gj(l);A=(b>>>0<=1?1:b)-1|0;oa:while(1){b=x[i>>2];x[31785]=0;b=U(153,b|0,x[d+140>>2],1)|0;e=x[31785];x[31785]=0;if((e|0)==1){break na}pa:{if(!b){break pa}x[31785]=0;b=R(200,i|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break C}if(!b){C=d,E=vb(x[l>>2]),x[C+84>>2]=E;e=vb(x[l+4>>2]);while(1){b=x[d+84>>2];if(Ib(b,e)){we(Vb(x[k>>2],f),Ue(Le(d+112|0,y[b|0],y[b+1|0]),j));Wd(d+84|0);continue}else{gj(l);if((j|0)==(A|0)){break pa}b=Vb(x[k>>2],f);j=j+1|0;Ve(d+112|0,x[b>>2],x[x[b+48>>2]+12>>2],j);b=x[d+116>>2];x[d+88>>2]=x[d+112>>2];x[d+92>>2]=b;continue oa}}}w[d+116>>1]=0;x[d+112>>2]=0;h=d+112|0;if(b>>>0<=z[t>>1]){h=Vc(x[d+88>>2],b-1|0)}x[31785]=0;b=R(200,i|0)|0;e=x[31785];x[31785]=0;qa:{ra:{if((e|0)!=1){sa:{if(!(b&1)){break sa}x[31785]=0;e=R(200,i|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break C}if((e|0)!=31){if((e-1&255)>>>0>252){break sa}e=(D(e>>>4|0,12)+(e&15)|0)+13|0}else{e=255}v[h|0]=e}if(!(b&2)){break qa}x[31785]=0;e=R(200,i|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){break ra}}break C}v[h+1|0]=e}if(!(b&60)){continue}r=0;s=0;if(b&4){x[31785]=0;s=R(200,i|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break C}}if(b&8){x[31785]=0;r=R(200,i|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break C}}g=0;e=0;if(b&16){x[31785]=0;e=R(200,i|0)|0;B=x[31785];x[31785]=0;if((B|0)==1){break C}}if(b&32){x[31785]=0;g=R(200,i|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break C}}b=d+84|0;G$(b,e,g);e=Ic(b);b=d+82|0;G$(b,s,r);g=Ic(b);b=y[d+82|0];ta:{if((b|0)!=13){if(b){break ta}b=0;if(y[d+84|0]==13){break ta}}og(d+84|0,d+82|0);og(e,g);b=y[d+82|0]}sn(d+80|0,h,y[d+84|0],y[e|0],b&255,y[g|0]);if(F$(y[d+80|0],y[d+81|0])){b=x[zb(d+76|0,vb(x[l>>2]))>>2];x[31785]=0;S(287,l|0,b|0,d+80|0);b=x[31785];x[31785]=0;if((b|0)==1){break C}}b=y[h+3|0];if((b|0)==43){u=1;continue}if((b|0)!=31){continue}m=1;continue}break}tb(n)}ub(i);f=f+1|0;continue}break}break C}g=0;e=0;if(c&4){break aa}break H}b=N()|0;break b}b=N()|0;break o}b=N()|0;break o}x[d+152>>2]=-1778364416;x[d+156>>2]=-16756736;x[31785]=0;S(267,d+264|0,d+376|0,1146310725);b=x[31785];x[31785]=0;if((b|0)==1){break E}x[31785]=0;b=R(280,x[d+264>>2])|0;f=x[31785];x[31785]=0;if((f|0)==1){break D}if(b){x[31785]=0;m=R(276,d+264|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break D}j=a+480188|0;b=0;f=e;while(1){ua:{if((b|0)==(m|0)){x[31785]=0;O(288,d+264|0,d+152|0);b=x[31785];x[31785]=0;if((b|0)!=1){break ua}break D}x[31785]=0;h=R(200,d+264|0)|0;i=x[31785];x[31785]=0;va:{wa:{if((i|0)!=1){if(z[j>>1]<=b>>>0){break va}if(!e){break wa}i=((b<<5)+a|0)+480280|0;x[i>>2]=x[i>>2]&-67108865|((h|0)!=0)<<26;break va}break D}if(h){break va}f=1;v[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}e=f&1}ub(d+264|0);if(!e){break $}b=rd(a+906300|0,0);x[31785]=0;W(289,b|0);f=x[31785];x[31785]=0;if((f|0)==1){break _}x[b+16>>2]=810369604;x[b+20>>2]=1869112133;x[b+24>>2]=655376;x[b+28>>2]=0;x[d+264>>2]=0;e=b+48|0;C$(b+32|0,e,d+264|0);x[31785]=0;f=P(37,d+132|0,9576)|0;h=x[31785];x[31785]=0;if((h|0)==1){break Z}cE(e,f);tb(f);x[31785]=0;f=P(37,d+112|0,9540)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Y}cw(b+80|0,f);tb(f);x[31785]=0;O(290,b+4|0,8);f=x[31785];x[31785]=0;if((f|0)==1){break _}B$(d+264|0,y[d+153|0],y[d+155|0],y[d+157|0],y[d+159|0]);f=x[d+268>>2];b=x[b+4>>2];e=x[d+264>>2];v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=f;v[b+5|0]=f>>>8;v[b+6|0]=f>>>16;v[b+7|0]=f>>>24}if(!g){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}x[d+88>>2]=D(b,127)>>>5;x[31785]=0;O(291,d+152|0,4113);e=x[31785];x[31785]=0;if((e|0)==1){break X}x[31785]=0;O(292,d+100|0,d+88|0);e=x[31785];x[31785]=0;if((e|0)==1){break W}x[31785]=0;S(293,d+264|0,d+152|0,d+100|0);e=x[31785];x[31785]=0;if((e|0)==1){break V}e=d+264|0;ue(d+68|0,e);qf(Me(f,b),x[d+68>>2],x[d+72>>2]);tb(e);tb(d+100|0);e=d+152|0;Eb(e);x[31785]=0;O(291,e|0,4095);e=x[31785];x[31785]=0;if((e|0)==1){break T}x[31785]=0;O(292,d+100|0,d+88|0);e=x[31785];x[31785]=0;if((e|0)==1){break S}x[31785]=0;S(293,d+264|0,d+152|0,d+100|0);e=x[31785];x[31785]=0;if((e|0)==1){break R}e=d+264|0;ue(d+60|0,e);qf(Me(f,b+32|0),x[d+60>>2],x[d+64>>2]);tb(e);tb(d+100|0);e=d+152|0;Eb(e);x[31785]=0;O(291,e|0,4086);e=x[31785];x[31785]=0;if((e|0)==1){break P}x[31785]=0;O(292,d+100|0,d+88|0);e=x[31785];x[31785]=0;if((e|0)==1){break O}x[31785]=0;S(293,d+264|0,d+152|0,d+100|0);e=x[31785];x[31785]=0;if((e|0)==1){break N}e=d+264|0;ue(d+52|0,e);qf(Me(f,b- -64|0),x[d+52>>2],x[d+56>>2]);tb(e);tb(d+100|0);e=d+152|0;Eb(e);x[31785]=0;O(291,e|0,4059);e=x[31785];x[31785]=0;if((e|0)==1){break L}x[31785]=0;O(292,d+100|0,d+88|0);e=x[31785];x[31785]=0;if((e|0)==1){break K}x[31785]=0;S(293,d+264|0,d+152|0,d+100|0);e=x[31785];x[31785]=0;if((e|0)==1){break J}e=d+264|0;ue(d+44|0,e);qf(Me(f,b+96|0),x[d+44>>2],x[d+48>>2]);b=b+1|0;tb(e);tb(d+100|0);Eb(d+152|0);continue}}b=N()|0;break r}b=N()|0;break r}b=N()|0;break r}b=N()|0;break r}b=N()|0;break U}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}b=N()|0;break r}b=N()|0;break Q}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}b=N()|0;break r}b=N()|0;break M}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}b=N()|0;break r}b=N()|0;break I}b=N()|0;tb(d+100|0)}Eb(d+152|0);break r}x[31785]=0;S(267,d+264|0,d+376|0,1397575756);b=x[31785];x[31785]=0;xa:{if((b|0)!=1){x[31785]=0;b=R(175,x[d+264>>2])|0;f=x[31785];x[31785]=0;if((f|0)!=1){ya:{j=1;if(!(c&2)|b^1){break xa}c=a+480190|0;while(1){f=j&65535;if(f>>>0>z[c>>1]){break xa}x[31785]=0;b=R(284,d+264|0)|0;e=x[31785];x[31785]=0;za:{if((e|0)!=1){x[31785]=0;e=R(284,d+264|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break ya}if(!(b&7)){break za}f=(D(f,104)+a|0)+484380|0;x[f>>2]=e;b=ad(d+152|0,b&4?32:b&2?16:8,1,1,0);x[31785]=0;U(218,b|0,f|0,d+264|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break za}break ya}break ya}j=j+1|0;continue}}}b=N()|0;ub(d+264|0);break r}b=N()|0;break r}ub(d+264|0);ub(d+208|0);ub(d+300|0);ub(d+320|0)}fe(d+376|0);ub(q)}fb=d+416|0;return o|0}b=N()|0;break r}b=N()|0;ub(d+264|0);break r}b=N()|0;tb(n);break A}b=N()|0}ub(i);break w}b=N()|0;break w}b=N()|0;break w}b=N()|0}kd(l);break u}b=N()|0}ub(d+264|0);break r}b=N()|0;break r}b=N()|0}ub(d+208|0);break o}b=N()|0;break o}b=N()|0;ub(d+264|0)}ub(d+300|0);break l}b=N()|0;break l}b=N()|0}ub(d+320|0);break b}b=N()|0;break b}b=N()|0;tb(d+264|0);break h}b=N()|0}tb(d+300|0);break f}b=N()|0}Eb(d+320|0);break b}b=N()|0;break b}b=N()|0;break b}b=N()|0}fe(d+376|0)}ub(q);Q(b|0);p()}function Xoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-336|0;fb=d;xc(b);a:{if(!_o(b,d+324|0)){break a}if(!aX(d+324|0)){break a}q=Fe(d+304|0,b);o=Nb(d+292|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!c){x[31785]=0;O(667,d+40|0,q|0);b=x[31785];x[31785]=0;if((b|0)==1){break v}break x}x[31785]=0;O(668,d+40|0,q|0);b=x[31785];x[31785]=0;if((b|0)==1){break w}}b=d+40|0;jv(o,b);fe(b);x[31785]=0;S(669,b|0,o|0,1413891155);b=x[31785];x[31785]=0;y:{z:{if((b|0)!=1){x[31785]=0;e=P(670,d+40|0,14235)|0;b=x[31785];x[31785]=0;if((b|0)==1){break z}ub(d+40|0);if((c|0)!=0&e){break y}break b}b=N()|0;break c}b=N()|0;ub(d+40|0);break c}x[31785]=0;O(249,a|0,4194304);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[a+480208>>2]=12;x[31785]=0;S(669,d+272|0,o|0,1280592212);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=R(157,x[d+272>>2])|0;k=x[31785];x[31785]=0;if((k|0)==1){break g}x[31785]=0;S(459,d+272|0,a+1298308|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break g}f=a+484360|0;h=a+484376|0;gj(Wb(x[f>>2],y[h|0]));k=Nb(d+260|0);v[d+259|0]=0;v[d+258|0]=0;x[31785]=0;S(671,d+244|0,o|0,1196314451);b=x[31785];x[31785]=0;if((b|0)==1){break i}t=d,u=vb(x[d+244>>2]),x[t+240>>2]=u;j=d+228|0;r=vb(x[d+248>>2]);A:{while(1){b=x[d+240>>2];if(!Ib(b,r)){break A}m=Fe(d+40|0,b);x[31785]=0;e=P(672,m|0,d+28|0)|0;b=x[31785];x[31785]=0;B:{C:{if((b|0)!=1){b=1;if(!(e&y[d+37|0]==1)){break B}t=a,u=Hd(y[d+38|0],z[a+480188>>1],127),w[t+480188>>1]=u;x[31785]=0;l=R(673,d+184|0)|0;b=x[31785];x[31785]=0;D:{E:{F:{if((b|0)!=1){b=d+172|0;hf(b,d+28|0,9,1);x[31785]=0;O(221,d+136|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break F}b=d+16|0;gc(b,j,10);e=b;b=d+136|0;jm(e,b);tb(b);b=Wb(x[a+484360>>2],y[h|0]);if(mc(x[b>>2],x[b+4>>2])){break D}x[31785]=0;b=R(277,f|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break m}if((b|0)!=255){break E}b=2;break C}b=N()|0;break k}b=N()|0;break l}b=Wb(x[a+484360>>2],y[h|0])}x[31785]=0;O(674,d+160|0,j|0);e=x[31785];x[31785]=0;if((e|0)==1){break m}e=b;b=d+160|0;gp(e,b);tb(b);x[31785]=0;O(668,d+172|0,m|0);b=x[31785];x[31785]=0;if((b|0)!=1){t=d,u=vb(x[d+172>>2]),x[t+156>>2]=u;s=vb(x[d+176>>2]);while(1){G:{H:{I:{J:{K:{b=x[d+156>>2];if(Ib(b,s)){ep(d+136|0,b);ti(d+16|0,x[b>>2],x[b+4>>2]);e=x[d+16>>2];if((e|0)==1212960847){break K}b=0;if((e|0)!=1312903248){break G}while(1){e=b&65535;if(e>>>0>=z[a+480188>>1]){break G}x[31785]=0;i=U(153,x[d+136>>2],x[d+144>>2],2)|0;g=x[31785];x[31785]=0;if((g|0)==1){break I}if(!i){break G}x[31785]=0;O(201,d+8|0,d+136|0);i=x[31785];x[31785]=0;if((i|0)!=1){oC(l,e,y[d+8|0],y[Ic(d+8|0)|0],d+259|0,k);b=b+1|0;continue}break}break I}b=0;if(z[d+220>>1]==65535|z[d+222>>1]==65535){break J}b=y[h|0];e=x[a+484360>>2];x[31785]=0;W(675,Wb(e,b)|0);b=x[31785];x[31785]=0;if((b|0)!=1){b=0;x[31785]=0;O(676,k|0,l|0);e=x[31785];x[31785]=0;if((e|0)!=1){break J}}b=N()|0;break H}if(A[d+20>>2]<9){break G}e=0;x[31785]=0;P(186,d+136|0,2)|0;b=x[31785];x[31785]=0;i=65535;L:{if((b|0)!=1){while(1){x[31785]=0;b=U(153,x[d+136>>2],x[d+144>>2],1)|0;g=x[31785];x[31785]=0;M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((g|0)!=1){if(!b){break G}x[31785]=0;g=R(200,d+136|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break I}b=4;switch(g|0){case 0:break G;case 14:break N;case 13:break O;case 12:break Q;case 8:break R;case 7:break S;case 2:break T;case 6:break U;case 5:break V;case 3:case 4:break W;case 1:break X;default:break P}}break I}b=Wb(x[a+484360>>2],y[h|0]);if(z[d+220>>1]==65535){t=d,u=dm(x[b>>2],x[b+4>>2]),w[t+220>>1]=u}b=dm(x[b>>2],x[b+4>>2]);x[31785]=0;w[d+222>>1]=b;b=P(677,d+136|0,d+258|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break I}Y:{Z:{switch(b-254|0){case 1:b=65535;break Y;case 0:break Z;default:break Y}}b=65534}g=y[h|0];n=x[a+484360>>2];x[31785]=0;O(540,Wb(n,g)|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break I}i=(i&65535)==65535?e:i;break M}x[31785]=0;b=R(192,d+136|0)|0;n=x[31785];x[31785]=0;if((n|0)!=1){_:{if(b>>>0<(i&65535)>>>0){b=z[d+224>>1];break _}b=b-i|0;w[d+224>>1]=b}_e(Wb(x[a+484360>>2],y[h|0]),b&65535);if((g|0)!=3){break M}x[31785]=0;P(186,d+136|0,1)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break M}}break I}x[31785]=0;O(201,d+8|0,d+136|0);b=x[31785];x[31785]=0;if((b|0)!=1){oC(l,y[d+8|0],y[Ic(d+8|0)|0],-1,d+259|0,k);break M}break I}b=1}x[31785]=0;P(186,d+136|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break M}break I}x[31785]=0;b=R(200,d+136|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break I}v[d+227|0]=b;break M}x[31785]=0;b=R(200,d+136|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break I}v[d+226|0]=b;break M}x[31785]=0;b=P(643,d+136|0,d+8|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break I}if(y[d+8|0]|!b|(y[d+10|0]|y[d+9|0]!=255)){break P}if(y[d+11|0]|y[d+12|0]!=1){break P}if(!y[d+13|0]){break M}}ub(d+136|0);b=1;break J}x[31785]=0;O(552,d+8|0,d+136|0);b=x[31785];x[31785]=0;if((b|0)!=1){b=d+8|0;g=Ic(b);oC(l,y[d+8|0],y[Ze(b)|0],y[g|0],d+259|0,k);break M}break I}x[31785]=0;O(201,d+8|0,d+136|0);b=x[31785];x[31785]=0;if((b|0)==1){break L}b=x[d+196>>2];n=Sc(b,x[d+200>>2]);g=y[d+8|0];if(n>>>0<=g>>>0){break M}n=Ic(d+8|0);t=xb(b,g),u=(y[n|0]>>>2|0)+1|0,v[t|0]=u}e=e+1|0;continue}}break I}break I}fe(d+172|0);break C}b=N()|0;ub(d+136|0)}fe(d+172|0);break l}ub(d+136|0);rn(d+156|0);continue}}b=N()|0;break l}b=N()|0;break k}iv(l)}ub(m);if(!b){Xf(d+240|0);continue}break}e=0;if((b|0)!=2){break s}}e=0;ak(f,0);b=x[k>>2];if(mc(b,x[k+4>>2])){break s}if(!(c&2)){break t}x[31785]=0;S(671,d+136|0,o|0,1347244868);b=x[31785];x[31785]=0;$:{if((b|0)!=1){t=d,u=vb(x[d+136>>2]),x[t+16>>2]=u;e=a+480190|0;i=d+53|0;h=d+57|0;l=vb(x[d+140>>2]);m=y[d+258|0];while(1){b=x[d+16>>2];if(!Ib(b,l)){Qc(d+136|0);b=x[k>>2];break t}aa:{ba:{ca:{if(!m){x[31785]=0;f=P(678,b|0,d+40|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break aa}if(!f){break ba}f=y[d+92|0]|y[d+93|0]<<8;j=f+1|0;w[d+8>>1]=j;if(f>>>0>3998){break ca}t=a,u=z[se(e,d+8|0)>>1],w[t+480190>>1]=u;x[31785]=0;O(679,d+40|0,(D(j&65535,104)+a|0)+484380|0);f=x[31785];x[31785]=0;if((f|0)==1){break aa}f=d+28|0;$W(f,i);x[31785]=0;O(221,d+172|0,f|0);f=x[31785];x[31785]=0;if((f|0)==1){break u}f=d+172|0;zc(((z[d+8>>1]<<5)+a|0)+946304|0,f);tb(f);break ca}x[31785]=0;f=P(680,b|0,d+40|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break u}if(!f){break ba}f=y[d+96|0]|y[d+97|0]<<8;j=f+1|0;w[d+8>>1]=j;if(f>>>0>3998){break ca}t=a,u=z[se(e,d+8|0)>>1],w[t+480190>>1]=u;x[31785]=0;O(681,d+40|0,(D(j&65535,104)+a|0)+484380|0);f=x[31785];x[31785]=0;if((f|0)==1){break u}f=d+28|0;$W(f,h);x[31785]=0;O(221,d+172|0,f|0);f=x[31785];x[31785]=0;if((f|0)==1){break $}f=d+172|0;zc(((z[d+8>>1]<<5)+a|0)+946304|0,f);tb(f)}f=z[d+8>>1];if((f-1&65535)>>>0>3998){break ba}j=ad(d+40|0,8,1,0,2);x[31785]=0;U(218,j|0,(D(f,104)+a|0)+484380|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break ba}break u}Xf(d+16|0);continue}break}break u}b=N()|0;break j}break u}b=N()|0;break c}b=N()|0;break c}b=N()|0;Qc(d+136|0);break j}b=nC(b,0);x[a+480196>>2]=y[b+43|0];x[a+480204>>2]=D(y[b+42|0],1e4);_e(Wb(x[a+484360>>2],y[a+484376|0]),z[b+40>>1]);b=0;while(1){if(z[a+480188>>1]>b>>>0){e=(b<<5)+a|0;i=e+480280|0;Ye(i);h=nC(x[k>>2],0);t=e+480286|0,u=y[xb(x[h+12>>2],b)|0],w[t>>1]=u;t=e+480284|0,u=y[xb(x[h>>2],b)|0],w[t>>1]=u;Kb(d+40|0,x[h+24>>2],b);t=i,u=x[i>>2]&-257|(Hb(x[x[d+40>>2]>>2],x[d+44>>2])?256:0),x[t>>2]=u;b=b+1|0;continue}break}x[31785]=0;b=P(1,d+172|0,(y[d+258|0]?17354:17211)|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break n}yb(a+1298344|0,b);tb(b);x[31785]=0;b=P(1,d+28|0,10147)|0;e=x[31785];x[31785]=0;if((e|0)==1){break o}yb(a+1298356|0,b);tb(b);t=a+1298404|0,u=x[Gc(d+40|0,4)>>2],x[t>>2]=u;e=1;if(!(c&1)|!z[a+480188>>1]){break s}x[31785]=0;S(671,d+16|0,o|0,1146045008);b=x[31785];x[31785]=0;if((b|0)==1){break p}b=x[d+20>>2];c=x[d+16>>2];x[31785]=0;l=a+484344|0;O(226,l|0,Lf(c,b)&65535);b=x[31785];x[31785]=0;if((b|0)==1){break r}t=d,u=vb(x[d+16>>2]),x[t+240>>2]=u;j=vb(x[d+20>>2]);while(1){h=x[d+240>>2];if(!Ib(h,j)){da:{ea:{b=x[k>>2];e=x[k+4>>2];if(hv(b,e)>>>0<2){break ea}m=a+484348|0;f=y[d+259|0];c=0;while(1){if(hv(b,e)>>>0<=c>>>0){break ea}g=x[a+484344>>2];n=x[m>>2];h=Sj(x[a+484360>>2],c&255);r=x[h>>2];i=nC(b,c);j=z[i+36>>1];if(Ge(g,n,z[_b(r,j)>>1])){x[31785]=0;e=P(371,h|0,j|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break da}fa:{if(!f){break fa}b=0;while(1){if(z[a+480188>>1]<=b>>>0){break fa}j=mC(x[i+24>>2],b);h=Vb(x[l>>2],e);ga:{if(j){we(h,Vh($o(Ue(Le(d+40|0,20,145),0),b&65535)));break ga}we(h,Vh($o(Ue(Le(d+40|0,9,y[xb(x[i>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;we(Vb(x[l>>2],e),Vh(Ue(Le(b,16,y[i+43|0]),0)));we(Vb(x[l>>2],e),Vh(Ue(Le(b,17,y[i+42|0]),0)));e=x[k+4>>2];b=x[k>>2]}c=c+1|0;continue}}Qc(d+16|0);e=1;break s}b=N()|0;break q}b=x[h>>2];x[31785]=0;b=R(157,b|0)|0;c=x[31785];x[31785]=0;ha:{ia:{ja:{ka:{la:{ma:{na:{if((c|0)==1){break na}x[31785]=0;c=R(154,h|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break na}if((b|0)!=(c|0)){break ha}b=x[h>>2];x[31785]=0;b=P(682,b|0,8)|0;c=x[31785];x[31785]=0;if((c|0)==1){break na}if(!b){break ha}x[31785]=0;m=P(677,h|0,d+258|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break ia}x[31785]=0;f=R(192,h|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break ja}x[31785]=0;b=U(199,l|0,m|0,f|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ja}if(!b){break ha}i=0;while(1){if((f|0)==(i|0)){break ha}b=Vb(x[l>>2],m);Ve(d+8|0,x[b>>2],x[x[b+48>>2]+12>>2],i);x[31785]=0;b=R(192,h|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ma}oa:{if(b>>>0>=3){x[31785]=0;S(188,d+136|0,h|0,b-2|0);b=x[31785];x[31785]=0;if((b|0)==1){break ka}b=d+136|0;e=ic(d+40|0,b);ub(b);while(1){b=x[e>>2];x[31785]=0;b=U(153,b|0,x[d+48>>2],3)|0;c=x[31785];x[31785]=0;if((c|0)==1){break oa}if(b){x[31785]=0;O(201,d+136|0,e|0);b=x[31785];x[31785]=0;pa:{qa:{ra:{sa:{if((b|0)!=1){w[d+156>>1]=z[a+480188>>1]-1;t=d,u=y[Ic(d+136|0)|0],w[t+6>>1]=u;c=Vc(x[d+8>>2],z[Mc(d+156|0,d+6|0)>>1]);b=v[d+136|0];if((b|0)>=0){break pa}x[31785]=0;b=R(200,e|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break la}if(y[d+258|0]){break ra}if((b|0)!=255){break sa}b=254;break qa}break la}if(b>>>0>128){break qa}b=(D(b>>>4|0,12)+(b&15)|0)+13|0;break qa}b=b>>>0<85?b+36|0:b}v[c|0]=b;b=y[d+136|0]}if(b&64){x[31785]=0;b=R(200,e|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break la}v[c+1|0]=b+1;b=y[d+136|0]}if(b&32){x[31785]=0;b=R(200,e|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break la}v[d+156|0]=b;v[c+2|0]=1;v[d+6|0]=127;t=c,u=y[Ub(d+156|0,d+6|0)|0]+1>>>1|0,v[t+4|0]=u;b=y[d+136|0]}if(!(b&16)){continue}x[31785]=0;O(201,d+156|0,e|0);b=x[31785];x[31785]=0;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{if((b|0)!=1){b=y[Ic(d+156|0)|0];v[c+5|0]=b;switch(y[d+156|0]-1|0){case 72:break ua;case 71:break va;case 70:break wa;case 61:break xa;case 60:break ya;case 53:break za;case 52:break Aa;case 51:break Ba;case 50:break Da;case 43:break Ea;case 42:break Fa;case 41:break Ga;case 40:break Ha;case 31:break Ia;case 30:break Ja;case 23:break Ka;case 22:break La;case 21:break Ma;case 20:break Na;case 18:break Oa;case 17:break Pa;case 15:break Qa;case 16:break Ra;case 14:break Sa;case 13:break Ta;case 12:break Ua;case 11:break Va;case 10:break Wa;case 3:break Xa;case 2:break Ya;case 1:break Za;case 0:break _a;default:break ta}}break la}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4|15;continue}v[c+5|0]=b<<3|15;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b<<4;continue}v[c+5|0]=b<<3&240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1|240;continue}v[c+3|0]=11;if(y[d+258|0]){v[c+5|0]=b&15;continue}if(b>>>0<=1){v[c+5|0]=b|240;continue}v[c+5|0]=b>>>1&15;continue}v[c+3|0]=2;t=c,u=gv(b,y[d+258|0])|240,v[t+5|0]=u;continue}v[c+3|0]=2;t=c,u=gv(b,y[d+258|0]),v[t+5|0]=u;continue}v[c+3|0]=3;t=c,u=gv(b,y[d+258|0])|240,v[t+5|0]=u;continue}v[c+3|0]=3;t=c,u=gv(b,y[d+258|0]),v[t+5|0]=u;continue}v[c+3|0]=4;if(y[d+258|0]){continue}v[c+5|0]=(b&252)>>>2;continue}v[c+3|0]=20;v[c+5|0]=b&1|16;continue}v[c+3|0]=6;v[c+5|0]=b&240;continue}v[c+3|0]=6;v[c+5|0]=(b&240)>>>4;continue}v[c+3|0]=20;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=b&15|48;continue}v[c+3|0]=7;v[c+5|0]=b|240;continue}v[c+3|0]=7;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=b&15|64;continue}v[c+3|0]=10;x[31785]=0;b=R(200,e|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){break Ca}break la}v[c+3|0]=15;continue}v[c+3|0]=20;v[c+5|0]=b&15|192;continue}v[c+3|0]=20;v[c+5|0]=b&15|208;continue}v[c+3|0]=12;b=(b&254)>>>1|0}v[c+5|0]=b;x[31785]=0;P(186,e|0,1)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}break la}v[c+5|0]=0;v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=b&15|176;continue}v[c+3|0]=20;v[c+5|0]=b&15|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=b&15|32;continue}v[c+3|0]=20;v[c+5|0]=b&15|128;continue}v[c+3|0]=0;continue}break}ub(e)}i=i+1|0;continue}break}break la}b=N()|0;break q}b=N()|0;break q}b=N()|0;ub(e);break q}b=N()|0;break q}b=N()|0;break q}b=N()|0;break q}Xf(d+240|0);continue}}Qc(d+244|0);_W(k);ub(d+272|0);break b}b=N()|0}Qc(d+16|0);break j}b=N()|0;break j}b=N()|0;break j}b=N()|0;break j}b=N()|0}iv(l)}ub(m)}Qc(d+244|0);break h}b=N()|0}_W(k);break f}b=N()|0}ub(d+272|0);break c}b=N()|0;break c}b=N()|0}fe(o);ub(q);Q(b|0);p()}fe(o);ub(q)}fb=d+336|0;return e|0}function Doa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=fb-304|0;fb=e;xc(b);a:{if(!kv(b,e+208|0)){break a}if(!KW(e+208|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(JW(e+208|0),hb))){break a}b:{if(!c){break b}Bd(a,2);x[a+480260>>2]=64;x[a+480264>>2]=32767;j=Fb(e+196|0);d=y[e+248|0]|y[e+249|0]<<8;l=(d|0)==20479?y[e+262|0]|y[e+263|0]<<8:d-16464|0;c:{d:{e:{f:{g:{h:{i:{j:{switch(d>>>12|0){case 0:if((d|0)!=520){break e}x[31785]=0;d=P(1,e+184|0,12398)|0;g=x[31785];x[31785]=0;if((g|0)!=1){yb(j,d);break f}f=N()|0;break c;case 1:k:{if((d|0)!=4896){break k}d=y[e+270|0]|y[e+271|0]<<8;if(d){break k}if(!((y[e+246|0]|y[e+247|0]<<8)&65455|(y[e+260|0]|y[e+240|0]&15))){l:{if(v[e+259|0]<0){x[a+1074308>>2]=18219008;x[31785]=0;d=P(1,e+184|0,14930)|0;f=x[31785];x[31785]=0;if((f|0)!=1){break l}f=N()|0;break c}x[a+1074308>>2]=16777216;x[31785]=0;d=P(1,e+184|0,13442)|0;f=x[31785];x[31785]=0;if((f|0)==1){break i}}yb(j,d);tb(d);x[31785]=0;f=1;U(269,a+1074312|0,81,1)|0;d=x[31785];x[31785]=0;g=1;if((d|0)!=1){break e}break d}if(y[e+260|0]|d|(y[e+261|0]|(y[e+246|0]|y[e+247|0]<<8))){break k}x[31785]=0;d=P(1,e+184|0,9496)|0;g=x[31785];x[31785]=0;if((g|0)!=1){yb(j,d);break f}f=N()|0;break c}x[31785]=0;d=P(1,e+184|0,8514)|0;f=x[31785];x[31785]=0;i=1;if((f|0)!=1){yb(j,d);tb(d);break g}f=N()|0;break c;case 2:x[31785]=0;d=P(1,e+184|0,6828)|0;f=x[31785];x[31785]=0;g=1;if((f|0)!=1){yb(j,d);tb(d);break g}f=N()|0;break c;case 3:m:{n:{o:{p:{if(d>>>0<=12820){x[31785]=0;f=P(1,e+184|0,8577)|0;g=x[31785];x[31785]=0;if((g|0)!=1){yb(j,f);tb(f);break p}f=N()|0;break c}x[31785]=0;O(446,e+184|0,4035);f=x[31785];x[31785]=0;if((f|0)==1){break o}x[31785]=0;x[e+172>>2]=(y[e+248|0]|y[e+249|0]<<8)-12820;S(447,e+48|0,e+184|0,e+172|0);f=x[31785];x[31785]=0;if((f|0)==1){break n}f=e+48|0;yb(j,f);tb(f);Eb(e+184|0)}f=y[e+248|0]|y[e+249|0]<<8;if(f>>>0<12807){break h}g=y[e+264|0]|y[e+265|0]<<8|(y[e+266|0]<<16|y[e+267|0]<<24);if(g){break m}break h}f=N()|0;break c}f=N()|0;Eb(e+184|0);break c}f=pF(f,g);g=bp(e+48|0);x[g+32>>2]=f;x[31785]=0;O(449,a+1298412|0,g|0);f=x[31785];x[31785]=0;if((f|0)!=1){break h}f=N()|0;break c;case 4:if((d|0)==16640){x[31785]=0;d=P(1,e+184|0,8360)|0;i=x[31785];x[31785]=0;g=1;if((i|0)!=1){yb(j,d);tb(d);x[31785]=0;U(269,a+1074312|0,81,1)|0;d=x[31785];x[31785]=0;i=0;if((d|0)==1){break d}break e}f=N()|0;break c}x[31785]=0;S(450,e+48|0,d|0,y[e+262|0]|y[e+263|0]<<8);d=x[31785];x[31785]=0;q:{r:{s:{if((d|0)!=1){d=e+48|0;yb(j,d);tb(d);x[a+480260>>2]=1;if((l|0)<4201){break s}x[31785]=0;U(269,a+1074312|0,7,1)|0;d=x[31785];x[31785]=0;if((d|0)==1){break d}break r}f=N()|0;break c}if((l|0)<2386){break q}}x[31785]=0;U(269,a+1074312|0,38,1)|0;d=x[31785];x[31785]=0;if((d|0)==1){break d}}x[31785]=0;P(270,a+1074312|0,118)|0;d=x[31785];x[31785]=0;g=1;h=1;if((d|0)==1){break d}break e;case 5:if((d|0)!=21575){d=d&4095;x[a+1074308>>2]=d<<16|(d>>>0>296?y[e+262|0]|y[e+263|0]<<8:0)&65535;x[31785]=0;d=P(1,e+184|0,18434)|0;f=x[31785];x[31785]=0;t:{u:{v:{if((f|0)!=1){f=x[a+1074308>>2];x[31785]=0;O(137,e+172|0,f|0);f=x[31785];x[31785]=0;if((f|0)==1){break v}f=0;x[31785]=0;S(2,e+48|0,d|0,e+172|0);g=x[31785];x[31785]=0;if((g|0)==1){break u}g=e+48|0;yb(j,g);tb(g);tb(e+172|0);break f}f=N()|0;break c}f=N()|0;break t}f=N()|0;tb(e+172|0)}tb(d);break c}x[31785]=0;d=P(1,e+184|0,8561)|0;g=x[31785];x[31785]=0;if((g|0)!=1){yb(j,d);break f}f=N()|0;break c;case 6:x[31785]=0;d=P(1,e+184|0,8360)|0;g=x[31785];x[31785]=0;if((g|0)!=1){yb(j,d);tb(d);x[31785]=0;U(269,a+1074312|0,81,1)|0;d=x[31785];x[31785]=0;g=0;if((d|0)==1){break d}break e}f=N()|0;break c;case 7:x[31785]=0;d=P(1,e+184|0,8372)|0;g=x[31785];x[31785]=0;if((g|0)!=1){yb(j,d);break f}f=N()|0;break c;default:break j}}if((d|0)!=51712){break e}x[31785]=0;d=P(1,e+184|0,9295)|0;g=x[31785];x[31785]=0;if((g|0)!=1){yb(j,d);break f}f=N()|0;break c}f=N()|0;break c}x[31785]=0;f=U(269,a+1074312|0,7,1)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}x[31785]=0;f=U(269,f|0,23,1)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}x[31785]=0;f=U(269,f|0,38,1)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}x[31785]=0;U(269,f|0,107,1)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}g=1;x[a+480260>>2]=1;f=0;if(d>>>0>12820){break e}}x[31785]=0;W(698,e+172|0);d=x[31785];x[31785]=0;w:{x:{y:{if((d|0)!=1){d=y[e+248|0]|y[e+249|0]<<8;x[e+148>>2]=d>>>8&15;x[31785]=0;x[e+132>>2]=d&255;O(448,e+160|0,e+132|0);d=x[31785];x[31785]=0;if((d|0)==1){break y}f=0;x[31785]=0;aa(699,e+48|0,e+172|0,j|0,e+148|0,e+160|0);d=x[31785];x[31785]=0;if((d|0)==1){break x}d=e+48|0;yb(j,d);tb(d);tb(e+160|0);Eb(e+172|0);break e}f=N()|0;break c}f=N()|0;break w}f=N()|0;tb(e+160|0)}Eb(e+172|0);break c}tb(d);g=0}x[31785]=0;d=P(1,e+172|0,15205)|0;m=x[31785];x[31785]=0;z:{A:{B:{C:{D:{E:{F:{G:{if((m|0)!=1){yb(a+1298344|0,d);tb(d);x[31785]=0;d=P(1,e+160|0,10484)|0;m=x[31785];x[31785]=0;if((m|0)==1){break G}yb(a+1298356|0,d);tb(d);o=yb(a+1298368|0,j);B=a+1298404|0,C=x[Gc(e+48|0,x[a+1074308>>2]?22:4)>>2],x[B>>2]=C;if(g){x[31785]=0;d=P(270,a+1074312|0,77)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}x[31785]=0;d=P(270,d|0,78)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}x[31785]=0;d=P(270,d|0,79)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}x[31785]=0;d=P(270,d|0,80)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}x[31785]=0;d=P(270,d|0,82)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}x[31785]=0;d=P(270,d|0,96)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}x[31785]=0;P(270,d|0,113)|0;d=x[31785];x[31785]=0;if((d|0)==1){break d}}d=y[e+248|0]|y[e+249|0]<<8;if(d>>>0<=4865){x[31785]=0;P(270,a+1074312|0,118)|0;d=x[31785];x[31785]=0;if((d|0)==1){break d}d=y[e+248|0]|y[e+249|0]<<8}g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|(d&65535)>>>0>12819|f}x[31785]=0;d=a+901404|0;W(700,d|0);g=x[31785];x[31785]=0;if((g|0)==1){break d}if(!f){Zq(d)}d=e+148|0;_i(d,1,e+208|0);x[31785]=0;O(221,e+48|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break D}d=e+48|0;yb(a+1298308|0,d);tb(d);d=y[e+246|0]|y[e+247|0]<<8;if(d&16){x[a+480208>>2]=x[a+480208>>2]|65536}if(d&1){x[a+480208>>2]=x[a+480208>>2]|131072}f=y[e+248|0]|y[e+249|0]<<8;if(!(!(d&64)&(f|0)!=4864)){x[a+480208>>2]=x[a+480208>>2]|2}d=y[e+257|0];x[a+480196>>2]=d;if(!(!i|(d|0)!=255?d:0)){x[a+480196>>2]=6}d=y[e+258|0];x[a+480204>>2]=d>>>0<33?i?125e4:32e4:D(d,1e4);v[e+48|0]=y[e+256|0];v[e+148|0]=64;d=y[Ub(e+48|0,e+148|0)|0];x[a+480200>>2]=d<<2;if(!(d|f>>>0>4895)){x[a+480200>>2]=256}g=y[e+259|0];if((y[e+250|0]|y[e+251|0]<<8)!=1|g>>>0>7){break F}x[e+48>>2]=(g<<4)+16;x[e+148>>2]=127;f=x[pd(e+48|0,e+148|0)>>2];break E}f=N()|0;break c}f=N()|0;break c}f=32;if((g|16)==18){break E}d=g&127;f=48;if(!d){break E}x[e+48>>2]=d;x[e+148>>2]=16;f=x[We(e+48|0,e+148|0)>>2]}x[a+480228>>2]=f;d=0;m=x[a+1074308>>2]!=0|g<<24>>24<0;if(!m){B=a,C=Bc(uua(f<<3|5,f>>>29|0,11,0),hb),x[B+480228>>2]=C}r=a+480188|0;w[r>>1]=4;x[a+480232>>2]=h?(l|0)<3299?64:36:36;f=rc(e+144|0);while(1){if((d|0)==32){d=a+480188|0;if(!z[d>>1]){w[d>>1]=1}d=y[a+484376|0];g=x[a+484360>>2];x[31785]=0;aa(351,Wb(g,d)|0,b|0,y[e+240|0]|y[e+241|0]<<8,255,254);d=x[31785];x[31785]=0;if((d|0)!=1){m=Nb(e+148|0);x[31785]=0;U(216,b|0,m|0,y[e+242|0]|y[e+243|0]<<8)|0;d=x[31785];x[31785]=0;if((d|0)!=1){r=Nb(e+132|0);x[31785]=0;U(216,b|0,r|0,y[e+244|0]|y[e+245|0]<<8)|0;d=x[31785];x[31785]=0;H:{if((d|0)!=1){if(y[e+261|0]!=252){break C}d=0;x[31785]=0;O(701,b|0,e+48|0);g=x[31785];x[31785]=0;if((g|0)==1){break H}while(1){if((d|0)==32){break C}g=y[(e+48|0)+d|0];I:{if(!(g&32)){break I}if(i){Pc(e+36|0,f,d);if(Hb(x[x[e+36>>2]>>2],x[e+40>>2])){break I}}w[((d<<5)+a|0)+480284>>1]=(((g&15)<<8|8)>>>0)/15}d=d+1|0;continue}}f=N()|0;break B}f=N()|0;break B}f=N()|0;break A}f=N()|0;break c}g=(d<<5)+a|0;l=g+480280|0;Ye(l);h=y[(e+d|0)+272|0];q=h&126;J:{if((h|0)!=255){h=h<<24>>24;w[r>>1]=d+1;if(m){w[g+480284>>1]=h&8?204:51}if((h|0)>=0){break J}}x[l>>2]=1024}if((q-16&255)>>>0<=13){w[g+480284>>1]=128;g=e+48|0;Pc(g,f,d);Uo(g)}d=d+1|0;continue}}f=N()|0;break c}w[e+48>>1]=y[e+242|0]|y[e+243|0]<<8;w[e+36>>1]=3999;f=z[Mc(e+48|0,e+36|0)>>1];w[a+480190>>1]=f;q=c&2;s=e+96|0;d=0;h=0;g=0;l=0;K:{L:{M:{N:{O:{P:{Q:{R:{S:{while(1){if((f&65535)>>>0<=d>>>0){if(!(!(h&i)|l&65535)&(y[e+248|0]|y[e+249|0]<<8)!=4864){break Q}if(!i){break P}x[31785]=0;d=l&65535;f=U(269,a+1074312|0,79,d>>>0>1|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break N}x[31785]=0;d=d>>>0<2;f=U(269,f|0,107,d|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break N}x[31785]=0;U(269,f|0,38,d|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break N}x[31785]=0;d=l&65535;P(130,o|0,(d>>>0>1?17398:17405)|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break N}if(d>>>0<2){break P}x[a+480228>>2]=48;break P}f=_b(x[m>>2],d);f=y[f|0]|y[f+1|0]<<8;x[31785]=0;f=P(152,b|0,f<<4)|0;n=x[31785];x[31785]=0;if((n|0)==1){break L}T:{U:{if(!f){break U}x[31785]=0;f=P(702,b|0,e+48|0)|0;n=x[31785];x[31785]=0;if((n|0)==1){break L}if(!f){break U}x[31785]=0;f=d+1|0;n=(D(f,104)+a|0)+484380|0;S(703,e+48|0,n|0,i|0);k=x[31785];x[31785]=0;if((k|0)==1){break L}k=e+24|0;_i(k,1,s);x[31785]=0;O(221,e+36|0,k|0);k=x[31785];x[31785]=0;if((k|0)==1){break T}k=((f<<5)+a|0)+946304|0;f=e+36|0;zc(k,f);tb(f);if(y[e+48|0]>1){break U}V:{if(!q|!(y[e+64|0]|y[e+65|0]<<8|(y[e+66|0]<<16|y[e+67|0]<<24))){break V}f=HW(e+48|0);x[31785]=0;f=P(152,b|0,f|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break S}if(!f){break V}f=e+36|0;GW(f,y[e+78|0],y[e+79|0],(y[e+250|0]|y[e+251|0]<<8)==1);x[31785]=0;U(218,f|0,n|0,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break R}g=y[e+39|0]==10|g;h=1}l=y[e+88|0]|y[e+89|0]<<8|l}d=d+1|0;f=z[a+480190>>1];continue}break}f=N()|0;break B}f=N()|0;break B}f=N()|0;break B}x[31785]=0;d=P(1,e+48|0,9760)|0;f=x[31785];x[31785]=0;if((f|0)==1){break O}yb(o,d);tb(d)}if(g&1){break M}break K}f=N()|0;break B}f=N()|0;break B}x[31785]=0;d=P(1,e+36|0,17338)|0;f=x[31785];x[31785]=0;W:{if((f|0)!=1){x[31785]=0;P(77,o|0,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break W}tb(d);break K}f=N()|0;break B}f=N()|0;tb(d);break B}f=N()|0;break B}if(!(c&1)){break z}c=y[e+248|0]|y[e+249|0]<<8;w[e+24>>1]=y[e+244|0]|y[e+245|0]<<8;w[e+16>>1]=255;s=z[Mc(e+24|0,e+16|0)>>1];x[31785]=0;i=a+484344|0;O(226,i|0,s|0);d=x[31785];x[31785]=0;if((d|0)!=1){n=c>>>0<4896;u=a+480188|0;h=0;o=0;q=0;X:{Y:{while(1){if((h|0)==(s|0)){if(!n){break z}a=z[a+480188>>1];if((a|0)>(o+q|0)|(a|0)<=(o-q|0)){break z}d=pg(x[i>>2],x[i+4>>2])-1&65535;b=0;Z:{if(pg(x[i>>2],x[i+4>>2])>>>0<=d>>>0){break Z}while(1){c=b&65535;if(c>>>0>d>>>0){break Z}a=sg(x[i>>2],c);f=x[a>>2];if(Ib(f,x[a+4>>2])){a=vb(f);f=vb(x[sg(x[i>>2],c)+4>>2]);c=fb-16|0;fb=c;x[c+12>>2]=a;while(1){if(Ib(a,f)){if(y[a+3|0]==31){v[a+3|0]=20;v[a+5|0]=y[a+5|0]|128}a=x[ah(c+12|0)>>2];continue}break}fb=c+16|0}b=b+1|0;continue}}break z}x[31785]=0;c=U(199,i|0,h&65535,64)|0;d=x[31785];x[31785]=0;_:{if((d|0)==1){break _}$:{if(!c){break $}c=_b(x[r>>2],h);c=y[c|0]|y[c+1|0]<<8;if(!c){break $}x[31785]=0;c=P(152,b|0,c<<4)|0;d=x[31785];x[31785]=0;if((d|0)==1){break _}if(!c){break $}x[31785]=0;P(186,b|0,2)|0;c=x[31785];x[31785]=0;if((c|0)==1){break _}d=0;c=Vb(x[i>>2],h);Ve(e+24|0,x[c>>2],x[x[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break $}f=d;x[31785]=0;c=R(200,b|0)|0;d=x[31785];x[31785]=0;aa:{if((d|0)!=1){d=c<<24>>24;if(d){break aa}d=64;if(f>>>0>62){continue}c=Vb(x[i>>2],h);d=f+1|0;Ve(e+16|0,x[c>>2],x[x[c+48>>2]+12>>2],d);c=x[e+20>>2];x[e+24>>2]=x[e+16>>2];x[e+28>>2]=c;continue}f=N()|0;break B}g=Jg(e+16|0);k=d&31;if(k>>>0<z[u>>1]){g=Vc(x[e+24>>2],k)}t=d&255;if(t&32){x[31785]=0;O(201,e+14|0,b|0);c=x[31785];x[31785]=0;ba:{ca:{da:{if((c|0)!=1){A=Ic(e+14|0);c=y[e+14|0];if(c>>>0>239){break da}c=EW((D(c>>>4|0,12)+(c&15)|0)+13|0);break ca}f=N()|0;break B}ea:{switch(c-254|0){case 0:break ca;case 1:break ea;default:break ba}}c=0}v[g|0]=c}v[g+1|0]=y[A|0]}if(t&64){x[31785]=0;c=R(200,b|0)|0;t=x[31785];x[31785]=0;if((t|0)==1){break Y}c=c<<24>>24;v[e+14|0]=c;fa:{if((c|0)<=-64){v[g+2|0]=2;c=c^-128;break fa}v[g+2|0]=1;v[e+13|0]=64;c=y[Ub(e+14|0,e+13|0)|0]}v[g+4|0]=c}ga:{if((d|0)>=0){break ga}x[31785]=0;O(201,e+14|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break X}hD(g,y[e+14|0],y[Ic(e+14|0)|0],0);c=y[g+3|0];ha:{if((c|0)!=10){if((c|0)!=31){if((c|0)!=20){break ga}c=y[g+5|0];if((c&240)!=160|(y[e+248|0]|y[e+249|0]<<8)>>>0>4895){break ga}if((l&65535)>>>0>1){break ha}d=y[(e+k|0)+272|0]&127;if(d>>>0>=16){break ha}ia:{switch(c-160|0){case 0:case 2:v[g+5|0]=d&8?-116:-125;break ga;case 1:case 3:v[g+5|0]=d&8?-125:-116;break ga;default:break ia}}if(c>>>0>167){break ha}v[g+5|0]=136;break ga}c=y[g+5|0];if(c>>>0>15){n=0;break ga}if(c>>>0<=7){q=q+1|0;break ga}o=((c|0)!=8)+o|0;break ga}if(y[g+5|0]|(y[e+248|0]|y[e+249|0]<<8)>>>0>4865){break ga}}v[g+3|0]=37}d=f;continue}}h=h+1|0;continue}break}f=N()|0;break B}f=N()|0;break B}f=N()|0;break B}f=N()|0}kd(r)}kd(m);break c}kd(r);kd(m);tb(j);break b}f=N()|0}tb(j);Q(f|0);p()}d=1}fb=e+304|0;return d|0}function soa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,T=0,V=0;d=fb-480|0;fb=d;xc(b);j=fb-16|0;fb=j;e=d+276|0;pW(j+8|0,e);h=x[j+12>>2];l=b;kc(j,x[b>>2],x[b+8>>2],x[j+8>>2],x[j+12>>2]);b=x[j+4>>2];if((b|0)==(h|0)){Yb(l,x[j+12>>2])}fb=j+16|0;b=(b|0)==(h|0);if(!b){oW(e)}a:{if(!b){break a}if(!qW(d+276|0)){break a}if(!c){n=1;break a}Bd(a,134217728);b=d+8|0;cg(b,3973);x[31785]=0;S(706,d+116|0,b|0,y[d+280|0]|y[d+281|0]<<8);b=x[31785];x[31785]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=d+116|0;yb(a+1298344|0,b);tb(b);Eb(d+8|0);j=uc(b,8994);yb(a+1298356|0,j);tb(j);T=a+1298404|0,V=x[Gc(b,28)>>2],x[T>>2]=V;x[a+480188>>2]=4;T=a,V=Cb(y[d+412|0]|y[d+413|0]<<8),x[T+480196>>2]=V;b=y[d+416|0]|y[d+417|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;T=a,V=nW(Cb(b)),x[T+480204>>2]=V;_v(Wb(x[a+484360>>2],y[a+484376|0]),d+284|0,y[d+282|0]);r=a+480190|0;m=a+480188|0;q=Nb(d+264|0);t=Nb(d+252|0);h:{i:{j:{k:{l:{while(1){if(Cb(y[d+476|0]|y[d+477|0]<<8)>>>0<=(f&65535)>>>0){break k}x[31785]=0;b=R(276,l|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break g}w[d+228>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}n=Cb(y[d+478|0]|y[d+479|0]<<8);if((Cb(y[d+280|0]|y[d+281|0]<<8)|0)==2){x[31785]=0;b=R(284,l|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break h}n=b-2|0}x[31785]=0;S(188,d+8|0,l|0,n|0);b=x[31785];x[31785]=0;if((b|0)==1){break i}b=d+8|0;e=ic(d+116|0,b);ub(b);B=z[se(r,d+228|0)>>1];w[r>>1]=B;x[31785]=0;g=D(z[d+228>>1],104)+a|0;h=g+484380|0;O(282,h|0,1);b=x[31785];x[31785]=0;m:{n:{o:{if((b|0)==1){break o}if(Cb(y[d+280|0]|y[d+281|0]<<8)>>>0>1){break n}x[31785]=0;O(707,e|0,g+484423|0);b=x[31785];x[31785]=0;if((b|0)==1){break o}x[31785]=0;P(186,e|0,1)|0;b=x[31785];x[31785]=0;if((b|0)==1){break o}x[31785]=0;S(334,e|0,((z[d+228>>1]<<5)+a|0)+946304|0,30);b=x[31785];x[31785]=0;if((b|0)!=1){break m}}h=N()|0;break f}b=Fb(d+8|0);x[31785]=0;S(361,e|0,b|0,257);j=x[31785];x[31785]=0;p:{q:{if((j|0)==1){break q}ye(g+484423|0,b);x[31785]=0;P(186,e|0,1)|0;j=x[31785];x[31785]=0;if((j|0)==1){break q}x[31785]=0;S(361,e|0,b|0,31);j=x[31785];x[31785]=0;if((j|0)==1){break q}zc(((z[d+228>>1]<<5)+a|0)+946304|0,b);if(!(v[d+124|0]&1)){break p}x[31785]=0;P(186,e|0,1)|0;j=x[31785];x[31785]=0;if((j|0)!=1){break p}}h=N()|0;tb(b);break f}tb(b)}x[31785]=0;O(708,e|0,d+8|0);b=x[31785];x[31785]=0;if((b|0)==1){break l}k=fb-16|0;fb=k;j=$b(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24));x[h>>2]=j;v[k+15|0]=y[d+12|0];v[k+14|0]=64;T=h,V=y[Ub(k+15|0,k+14|0)|0]<<2,w[T+30>>1]=V;i=$b(y[d+14|0]|y[d+15|0]<<8|(y[d+16|0]<<16|y[d+17|0]<<24));x[h+4>>2]=i;b=$b(y[d+14|0]|y[d+15|0]<<8|(y[d+16|0]<<16|y[d+17|0]<<24))+$b(y[d+18|0]|y[d+19|0]<<8|(y[d+20|0]<<16|y[d+21|0]<<24))|0;x[h+8>>2]=b;if(i>>>0>=j>>>0){i=j-1|0;x[h+4>>2]=i}if(b>>>0>j>>>0){x[h+8>>2]=j;b=j}r:{if(b>>>0<i>>>0){x[h+4>>2]=0;x[h+8>>2]=0;break r}if(b>>>0<=i>>>0){break r}w[h+34>>1]=z[h+34>>1]|2;T=wb(h+68|0,0),V=i,x[T>>2]=V}fb=k+16|0;s:{t:{u:{switch(Cb(y[d+280|0]|y[d+281|0]<<8)|0){case 2:v[g+484417|0]=y[d+26|0]<<3;break;case 0:break t;default:break u}}x[31785]=0;O(213,t|0,B|0);b=x[31785];x[31785]=0;if((b|0)==1){break l}x[31785]=0;O(709,q|0,B|0);b=x[31785];x[31785]=0;if((b|0)==1){break l}j=Dd(x[q>>2],z[d+228>>1]-1|0);kW(j);x[31785]=0;b=R(276,l|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break j}h=x[l+8>>2];k=x[l>>2];x[31785]=0;h=U(153,k|0,h|0,b<<3)|0;k=x[31785];x[31785]=0;if((k|0)==1){break j}if(!h){break s}x[31785]=0;O(710,j|0,b|0);h=x[31785];x[31785]=0;if((h|0)==1){break j}n=0;x[d+248>>2]=0;if(!(!(y[g+484414|0]&2)|b)){b=x[g+484384>>2];x[d+240>>2]=b;h=x[g+484388>>2];x[31785]=0;x[d+244>>2]=h-b;O(711,j|0,d+240|0);b=x[31785];x[31785]=0;if((b|0)!=1){break t}h=N()|0;break f}while(1){if(b>>>0<=(n&65535)>>>0){break t}x[31785]=0;h=R(284,l|0)|0;g=x[31785];x[31785]=0;v:{if((g|0)==1){break v}x[31785]=0;x[d+240>>2]=h;h=R(284,l|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break v}x[31785]=0;x[d+244>>2]=h;O(711,j|0,d+240|0);h=x[31785];x[31785]=0;if((h|0)==1){break v}n=n+1|0;continue}break}h=N()|0;break f}ub(e);f=f+1|0;continue}break}ub(e);break c}h=N()|0;break f}w:{x:{y:{z:{if(Cb(y[d+280|0]|y[d+281|0]<<8)){u=y[d+283|0];w[d+238>>1]=4;C=128;break z}x[31785]=0;C=R(276,l|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){h=N()|0;break e}b=y[d+280|0]|y[d+281|0]<<8;u=y[d+283|0];w[d+238>>1]=4;if(!Cb(b)){break y}}j=x[l+8>>2];h=0;while(1){A:{if((h&65535)>>>0>=C>>>0){break A}x[31785]=0;b=R(276,l|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break x}if((b|0)==65535){break A}x[31785]=0;u=R(276,l|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break x}x[31785]=0;b=R(276,l|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break x}w[d+238>>1]=b;if(b>>>0>127){break c}T=m,V=z[se(m,d+238|0)>>1],w[T>>1]=V;x[31785]=0;P(186,l|0,D(b,u)<<2)|0;b=x[31785];x[31785]=0;if((b|0)==1){break x}h=h+1|0;continue}break}x[31785]=0;P(152,l|0,j|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break w}}b=z[m>>1];x[31785]=0;E=P(712,d+240|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){J=a+484344|0;M=c&1;F=Cb(y[d+414|0]|y[d+415|0]<<8);b=0;j=0;while(1){B:{C:{D:{E:{if((b&65535)>>>0>=C>>>0){break E}F:{if(!Cb(y[d+280|0]|y[d+281|0]<<8)){n=z[d+238>>1];h=b;break F}x[31785]=0;h=R(276,l|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break B}if((h|0)==65535){break E}x[31785]=0;u=R(276,l|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break B}x[31785]=0;n=R(276,l|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break B}w[d+238>>1]=n}e=x[l+8>>2];g=x[l>>2];x[31785]=0;f=e;G=u&65535;e=G<<2;g=U(153,g|0,f|0,D(e,n&65535)|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break B}if(!g){break E}if(!M){break D}x[31785]=0;K=h&65535;h=U(199,J|0,K|0,G|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break B}if(!h){break D}s=0;G:while(1){if((s|0)==(G|0)){break C}h=Vb(x[J>>2],K);Ve(d+228|0,x[h>>2],x[x[h+48>>2]+12>>2],s);h=0;H=0;n=0;H:{I:{J:{switch((F&3)-1|0){case 0:n=!(s&3);break I;case 1:n=!(s&1);break I;case 2:break J;default:break H}}n=(s&3)!=3}}while(1){if(z[d+238>>1]<=h>>>0){s=s+1|0;continue G}e=x[E>>2];g=Vc(x[d+228>>2],h);x[31785]=0;O(360,d+224|0,l|0);f=x[31785];x[31785]=0;if((f|0)==1){break B}k=D(h,9)+e|0;e=d+224|0;f=Ic(e);o=Ze(e);v[g+1|0]=y[d+224|0];i=y[f|0];v[g|0]=i;f=y[cj(e)|0];v[g+5|0]=f;m=g+5|0;if(i){v[g|0]=i+25;v[k+8|0]=0;v[k|0]=0;v[k+1|0]=0;v[k+2|0]=0;v[k+3|0]=0;v[k+4|0]=0;v[k+5|0]=0;v[k+6|0]=0;v[k+7|0]=0;f=y[g+5|0]}i=f&255;o=y[o|0];K:{L:{if(o>>>0>=240){e=i|(o&15)<<8;if(e){v[g+3|0]=17;T=g,V=Zl(+(nW(e)>>>0)/1e4),v[T+5|0]=V;i=0;break K}break L}I=i>>>4|0;L=i<<4;e=I|L;M:{switch(o|0){case 0:if(f&255){v[g+3|0]=1;i=0;break K}break L;case 1:v[g+3|0]=2;i=0;break K;case 2:v[g+3|0]=3;i=0;break K;case 3:v[d+220|0]=15;T=k,V=y[Ub(m,d+220|0)|0]|16,v[T|0]=V;v[k+7|0]=0;v[k+1|0]=0;v[k+2|0]=0;break L;case 4:v[d+220|0]=15;T=k,V=y[Ub(m,d+220|0)|0]|32,v[T|0]=V;v[k+7|0]=0;v[k+1|0]=0;v[k+2|0]=0;break L;case 5:v[k+7|0]=0;v[k+2|0]=0;v[k+1|0]=f;v[k|0]=0;break L;case 6:v[k+7|0]=0;v[k+2|0]=f;v[k|0]=0;v[k+1|0]=0;break L;case 7:v[g+3|0]=23;i=0;j=0;break K;case 8:v[g+3|0]=0;i=1;j=e;break K;case 9:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Ub(m,d+220|0)|0]|16,v[T+5|0]=V;i=0;break K;case 10:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Ub(m,d+220|0)|0]|32,v[T+5|0]=V;i=0;break K;case 11:v[k+3|0]=e;break L;case 12:v[g+4|0]=f;i=1;v[g+2|0]=1;v[k+3|0]=0;v[g+3|0]=0;break K;case 13:N:{O:{if((f&255)>>>0>=16){v[g+2|0]=4;f=(f&240)>>>4|0;break O}if(!(i&15)){break N}v[g+2|0]=3}v[g+4|0]=f}v[k+3|0]=0;break L;case 14:v[g+3|0]=19;v[g+5|0]=!(f&255);i=0;break K;case 15:v[g+3|0]=16;v[g+5|0]=(f&240)>>>4;F=f&15;i=0;break K;case 16:v[k+5|0]=0;v[k+4|0]=f;break L;case 17:v[k+6|0]=i&15?f:0;break L;case 18:v[g+3|0]=14;i=0;break K;case 19:v[k+8|0]=0;v[k+7|0]=f;v[k+2|0]=0;v[k|0]=0;v[k+1|0]=0;break L;case 20:v[g+3|0]=12;i=0;break K;case 22:e=y[g+1|0];P:{if(!e){break P}i=x[q>>2];if(Qd(i,x[q+4>>2])>>>0<e>>>0){break P}f=f-1|0;v[m|0]=f;x[31785]=0;R(713,d+116|0)|0;o=x[31785];x[31785]=0;if((o|0)==1){break B}x[d+220>>2]=9;e=Dd(i,e-1|0);T=d,V=Qd(x[e>>2],x[e+4>>2]),x[T+112>>2]=V;if(A[Gb(d+220|0,d+112|0)>>2]<=(f&255)>>>0){break P}v[g+2|0]=15;v[g+4|0]=y[g+5|0]}break L;case 23:e=y[g+1|0];Q:{if(!e){break Q}i=x[q>>2];if(Qd(i,x[q+4>>2])>>>0<e>>>0){break Q}f=f-1|0;v[m|0]=f;e=Dd(i,e-1|0);i=x[e>>2];o=Qd(i,x[e+4>>2]);e=f&255;if(o>>>0<=e>>>0){break Q}e=Dd(i,e);f=z[e+8>>1];R:{if(f){break R}f=0;i=z[r>>1];if(!si(i)){break R}f=i+1|0;w[r>>1]=f;w[e+8>>1]=f}v[g+1|0]=f}break L;case 24:e=y[g+1|0];S:{if(!e){break S}i=x[q>>2];if(Qd(i,x[q+4>>2])>>>0<e>>>0){break S}f=f-1|0;v[m|0]=f;x[31785]=0;R(713,d+8|0)|0;o=x[31785];x[31785]=0;if((o|0)==1){break B}x[d+220>>2]=9;e=Dd(i,e-1|0);T=d,V=Qd(x[e>>2],x[e+4>>2]),x[T+112>>2]=V;if(A[Gb(d+220|0,d+112|0)>>2]>(f&255)>>>0){v[g+2|0]=15;v[g+4|0]=y[g+5|0]}e=_b(x[t>>2],y[g+1|0]-1|0);f=z[e>>1];T:{if(f){break T}f=0;i=z[r>>1];if(!si(i)){break T}f=i+1|0;w[r>>1]=f;w[e>>1]=f}v[g+1|0]=f}break L;case 25:e=y[g+1|0];U:{if(!e){break U}i=x[q>>2];if(Qd(i,x[q+4>>2])>>>0<e>>>0){break U}f=f-1|0;v[m|0]=f;e=Dd(i,e-1|0);i=x[e>>2];o=Qd(i,x[e+4>>2]);e=f&255;if(o>>>0<=e>>>0){break U}e=Dd(i,e);f=z[e+10>>1];V:{if(f){break V}f=0;i=z[r>>1];if(!si(i)){break V}f=i+1|0;w[r>>1]=f;w[e+10>>1]=f}v[g+1|0]=f}break L;case 29:v[g+5|0]=e;v[g+3|0]=11;if(i&15){v[m|0]=L|15;i=0;break K}i=0;if((f&255)>>>0<16){break K}v[m|0]=I|240;break K;case 32:if((f&255)>>>0>=16){v[k+3|0]=I;break L}v[g+3|0]=19;v[g+5|0]=f|192;i=0;break K;case 33:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Ub(m,d+220|0)|0]|208,v[T+5|0]=V;i=0;break K;case 34:v[g+3|0]=19;v[d+220|0]=15;T=g,V=y[Ub(m,d+220|0)|0]|144,v[T+5|0]=V;i=0;break K;case 73:v[g+3|0]=10;i=0;break K;case 78:if((f&112|128)==224){v[g+3|0]=19;i=0;break K}break L;case 79:if((f&255)>>>0<=31){v[g+3|0]=16;i=0;F=0;break K}v[g+3|0]=17;i=0;break K;default:break M}}}v[g+3|0]=0;i=1}o=0;e=y[k+3|0];if(!(y[g+2|0]|!e)){f=e;o=e>>>4|0;e=e>>>0<16;v[g+4|0]=e?f:o;v[g+2|0]=e?6:5;o=1}W:{if(!i){break W}f=y[k+1|0];X:{if(f){v[g+3|0]=2;break X}f=y[k+2|0];if(f){v[g+3|0]=3;break X}f=y[k|0];if(f){v[g+3|0]=19;break X}f=y[k+7|0];if(f){v[g+3|0]=4;v[k+8|0]=f;break X}f=y[k+4|0];if(f){v[g+3|0]=5;v[k+5|0]=f;break X}if(!(!y[k+3|0]|o)){v[g+3|0]=11;e=y[k+3|0];v[g+5|0]=e;if(e&15){f=e|-16;break X}if(e>>>0<16){break W}f=e|15;break X}f=y[k+6|0];if(f){v[g+3|0]=8;break X}if(n){v[g+3|0]=20;n=0;f=97;break X}n=0;e=j&255;if(!e|H){break W}v[g+5|0]=j;v[g+3|0]=24;if(j&15){f=j|-16}else{H=1;if(e>>>0<16){break W}f=j|15}H=1}v[m|0]=f}h=h+1|0;continue}}}x[a+480228>>2]=256/z[a+480188>>1];i=1;Ch(a,1);if(Cb(y[d+280|0]|y[d+281|0]<<8)){Y:{while(1){b=x[l+8>>2];j=x[l>>2];x[31785]=0;b=U(153,j|0,b|0,2)|0;j=x[31785];x[31785]=0;if((j|0)==1){break B}if(!b){break Y}x[31785]=0;b=R(276,l|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break B}if((b|0)==65535){break Y}x[31785]=0;P(186,l|0,2)|0;b=x[31785];x[31785]=0;if((b|0)==1){break B}x[31785]=0;b=R(284,l|0)|0;j=x[31785];x[31785]=0;if((j|0)!=1){x[31785]=0;P(186,l|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}break B}x[31785]=0;P(186,l|0,34)|0;b=x[31785];x[31785]=0;if((b|0)==1){break B}}Z:{if(!(c&2)){break Z}while(1){b=i&65535;if(b>>>0>B>>>0){break Z}_:{h=(D(b,104)+a|0)+484380|0;if(!x[h>>2]){break _}c=ad(d+228|0,8,1,0,0);x[31785]=0;U(218,c|0,h|0,l|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break B}c=x[q>>2];if(Qd(c,x[q+4>>2])>>>0<b>>>0){break _}k=b-1|0;g=Dd(c,k);c=0;b=0;n=fb-112|0;fb=n;$:{f=x[h>>2];if(!ge(f,x[h+20>>2])){break $}r=x[g>>2];j=Qd(r,x[g+4>>2]);if(j>>>0<2){break $}e=Oo(n+8|0,h);x[e+20>>2]=0;x[e>>2]=0;aa:{while(1){if((c|0)==(j|0)){break aa}ba:{m=Dd(r,c);s=x[m>>2];if(s>>>0>=f>>>0){break ba}m=x[m+4>>2];if(m>>>0>f-s>>>0|268435456-m>>>0<b>>>0){break ba}b=b+m|0;x[e>>2]=b;c=c+1|0;continue}break}j=c}if(!Bh(e)){break $}m=e+68|0;b=0;c=0;while(1){if((c|0)==(j|0)){hn(h);b=Oo(h,e);x[b+4>>2]=0;x[b+8>>2]=x[b>>2];w[b+34>>1]=z[b+34>>1]|2;break $}o=x[e+20>>2]+b|0;r=x[h+20>>2];f=Dd(x[g>>2],c);yc(o,r+x[f>>2]|0,x[f+4>>2]);x[f>>2]=b;if(c-10>>>0>=4294967287){T=wb(m,c-1|0),V=b,x[T>>2]=V}c=c+1|0;b=x[f+4>>2]+b|0;continue}}fb=n+112|0;b=z[_b(x[t>>2],k)>>1];if(b){iC(h,(D(b,104)+a|0)+484380|0,0,x[h>>2],0)}b=Dd(x[q>>2],k);T=d,V=vb(x[b>>2]),x[T+228>>2]=V;c=vb(x[b+4>>2]);while(1){b=x[d+228>>2];if(!Ib(b,c)){break _}j=z[b+8>>1];if(j){iC(h,(D(j,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],1)}j=z[b+10>>1];if(j){iC(h,(D(j,104)+a|0)+484380|0,x[b>>2],x[b+4>>2],0)}Uq(d+228|0);continue}}i=i+1|0;continue}}mW(E);n=1;break b}x[31785]=0;P(186,l|0,D(e,z[d+238>>1])|0)|0;h=x[31785];x[31785]=0;if((h|0)!=1){break C}break B}b=b+1|0;continue}break}h=N()|0;mW(E);break e}h=N()|0;break e}h=N()|0;break e}h=N()|0;break e}h=N()|0;break f}h=N()|0;break e}h=N()|0;break e}h=N()|0;Eb(d+8|0);break d}h=N()|0;break e}ub(e)}kd(t);lW(q)}Q(h|0);p()}n=0}kd(t);lW(q)}fb=d+480|0;return n|0}function $Q(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=fb-16|0;fb=n;a:{if((Nf(x[x[a+48>>2]+12>>2])|0)!=(Nf(x[x[b+48>>2]+12>>2])|0)){break a}if((a|0)!=(b|0)){c=fb-16|0;fb=c;h=x[b>>2];d=x[b+4>>2];g=Jk(h,d);b:{if(Tv(a)>>>0>=g>>>0){f=d;i=x[a>>2];e=Jk(i,x[a+4>>2]);o=e>>>0>=g>>>0;if(!o){x[c+12>>2]=h;x[c+12>>2]=x[c+12>>2]+D(e,6);f=x[c+12>>2]}k=fb-16|0;fb=k;q=k+8|0;e=fb-32|0;fb=e;Vl(e+24|0,h,f);j=fb-16|0;fb=j;p=x[e+28>>2];m=x[e+24>>2];l=p-m|0;if((m|0)!=(p|0)){ai(i,m,l)}l=D((l|0)/6|0,6);x[j+12>>2]=l+i;Td(e+16|0,l+m|0,j+12|0);fb=j+16|0;h=Sq(h,x[e+16>>2]);r=e,s=Sq(i,x[e+20>>2]),x[r+12>>2]=s;Td(q,h,e+12|0);fb=e+32|0;e=x[k+12>>2];fb=k+16|0;if(!o){du(a,f,d,g-Jk(x[a>>2],x[a+4>>2])|0);break b}cD(a,e);break b}aR(a);gZ(a,_C(a,g));du(a,h,d,g)}fb=c+16|0}x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=x[b+20>>2];_Q(a+24|0,b+24|0);fw(a+36|0,b+36|0);if(x[x[x[a+48>>2]+12>>2]+480180>>2]==x[x[x[b+48>>2]+12>>2]+480180>>2]){break a}c=vb(x[a>>2]);x[n+12>>2]=c;m=vb(x[a+4>>2]);while(1){if(!Ib(c,m)){break a}d=0;g=fb-112|0;fb=g;k=x[x[a+48>>2]+12>>2];e=x[k+480180>>2];h=x[x[x[b+48>>2]+12>>2]+480180>>2];c:{if((e|0)==(h|0)){break c}f=y[c+3|0];d:{e:{if((e|0)!=16){break e}i=y[c+5|0];if(!((f|0)!=19|(i|0)!=144)){v[c+3|0]=0;e=1;break d}d=5;e=1;if((f|0)!=5){break e}v[c+5|0]=i>>>1&7|i&240;break d}if(!((h|0)==67108864|(f|0)!=45)){v[c+5|0]=159;d=20;v[c+3|0]=20;break d}if((f|0)!=46){d=f;break d}d=13;v[c+3|0]=13;v[c+5|0]=y[c+5|0]+3>>>2}l=(e|0)==32|(e|0)==16777216|(e|0)==2;f:{g:{h:{i:{j:{k:{if((h|0)==2){f=9;j=1;i=wD(2);if((d&255)!=9){break k}v[c+5|0]=y[c+5|0]+1>>>1;break h}j=(h|0)==32|(h|0)==16777216;f=9;i=wD(h);if((d&255)!=9){break k}if((e|0)!=2){break h}f=y[c+5|0];if((f|0)!=164){break j}v[c+5|0]=145;d=h&16777248?20:28;v[c+3|0]=d;break g}if((d&255)!=32){f=d;break h}d=x[i+84>>2];if(Zi(d,32)){break i}f=31;if(!Zi(d,31)){break i}v[c+3|0]=31;break h}r=c,s=ej(f<<1),v[r+5|0]=s;break g}f=32}l:{if((e|0)==16777216){d=y[c|0];m:{if(!Sg(d)){d=f;break m}j=x[i+84>>2];d=(d|0)==252?31:32;if(!Zi(j,d)){d=Zi(j,31)?31:0}w[g+4>>1]=999;r=g,s=Hj(f,y[c+5|0]),w[r+110>>1]=s;r=c,s=(D(z[Mc(g+4|0,g+110|0)>>1],127)>>>0)/999|0,v[r+5|0]=s;v[c+2|0]=0;v[c+3|0]=d;v[c|0]=0;v[c+1|0]=0}n:{o:{p:{f=d&255;switch(f-33|0){case 1:break g;case 2:case 3:break n;case 0:break o;default:break p}}if((f|0)!=20){break g}d=y[c+5|0];if((d&240)!=112|(d&15)>>>0<13){break l}v[c+5|0]=124;break l}d=20;v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>4|208;break g}q:{j=v[c+5|0];r:{if((j|0)>=0){v[c+3|0]=3;f=-128-j|0;d=3;break r}f=128;if((j|0)==-128){break q}v[c+3|0]=2;f=j^-128;d=2}v[c+5|0]=f;if((f&255)>>>0>30){break q}v[c+5|0]=f+1>>>1|224;break g}v[g+4|0]=(f&255)+7>>>3;v[g+110|0]=15;r=c,s=y[Ub(g+4|0,g+110|0)|0]|240,v[r+5|0]=s;break g}d=f;s:{switch(e-1|0){case 0:case 3:break s;default:break g}}if(!j){break g}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{d=d&255;switch(d-1|0){case 2:break x;case 1:break y;case 0:break B;default:break C}}D:{switch(d-25|0){case 1:case 2:break f;case 4:break u;case 0:break v;case 3:break w;default:break D}}if((d|0)==13){break z}if((d|0)==19){break A}if((d|0)!=37){break f}v[c+3|0]=0;break f}if(y[c+5|0]){break f}v[c+3|0]=0;break f}xr(c);break f}E:{switch(y[c+2|0]){case 0:case 1:v[c+2|0]=1;v[c+3|0]=0;d=y[c+5|0];v[c+5|0]=0;v[c+4|0]=d>>>0>=64?64:d;break f;case 2:break E;default:break f}}og(c+4|0,c+5|0);v[c+2|0]=1;if(y[c+4|0]>=65){v[c+4|0]=64}v[c+3|0]=20;v[c+5|0]=y[c+5|0]>>>2|128;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}if(y[c+5|0]<224){break f}v[c+5|0]=223;break f}d=y[c+5|0];f=(d&240)-16>>>4|0;if(f>>>0>9){break f}if(!(1<<f&880)){if(!f){break t}if((f|0)!=1){break f}v[c+3|0]=3;v[c+5|0]=d&15|224;break f}v[c+3|0]=20;if(!(h&2)|(d|0)!=145){break f}v[c+5|0]=164;v[c+3|0]=9;break f}if(y[c|0]){break f}v[c+3|0]=20;v[c|0]=(h|0)==2?-2:-1;d=y[c+5|0];if(!d){v[c+1|0]=0}v[c+5|0]=d&15|208;break f}d=y[c+5|0];if(d>>>0>=16){v[g+4|0]=14;v[g+110|0]=d>>>4;r=c,s=y[Ub(g+4|0,g+110|0)|0]|240,v[r+5|0]=s;break f}v[g+4|0]=14;v[g+110|0]=d;r=c,s=y[Ub(g+4|0,g+110|0)|0]<<4|15,v[r+5|0]=s;break f}v[c+3|0]=2;v[c+5|0]=d&15|224;break f}d=20}F:{if(!l){break F}G:{switch(h-1|0){case 0:case 3:break G;default:break F}}H:{I:{switch(y[c|0]-253|0){case 1:v[c|0]=0;if(!(d&255?(h|0)==4:0)){v[c+5|0]=0;v[c+3|0]=13;break f}v[c+4|0]=0;v[c+2|0]=1;break H;case 0:break I;default:break H}}v[c|0]=255}J:{K:{L:{M:{N:{O:{P:{Q:{R:{f=d&255;switch(f-2|0){case 2:case 3:case 6:case 7:case 8:case 10:case 11:case 12:case 14:case 16:case 17:break f;case 13:break J;case 15:break L;case 1:break M;case 0:break N;case 9:break O;case 4:case 5:break P;case 18:break Q;default:break R}}if((f|0)!=29){break f}d=y[c+5|0];f=d&15;if((f|0)!=15|d>>>0<16){break K}v[c+5|0]=d>>>4;break f}S:{if(y[c+3|0]!=20){break S}v[c+3|0]=19;T:{U:{V:{W:{X:{Y:{Z:{_:{d=y[c+5|0];switch((d&240)-16>>>4|0){case 4:case 5:case 8:case 9:break T;case 6:break U;case 10:break V;case 7:break W;case 3:break X;case 2:break Y;case 1:break Z;case 0:break _;default:break S}}v[c+5|0]=d&15|48;break S}v[c+5|0]=d&175^120;break S}v[c+5|0]=d&15|64;break S}v[c+5|0]=d&15|112;break S}v[c+3|0]=9;v[c+5|0]=D(d&15,17);break S}v[c+5|0]=d&15|96;break S}v[c+3|0]=0;break S}v[c+3|0]=28}break f}if(y[c+2|0]){break O}f=y[c+5|0];j=f&15;if(!((j|0)==15&f>>>0>=16)&(!j|(f&240)!=240)){break O}f=11;$:{switch((d&255)-6|0){case 1:f=8;case 0:v[c+2|0]=f;break;default:break $}}v[c+4|0]=0}d=y[c+5|0];f=d&15;if(!((f|0)!=15|d>>>0<16)){v[c+3|0]=19;v[c+5|0]=d>>>4|160;break f}if(!f|(d&240)!=240){break f}v[c+5|0]=f|176;v[c+3|0]=19;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&15|16;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+5|0]=d|16;v[c+3|0]=28;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|16;break f}v[c+3|0]=2;break f}d=y[c+5|0];if(d>>>0>=240){v[c+3|0]=19;v[c+5|0]=d&15|32;break f}if(d>>>0>=224){d=d&15;if((h|0)==4){v[c+5|0]=d|32;v[c+3|0]=28;break f}v[c+3|0]=19;v[c+5|0]=d+3>>>2|32;break f}v[c+3|0]=3;break f}if(y[c+5|0]>31){break f}v[c+3|0]=0;break f}if(!(!f|(d&240)!=240)){v[c+5|0]=d<<4;break f}if(f){v[c+5|0]=240;break f}if(d>>>0>=16){v[c+5|0]=15;break f}v[c+5|0]=0;break f}d=y[c+5|0];if((d-1&255)>>>0>14){break f}v[c+5|0]=d|128;break f}if((e|0)!=16777216&(e|0)!=32|(h|0)!=2){break f}aa:{switch(y[c|0]-253|0){case 0:case 2:v[c|0]=254;break;default:break aa}}ba:{switch((d&255)-20|0){case 0:d=y[c+5|0];f=d&240;if((f|0)!=144){if((f|0)!=112){break f}v[c+3|0]=0;break f}ca:{switch(d-144|0){case 1:v[c+5|0]=164;v[c+3|0]=9;break f;case 0:break ca;default:break f}}v[c+5|0]=64;v[c+3|0]=9;break f;case 3:break ba;default:break f}}v[g+4|0]=128;r=c,s=y[Ub(g+4|0,c+5|0)|0]+1>>>1|0,v[r+5|0]=s}da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{if(!((e|0)!=16777216&(e|0)!=32)){if((h|0)!=4){break na}d=y[c+3|0];if((d|0)==23){break ma}if((d|0)!=5){break ka}d=y[c+5|0];v[c+5|0]=(d&15)+1>>>1|d&240;break la}if((e|0)!=4){break na}oa:{switch(h-1|0){case 1:case 2:break ia;case 0:case 3:break la;default:break oa}}if((h|0)!=16777216&(h|0)!=32){break ia}d=y[c+3|0];if((d|0)!=23){if((d|0)!=5){break na}d=y[c+5|0];v[g+4|0]=d<<1&30;v[g+110|0]=15;r=c,s=y[Ub(g+4|0,g+110|0)|0]|d&240,v[r+5|0]=s;break na}v[g+4|0]=64;r=c,s=y[Ub(g+4|0,c+5|0)|0]<<1,v[r+5|0]=s}switch(h-1|0){case 0:case 3:break la;default:break ja}}v[g+4|0]=128;r=c,s=y[Ub(g+4|0,c+5|0)|0]+1>>>1|0,v[r+5|0]=s}d=y[c+3|0]}pa:{switch((d&255)-16|0){case 0:v[g+4|0]=31;r=c,s=y[Ub(c+5|0,g+4|0)|0],v[r+5|0]=s;break ja;case 1:break pa;default:break ja}}v[g+4|0]=32;r=c,s=y[af(c+5|0,g+4|0)|0],v[r+5|0]=s}qa:{if((e|0)!=1){break qa}ra:{sa:{ta:{ua:{va:{wa:{xa:{d=y[c+3|0];switch(d-2|0){case 2:case 3:case 6:case 7:case 8:break qa;case 0:case 1:case 9:break ua;case 5:break va;case 4:break wa;default:break xa}}switch(d-19|0){case 1:break sa;case 0:break ta;default:break qa}}if(y[c+5|0]){break qa}d=4;break ra}if(y[c+5|0]){break qa}d=5;break ra}if(y[c+5|0]){break qa}d=0;break ra}f=y[c+5|0];d=(f<<4|(f<<24)+1610612736>>>28)&255;if(!(d>>>0>8|!(1<<d&387))){v[c+3|0]=0}d=0;if(f>>>0>239){break ra}break qa}d=0;if(y[c+5|0]<240){break qa}}v[c+3|0]=d}if((h|0)!=1){break ia}if(!Cl(y[c|0])){e=y[c+3|0];break ha}v[c|0]=0;e=y[c+3|0];if((e|0)!=19){if(e){break ha}v[c+5|0]=0;e=13;v[c+3|0]=13;break ea}f=y[c+5|0];if((f&240)!=208){break ga}v[c+5|0]=f&15|192;e=19;break ea}d=y[c+3|0];if(!(d|(h|0)!=2)){e=0;ya:{switch(y[c+2|0]-3|0){case 1:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0];e=11;break da;case 0:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;e=11;break da;case 3:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]|240;e=11;break da;case 2:v[c+2|0]=0;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4|15;e=11;break da;case 10:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;e=3;break da;case 9:v[c+2|0]=0;v[c+3|0]=2;e=2;v[c+5|0]=y[c+4|0]<<2;break da;case 8:v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;e=4;break da;case 5:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0];e=5;break da;case 4:v[c+2|0]=0;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4;e=5;break da;case 6:v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0]<<4;e=29;break da;case 7:break ya;default:break da}}v[c+2|0]=0;v[c+3|0]=29;v[c+5|0]=y[c+4|0];e=29;break da}if((h|0)==4){e=19;za:{if((d&255)!=19){f=y[c|0];e=d;break za}f=y[c|0];if(f|(y[c+5|0]&240)!=208){break za}e=0;v[c+5|0]=0;v[c+3|0]=0;f=0}Aa:{if(Cl(f)){v[c+1|0]=0;d=e&255;if(!d){break Aa}if((d|0)!=19){break da}e=19;d=y[c+5|0];if((d&240)!=208){break da}v[c|0]=0;v[c+5|0]=d&15;e=25;v[c+3|0]=25;break da}if(e&255){break da}}e=0;Ba:{switch(y[c+2|0]-11|0){case 2:v[c+2|0]=0;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;e=3;break da;case 1:v[c+2|0]=0;v[c+3|0]=2;e=2;v[c+5|0]=y[c+4|0]<<2;break da;case 0:break Ba;default:break da}}v[c+2|0]=0;v[c+3|0]=4;v[c+5|0]=y[(y[c+4|0]&15)+42448|0];e=4;break da}Ca:{if((h|0)!=16777216&(h|0)!=32){break Ca}Da:{if(d&255|((e|0)==32|(e|0)==16777216)){break Da}d=0;Ea:{Fa:{switch(y[c+2|0]-7|0){case 2:v[c+3|0]=29;f=y[c+4|0]<<4;d=29;break Ea;case 3:v[c+3|0]=29;f=y[c+4|0];d=29;break Ea;case 0:v[c+3|0]=5;f=y[c+4|0]<<4;d=5;break Ea;case 4:break Fa;default:break Da}}v[c+3|0]=4;f=y[c+4|0]<<4;d=4}v[c+2|0]=0;v[c+5|0]=f}f=y[c+2|0];if(f>>>0>15|!(1<<f&47480)){break Ca}v[g+4|0]=9;r=c,s=y[Ub(c+4|0,g+4|0)|0],v[r+4|0]=s}e=d;break da}Ga:{Ha:{Ia:{d=e&255;switch(d-15|0){case 4:break Ga;case 0:break Ha;case 1:case 2:case 3:break ea;default:break Ia}}if(!d){break fa}break ea}e=19;v[c+3|0]=19;v[c+5|0]=y[c+5|0]&15|144;break ea}f=y[c+5|0]}e=19;if(f>>>0<240){break ea}v[c+3|0]=0}e=0;Ja:{switch(y[c+2|0]-1|0){case 0:e=13;v[c+3|0]=13;v[c+5|0]=y[c+4|0];break ea;case 1:e=9;v[c+3|0]=9;d=y[c+4|0];v[c+5|0]=d>>>0>=64?-1:d<<2;break ea;case 3:e=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0];break ea;case 2:e=11;v[c+3|0]=11;v[c+5|0]=y[c+4|0]<<4;break ea;case 5:e=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|176;break ea;case 4:e=19;v[c+3|0]=19;v[c+5|0]=y[c+4|0]|160;break ea;case 12:e=3;v[c+3|0]=3;v[c+5|0]=y[c+4|0]<<2;break ea;case 11:e=2;v[c+3|0]=2;v[c+5|0]=y[c+4|0]<<2;break ea;case 10:e=4;v[c+3|0]=4;v[c+5|0]=y[c+4|0]<<2;break ea;case 7:e=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0];break ea;case 6:break Ja;default:break ea}}e=5;v[c+3|0]=5;v[c+5|0]=y[c+4|0]<<4}v[c+2|0]=0}Ka:{if(y[c+2|0]!=15){break Ka}if(Lv(x[i+88>>2],15)){break Ka}d=e&255;if(!(!d|(d|0)==10)){if(Zi(x[i+84>>2],e&255)){break Ka}}v[c+2|0]=0;v[c+3|0]=10;La:{Ma:{e=y[c+1|0];if(!e){break Ma}f=y[c+5|0];if(z[k+480192>>1]>=e>>>0){h=y[c|0];Na:{if(!zd(h)){break Na}j=x[(k+(e<<2)|0)+900380>>2];if(!j){break Na}e=z[_b(j+236|0,h-1|0)>>1]}if(!(e&65535)){break Ma}}if(z[k+480190>>1]<(e&65535)>>>0){break Ma}h=y[c+4|0];Kv(g+4|0);if(h>>>0>9){break Ma}d=(d|0)==10?f:0;f=ri(k,e&65535);e=y[c+4|0];if(!e){f=sua(x[f>>2],0,d&255,0);d=hb;f=f+32768|0;d=f>>>0<32768?d+1|0:d;d=ej(Bc((d&65535)<<16|f>>>16,d>>>16|0));break La}d=ej((x[wb(f+68|0,e-1|0)>>2]+((d&255)<<8)|0)+128>>>8|0);break La}d=y[c+4|0]<<3}v[c+5|0]=d;e=y[c+3|0]}Oa:{Pa:{d=e&255;switch(d-42|0){case 0:case 2:break Pa;default:break Oa}}if(Zi(x[i+84>>2],d)){break Oa}e=10;v[c+3|0]=10}f=y[c|0];Qa:{if(f>>>0>=y[i+8|0]){d=1;if(f>>>0<=y[i+9|0]){break Qa}}if(Cl(f)){Ra:{switch(f-253|0){case 1:d=y[i+70|0]!=0;break Qa;case 2:d=y[i+71|0]!=0;break Qa;case 0:d=y[i+72|0]!=0;break Qa;default:break Ra}}d=x[i>>2]==16777216;break Qa}d=!f}if(!d){v[c|0]=0}if(!Zi(x[i+84>>2],e&255)){v[c+3|0]=0}if(Lv(x[i+88>>2],y[c+2|0])){break c}v[c+2|0]=0}fb=g+112|0;c=x[ah(n+12|0)>>2];continue}}fb=n+16|0;return a}function zna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;d=fb-576|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!iD(b,d+496|0)){break l}if(!iV(d+496|0)){break l}if(!Mb(x[b>>2],x[b+8>>2],Bc(hV(d+496|0),hb))){break l}if(!c){e=1;break l}Bd(a,4);ag(a);v[a+1074368|0]=4;k=Fb(d+484|0);l=d+534|0;m:{if(!(Ob(l,18617,20)|(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))!=276)){q=41384;e=48;if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break m}e=jD(d+513|0,0,20)?1154:34;break m}q=41384;if(!Ob(l,18596,20)){e=1;break m}f=d+104|0;Zj(f,3,l);x[31785]=0;S(372,d+192|0,4,f|0);f=x[31785];x[31785]=0;n:{if((f|0)!=1){f=d+192|0;yb(k,f);tb(f);if(Ob(l,18434,8)){break n}e=1048;break m}b=N()|0;break a}if(!Ob(l,18334,12)){e=16;if(!Ob(d+546|0,18638,8)){break m}v[a+1074368|0]=5;break m}if(!Ob(l,11678,20)){e=48;break m}if(!Ob(l,25696,15)){x[31785]=0;f=P(270,a+1074312|0,54)|0;e=x[31785];x[31785]=0;if((e|0)==1){break b}x[31785]=0;P(270,f|0,51)|0;f=x[31785];x[31785]=0;if((f|0)==1){break b}q=41376;e=16;break m}o:{if(Ob(l,25712,14)){if(Ob(l,25727,14)){break o}}x[31785]=0;f=P(270,a+1074312|0,57)|0;e=x[31785];x[31785]=0;if((e|0)==1){break b}x[31785]=0;P(270,f|0,51)|0;f=x[31785];x[31785]=0;e=16;if((f|0)!=1){break m}break b}e=Ob(l,18422,11)?16:256}f=d+104|0;u=d+513|0;Zj(f,3,u);x[31785]=0;O(221,d+192|0,f|0);f=x[31785];x[31785]=0;p:{q:{r:{s:{t:{if((f|0)!=1){f=d+192|0;yb(a+1298308|0,f);tb(f);x[a+480260>>2]=1;x[a+480264>>2]=31999;_e(Wb(x[a+484360>>2],y[a+484376|0]),y[d+562|0]|y[d+563|0]<<8);w[a+480188>>1]=y[d+564|0]|y[d+565|0]<<8;w[d+192>>1]=y[d+568|0]|y[d+569|0]<<8;w[d+104>>1]=255;H=a+480192|0,I=z[Mc(f,d+104|0)>>1],w[H>>1]=I;f=y[d+572|0]|y[d+573|0]<<8;if(f){x[a+480196>>2]=f}f=y[d+574|0]|y[d+575|0]<<8;if(f){f=D(f,1e4);f=f>>>0>=1e7?1e7:f;x[a+480204>>2]=f>>>0<=32e4?32e4:f}f=y[d+570|0]|y[d+571|0]<<8;x[a+480208>>2]=f<<4&16|f<<3&32768;g=y[a+484376|0];m=x[a+484360>>2];x[31785]=0;aa(351,Wb(m,g)|0,b|0,y[d+560|0]|y[d+561|0]<<8,65535,65535);g=x[31785];x[31785]=0;if((g|0)==1){break b}g=f>>>12&1?(e|0)==34?146:e:e;if(!(y[d+560|0]|y[d+561|0]<<8|g>>>0>1023)){f=y[a+484376|0];e=x[a+484360>>2];x[31785]=0;W(767,Wb(e,f)|0);f=x[31785];x[31785]=0;if((f|0)==1){break b}}x[31785]=0;P(152,b|0,(y[d+556|0]|y[d+557|0]<<8|(y[d+558|0]<<16|y[d+559|0]<<24))+60|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break b}if((y[d+554|0]|y[d+555|0]<<8)>>>0>=260){x[31785]=0;S(768,b|0,d+496|0,a|0);f=x[31785];x[31785]=0;if((f|0)==1){break b}}v[d+483|0]=0;B=c&2;F=d+122|0;n=d+225|0;m=Nb(d+468|0);G=a+480192|0;r=1;f=-1;while(1){e=r&65535;if(e>>>0>z[G>>1]){if(!(!(g&2)|s&255)){g=jD(u,0,20)?g|16:g}if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){break r}if(c&3){x[31785]=0;S(768,b|0,d+496|0,a|0);c=x[31785];x[31785]=0;if((c|0)==1){break q}}if(!B){break r}n=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>z[n>>1]){break r}i=x[m>>2];x[31785]=0;U(218,wb(i,c-1|0)|0,(D(c,104)+a|0)+484380|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}x[31785]=0;i=R(154,b|0)|0;h=x[31785];x[31785]=0;u:{v:{if((h|0)!=1){Eh(b,4);x[31785]=0;S(769,b|0,d+192|0,(i?i:263)|0);i=x[31785];x[31785]=0;if((i|0)==1){break s}w:{if((g|0)==1){i=x[d+192>>2];if((i|0)!=263){g=16;if((i|0)!=245){break w}x[a+1074308>>2]=16777381;x[31785]=0;g=P(1,d+180|0,13442)|0;i=x[31785];x[31785]=0;if((i|0)!=1){yb(k,g);tb(g);g=17;break w}b=N()|0;break c}x[a+1074308>>2]=16777395;x[31785]=0;g=P(1,d+168|0,13357)|0;i=x[31785];x[31785]=0;if((i|0)!=1){yb(k,g);tb(g);g=17;break w}b=N()|0;break c}if(y[d+219|0]|y[d+220|0]<<8){break w}i=x[d+192>>2];if(!(!(g&2)|(y[d+221|0]|y[d+222|0]<<8|(y[d+223|0]<<16|y[d+224|0]<<24))|(i|0)!=263)){g=g|16;break w}if(!(!(g&256)|(i|0)==29)){g=g&-257;break w}if(!(g&160)){break w}g=(i|0)==33?g:0}x[31785]=0;i=U(254,a|0,e|0,0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break s}if(!i){break u}i=((e<<2)+a|0)+900380|0;e=x[i>>2];x[31785]=0;O(770,d+192|0,e|0);e=x[31785];x[31785]=0;if((e|0)==1){break s}e=y[d+218|0];x:{if((f|0)==-1){f=e;break x}if(!(g&32)|(e|0)==(f|0)){break x}g=g&-161|128}e=y[d+219|0]|y[d+220|0]<<8;if(!e){break u}x[31785]=0;h=y[d+439|0];j=y[d+435|0]|y[d+436|0]<<8;o=y[d+434|0];t=y[d+433|0];S(771,d+156|0,a|0,e|0);e=x[31785];x[31785]=0;if((e|0)==1){break t}g=h|(j|(o|t))?g&-4:g;i=x[i>>2]+236|0;e=12;h=x[d+156>>2];j=Xc(h,x[d+160>>2]);y:{while(1){z:{if((e|0)==108){if((y[d+554|0]|y[d+555|0]<<8)>>>0>259){Gf(m)}e=0;x[31785]=0;i=P(772,d+144|0,y[d+219|0]|y[d+220|0]<<8)|0;h=x[31785];x[31785]=0;if((h|0)!=1){break z}b=N()|0;break y}if(j>>>0>z[_b(i,e)>>1]){o=z[_b(h,z[_b(i,e)>>1])>>1];H=_b(i,e),I=o,w[H>>1]=I}e=e+1|0;continue}break}A:{B:{C:{D:{while(1){h=y[d+219|0]|y[d+220|0]<<8;if(e>>>0>=h>>>0){e=0;if((y[d+554|0]|y[d+555|0]<<8)>>>0<=259){break v}E:{while(1){if(e>>>0>=h>>>0){break v}j=y[wb(x[m>>2],e)+3|0];h=x[wb(x[i>>2],e)>>2];x[31785]=0;S(188,d+72|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=x[31785];x[31785]=0;if((h|0)!=1){j=d+72|0;h=ic(d+104|0,j);ub(j);j=x[d+156>>2];if(!(!B|Xc(j,x[d+160>>2])>>>0<=e>>>0)){o=z[_b(j,e)>>1];j=wb(x[m>>2],e);j=y[j|0]|y[j+1|0]<<8|(y[j+2|0]<<16|y[j+3|0]<<24);x[31785]=0;x[d+68>>2]=j;x[d+8>>2]=j;j=ba(773,(D(o,104)+a|0)+484380|0,d+8|0,h|0,d+483|0)|0;o=x[31785];x[31785]=0;if((o|0)==1){break E}C=j^1|C}ub(h);e=e+1|0;h=y[d+219|0]|y[d+220|0]<<8;continue}break}b=N()|0;break A}b=N()|0;ub(h);break A}x[31785]=0;O(774,b|0,d+104|0);h=x[31785];x[31785]=0;if((h|0)==1){break B}h=d+72|0;j=y[d+118|0];F:{if(!(j&48|y[d+121|0]!=173)){ad(h,8,1,0,10);break F}ad(h,j&16?16:8,j&32?3:1,0,2)}x[31785]=0;O(775,m|0,h|0);h=x[31785];x[31785]=0;if((h|0)!=1){H=wb(x[i>>2],e),I=x[d+104>>2],x[H>>2]=I;o=y[d+121|0];h=x[d+156>>2];if(Xc(h,x[d+160>>2])>>>0>e>>>0){j=z[_b(h,e)>>1];x[31785]=0;h=(D(j,104)+a|0)+484380|0;O(776,d+104|0,h|0);t=x[31785];x[31785]=0;if((t|0)==1){break D}v[h+38|0]=y[n+202|0];v[h+39|0]=y[n+203|0];v[h+40|0]=y[n+204|0];v[h+41|0]=y[n+205|0];h=d+92|0;im(h,3,F);x[31785]=0;O(221,d+72|0,h|0);h=x[31785];x[31785]=0;if((h|0)==1){break C}h=d+72|0;zc(((j<<5)+a|0)+946304|0,h);tb(h);g=(y[d+118|0]&3)==3?(g&2)>>>1|0?g|4:g:g}s=o|s;e=e+1|0;E=y[qi(x[m+4>>2])+3|0]==10|E;continue}break}b=N()|0;break A}b=N()|0;break A}b=N()|0;break A}b=N()|0}sc(i)}kd(d+156|0);break c}b=N()|0;break c}sc(i);kd(d+156|0)}r=r+1|0;continue}}b=N()|0;break a}b=N()|0;break c}b=N()|0;break c}G:{if(!(C&1)){break G}x[31785]=0;c=P(1,d+104|0,16836)|0;e=x[31785];x[31785]=0;H:{if((e|0)!=1){e=x[a+1298472>>2];x[31785]=0;S(389,e|0,2,c|0);e=x[31785];x[31785]=0;if((e|0)==1){break H}tb(c);break G}b=N()|0;break c}b=N()|0;tb(c);break c}x[31785]=0;c=P(416,b|0,5578)|0;e=x[31785];x[31785]=0;if((e|0)==1){break q}if(c){x[31785]=0;c=R(154,b|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break q}x[31785]=0;V(339,a+1298332|0,b|0,c|0,0);c=x[31785];x[31785]=0;if((c|0)==1){break q}g=g|16}x[31785]=0;n=P(416,b|0,14197)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}if(n){x[31785]=0;c=R(154,b|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break d}x[31785]=0;e=a+901404|0;S(777,b|0,e|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}kD(e);g=g|16}x[31785]=0;c=P(416,b|0,13954)|0;e=x[31785];x[31785]=0;if((e|0)==1){break d}if(!c){break p}x[31785]=0;c=R(154,b|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){w[d+192>>1]=c>>>5;H=d,I=pg(x[a+484344>>2],x[a+484348>>2]),w[H+72>>1]=I;c=z[Mc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){g=g|16;break p}x[31785]=0;O(583,b|0,d+192|0);i=x[31785];x[31785]=0;I:{if((i|0)==1){break I}i=x[a+484344>>2];x[31785]=0;O(584,Vb(i,e)|0,d+192|0);i=x[31785];x[31785]=0;if((i|0)==1){break I}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31785]=0;c=P(416,b|0,13959)|0;e=x[31785];x[31785]=0;if((e|0)==1){break d}J:{if(!c){break J}x[31785]=0;c=R(154,b|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){w[d+192>>1]=(c>>>0)/20;w[d+72>>1]=z[a+480188>>1];c=z[Mc(d+192|0,d+72|0)>>1];e=0;while(1){if((c|0)==(e|0)){g=g|16;break J}x[31785]=0;S(428,b|0,((e<<5)+a|0)+480289|0,20);i=x[31785];x[31785]=0;if((i|0)!=1){e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}c=x[b+8>>2];e=x[b>>2];x[31785]=0;c=U(153,e|0,c|0,8)|0;e=x[31785];x[31785]=0;if((e|0)==1){break d}if(c){c=x[b+8>>2];x[31785]=0;S(429,d+192|0,a|0,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break h}g=(c|0)==x[b+8>>2]?g:g|16}K:{if(!(g&16)){break K}if(g&4){x[a+1074308>>2]=17367040;x[31785]=0;c=P(1,d+192|0,14838)|0;e=x[31785];x[31785]=0;if((e|0)!=1){yb(k,c);tb(c);break K}b=N()|0;break c}if(!(g&2)){break K}x[a+1074308>>2]=18219008;x[31785]=0;c=P(1,d+192|0,15017)|0;e=x[31785];x[31785]=0;if((e|0)==1){break g}yb(k,c);tb(c)}L:{M:{N:{O:{P:{Q:{R:{if(!Ob(l,18434,8)){x[31785]=0;c=U(396,d+72|0,d+542|0,12)|0;e=x[31785];x[31785]=0;if((e|0)==1){break R}x[31785]=0;S(261,d+156|0,1,c|0);e=x[31785];x[31785]=0;if((e|0)==1){break Q}x[31785]=0;e=R(778,d+156|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break P}x[a+1074308>>2]=e;tb(d+156|0);v[a+1074368|0]=A[a+1074308>>2]<19007257?4:5;tb(c);g=24}if(!(!x[a+1074308>>2]|g&8)){v[a+1074368|0]=0;Ev(a+1074312|0)}c=g&32;S:{if(!c){break S}v[a+1074368|0]=5;if(!n){Zq(a+901404|0)}if((y[d+554|0]|y[d+555|0]<<8)>>>0<260){break S}x[31785]=0;U(269,a+1074312|0,4,1)|0;e=x[31785];x[31785]=0;if((e|0)==1){break d}}if(!yd(x[k+4>>2],y[k+11|0])){break L}if(!(g&256)|s&255|f+1>>>0>1){break M}x[31785]=0;c=P(1,d+156|0,8312)|0;f=x[31785];x[31785]=0;if((f|0)==1){break N}yb(k,c);tb(c);break L}b=N()|0;break c}b=N()|0;break O}b=N()|0;tb(d+156|0)}tb(c);break c}b=N()|0;break c}if(c){x[31785]=0;c=P(1,d+156|0,12090)|0;f=x[31785];x[31785]=0;if((f|0)!=1){yb(k,c);tb(c);break L}b=N()|0;break c}x[31785]=0;c=P(1,d+156|0,9760)|0;f=x[31785];x[31785]=0;if((f|0)==1){break f}yb(k,c);tb(c)}v[d+67|0]=0;if(z[a+480192>>1]){x[31785]=0;c=P(439,a|0,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break i}v[d+67|0]=c}x[31785]=0;ba(440,a|0,b|0,1,d+67|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break i}e=x[a+1074308>>2];T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if(y[d+67|0]){if(e>>>0>18284543){break fa}x[a+1074308>>2]=18284544;break fa}if(e>>>0<18284544){break ea}}x[31785]=0;c=P(1,d+52|0,18434)|0;b=x[31785];x[31785]=0;if((b|0)==1){break da}b=x[a+1074308>>2];x[31785]=0;O(779,d+40|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break ca}x[31785]=0;S(2,d+92|0,c|0,d+40|0);b=x[31785];x[31785]=0;if((b|0)==1){break ba}b=d+92|0;yb(k,b);tb(b);tb(d+40|0);tb(c);e=x[a+1074308>>2]}ga:{if(e-1>>>0>19005952){break ga}b=x[a+484344>>2];g=x[a+484348>>2];if(!Ge(b,g,254)){b=y[a+484376|0];c=x[a+484360>>2];x[31785]=0;W(780,Wb(c,b)|0);b=x[31785];x[31785]=0;if((b|0)==1){break i}g=x[a+484348>>2];b=x[a+484344>>2]}if(Ge(b,g,255)){break ga}DC(Wb(x[a+484360>>2],y[a+484376|0]),255,65535)}x[31785]=0;O(781,d+40|0,4122);b=x[31785];x[31785]=0;if((b|0)==1){break $}b=y[d+554|0]|y[d+555|0]<<8;x[d+12>>2]=b>>>8;x[31785]=0;x[d+24>>2]=b&255;O(448,d+28|0,d+24|0);b=x[31785];x[31785]=0;if((b|0)==1){break _}x[31785]=0;V(434,d+92|0,d+40|0,d+12|0,d+28|0);b=x[31785];x[31785]=0;if((b|0)==1){break Z}b=d+92|0;c=yb(a+1298344|0,b);tb(b);tb(d+28|0);Eb(d+40|0);f=yb(a+1298368|0,k);H=a+1298404|0,I=x[Gc(b,x[(x[a+1074308>>2]?41376:q)>>2])>>2],x[H>>2]=I;if(!y[d+483|0]){break U}yb(a+1298380|0,c);x[31785]=0;b=P(1,d+92|0,15435)|0;e=x[31785];x[31785]=0;if((e|0)==1){break X}yb(c,b);tb(b);x[31785]=0;b=P(1,d+40|0,10111)|0;c=x[31785];x[31785]=0;if((c|0)==1){break W}yb(a+1298356|0,b);tb(b);x[31785]=0;b=P(1,d+28|0,10112)|0;c=x[31785];x[31785]=0;if((c|0)==1){break V}yb(a+1298392|0,b);break T}b=N()|0;break c}b=N()|0;break aa}b=N()|0;tb(d+40|0)}tb(c);break c}b=N()|0;break c}b=N()|0;break Y}b=N()|0;tb(d+28|0)}Eb(d+40|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[31785]=0;b=P(1,d+92|0,10112)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}yb(a+1298356|0,b)}tb(b);e=1;if(E&1){x[31785]=0;a=P(1,d+12|0,17338)|0;b=x[31785];x[31785]=0;if((b|0)==1){break k}x[31785]=0;P(77,f|0,a|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break j}tb(a)}sc(m);tb(k)}fb=d+576|0;return e|0}b=N()|0;break c}b=N()|0;tb(a);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}sc(m);break a}b=N()|0}tb(k);Q(b|0);p()}function Rja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,n=0,o=0,s=0,t=0,u=0,B=0,C=0,F=0,G=0,H=0,I=0,J=E(0),K=E(0),L=0,M=0;h=fb-32|0;fb=h;b=x[a+1074308>>2];if(!(b>>>0>18285125|(b|0)==18284544)){Yf(a+1074312|0,0)}b=h+12|0;i=a+1074312|0;Kb(b,i,0);d=Hb(x[x[h+12>>2]>>2],x[h+16>>2]);c=a+480180|0;e=x[c>>2];Kb(b,i,0);m=d&(e&16777248)!=0;G=Hb(x[x[h+12>>2]>>2],x[h+16>>2]);H=x[c>>2];a:{b=x[a+1074308>>2];if(b>>>0>18874367){break a}e=a+480192|0;d=1;while(1){b:{b=d&65535;if(b>>>0<=z[e>>1]){b=x[((b<<2)+a|0)+900380>>2];if(!b){break b}x[h+12>>2]=D(y[b+20|0],100)>>>6;x[h+24>>2]=100;L=b,M=x[Gb(h+12|0,h+24|0)>>2],v[L+20|0]=M;if(A[a+1074308>>2]>18350079&m){break b}f=v[b+26|0];v[b+26|0]=((f>>31|1)+f|0)/2;if(A[a+1074308>>2]>18285313&m){break b}mD(Xh(b,2),x[c>>2]);f=x[a+1074308>>2];c:{if(f>>>0<18284544){break c}if(f>>>0>18285135){break b}if(!y[b+34|0]){break c}if(!Nj(y[b+31|0])){break c}Lb(i,2,1);if(A[a+1074308>>2]>18285135){break b}}if(!(y[b+24|0]|(y[b+23|0]|(y[b+19|0]|y[b+20|0])))){break b}Lb(i,1,1)}d:{if(!(x[a+480180>>2]&16777248)|A[a+1074308>>2]>18285313&m){break d}b=z[a+480190>>1]+1&65535;d=b>>>0<=1?1:b;c=1;while(1){if((c|0)==(d|0)){break d}b=D(c,104)+a|0;e=b+484419|0;if(!(y[e|0]|!(y[b+484421|0]|y[b+484420|0]))){v[e|0]=255}c=c+1|0;continue}}b=a+901404|0;c=b+288|0;d=ZU(c);while(1){if((c|0)==(d|0)){e:{c=b+800|0;b=fC(c);while(1){if((c|0)==(b|0)){break e}YU(c);c=c+32|0;continue}}}else{YU(c);c=c+32|0;continue}break}b=x[a+1074308>>2];break a}d=d+1|0;continue}}f:{if(!(x[a+480180>>2]&16777252)|((b|0)==18874368|b>>>0>18874895)){break f}c=z[a+480192>>1]+1&65535;f=c>>>0<=1?1:c;d=0;c=1;while(1){if((c|0)==(f|0)){if(!(d&1)){break f}Lb(i,3,1);b=x[a+1074308>>2]}else{e=x[((c<<2)+a|0)+900380>>2];if(!(!e|!y[e+31|0])){v[e+33|0]=13;d=1}c=c+1|0;continue}break}}g:{if(!(x[a+480180>>2]&16777248)|((b|0)==19005440|b>>>0>19006225)){break g}Kb(h+12|0,i,0);if(!Hb(x[x[h+12>>2]>>2],x[h+16>>2])){Kb(h+24|0,i,1);if(!Hb(x[x[h+24>>2]>>2],x[h+28>>2])){break g}}b=z[a+480192>>1]+1&65535;d=b>>>0<=1?1:b;c=1;while(1){if((c|0)==(d|0)){break g}b=x[((c<<2)+a|0)+900380>>2];if(!(!b|!y[b+19|0]|!(v[b+80|0]&1))){v[b+19|0]=0}c=c+1|0;continue}}h:{if(A[a+1074308>>2]>19007232){break h}c=a+906300|0;e=Dj(c);while(1){if((c|0)==(e|0)){break h}d=h+12|0;b=fb-32|0;fb=b;f=b+8|0;k=c+80|0;MR(f,k);x[31785]=0;S(126,b+20|0,22,f|0);f=x[31785];x[31785]=0;i:{j:{k:{if((f|0)!=1){x[31785]=0;S(247,d|0,0,b+20|0);f=x[31785];x[31785]=0;if((f|0)==1){break k}Sb(b+20|0);tb(b+8|0);fb=b+32|0;break i}a=N()|0;break j}a=N()|0;Sb(b+20|0)}tb(b+8|0);Q(a|0);p()}cw(k,d);c=c+160|0;tb(d);continue}}l:{m:{n:{o:{p:{q:{if(x[a+480180>>2]!=4){break q}d=x[a+1074308>>2];if(d>>>0<19007257){break o}if(d>>>0>19071235){break p}if(y[a+1074368|0]!=4){break q}FA(a,5)}d=x[a+1074308>>2]}if(d>>>0>19202054){break n}b=19202048;if((d|0)==19202048){break m}}b=z[a+480192>>1]+1&65535;f=b>>>0<=1?1:b;b=1;while(1){if((b|0)==(f|0)){break n}e=x[((b<<2)+a|0)+900380>>2];r:{if(!e|!y[e+20|0]|!y[e+31|0]){break r}c=e+236|0;k=fr(c);while(1){if((c|0)!=(k|0)){g=z[c>>1];c=c+2|0;if(!g){continue}break r}break}v[e+20|0]=0}b=b+1|0;continue}}b=d;if(b>>>0>19267583){break l}}c=z[a+480192>>1]+1&65535;e=c>>>0<=1?1:c;c=1;while(1){if((c|0)==(e|0)){break l}d=x[((c<<2)+a|0)+900380>>2];s:{if(!d){break s}b=v[d+26|0];v[d+26|0]=((b>>31|1)+b|0)/2;b=x[a+1074308>>2];if(b>>>0>18350079&m){break s}v[d+19|0]=y[d+19|0]+3>>>2}c=c+1|0;continue}}t:{if(b>>>0>19398673){break t}d=z[a+480192>>1];c=1;while(1){e=c&65535;if(e>>>0>d>>>0){break t}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+65|0]==255){c=c+1|0;continue}else{Lb(i,94,1);b=x[a+1074308>>2]}break}}u:{if(b>>>0>19399427){break u}d=z[a+480192>>1];c=1;while(1){e=c&65535;if(e>>>0>d>>>0){break u}e=x[((e<<2)+a|0)+900380>>2];if(!e|y[e+36|0]>1){c=c+1|0;continue}else{Lb(i,101,1);b=x[a+1074308>>2]}break}}v:{if(b>>>0>19923027){break v}d=z[a+480190>>1];c=1;while(1){b=c&65535;if(b>>>0>d>>>0){break v}b=D(b,104)+a|0;if(!ge(x[b+484380>>2],x[b+484400>>2])|!(y[b+484414|0]&20)){c=c+1|0;continue}else{Lb(i,116,1)}break}}b=fb-16|0;fb=b;w[h+4>>1]=0;x[h>>2]=a;Kb(b+8|0,a+1074312|0,0);L=h,M=Hb(x[x[b+8>>2]>>2],x[b+12>>2]),v[L+6|0]=M;fb=b+16|0;c=x[h>>2];t=x[h+4>>2];d=a+484344|0;B=d;C=pg(x[d>>2],x[d+4>>2])-1&65535;b=fb-32|0;fb=b;w:{if(pg(x[d>>2],x[d+4>>2])>>>0<=C>>>0){break w}while(1){e=F&65535;if(e>>>0>C>>>0){break w}d=sg(x[B>>2],e);f=x[d>>2];if(Ib(f,x[d+4>>2])){d=vb(f);I=vb(x[sg(x[B>>2],e)+4>>2]);x[b+24>>2]=c;x[b+28>>2]=t;x[b+8>>2]=c;x[b+12>>2]=t;k=b+8|0;s=fb-16|0;fb=s;x[s+12>>2]=d;while(1){if(Ib(d,I)){u=z[k+4>>1];e=u+1|0;w[k+4>>1]=e;g=x[k>>2];w[k+4>>1]=z[g+480188>>1]>(e&65535)>>>0?e:0;x:{if(Sg(y[d|0])){break x}f=x[g+1074308>>2];y:{n=x[g+480180>>2];z:{A:{if((n|0)==2){if(f>>>0>18415615){break A}if(y[d+3|0]!=23){break z}If(d+5|0,64);break z}B:{if(n&16777248){C:{D:{if(f>>>0>=18285314){if(y[k+6|0]){break D}e=0;g=0;if(f>>>0>18874367){break C}}E:{switch(y[d+3|0]-20|0){case 3:If(d+5|0,128);break D;case 0:break E;default:break D}}e=y[d+5|0];if((e|0)!=208){if((e|0)!=192){break D}v[d|0]=254;v[d+3|0]=0;break D}v[d+3|0]=0}F:{G:{H:{if(f>>>0>=18350080){if(y[k+6|0]){break H}e=0;g=0;if(f>>>0>18874367){break C}}g=y[d+3|0];if(g>>>0>29){break G}e=1;if(!(1<<g&536873152)){break G}break F}e=0;g=0;if(f>>>0>18874367){break C}g=y[d+3|0]}e=0}g=(g|0)==24|(g|0)==22}I:{if(!(e|g)){break I}g=y[d+5|0];e=g&15;if(!e|(e|0)==15){break I}g=g&240;if(!g|(g|0)==240){break I}v[d+5|0]=y[d+3|0]==24?g:e}J:{if((f|0)==19005440|f>>>0>19005699){break J}e=z[x[k>>2]+480192>>1];if(y[k+6|0]|(!e|e>>>0>=y[d+1|0])){break J}v[d+4|0]=0;v[d+2|0]=1}if(y[d+3|0]!=18|y[d+5|0]!=17){break A}if(f>>>0>19468801){break y}if(!Pb(x[k>>2]+1074312|0,22)|y[x[k>>2]+480208|0]&4){break A}g=d+5|0;break B}if((n|0)!=4){break A}e=!y[k+6|0];K:{if((e|f>>>0<18285314)&f>>>0<=18874367){break K}if(f>>>0>19137025){break y}if(y[d+3|0]!=23|y[d+5|0]<65){break K}v[d+3|0]=0}L:{M:{N:{if(!(!(e&f>>>0<18874368)&f>>>0>=18415616)){e=y[d+3|0];g=y[d+2|0];if((e|0)!=10|(g|0)!=11){break N}e=0;v[d+3|0]=0;break L}if(f>>>0>18874639){break M}e=y[d+3|0];g=y[d+2|0]}if((g|0)!=11|(e|0)!=4){break L}g=y[d+4|0];if(!(g|y[k+6|0])){e=4;break L}e=4;o=y[d+5|0];if(!o){break L}v[d+2|0]=0;L=d,M=Rv((g<<4)+o|0),v[L+5|0]=M;break L}if(f>>>0>19007240){break y}e=y[d+3|0]}if(y[d+5|0]|(e|0)!=16){break A}g=d+3|0}v[g|0]=0}if(f>>>0>18874367){break y}}e=y[d+3|0];g=y[d+5|0]&240;O:{P:{if((e|0)!=28|(g|0)!=96){o=0}else{if(!y[k+6|0]|(n|0)!=4){break P}o=f>>>0<18350080}if(!(o|(e|0)==20&(g|0)==96)){break O}}e=D(u,-6)+d|0;while(1){if(d>>>0>e>>>0){if(!((y[e+3|0]|8)!=28|(y[e+5|0]&240)!=96)){v[e+3|0]=0}e=e+6|0;continue}break}e=y[d+3|0]}if((e|0)!=20|(g|0)!=224){break y}e=D(u,-6)+d|0;while(1){if(d>>>0<=e>>>0){break y}if(!(y[e+3|0]!=20|(y[e+5|0]&240)!=224)){v[e+3|0]=0}e=e+6|0;continue}}e=y[d+2|0];if(!((e|0)!=8|f>>>0>19333174|(f|0)==19333120)){f=y[d+4|0];e=y[d+3|0];if(!(!f|(e|0)!=7)){v[d+3|0]=11;break x}Q:{R:{switch(e-5|0){default:if((e|0)!=26){break x}break;case 1:break x;case 2:break Q;case 0:break R}}g=y[d+5|0];if(!(g&15)){v[d+2|0]=0;v[d+3|0]=5;v[d+5|0]=g|f&15;break x}S:{switch(e-5|0){case 1:break x;case 0:case 2:break Q;default:break S}}if((e|0)!=26){break x}}v[d+2|0]=0;break x}T:{if(!((n|0)==16777216|(e|0)!=15)){e=y[d+3|0];if(e){break T}v[d+2|0]=0;v[d+3|0]=10;v[d+5|0]=y[d+4|0]<<3;break x}if((e|0)!=15){break x}e=y[d+3|0]}if((e&255)!=10|f>>>0>19922963){break x}if(y[d+4|0]?y[d+5|0]:1){v[d+2|0]=0;break x}v[d+3|0]=0}d=x[ah(s+12|0)>>2];continue}break}d=x[k+4>>2];x[b+16>>2]=x[k>>2];x[b+20>>2]=d;fb=s+16|0}F=F+1|0;continue}}x[h+12>>2]=c;x[h+16>>2]=t;fb=b+32|0;U:{b=A[a+1074308>>2]<19267584;if(b&m){c=40544;while(1){if((c|0)==40888){break U}b=x[a+1074308>>2];d=x[c+4>>2];Lb(i,x[c>>2],b>>>0>=d>>>0|(b|0)==(d&-65536));c=c+8|0;continue}}if(!(b&((H|0)==4&G))){break U}c=40896;while(1){if((c|0)==41136){break U}Lb(i,x[c>>2],A[a+1074308>>2]>=A[c+4>>2]);c=c+8|0;continue}}V:{W:{b=x[a+480180>>2];if(b&16777248){c=41136;while(1){if((c|0)==41208){break W}b=x[a+1074308>>2];d=x[c+4>>2];e=d&-65536;if(!(b>>>0>=e>>>0&(b>>>0<=e>>>0|d>>>0<=b>>>0))){Yf(i,x[c>>2])}c=c+8|0;continue}}c=41280;d=41216;X:{switch(b-2|0){case 2:while(1){if((d|0)==41280){break W}if(A[a+1074308>>2]<A[d+4>>2]){Yf(i,x[d>>2])}d=d+8|0;continue};case 0:break X;default:break V}}while(1){if((c|0)==41376){break W}if(A[a+1074308>>2]<A[c+4>>2]){Yf(i,x[c>>2])}c=c+8|0;continue}}b=x[a+480180>>2]}Y:{if((b|0)==4){c=x[a+1074308>>2];if(c>>>0>18415615){break Y}Lb(i,98,1)}c=x[a+1074308>>2]}d=8;if(c-19333159>>>0<=33){c=0;while(1){if((c|0)!=5){b=c+77|0;Kb(h+12|0,i,b);Yf(Lb(i,c+86|0,Hb(x[x[h+12>>2]>>2],x[h+16>>2])),b);c=c+1|0;continue}break}c=x[a+1074308>>2]}Z:{if(c>>>0>=18284544){if(c>>>0>18874627){break Z}d=6;if((c|0)==18874368){break Z}}Lb(i,d,1)}b=x[a+1074308>>2];_:{if(y[a+480208|0]&16){if(b>>>0<=19136511){Yf(i,7);break _}if(!(x[a+480180>>2]&16777248)|b>>>0>19267583){break _}Lb(i,7,1);break _}if((b|0)==19922944|b>>>0>19922997){break _}Yf(i,7)}Kb(h+12|0,i,31);$:{if(!Hb(x[x[h+12>>2]>>2],x[h+16>>2])){break $}b=x[a+1074308>>2];if(b>>>0<19071234|b>>>0>19398722){break $}d=z[a+480192>>1];c=1;while(1){b=c&65535;if(b>>>0>d>>>0){break $}aa:{b=x[((b<<2)+a|0)+900380>>2];if(!b){break aa}e=y[b+65|0];if(!(y[b+60|0]&4)|(e|0)==255|e>>>0<=y[b- -64|0]){break aa}Lb(i,97,1);break $}c=c+1|0;continue}}b=x[a+480180>>2];ba:{if(!(b&16777218)){break ba}d=z[a+480190>>1];c=1;while(1){e=c&65535;if(e>>>0>d>>>0){break ba}c=c+1|0;if(!(y[(D(e,104)+a|0)+484415|0]&2)){continue}break}ca:{da:{ea:{if(!(!z[a+480192>>1]|(b|0)!=16777216)){c=x[a+1074308>>2];if(c>>>0<19398688){break da}if(c>>>0>19464277){break ea}Lb(i,109,1)}c=x[a+1074308>>2]}if((c|0)==19922944|c>>>0>19922996){break ca}}Yf(i,111);c=x[a+1074308>>2]}b=x[a+480180>>2];if(!((b|0)!=2|c>>>0>19464191)){Lb(i,108,1);break ba}if((b|0)==2){break ba}Yf(i,108)}d=x[a+1074308>>2];fa:{ga:{if(d>>>0<19333186){break ga}if(d>>>0<=19923013){if(!(x[a+480180>>2]&16777252)){break ga}c=a+906300|0;b=Dj(c);while(1){if((c|0)!=(b|0)){ha:{if((y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))!=1146637647|(y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24))!=-271958638){break ha}if((Sc(x[c+4>>2],x[c+8>>2])|0)!=32){break ha}d=Cc(h+12|0,17059);cw(c+80|0,d);tb(d)}c=c+160|0;continue}break}d=x[a+1074308>>2]}if(d>>>0>19988488){break fa}}if(!(x[a+480180>>2]&16777252)){break fa}c=a+906300|0;e=Dj(c);while(1){if((c|0)==(e|0)){break fa}b=c;c=b+160|0;if(!Pi(x[b+16>>2],x[b+20>>2])){continue}break}Lb(i,117,1);d=x[a+1074308>>2]}ia:{if(!(x[a+480180>>2]&16777252)|d-19333120>>>0>591359){break ia}a=a+906300|0;d=Dj(a);while(1){if((a|0)==(d|0)){break ia}ja:{if((y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))!=1146637647|(y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))!=-281111764){break ja}b=x[a+4>>2];if((Sc(b,x[a+8>>2])|0)!=24){break ja}J=Ld(E(E(E((l(2,y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));K=Ld(E(E(E((l(2,y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24)),r())*E(2e3))+E(-1))/E(1999)),E(0));c=(q(J),j(2));v[b+12|0]=c;v[b+13|0]=c>>>8;v[b+14|0]=c>>>16;v[b+15|0]=c>>>24;b=x[a+4>>2];c=(q(K),j(2));v[b+16|0]=c;v[b+17|0]=c>>>8;v[b+18|0]=c>>>16;v[b+19|0]=c>>>24}a=a+160|0;continue}}fb=h+32|0}function nP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-32|0;fb=g;a:{b:{c:{d:{e:{f:{if(ke(b,22485)){Fb(a);break f}if(ke(b,9903)){b=fb-96|0;fb=b;f=Fb(a);x[31785]=0;W(131,b- -64|0);a=x[31785];x[31785]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((a|0)!=1){x[31785]=0;x[b+40>>2]=0;O(1126,b+52|0,b+40|0);a=x[31785];x[31785]=0;if((a|0)==1){break C}x[31785]=0;a=P(845,f|0,b+52|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break B}tb(b+52|0);x[31785]=0;a=P(994,a|0,16978)|0;c=x[31785];x[31785]=0;if((c|0)==1){break A}x[31785]=0;x[b+40>>2]=7;O(1126,b+52|0,b+40|0);c=x[31785];x[31785]=0;if((c|0)==1){break z}x[31785]=0;a=P(845,a|0,b+52|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break y}tb(b+52|0);x[31785]=0;a=P(994,a|0,16978)|0;c=x[31785];x[31785]=0;if((c|0)==1){break A}x[31785]=0;x[b+40>>2]=0;O(1126,b+52|0,b+40|0);c=x[31785];x[31785]=0;if((c|0)==1){break x}x[31785]=0;a=P(845,a|0,b+52|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break w}tb(b+52|0);x[31785]=0;a=P(994,a|0,15193)|0;c=x[31785];x[31785]=0;if((c|0)==1){break A}c=Nb(b+52|0);d=x[b+76>>2];if(d){x[31785]=0;x[b+16>>2]=d;O(1126,b+28|0,b+16|0);d=x[31785];x[31785]=0;if((d|0)==1){break v}x[31785]=0;S(1020,b+40|0,8984,b+28|0);d=x[31785];x[31785]=0;if((d|0)==1){break u}x[31785]=0;O(181,c|0,b+40|0);d=x[31785];x[31785]=0;if((d|0)==1){break t}tb(b+40|0);tb(b+28|0)}if(!Ad(y[b+80|0])){break p}x[31785]=0;d=P(37,b+40|0,12859)|0;e=x[31785];x[31785]=0;if((e|0)==1){break r}x[31785]=0;O(181,c|0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break q}tb(d);break o}a=N()|0;break h}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break i}a=N()|0;tb(b+52|0);break i}a=N()|0;break j}a=N()|0;break s}a=N()|0;tb(b+40|0)}tb(b+28|0);break j}a=N()|0;break j}a=N()|0;tb(d);break j}if(!Ad(y[b+81|0])){break o}x[31785]=0;d=P(37,b+40|0,12630)|0;e=x[31785];x[31785]=0;if((e|0)==1){break n}x[31785]=0;O(181,c|0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break m}tb(d)}if(Ad(y[b+82|0])){break l}break k}a=N()|0;break j}a=N()|0;tb(d);break j}x[31785]=0;d=P(37,b+28|0,11143)|0;e=x[31785];x[31785]=0;D:{if((e|0)!=1){x[31785]=0;O(181,c|0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break D}tb(d);break k}a=N()|0;break j}a=N()|0;tb(d);break j}if(mc(x[c>>2],x[c+4>>2])){break g}x[31785]=0;a=P(994,a|0,17008)|0;d=x[31785];x[31785]=0;if((d|0)!=1){x[31785]=0;d=P(37,b+4|0,16978)|0;e=x[31785];x[31785]=0;E:{F:{G:{if((e|0)!=1){x[31785]=0;S(1127,b+16|0,c|0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break G}x[31785]=0;P(845,a|0,b+16|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break F}tb(b+16|0);tb(d);break g}a=N()|0;break j}a=N()|0;break E}a=N()|0;tb(b+16|0)}tb(d);break j}a=N()|0}Pd(c)}vg(b- -64|0)}tb(f);break a}Pd(c);vg(b- -64|0);fb=b+96|0;break f}if(ke(b,8152)){x[g>>2]=0;Oq(a,g);break f}if(ke(b,8130)){x[g>>2]=7;Oq(a,g);break f}if(ke(b,10863)){x[g>>2]=0;Oq(a,g);break f}if(ke(b,10635)){Cc(a,15193);break f}if(ke(b,11424)){Cc(a,16013);break f}if(ke(b,7432)){b=fb-48|0;fb=b;xG(b+24|0);x[31785]=0;W(148,b+12|0);c=x[31785];x[31785]=0;H:{I:{J:{K:{if((c|0)!=1){x[31785]=0;S(149,b+36|0,b+24|0,b+12|0);c=x[31785];x[31785]=0;if((c|0)==1){break K}x[31785]=0;O(1068,a|0,b+36|0);a=x[31785];x[31785]=0;if((a|0)==1){break J}tb(b+36|0);tb(b+12|0);tb(b+24|0);fb=b+48|0;break f}a=N()|0;break H}a=N()|0;break I}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(b+24|0);break a}if(ke(b,9919)){b=fb-16|0;fb=b;e=fb-16|0;fb=e;x[e+12>>2]=101;i=b+4|0;c=fb-96|0;fb=c;f=Nb(c+84|0);L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{d=x[e+12>>2];if(d&1){x[31785]=0;O(137,c+52|0,19988519);d=x[31785];x[31785]=0;if((d|0)==1){break _}x[31785]=0;O(104,f|0,c+52|0);d=x[31785];x[31785]=0;if((d|0)==1){break Z}tb(c+52|0);d=x[e+12>>2]}if(!(d&4)){break X}x[31785]=0;d=ca(138)|0;h=x[31785];x[31785]=0;if((h|0)==1){break W}if(!d){break Y}break X}d=N()|0;break M}d=N()|0;tb(c+52|0);break M}x[31785]=0;W(139,c+52|0);d=x[31785];x[31785]=0;$:{if((d|0)!=1){x[31785]=0;O(104,f|0,c+52|0);d=x[31785];x[31785]=0;if((d|0)==1){break $}tb(c+52|0);break X}d=N()|0;break M}d=N()|0;tb(c+52|0);break M}aa:{d=x[e+12>>2];if(!(d&32)){break aa}x[31785]=0;W(131,c+52|0);d=x[31785];x[31785]=0;ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{if((d|0)!=1){x[31785]=0;O(140,c+40|0,c+52|0);d=x[31785];x[31785]=0;if((d|0)==1){break ca}d=yd(x[c+44>>2],y[c+51|0]);tb(c+40|0);if(!d){x[31785]=0;W(141,c+28|0);d=x[31785];x[31785]=0;if((d|0)==1){break ta}x[31785]=0;O(140,c+16|0,c+52|0);d=x[31785];x[31785]=0;if((d|0)==1){break sa}x[31785]=0;S(142,c+40|0,c+28|0,c+16|0);d=x[31785];x[31785]=0;if((d|0)==1){break ra}x[31785]=0;O(104,f|0,c+40|0);d=x[31785];x[31785]=0;if((d|0)==1){break qa}tb(c+40|0);tb(c+16|0);Eb(c+28|0)}d=Bp(c+52|0);if(!yd(x[d+4>>2],y[d+11|0])){x[31785]=0;W(143,c+28|0);h=x[31785];x[31785]=0;if((h|0)==1){break na}x[31785]=0;S(144,c+40|0,c+28|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break ma}x[31785]=0;O(104,f|0,c+40|0);d=x[31785];x[31785]=0;if((d|0)==1){break la}tb(c+40|0);Eb(c+28|0)}x[31785]=0;O(145,c+40|0,c+52|0);d=x[31785];x[31785]=0;if((d|0)==1){break ja}d=yd(x[c+44>>2],y[c+51|0]);tb(c+40|0);if(!d){x[31785]=0;W(141,c+28|0);d=x[31785];x[31785]=0;if((d|0)==1){break ia}x[31785]=0;O(145,c+16|0,c+52|0);d=x[31785];x[31785]=0;if((d|0)==1){break ha}x[31785]=0;S(142,c+40|0,c+28|0,c+16|0);d=x[31785];x[31785]=0;if((d|0)==1){break ga}x[31785]=0;O(104,f|0,c+40|0);d=x[31785];x[31785]=0;if((d|0)==1){break fa}tb(c+40|0);tb(c+16|0);Eb(c+28|0)}vg(c+52|0);d=x[e+12>>2];break aa}d=N()|0;break M}d=N()|0;break ba}d=N()|0;break oa}d=N()|0;break pa}d=N()|0;tb(c+40|0)}tb(c+16|0)}Eb(c+28|0);break ba}d=N()|0;break ba}d=N()|0;break ka}d=N()|0;tb(c+40|0)}Eb(c+28|0);break ba}d=N()|0;break ba}d=N()|0;break ba}d=N()|0;break da}d=N()|0;break ea}d=N()|0;tb(c+40|0)}tb(c+16|0)}Eb(c+28|0);break ba}d=N()|0}vg(c+52|0);break M}ua:{if(!(d&64)){break ua}x[31785]=0;d=ca(138)|0;h=x[31785];x[31785]=0;if((h|0)==1){break W}if(d){break ua}d=c+52|0;Fb(d);x[31785]=0;O(104,f|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break N}tb(c+52|0)}if(y[e+12|0]&128){x[31785]=0;W(146,c+52|0);d=x[31785];x[31785]=0;if((d|0)==1){break V}x[31785]=0;O(104,f|0,c+52|0);d=x[31785];x[31785]=0;if((d|0)==1){break U}tb(c+52|0)}x[31785]=0;h=P(1,c+52|0,22485)|0;d=x[31785];x[31785]=0;if((d|0)==1){break T}x[31785]=0;S(147,c+4|0,f|0,h|0);d=x[31785];x[31785]=0;if((d|0)==1){break S}x[31785]=0;W(148,c+40|0);d=x[31785];x[31785]=0;if((d|0)==1){break R}x[31785]=0;S(149,i|0,c+4|0,c+40|0);d=x[31785];x[31785]=0;if((d|0)==1){break Q}tb(c+40|0);tb(c+4|0);tb(h);Pd(f);fb=c+96|0;break L}d=N()|0;break M}d=N()|0;break M}d=N()|0;tb(c+52|0);break M}d=N()|0;break M}d=N()|0;break O}d=N()|0;break P}d=N()|0;tb(c+40|0)}tb(c+4|0)}tb(h);break M}d=N()|0;tb(c+52|0)}Pd(f);Q(d|0);p()}fb=e+16|0;x[31785]=0;O(1068,a|0,i|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,10535)){b=fb-48|0;fb=b;c=b+4|0;es(c);x[31785]=0;O(140,b+36|0,c|0);c=x[31785];x[31785]=0;va:{wa:{if((c|0)!=1){x[31785]=0;O(1068,a|0,b+36|0);a=x[31785];x[31785]=0;if((a|0)==1){break wa}tb(b+36|0);vg(b+4|0);fb=b+48|0;break f}a=N()|0;break va}a=N()|0;tb(b+36|0)}vg(b+4|0);break a}if(ke(b,11387)){b=fb-32|0;fb=b;es(b);x[31785]=0;O(1128,a|0,Bp(b)|0);a=x[31785];x[31785]=0;if((a|0)!=1){vg(b);fb=b+32|0;break f}a=N()|0;vg(b);break a}if(ke(b,9932)){b=fb-48|0;fb=b;es(b+16|0);c=x[b+28>>2];xa:{if(c){x[31785]=0;x[b+12>>2]=c;O(1126,a|0,b+12|0);a=x[31785];x[31785]=0;if((a|0)!=1){break xa}a=N()|0;vg(b+16|0);break a}Fb(a)}vg(b+16|0);fb=b+48|0;break f}if(ke(b,12849)){es(g);b=y[g+16|0];x[31785]=0;P(37,a|0,(Ad(b)?15690:16013)|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break e}vg(g);break f}if(ke(b,9948)){es(g);b=y[g+17|0];x[31785]=0;P(37,a|0,(Ad(b)?15690:16013)|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){vg(g);break f}break e}if(ke(b,12302)){es(g);b=y[g+18|0];x[31785]=0;P(37,a|0,(Ad(b)?15690:16013)|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){vg(g);break f}break e}if(ke(b,12604)){b=fb-16|0;fb=b;c=fb-32|0;fb=c;f=b+4|0;d=Fb(f);x[31785]=0;W(131,c|0);e=x[31785];x[31785]=0;ya:{za:{if((e|0)!=1){x[31785]=0;O(132,d|0,Bp(c)|0);e=x[31785];x[31785]=0;if((e|0)==1){break za}vg(c);fb=c+32|0;break ya}a=N()|0;break b}a=N()|0;vg(c);break b}x[31785]=0;O(1068,a|0,f|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,8273)){b=fb-16|0;fb=b;c=fb-48|0;fb=c;f=b+4|0;d=Fb(f);x[31785]=0;O(134,c+24|0,4155);e=x[31785];x[31785]=0;Aa:{Ba:{Ca:{Da:{if((e|0)!=1){x[c+20>>2]=17;x[c+16>>2]=0;x[31785]=0;x[c+12>>2]=0;aa(135,c+36|0,c+24|0,c+20|0,c+16|0,c+12|0);e=x[31785];x[31785]=0;if((e|0)==1){break Da}x[31785]=0;P(77,d|0,c+36|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Ca}tb(c+36|0);Eb(c+24|0);fb=c+48|0;break Aa}a=N()|0;break b}a=N()|0;break Ba}a=N()|0;tb(c+36|0)}Eb(c+24|0);break b}x[31785]=0;O(1068,a|0,f|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,6877)){b=fb-16|0;fb=b;d=b+4|0;c=fb-32|0;fb=c;f=c+8|0;Cc(f,20420);x[31785]=0;S(126,c+20|0,0,f|0);f=x[31785];x[31785]=0;Ea:{Fa:{Ga:{if((f|0)!=1){x[31785]=0;O(12,d|0,c+20|0);f=x[31785];x[31785]=0;if((f|0)==1){break Ga}Sb(c+20|0);tb(c+8|0);fb=c+32|0;break Ea}a=N()|0;break Fa}a=N()|0;Sb(c+20|0)}tb(c+8|0);break a}x[31785]=0;O(1068,a|0,d|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,6475)){b=fb-48|0;fb=b;c=uc(b+24|0,18481);x[31785]=0;O(1129,b+12|0,2);d=x[31785];x[31785]=0;Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){x[31785]=0;S(2,b+36|0,c|0,b+12|0);d=x[31785];x[31785]=0;if((d|0)==1){break Ka}x[31785]=0;O(1068,a|0,b+36|0);a=x[31785];x[31785]=0;if((a|0)==1){break Ja}tb(b+36|0);tb(b+12|0);tb(c);fb=b+48|0;break f}a=N()|0;break Ha}a=N()|0;break Ia}a=N()|0;tb(b+36|0)}tb(b+12|0)}tb(c);break a}if(ke(b,11410)){b=fb-16|0;fb=b;c=fb-16|0;fb=c;Cc(c+4|0,18820);e=b+4|0;f=Fb(e);h=y[c+15|0];i=x[c+8>>2];x[31785]=0;O(96,f|0,uh(i,h)|0);h=x[31785];x[31785]=0;La:{if((h|0)!=1){Ma:{while(1){if(uh(x[c+8>>2],y[c+15|0])>>>0>d>>>0){h=y[cc(c+4|0,d)|0];x[31785]=0;O(98,f|0,h|0);h=x[31785];x[31785]=0;if((h|0)==1){break Ma}d=d+1|0;continue}break}tb(c+4|0);fb=c+16|0;break La}}a=N()|0;tb(f);tb(c+4|0);break a}x[31785]=0;O(1068,a|0,e|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,10542)){b=fb-16|0;fb=b;c=b+4|0;as(c,0);x[31785]=0;O(1068,a|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,10517)){b=fb-16|0;fb=b;c=b+4|0;as(c,2);x[31785]=0;O(1068,a|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}if(ke(b,10502)){b=fb-16|0;fb=b;c=b+4|0;as(c,3);x[31785]=0;O(1068,a|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(b+4|0);fb=b+16|0;break f}break c}Fb(a)}fb=g+32|0;break d}a=N()|0;vg(g);break a}return}a=N()|0;tb(b+4|0);break a}tb(d)}Q(a|0);p()}function kta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0;e=fb-416|0;fb=e;xc(b);f=e+399|0;g=_$(b,f);if(!g){nE(f)}a:{b:{c:{d:{e:{f:{if(!g){break f}if(!C_(e+399|0)){break f}if(!Mb(x[b>>2],x[b+8>>2],Bc(72,0))){break f}if(!c){d=1;break f}Bd(a,1);x[a+480208>>2]=x[a+480208>>2]&-25231361|16842752;j=y[e+408|0];w[a+480190>>1]=63;w[a+480188>>1]=j;g:{h:{i:{while(1){if((j&65535)>>>0<=d>>>0){j:{Tb(e+320|0,0,64);d=1;k:{l:{m:{n:{while(1){o:{f=d&65535;if(f>>>0>z[a+480190>>1]){tE(b,a+1298308|0);f=e+312|0;d=fb-16|0;fb=d;p:{if(!Mb(x[b>>2],x[b+8>>2],8)){v[d|0]=0;Rh(f,8,d);break p}al(d+8|0,f);md(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;o=Nb(e+300|0);f=y[e+409|0]|y[e+410|0]<<8;if(f){d=Nb(e+212|0);x[31785]=0;f=U(329,b|0,d|0,D(f,y[e+408|0])<<1)|0;g=x[31785];x[31785]=0;if((g|0)==1){break k}if(!f){break j}le(e+272|0,x[d>>2],x[d+4>>2]);f=Jd(e+264|0);x[31785]=0;g=x[f+4>>2];x[e+40>>2]=x[f>>2];x[e+44>>2]=g;f=dg(330,e+280|0,x[e+272>>2],x[e+276>>2],e+40|0);g=x[31785];x[31785]=0;if((g|0)==1){break o}g=x[d+4>>2];j=x[d>>2];x[31785]=0;U(216,f|0,o|0,Sc(j,g)>>>1|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break n}ub(f);dc(d)}m=Nb(e+252|0);x[31785]=0;O(331,m|0,(y[e+411|0]|y[e+412|0]<<8)<<8);d=x[31785];x[31785]=0;if((d|0)==1){break i}d=0;while(1){f=d&65535;d=y[e+411|0]|y[e+412|0]<<8;if(f>>>0>=d>>>0){break l}x[e+212>>2]=d-f;x[e+160>>2]=2e3;d=e+212|0;g=x[pd(d,e+160|0)>>2];d=Nb(d);x[31785]=0;g=U(329,b|0,d|0,g<<8)|0;j=x[31785];x[31785]=0;if((j|0)==1){break d}if(!g){break m}g=zb(e+248|0,vb(x[m+4>>2]));j=vb(x[d>>2]);i=vb(x[e+216>>2]);g=x[g>>2];x[31785]=0;V(332,m|0,g|0,j|0,i|0);g=x[31785];x[31785]=0;if((g|0)==1){break d}dc(d);d=f+2e3|0;continue}}g=(D(f,104)+a|0)+484380|0;jd(g,1);h=f+(e+320|0)|0;f=be(b);v[h|0]=f;if(f<<24>>24>=0){C=g,E=z_(b)<<1,x[C>>2]=E}d=d+1|0;continue}break}a=N()|0;break b}a=N()|0;ub(f);break b}dc(d);d=0;break h}le(e+232|0,x[m>>2],x[m+4>>2]);kf(e+240|0,x[e+232>>2],x[e+236>>2]);q=a+484376|0;d=y[q|0];f=x[a+484360>>2];x[31785]=0;O(333,Wb(f,d)|0,y[e+409|0]|y[e+410|0]<<8);d=x[31785];x[31785]=0;if((d|0)==1){break e}r=a+484344|0;t=c&1;i=0;while(1){if((y[e+409|0]|y[e+410|0]<<8)>>>0<=i>>>0){g=c&2;j=1;q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{while(1){c=j&65535;if(c>>>0>z[a+480190>>1]){break x}x[31785]=0;d=y[c+(e+320|0)|0];S(334,b|0,((c<<5)+a|0)+946304|0,d&63);f=x[31785];x[31785]=0;if((f|0)==1){break v}C:{D:{if(d<<24>>24<0){break D}x[31785]=0;d=R(335,b|0)|0;f=x[31785];x[31785]=0;E:{F:{G:{H:{I:{J:{K:{L:{if((f|0)==1){break L}c=D(c,104)+a|0;f=c+484392|0;x[f>>2]=d<<1;x[31785]=0;d=R(335,b|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break K}if(d>>>0>=2){x[c+484396>>2]=x[f>>2]+(d<<1);d=c+484414|0;w[d>>1]=z[d>>1]|8}x[31785]=0;d=R(200,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break u}v[e+80|0]=d;v[e+180|0]=64;C=c+484410|0,E=y[Ub(e+80|0,e+180|0)|0]<<2,w[C>>1]=E;x[31785]=0;d=R(200,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break L}v[c+484417|0]=d<<4;c=c+484380|0;Zo(c);if(!x[c>>2]){break D}x[31785]=0;f=R(200,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break F}d=0;switch(f|0){case 4:case 5:break E;case 2:case 3:break H;case 1:break I;case 0:break J;default:break h}}a=N()|0;break c}a=N()|0;break c}if(g){f=Nb(e+80|0);i=x[b+8>>2];h=x[b>>2];k=x[c>>2];x[31785]=0;i=U(153,h|0,i|0,k|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break t}if(!i){break y}d=x[c>>2];x[31785]=0;S(336,b|0,f|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break t}C=e,E=vb(x[f>>2]),x[C+180>>2]=E;i=vb(x[e+84>>2]);while(1){d=x[e+180>>2];if(Ib(d,i)){h=d;d=y[d|0];v[h|0]=d<<7|(d^-1)>>>1&127;je(e+180|0);continue}break}le(e+200|0,x[f>>2],x[e+84>>2]);d=Jd(e+192|0);x[31785]=0;i=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=i;d=dg(330,e+212|0,x[e+200>>2],x[e+204>>2],e+16|0);i=x[31785];x[31785]=0;M:{if((i|0)!=1){i=ad(e+180|0,16,1,0,16);x[31785]=0;U(218,i|0,c|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break M}ub(d);dc(f);break D}a=N()|0;break q}a=N()|0;ub(d);break q}c=x[c>>2];break G}f=Nb(e+80|0);d=x[c>>2];x[31785]=0;S(337,e+180|0,b|0,d|0);d=x[31785];x[31785]=0;N:{O:{P:{if((d|0)!=1){d=e+180|0;i=pn(f,d);dc(d);if(g){le(e+152|0,x[i>>2],x[e+84>>2]);d=Jd(e+144|0);x[31785]=0;h=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=h;d=dg(330,e+160|0,x[e+152>>2],x[e+156>>2],e+24|0);h=x[31785];x[31785]=0;if((h|0)==1){break P}h=ad(e+180|0,8,1,0,2);x[31785]=0;U(218,h|0,c|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break O}ub(d)}dc(i);break D}a=T(29088)|0;if((gb|0)!=($(29088)|0)){break N}Y(a|0)|0;d=0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)!=1){break w}a=N()|0;break N}a=N()|0;break N}a=N()|0;ub(d)}dc(f);break c}if(g){d=ad(e+80|0,(f|0)==2?8:16,1,0,0);x[31785]=0;U(218,d|0,c|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break D}a=N()|0;break c}c=D(x[c>>2],f-1|0)}x[31785]=0;P(186,b|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break D}}a=N()|0;break c}i=Nb(e+80|0);d=x[c>>2];x[31785]=0;S(338,e+180|0,b|0,d|0);d=x[31785];x[31785]=0;Q:{R:{if((d|0)!=1){h=e+180|0;d=pn(i,h);dc(h);if(!g){break Q}if((f|0)!=5){break R}C=e,E=vb(x[d>>2]),x[C+180>>2]=E;k=vb(x[e+84>>2]);while(1){h=x[e+180>>2];if(!Ib(h,k)){break R}l=h;h=y[h|0];v[l|0]=y[(h>>>7|0)+24961|0]^h;je(e+180|0);continue}}a=T(29088)|0;if((gb|0)!=($(29088)|0)){break z}Y(a|0)|0;d=0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)!=1){break C}a=N()|0;break z}le(e+112|0,x[d>>2],x[e+84>>2]);h=Jd(e+104|0);x[31785]=0;k=x[h+4>>2];x[e+32>>2]=x[h>>2];x[e+36>>2]=k;h=dg(330,e+124|0,x[e+112>>2],x[e+116>>2],e+32|0);k=x[31785];x[31785]=0;if((k|0)==1){break B}f=(f|0)==5;f=ad(e+180|0,f?16:8,1,0,f?16:1);x[31785]=0;U(218,f|0,c|0,h|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break A}ub(h)}dc(d)}j=j+1|0;continue}break}dc(i);break h}a=N()|0;break z}a=N()|0;ub(h)}dc(i);break c}dc(f);break h}d=0;v[e+182|0]=0;w[e+180>>1]=0;w[e+80>>1]=y[e+413|0]|y[e+414|0]<<8;v[e+82|0]=y[e+415|0];while(1){if((d|0)!=3){c=y[xb(e+80|0,d)|0];C=xb(e+180|0,d),E=c,v[C|0]=E;d=d+1|0;continue}break}S:{T:{U:{V:{d=_f(e+180|0);if(d){c=Nb(e+180|0);x[31785]=0;b=U(329,b|0,c|0,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break s}if(!b){break T}le(e+72|0,x[c>>2],x[c+4>>2]);b=Jd(e- -64|0);x[31785]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;b=dg(330,e+80|0,x[e+72>>2],x[e+76>>2],e+8|0);f=x[31785];x[31785]=0;if((f|0)==1){break V}x[31785]=0;V(339,a+1298332|0,b|0,d|0,1);d=x[31785];x[31785]=0;if((d|0)==1){break U}ub(b);dc(c)}x[31785]=0;W(340,e+52|0);b=x[31785];x[31785]=0;if((b|0)!=1){break S}a=N()|0;break c}a=N()|0;break r}a=N()|0;ub(b);break r}dc(c);d=0;break h}x[31785]=0;S(341,e+180|0,e+52|0,y[e+407|0]);b=x[31785];x[31785]=0;W:{X:{if((b|0)!=1){b=e+180|0;yb(a+1298344|0,b);tb(b);Eb(e+52|0);x[31785]=0;b=P(1,b|0,10106)|0;c=x[31785];x[31785]=0;if((c|0)==1){break X}yb(a+1298356|0,b);tb(b);x[31785]=0;b=P(1,e+52|0,5121)|0;c=x[31785];x[31785]=0;if((c|0)==1){break W}yb(a+1298368|0,b);tb(b);C=a+1298404|0,E=x[Gc(e+48|0,24)>>2],x[C>>2]=E;d=1;break h}a=N()|0;Eb(e+52|0);break c}a=N()|0;break c}a=N()|0;break c}dc(f);break h}a=N()|0;break c}a=N()|0;break c}a=N()|0;break q}a=N()|0}dc(c);break c}dc(f);break c}C=_b(x[Wb(x[a+484360>>2],y[q|0])>>2],i),E=i,w[C>>1]=E;Y:{Z:{if(!t){break Z}x[31785]=0;s=i&65535;d=U(199,r|0,s|0,64)|0;f=x[31785];x[31785]=0;if((f|0)==1){break Y}if(!d){break Z}f=z[a+480188>>1];h=0;while(1){d=f&65535;if(d>>>0<=h>>>0){break Z}d=_b(x[o>>2],D(d,i)+h|0);d=y[d|0]|y[d+1|0]<<8;_:{if(d>>>0>=(y[e+411|0]|y[e+412|0]<<8)>>>0){break _}j=0;u=0-h|0;A=d<<8;d=Vb(x[r>>2],i);d=gd(x[d>>2],x[x[d+48>>2]+12>>2],0,h&65535);while(1){if((j|0)==64){break _}jr(e+212|0,x[e+240>>2],x[e+244>>2],(j<<2)+A|0,4);f=x[e+212>>2];g=xb(f,0);n=y[g|0]&63;v[d|0]=n?n+48|0:0;k=xb(f,1);v[d+1|0]=y[k|0]<<2&60|y[g|0]>>>6;l=y[k|0];g=xb(f,2);k=y[xb(f,3)|0];f=y[g|0];g=k<<4|f>>>4;w[e+80>>1]=g;B=l>>>6|0;l=f<<2&60;f=B|l;$:{if(!(y[xb(e+312|0,l>>>3|0)|0]>>>(f&7)&1)|!(f|g)){break $}v[d+5|0]=g;l=k>>>4|0;v[d+4|0]=l;aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{switch(f|0){case 0:case 1:case 2:case 32:case 33:case 34:Mf(d,f&15,g&255);if(!y[d+4|0]){break $}v[d+2|0]=f>>>0<32?3:4;break $;case 9:v[d+3|0]=10;v[d+5|0]=g>>>1;if(g>>>0<512){break $}v[d+2|0]=15;v[d+4|0]=k>>>5;break $;case 10:case 42:if(g>>>0>254){break ka}f=f&15;break;case 50:break ba;case 48:break ca;case 43:break da;case 47:break ea;case 17:case 18:case 26:case 27:break fa;case 22:case 25:case 28:case 29:case 30:break ga;case 16:case 19:case 20:case 21:case 23:case 31:break ha;case 13:break ia;case 11:case 15:break ja;case 3:case 4:case 5:case 6:case 7:case 12:break la;default:break aa}}Mf(d,f,g&255);break $}v[d+3|0]=19;v[d+5|0]=l|(f>>>0<32?16:32);if(k&15){v[d+2|0]=3;v[d+4|0]=(g&240)>>>4;break $}v[d+2|0]=4;v[d+4|0]=g&15;break $}v[d+3|0]=(f|0)==11?12:16;C=d,E=Rv(g),v[C+5|0]=E;break $}v[d+3|0]=14;if((g&255)>>>0<64){break $}v[d+5|0]=0;break $}v[d+3|0]=19;v[d+5|0]=g&15|f<<4;break $}v[d+3|0]=19;w[e+160>>1]=15;C=d,E=y[Mc(e+80|0,e+160|0)|0]|f<<4,v[C+5|0]=E;break $}v[d+3|0]=19;if(g&255){v[d+5|0]=g&15|((f|0)==17?16:(f|0)==26?16:32);if(k>>>0<16){break $}v[d+2|0]=f>>>0>25?6:5;break $}v[d+5|0]=l|(f>>>0>25?-80:-96);break $}if(!g){break aa}v[d+3|0]=17;x[e+160>>2]=8;x[e+124>>2]=g+4;C=d,E=Zg(x[We(e+160|0,e+124|0)>>2]/8|0),v[C+5|0]=E;break $}v[d+3|0]=14;k=D(u,6)+d|0;n=z[a+480188>>1];f=0;while(1){if((f|0)==(n|0)){break $}g=k+D(f,6)|0;if(!y[g+3|0]){v[g+3|0]=12;C=g,E=Rv(s),v[C+5|0]=E}f=f+1|0;continue}}v[d+3|0]=9;f=g&7;if(f){v[d+5|0]=y[f+24953|0];break $}f=g>>>4|0;if((f|0)==128){break aa}v[d+5|0]=f;if(g>>>0<=2047){v[d+5|0]=f^128;break $}v[d+5|0]=f^-1;break $}v[d+5|0]=0;v[d+3|0]=0;if(!n){v[d|0]=255;break $}v[d+3|0]=25;break $}v[d+3|0]=0}j=j+1|0;f=z[a+480188>>1];d=D(f,6)+d|0;continue}}h=h+1|0;continue}}i=i+1|0;continue}break}a=N()|0;break c}a=N()|0;break b}}else{LD(a,d&65535);w[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;j=z[a+480188>>1];continue}break}dc(d);d=0;break g}a=N()|0;break c}dc(m)}kd(o)}fb=e+416|0;return d|0}a=N()|0;break c}a=N()|0;dc(d)}dc(m);break a}dc(d)}kd(o);Q(a|0);p()}function K0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a:{n=ek(b,13928);if(!n){break a}o=a+480192|0;b:while(1){if(!Mb(x[b>>2],x[b+8>>2],6)){break a}g=Mg(b);if(!(!((g|0)==(yn(13747)|0)|!(g&1616928864)|g&-2139062144)&(g|0)!=70791730)){Eh(b,4);break a}l=1;c=eh(b);while(1){e=l&65535;if(e>>>0>z[o>>1]){continue b}e=x[((e<<2)+a|0)+900380>>2];if(e){c:{f=0;if((yn(16962)|0)==(g|0)){Yb(b,c);break c}h=fb-48|0;fb=h;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{switch(g-1349079874|0){default:if((g|0)==1095062094){break t}if((g|0)==1095126087){break q}if((g|0)==1129524782){break z}if((g|0)==1145263150){break W}if((g|0)==1145979182){break V}if((g|0)==1179463214){break x}if((g|0)==1851469358){break D}if((g|0)==1179931728){break l}Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if((g|0)!=1196830254){if((g|0)==1229341486){break S}if((g|0)==1229345326){break R}if((g|0)==1264266798){break E}if((g|0)==1296182830){break Q}if((g|0)==1296248366){break O}if((g|0)==1297100334){break P}if((g|0)==1297110852){break o}if((g|0)==1298747438){break B}if((g|0)==1313692462){break F}if((g|0)==1313751342){break X}if((g|0)==1345203758){break ha}if((g|0)==1346711086){break j}if((g|0)==1346720334){break u}if((g|0)==1346722606){break H}if((g|0)==1346784327){break r}if((g|0)==1347175726){break ba}if((g|0)==1347179310){break ca}if((g|0)==1347437358){break M}if((g|0)==1347441454){break N}if((g|0)==1347443502){break K}if((g|0)==1347628590){break U}if((g|0)==1347633710){break aa}if((g|0)==1347634478){break $}if((g|0)==1347703884){break m}if((g|0)==1347831112){break w}if((g|0)==1347833672){break v}if((g|0)==1349076270){break i}if((g|0)==1349076315){break G}if((g|0)==1349078085){break Z}if((g|0)==1349078099){break _}if((g|0)==1349079131){break J}if((g|0)==1378758190){break n}if((g|0)==1381183022){break y}if((g|0)==1447374382){break k}if((g|0)==1447383630){break s}if((g|0)==1447385902){break I}if((g|0)==1447447623){break p}if((g|0)==1447839022){break fa}if((g|0)==1447842606){break ga}if((g|0)==1448106798){break L}if((g|0)==1448226350){break A}if((g|0)==1448291886){break T}if((g|0)==1448297006){break ea}if((g|0)==1448297774){break da}if((g|0)!=1682320942){if((g|0)==1718508334){break C}if((g|0)!=1179594286|c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Bw(b,c),x[q>>2]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+15|0]=r;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Bw(b,c),x[q+4>>2]=r;break e}if(c>>>0>4){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Bw(b,c),x[q+8>>2]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+61|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+62|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+63|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e- -64|0,r=Gd(b,c),v[q|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+81|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+82|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+83|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+84|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+101|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+102|0]=r;break e;case 0:if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+103|0]=r;break e;case 3:break Y;case 1:case 2:break d}}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+104|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+16|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+17|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+18|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+19|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+20|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+21|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+22|0]=r;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=oF(b,c),w[q+28>>1]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+30|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+31|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=nF(b,c),v[q+26|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+27|0]=r;break e}d=h+8|0;ce(d,b,c);i=ic(h+28|0,d);ub(d);j=Xh(e,0);d=x[j>>2];while(1){if(Od(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31785]=0;k=R(195,i|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break h}d=x[j>>2];q=wb(d,f),r=k,w[q>>1]=r;f=f+1|0;continue}}d=h+8|0;ce(d,b,c);i=ic(h+28|0,d);ub(d);j=Xh(e,1);d=x[j>>2];while(1){if(Od(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31785]=0;k=R(195,i|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){d=x[j>>2];q=wb(d,f),r=k,w[q>>1]=r;f=f+1|0;continue}break}f=N()|0;break g}d=h+8|0;ce(d,b,c);i=ic(h+28|0,d);ub(d);j=Xh(e,2);d=x[j>>2];while(1){if(Od(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31785]=0;k=R(195,i|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){d=x[j>>2];q=wb(d,f),r=k,w[q>>1]=r;f=f+1|0;continue}break}f=N()|0;break g}d=h+8|0;ce(d,b,c);i=ic(h+28|0,d);ub(d);j=Xh(e,0);d=x[j>>2];while(1){if(Od(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31785]=0;k=R(196,i|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){d=x[j>>2];q=wb(d,f),r=k,v[q+2|0]=r;f=f+1|0;continue}break}f=N()|0;break g}d=h+8|0;ce(d,b,c);i=ic(h+28|0,d);ub(d);j=Xh(e,1);d=x[j>>2];while(1){if(Od(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31785]=0;k=R(196,i|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){d=x[j>>2];q=wb(d,f),r=k,v[q+2|0]=r;f=f+1|0;continue}break}f=N()|0;break g}d=h+8|0;ce(d,b,c);i=ic(h+28|0,d);ub(d);j=Xh(e,2);d=x[j>>2];while(1){if(Od(d,x[j+4>>2])>>>0<=f>>>0){ub(i);break e}x[31785]=0;k=R(196,i|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){d=x[j>>2];q=wb(d,f),r=k,v[q+2|0]=r;f=f+1|0;continue}break}f=N()|0;break g}if(c>>>0>128){break d}j=e+108|0;d=h+8|0;ce(d,b,c);i=ic(h+28|0,d);ub(d);while(1){if((f|0)==128){ub(i);break e}x[31785]=0;d=R(196,i|0)|0;k=x[31785];x[31785]=0;if((k|0)!=1){q=xb(j,f),r=d,v[q|0]=r;f=f+1|0;continue}break}f=N()|0;break g}if(c>>>0>256){break d}j=e+236|0;d=h+8|0;ce(d,b,c);i=ic(h+28|0,d);ub(d);while(1){if((f|0)==128){ub(i);break e}x[31785]=0;d=R(195,i|0)|0;k=x[31785];x[31785]=0;if((k|0)!=1){q=_b(j,f),r=d,w[q>>1]=r;f=f+1|0;continue}break}f=N()|0;break g}if(c>>>0>32){break d}j=e+492|0;d=h+8|0;ce(d,b,c);i=ic(h+28|0,d);ub(d);d=Fb(d);while(1){if((c|0)==(f|0)){break f}x[31785]=0;k=R(197,i|0)|0;m=x[31785];x[31785]=0;ia:{if((m|0)==1){break ia}x[31785]=0;P(198,d|0,k|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break ia}f=f+1|0;continue}break}f=N()|0;tb(d);break g}if(c>>>0>32){break d}j=e+524|0;d=h+8|0;ce(d,b,c);i=ic(h+28|0,d);ub(d);d=Fb(d);ja:{while(1){if((c|0)!=(f|0)){x[31785]=0;k=R(197,i|0)|0;m=x[31785];x[31785]=0;if((m|0)==1){break ja}x[31785]=0;P(198,d|0,k|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break ja}f=f+1|0;continue}break}zc(j,d);tb(d);ub(i);break e}f=N()|0;tb(d);break g}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+34|0]=r;break e}if(c>>>0>2){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=oF(b,c),w[q+12>>1]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+23|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+24|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+25|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+35|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+36|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+105|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+85|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+65|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+100|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+80|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=Gd(b,c),v[q+60|0]=r;break e}if(c>>>0>1){break d}if(!Mb(x[b>>2],x[b+8>>2],c)){break d}q=e,r=nF(b,c),v[q+33|0]=r;break e}f=1;i=lp(b,c);if(!kp(i)){break d}v[e+14|0]=i;break d}q=e,r=D(zw(b,c),1e4)+(A[e+40>>2]%1e4|0)|0,x[q+40>>2]=r;break e}d=(zw(b,c)>>>0)%1e4|0;f=x[e+40>>2];x[e+40>>2]=d+f-(f>>>0)%1e4;break e}x[h+28>>2]=240;q=h,r=lp(b,c),x[q+8>>2]=r;dh(e+48|0,x[Gb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;q=h,r=lp(b,c),x[q+8>>2]=r;dh(e+68|0,x[Gb(h+28|0,h+8|0)>>2]);break e}x[h+28>>2]=240;q=h,r=lp(b,c),x[q+8>>2]=r;dh(e+88|0,x[Gb(h+28|0,h+8|0)>>2]);break e}f=N()|0}ub(i);Q(f|0);p()}zc(j,d);tb(d);ub(i)}f=1}fb=h+48|0;if(!f){Yb(b,c);break c}if((yn(16967)|0)==(g|0)){f=y[e+15|0];v[e+15|0]=0;v[e+100|0]=y[e+100|0]&224|(f>>>5&4|f>>>6&1);v[e+60|0]=f>>>1&2|(f<<1&4|(y[e+60|0]&240|f&1));v[e+80|0]=y[e+80|0]&240|(f>>>4&2|(f>>>2&4|f>>>3&1))}}}l=l+1|0;continue}}}return n|0}function Ed(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(a>>>0<=244){g=x[31661];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=g>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+126684|0;d=x[a+126692>>2];a=x[d+8>>2];j:{if((b|0)==(a|0)){m=126644,n=vua(-2,c)&g,x[m>>2]=n;break j}x[a+12>>2]=b;x[b+8>>2]=a}a=d+8|0;b=c<<3;x[d+4>>2]=b|3;b=b+d|0;x[b+4>>2]=x[b+4>>2]|1;break a}k=x[31663];if(k>>>0>=h>>>0){break i}if(b){a=2<<c;a=(0-a|a)&b<<c;d=rua(0-a&a);a=d<<3;b=a+126684|0;e=x[a+126692>>2];a=x[e+8>>2];k:{if((b|0)==(a|0)){g=vua(-2,d)&g;x[31661]=g;break k}x[a+12>>2]=b;x[b+8>>2]=a}x[e+4>>2]=h|3;c=e+h|0;a=d<<3;d=a-h|0;x[c+4>>2]=d|1;x[a+e>>2]=d;if(k){b=(k&-8)+126684|0;f=x[31666];a=1<<(k>>>3);l:{if(!(a&g)){x[31661]=a|g;a=b;break l}a=x[b+8>>2]}x[b+8>>2]=f;x[a+12>>2]=f;x[f+12>>2]=b;x[f+8>>2]=a}a=e+8|0;x[31666]=c;x[31663]=d;break a}j=x[31662];if(!j){break i}c=x[(rua(0-j&j)<<2)+126948>>2];f=(x[c+4>>2]&-8)-h|0;b=c;while(1){m:{a=x[b+16>>2];if(!a){a=x[b+20>>2];if(!a){break m}}b=(x[a+4>>2]&-8)-h|0;d=b>>>0<f>>>0;f=d?b:f;c=d?a:c;b=a;continue}break}i=x[c+24>>2];d=x[c+12>>2];if((d|0)!=(c|0)){a=x[c+8>>2];x[a+12>>2]=d;x[d+8>>2]=a;break b}b=c+20|0;a=x[b>>2];if(!a){a=x[c+16>>2];if(!a){break h}b=c+16|0}while(1){e=b;d=a;b=a+20|0;a=x[b>>2];if(a){continue}b=d+16|0;a=x[d+16>>2];if(a){continue}break}x[e>>2]=0;break b}h=-1;if(a>>>0>4294967231){break i}a=a+11|0;h=a&-8;j=x[31662];if(!j){break i}f=0-h|0;g=0;n:{if(h>>>0<256){break n}g=31;if(h>>>0>16777215){break n}a=G(a>>>8|0);g=((h>>>38-a&1)-(a<<1)|0)+62|0}b=x[(g<<2)+126948>>2];o:{p:{q:{if(!b){a=0;break q}a=0;c=h<<((g|0)!=31?25-(g>>>1|0)|0:0);while(1){r:{e=(x[b+4>>2]&-8)-h|0;if(e>>>0>=f>>>0){break r}d=b;f=e;if(e){break r}f=0;a=b;break p}e=x[b+20>>2];b=x[((c>>>29&4)+b|0)+16>>2];a=e?(e|0)==(b|0)?a:e:a;c=c<<1;if(b){continue}break}}if(!(a|d)){d=0;a=2<<g;a=(0-a|a)&j;if(!a){break i}a=x[(rua(a&0-a)<<2)+126948>>2]}if(!a){break o}}while(1){b=(x[a+4>>2]&-8)-h|0;c=b>>>0<f>>>0;f=c?b:f;d=c?a:d;b=x[a+16>>2];if(b){a=b}else{a=x[a+20>>2]}if(a){continue}break}}if(!d|x[31663]-h>>>0<=f>>>0){break i}g=x[d+24>>2];c=x[d+12>>2];if((d|0)!=(c|0)){a=x[d+8>>2];x[a+12>>2]=c;x[c+8>>2]=a;break c}b=d+20|0;a=x[b>>2];if(!a){a=x[d+16>>2];if(!a){break g}b=d+16|0}while(1){e=b;c=a;b=a+20|0;a=x[b>>2];if(a){continue}b=c+16|0;a=x[c+16>>2];if(a){continue}break}x[e>>2]=0;break c}a=x[31663];if(a>>>0>=h>>>0){d=x[31666];b=a-h|0;s:{if(b>>>0>=16){c=d+h|0;x[c+4>>2]=b|1;x[a+d>>2]=b;x[d+4>>2]=h|3;break s}x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;c=0;b=0}x[31663]=b;x[31666]=c;a=d+8|0;break a}i=x[31664];if(i>>>0>h>>>0){b=i-h|0;x[31664]=b;c=x[31667];a=c+h|0;x[31667]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(x[31779]){c=x[31781]}else{x[31782]=-1;x[31783]=-1;x[31780]=4096;x[31781]=4096;x[31779]=l+12&-16^1431655768;x[31784]=0;x[31772]=0;c=4096}e=j+c|0;f=0-c|0;b=e&f;if(b>>>0<=h>>>0){break a}d=x[31771];if(d){c=x[31769];g=c+b|0;if(d>>>0<g>>>0|c>>>0>=g>>>0){break a}}t:{if(!(y[127088]&4)){u:{v:{w:{x:{d=x[31667];if(d){a=127092;while(1){c=x[a>>2];if(c>>>0<=d>>>0&d>>>0<c+x[a+4>>2]>>>0){break x}a=x[a+8>>2];if(a){continue}break}}c=Wo(0);if((c|0)==-1){break u}g=b;d=x[31780];a=d-1|0;if(a&c){g=(b-c|0)+(a+c&0-d)|0}if(g>>>0<=h>>>0){break u}d=x[31771];if(d){a=x[31769];f=a+g|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break u}}a=Wo(g);if((c|0)!=(a|0)){break w}break t}g=f&e-i;c=Wo(g);if((c|0)==(x[a>>2]+x[a+4>>2]|0)){break v}a=c}if((a|0)==-1){break u}if(h+48>>>0<=g>>>0){c=a;break t}c=x[31781];c=c+(j-g|0)&0-c;if((Wo(c)|0)==-1){break u}g=c+g|0;c=a;break t}if((c|0)!=-1){break t}}x[31772]=x[31772]|4}c=Wo(b);a=Wo(0);if((c|0)==-1|(a|0)==-1|a>>>0<=c>>>0){break d}g=a-c|0;if(g>>>0<=h+40>>>0){break d}}a=x[31769]+g|0;x[31769]=a;if(a>>>0>A[31770]){x[31770]=a}y:{e=x[31667];if(e){a=127092;while(1){d=x[a>>2];b=x[a+4>>2];if((d+b|0)==(c|0)){break y}a=x[a+8>>2];if(a){continue}break}break f}a=x[31665];if(!(a>>>0<=c>>>0?a:0)){x[31665]=c}a=0;x[31774]=g;x[31773]=c;x[31669]=-1;x[31670]=x[31779];x[31776]=0;while(1){d=a<<3;b=d+126684|0;x[d+126692>>2]=b;x[d+126696>>2]=b;a=a+1|0;if((a|0)!=32){continue}break}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[31664]=b;a=a+c|0;x[31667]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[31668]=x[31783];break e}if(y[a+12|0]&8|d>>>0>e>>>0|c>>>0<=e>>>0){break f}x[a+4>>2]=b+g;a=e+8&7?-8-e&7:0;c=a+e|0;x[31667]=c;b=x[31664]+g|0;a=b-a|0;x[31664]=a;x[c+4>>2]=a|1;x[(b+e|0)+4>>2]=40;x[31668]=x[31783];break e}d=0;break b}c=0;break c}if(A[31665]>c>>>0){x[31665]=c}b=c+g|0;a=127092;z:{A:{B:{C:{D:{E:{while(1){if((b|0)!=x[a>>2]){a=x[a+8>>2];if(a){continue}break E}break}if(!(y[a+12|0]&8)){break D}}a=127092;while(1){b=x[a>>2];if(b>>>0<=e>>>0){f=b+x[a+4>>2]|0;if(f>>>0>e>>>0){break C}}a=x[a+8>>2];continue}}x[a>>2]=c;x[a+4>>2]=x[a+4>>2]+g;j=(c+8&7?-8-c&7:0)+c|0;x[j+4>>2]=h|3;g=b+(b+8&7?-8-b&7:0)|0;i=h+j|0;a=g-i|0;if((e|0)==(g|0)){x[31667]=i;a=x[31664]+a|0;x[31664]=a;x[i+4>>2]=a|1;break A}if(x[31666]==(g|0)){x[31666]=i;a=x[31663]+a|0;x[31663]=a;x[i+4>>2]=a|1;x[a+i>>2]=a;break A}f=x[g+4>>2];if((f&3)==1){e=f&-8;F:{if(f>>>0<=255){c=x[g+12>>2];b=x[g+8>>2];if((c|0)==(b|0)){m=126644,n=x[31661]&vua(-2,f>>>3|0),x[m>>2]=n;break F}x[b+12>>2]=c;x[c+8>>2]=b;break F}h=x[g+24>>2];c=x[g+12>>2];G:{if((g|0)!=(c|0)){b=x[g+8>>2];x[b+12>>2]=c;x[c+8>>2]=b;break G}H:{f=g+20|0;b=x[f>>2];if(b){break H}f=g+16|0;b=x[f>>2];if(b){break H}c=0;break G}while(1){d=f;c=b;f=c+20|0;b=x[f>>2];if(b){continue}f=c+16|0;b=x[c+16>>2];if(b){continue}break}x[d>>2]=0}if(!h){break F}d=x[g+28>>2];b=(d<<2)+126948|0;I:{if(x[b>>2]==(g|0)){x[b>>2]=c;if(c){break I}m=126648,n=x[31662]&vua(-2,d),x[m>>2]=n;break F}x[h+(x[h+16>>2]==(g|0)?16:20)>>2]=c;if(!c){break F}}x[c+24>>2]=h;b=x[g+16>>2];if(b){x[c+16>>2]=b;x[b+24>>2]=c}b=x[g+20>>2];if(!b){break F}x[c+20>>2]=b;x[b+24>>2]=c}g=e+g|0;f=x[g+4>>2];a=a+e|0}x[g+4>>2]=f&-2;x[i+4>>2]=a|1;x[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+126684|0;c=x[31661];a=1<<(a>>>3);J:{if(!(c&a)){x[31661]=a|c;a=b;break J}a=x[b+8>>2]}x[b+8>>2]=i;x[a+12>>2]=i;x[i+12>>2]=b;x[i+8>>2]=a;break A}f=31;if(a>>>0<=16777215){b=G(a>>>8|0);f=((a>>>38-b&1)-(b<<1)|0)+62|0}x[i+28>>2]=f;x[i+16>>2]=0;x[i+20>>2]=0;b=(f<<2)+126948|0;d=x[31662];c=1<<f;K:{if(!(d&c)){x[31662]=c|d;x[b>>2]=i;break K}f=a<<((f|0)!=31?25-(f>>>1|0)|0:0);c=x[b>>2];while(1){b=c;if((x[c+4>>2]&-8)==(a|0)){break B}c=f>>>29|0;f=f<<1;d=(c&4)+b|0;c=x[d+16>>2];if(c){continue}break}x[d+16>>2]=i}x[i+24>>2]=b;x[i+12>>2]=i;x[i+8>>2]=i;break A}d=g-40|0;a=c+8&7?-8-c&7:0;b=d-a|0;x[31664]=b;a=a+c|0;x[31667]=a;x[a+4>>2]=b|1;x[(c+d|0)+4>>2]=40;x[31668]=x[31783];a=(f+(f-39&7?39-f&7:0)|0)-47|0;d=a>>>0<e+16>>>0?e:a;x[d+4>>2]=27;a=x[31776];x[d+16>>2]=x[31775];x[d+20>>2]=a;a=x[31774];x[d+8>>2]=x[31773];x[d+12>>2]=a;x[31775]=d+8;x[31774]=g;x[31773]=c;x[31776]=0;a=d+24|0;while(1){x[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((d|0)==(e|0)){break e}x[d+4>>2]=x[d+4>>2]&-2;f=d-e|0;x[e+4>>2]=f|1;x[d>>2]=f;if(f>>>0<=255){b=(f&-8)+126684|0;c=x[31661];a=1<<(f>>>3);L:{if(!(c&a)){x[31661]=a|c;a=b;break L}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break e}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+126948|0;d=x[31662];c=1<<a;M:{if(!(d&c)){x[31662]=c|d;x[b>>2]=e;break M}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);d=x[b>>2];while(1){b=d;if((f|0)==(x[b+4>>2]&-8)){break z}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=x[c+16>>2];if(d){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break e}a=x[b+8>>2];x[a+12>>2]=i;x[b+8>>2]=i;x[i+24>>2]=0;x[i+12>>2]=b;x[i+8>>2]=a}a=j+8|0;break a}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=x[31664];if(a>>>0<=h>>>0){break d}b=a-h|0;x[31664]=b;c=x[31667];a=c+h|0;x[31667]=a;x[a+4>>2]=b|1;x[c+4>>2]=h|3;a=c+8|0;break a}x[31660]=48;a=0;break a}N:{if(!g){break N}b=x[d+28>>2];a=(b<<2)+126948|0;O:{if(x[a>>2]==(d|0)){x[a>>2]=c;if(c){break O}j=vua(-2,b)&j;x[31662]=j;break N}x[g+(x[g+16>>2]==(d|0)?16:20)>>2]=c;if(!c){break N}}x[c+24>>2]=g;a=x[d+16>>2];if(a){x[c+16>>2]=a;x[a+24>>2]=c}a=x[d+20>>2];if(!a){break N}x[c+20>>2]=a;x[a+24>>2]=c}P:{if(f>>>0<=15){a=f+h|0;x[d+4>>2]=a|3;a=a+d|0;x[a+4>>2]=x[a+4>>2]|1;break P}x[d+4>>2]=h|3;e=d+h|0;x[e+4>>2]=f|1;x[e+f>>2]=f;if(f>>>0<=255){b=(f&-8)+126684|0;c=x[31661];a=1<<(f>>>3);Q:{if(!(c&a)){x[31661]=a|c;a=b;break Q}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a;break P}a=31;if(f>>>0<=16777215){a=G(f>>>8|0);a=((f>>>38-a&1)-(a<<1)|0)+62|0}x[e+28>>2]=a;x[e+16>>2]=0;x[e+20>>2]=0;b=(a<<2)+126948|0;R:{c=1<<a;S:{if(!(c&j)){x[31662]=c|j;x[b>>2]=e;break S}a=f<<((a|0)!=31?25-(a>>>1|0)|0:0);h=x[b>>2];while(1){b=h;if((x[b+4>>2]&-8)==(f|0)){break R}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=x[c+16>>2];if(h){continue}break}x[c+16>>2]=e}x[e+24>>2]=b;x[e+12>>2]=e;x[e+8>>2]=e;break P}a=x[b+8>>2];x[a+12>>2]=e;x[b+8>>2]=e;x[e+24>>2]=0;x[e+12>>2]=b;x[e+8>>2]=a}a=d+8|0;break a}T:{if(!i){break T}b=x[c+28>>2];a=(b<<2)+126948|0;U:{if(x[a>>2]==(c|0)){x[a>>2]=d;if(d){break U}m=126648,n=vua(-2,b)&j,x[m>>2]=n;break T}x[i+(x[i+16>>2]==(c|0)?16:20)>>2]=d;if(!d){break T}}x[d+24>>2]=i;a=x[c+16>>2];if(a){x[d+16>>2]=a;x[a+24>>2]=d}a=x[c+20>>2];if(!a){break T}x[d+20>>2]=a;x[a+24>>2]=d}V:{if(f>>>0<=15){a=f+h|0;x[c+4>>2]=a|3;a=a+c|0;x[a+4>>2]=x[a+4>>2]|1;break V}x[c+4>>2]=h|3;d=c+h|0;x[d+4>>2]=f|1;x[d+f>>2]=f;if(k){b=(k&-8)+126684|0;e=x[31666];a=1<<(k>>>3);W:{if(!(a&g)){x[31661]=a|g;a=b;break W}a=x[b+8>>2]}x[b+8>>2]=e;x[a+12>>2]=e;x[e+12>>2]=b;x[e+8>>2]=a}x[31666]=d;x[31663]=f}a=c+8|0}fb=l+16|0;return a}function pua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=fb-272|0;fb=e;xc(b);if(Ar(b,18647)){o=Fb(e+260|0);x[31785]=0;g=P(233,b|0,o|0)|0;d=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{if((d|0)!=1){if(!g){break a}x[31785]=0;g=P(248,b|0,e+253|0)|0;d=x[31785];x[31785]=0;g:{if((d|0)==1){break g}if(!g){break a}if(!X$(y[e+253|0],y[e+254|0])){break a}i=Bc(W$(e+253|0),hb);g=x[b+8>>2];d=x[b>>2];x[31785]=0;g=U(153,d|0,g|0,i|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break g}if(!g){break a}if(!c){break b}x[31785]=0;O(249,a|0,4096);d=x[31785];x[31785]=0;if((d|0)==1){break g}x[31785]=0;O(250,a+1298308|0,o|0);d=x[31785];x[31785]=0;if((d|0)==1){break g}d=y[e+255|0];w[a+480188>>1]=32;w[a+480192>>1]=d;Ch(a,1);x[31785]=0;f=P(1,e+240|0,9496)|0;d=x[31785];x[31785]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((d|0)!=1){yb(a+1298344|0,f);tb(f);x[31785]=0;f=P(1,e+228|0,7125)|0;d=x[31785];x[31785]=0;if((d|0)==1){break p}yb(a+1298356|0,f);tb(f);x[31785]=0;W(251,e+32|0);d=x[31785];x[31785]=0;if((d|0)==1){break o}v[e+204|0]=y[e+254|0];x[31785]=0;v[e|0]=y[e+253|0];O(252,e+216|0,e|0);d=x[31785];x[31785]=0;if((d|0)==1){break n}x[31785]=0;V(253,e+80|0,e+32|0,e+204|0,e+216|0);d=x[31785];x[31785]=0;if((d|0)==1){break m}d=e+80|0;yb(a+1298368|0,d);tb(d);tb(e+216|0);Eb(e+32|0);s=a+1298404|0,t=x[Gc(d,4)>>2],x[s>>2]=t;if(y[e+253|0]<2){break i}w[e+80>>1]=8192;x[31785]=0;f=R(192,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break k}w[e+32>>1]=f;s=a,t=D(z[se(e+80|0,e+32|0)>>1],1e4)>>>8|0,x[s+480204>>2]=t;x[31785]=0;v[e+80|0]=1;f=R(200,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break j}v[e+32|0]=f;s=a,t=y[af(e+80|0,e+32|0)|0],x[s+480196>>2]=t;x[31785]=0;P(186,b|0,3)|0;d=x[31785];x[31785]=0;if((d|0)!=1){x[31785]=0;f=R(192,b|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break h}}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break l}b=N()|0;tb(e+216|0)}Eb(e+32|0);break c}b=N()|0;break c}b=N()|0;break c}v[e+80|0]=32;x[31785]=0;f=R(200,b|0)|0;d=x[31785];x[31785]=0;q:{if((d|0)!=1){v[e+32|0]=f;s=a,t=D(y[af(e+80|0,e+32|0)|0],1e4),x[s+480204>>2]=t;x[31785]=0;v[e+80|0]=1;f=R(200,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break q}v[e+32|0]=f;s=a,t=y[af(e+80|0,e+32|0)|0],x[s+480196>>2]=t;x[31785]=0;f=R(200,b|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break h}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}x[a+480208>>2]=f>>>2&16|12;m=Nb(e+216|0);k=e+80|12;n=Nb(e+204|0);q=a+480190|0;r=1;while(1){r:{s:{d=r&65535;if(d>>>0>z[a+480192>>1]){break s}x[31785]=0;h=U(254,a|0,d|0,0)|0;d=x[31785];x[31785]=0;t:{if((d|0)==1){break t}if(!h){break s}x[31785]=0;f=P(243,b|0,h+492|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break t}if(!f){break s}x[31785]=0;l=R(200,b|0)|0;d=x[31785];x[31785]=0;u:{v:{w:{if((d|0)!=1){Tb(e+80|0,0,120);if(!l){break r}x:{if(y[e+253|0]){x[31785]=0;f=P(255,b|0,e+80|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break w}if(!f){break r}if(y[e+253|0]){break x}}d=gc(e+72|0,k,96);f=x[d>>2];d=x[d+4>>2];x[31785]=0;Rn(162,e+32|0,b,f,d);d=x[31785];x[31785]=0;if((d|0)==1){break v}if(!x[e+36>>2]){break r}}i=h+236|0;f=0;break u}b=N()|0;break d}b=N()|0;break d}b=N()|0;break d}while(1){if((f|0)!=120){g=z[q>>1];d=y[(e+80|0)+f|0];s=_b(i,f),t=(d+g|0)+1|0,w[s>>1]=t;f=f+1|0;continue}break}x[31785]=0;f=h+48|0;S(256,e|0,f|0,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break e}x[31785]=0;j=h+68|0;S(256,e+16|0,j|0,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break e}x[31785]=0;i=h+88|0;S(256,e- -64|0,i|0,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break e}x[31785]=0;O(257,b|0,e+56|0);d=x[31785];x[31785]=0;if((d|0)==1){break f}x[h>>2]=(y[e+57|0]|y[e+58|0]<<8)&4095;d=y[e+57|0]|y[e+58|0]<<8;iE(y[e+59|0]|y[e+60|0]<<8,f,0);iE(y[e+59|0]|y[e+60|0]<<8,j,1);iE(y[e+59|0]|y[e+60|0]<<8,i,2);s=e,t=vb(x[f>>2]),x[s+32>>2]=t;f=d>>>12|0;d=vb(x[h+52>>2]);while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)- -64>>>0)/127;s=g,t=y[Ub(e+28|0,e+54|0)|0],v[s+2|0]=t;Pe(e+32|0);continue}else{s=e,t=vb(x[j>>2]),x[s+32>>2]=t;d=vb(x[h+72>>2])}break}while(1){g=x[e+32>>2];if(Ib(g,d)){v[e+28|0]=64;v[e+54|0]=((y[g+2|0]<<6)+128>>>0)/255;s=g,t=y[Ub(e+28|0,e+54|0)|0],v[s+2|0]=t;Pe(e+32|0);continue}break}s=e,t=vb(x[i>>2]),x[s+32>>2]=t;j=f&3;i=vb(x[h+92>>2]);while(1){f=x[e+32>>2];if(Ib(f,i)){g=v[f+2|0];d=g>>31^-1;g=g^-128;h=j&31;if((j&63)>>>0>=32){d=g<<h;h=0}else{d=(1<<h)-1&g>>>32-h|d<<h;h=g<<h}y:{if((d|0)>=-1&h>>>0>=4294967292|(d|0)>=0){g=h+4|0;d=(((g>>>0<4?d+1|0:d)&7)<<29|g>>>3)&536870911;g=0;break y}g=0-((h>>>0>3)+d|0)|0;d=3-h|0;g=((g&7)<<29|d>>>3)&536870911;d=0-g|0;g=0-((g|0)!=0)|0}s=f,t=Fc(d,g)^128,v[s+2|0]=t;Pe(e+32|0);continue}else{d=z[q>>1]+1|0;w[e+54>>1]=d;f=0;j=d&65535;d=4e3-j|0;i=d>>>0<=4e3?d:0;z:{A:{B:{while(1){if((f|0)==(l|0)){break A}if((f|0)==(i|0)){x[31785]=0;P(186,b|0,20)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break A}b=N()|0;break d}x[31785]=0;g=f+j|0;P(243,b|0,((g<<5)+a|0)+946304|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break z}x[31785]=0;O(258,b|0,e+32|0);d=x[31785];x[31785]=0;C:{if((d|0)==1){break C}x[31785]=0;O(259,e+32|0,(D(g,104)+a|0)+484380|0);d=x[31785];x[31785]=0;if((d|0)==1){break C}x[31785]=0;w[e+28>>1]=y[e+56|0]|f<<8&32512|((y[e+51|0]&3)!=0)<<15;O(260,n|0,e+28|0);d=x[31785];x[31785]=0;if((d|0)==1){break B}f=f+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}x[31785]=0;O(260,m|0,e+54|0);d=x[31785];x[31785]=0;if((d|0)!=1){x[e+32>>2]=3999;x[e+28>>2]=l+z[q>>1];s=q,t=x[pd(e+32|0,e+28|0)>>2],w[s>>1]=t;break r}b=N()|0;break d}b=N()|0;break d}}}b=N()|0;break d}g=Fb(e+80|0);x[31785]=0;f=P(233,b|0,g|0)|0;d=x[31785];x[31785]=0;D:{E:{F:{G:{H:{if((d|0)!=1){I:{if(f){x[31785]=0;S(261,e+32|0,21,g|0);d=x[31785];x[31785]=0;if((d|0)==1){break I}d=e+32|0;yb(a+1298320|0,d);tb(d)}tb(g);f=0;J:{while(1){if((f|0)==32){x[31785]=0;f=P(262,b|0,e+16|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break G}if(!f){break F}g=x[e+16>>2];if(g>>>0<12){break H}f=x[b+8>>2];d=x[b>>2];x[31785]=0;f=U(153,d|0,f|0,g-11|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break G}if(f){break J}break H}d=(f<<5)+a|0;Ye(d+480280|0);x[31785]=0;O(234,b|0,d+480289|0);d=x[31785];x[31785]=0;if((d|0)!=1){f=f+1|0;continue}break}b=N()|0;break d}d=x[e+16>>2]-11|0;x[e+64>>2]=d;k=Nb(e+80|0);x[31785]=0;S(237,b|0,k|0,d|0);d=x[31785];x[31785]=0;K:{if((d|0)!=1){x[e+32>>2]=50529027;d=e+32|0;s=e,t=D(x[Gb(e- -64|0,d)>>2],85),x[s+56>>2]=t;l=Fb(d);x[e>>2]=x[e+20>>2];d=x[Gb(e+56|0,e)>>2];x[31785]=0;O(117,l|0,d|0);d=x[31785];x[31785]=0;L:{if((d|0)==1){break L}f=0;M:{while(1){d=x[e+64>>2];if(d>>>0<=f>>>0){break M}j=x[k>>2];g=y[xb(j,f)|0];h=d;d=f+1|0;if(!((g|0)!=255|h-d>>>0<2)){i=v[xb(j,d)|0];g=y[xb(j,f+2|0)|0];d=x[zb(e+12|0,yf(l))>>2];x[31785]=0;V(240,l|0,d|0,g|0,i|0);d=x[31785];x[31785]=0;if((d|0)!=1){f=f+3|0;continue}break L}x[31785]=0;O(118,l|0,g<<24>>24);g=x[31785];x[31785]=0;f=d;if((g|0)!=1){continue}break}break L}x[31785]=0;S(238,e|0,21,l|0);d=x[31785];x[31785]=0;if((d|0)!=1){N:{i=yb(l,e);tb(e);g=Jb(i);f=y[i+11|0];d=x[i+4>>2];x[31785]=0;aa(239,a+1298332|0,g|0,Wc(d,f)|0,74,0);d=x[31785];x[31785]=0;if((d|0)==1){break N}tb(i);dc(k);break H}}}b=N()|0;tb(l);break K}b=N()|0}dc(k);break d}}b=N()|0;tb(g);break d}f=y[a+484376|0];d=x[a+484360>>2];x[31785]=0;S(241,Wb(d,f)|0,b|0,y[e+258|0]|y[e+259|0]<<8);d=x[31785];x[31785]=0;if((d|0)==1){break G}i=c&1;if(i){x[31785]=0;O(226,a+484344|0,y[e+256|0]|y[e+257|0]<<8);d=x[31785];x[31785]=0;if((d|0)==1){break G}}j=a+484344|0;d=b;f=0;while(1){O:{if((y[e+256|0]|y[e+257|0]<<8)>>>0>f>>>0){g=x[d+8>>2];b=x[d>>2];x[31785]=0;g=U(153,b|0,g|0,4)|0;b=x[31785];x[31785]=0;if((b|0)==1){break D}if(g){break O}}if(!(c&2)){break F}f=0;g=a+480190|0;while(1){b=z[g>>1];if(f>>>0>=b>>>0){f=0;i=a+480190|0;while(1){if(b>>>0<=f>>>0){break F}g=z[_b(x[n>>2],f)>>1];c=g&255;P:{if(!c){break P}d=x[m>>2];c=c-1&65535;if(Xc(d,x[m+4>>2])>>>0<=c>>>0){break P}h=b;b=z[_b(d,c)>>1]+(g>>>8&127)&65535;if(h>>>0<b>>>0){break P}c=D(b,104);b=c+a|0;j=b+484380|0;g=x[j>>2];if(!ge(g,x[b+484400>>2])){break P}d=a+484380|0;c=d+c|0;b=z[c+34>>1];d=d+D(f+1|0,104)|0;x[d>>2]=g;w[d+34>>1]=z[d+34>>1]&65534|b&1;if(!Bh(d)){break P}yc(x[d+20>>2],x[c+20>>2],Rk(x[j>>2],z[j+34>>1]))}f=f+1|0;b=z[i>>1];continue}}b=z[_b(x[n>>2],f)>>1];if(b&255){f=f+1|0;continue}f=f+1|0;c=D(f,104)+a|0;b=ad(e+80|0,w[c+484414>>1]&1?16:8,1,0,b<<16>>16<0?6:0);x[31785]=0;U(218,b|0,c+484380|0,d|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}break}b=N()|0;break d}x[31785]=0;g=R(154,d|0)|0;b=x[31785];x[31785]=0;Q:{R:{S:{T:{if((b|0)!=1){x[31785]=0;S(188,e+32|0,d|0,g|0);b=x[31785];x[31785]=0;if((b|0)==1){break T}b=e+32|0;k=ic(e+80|0,b);ub(b);if(!i){break R}x[31785]=0;g=R(200,k|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Q}x[31785]=0;P(186,k|0,1)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Q}x[31785]=0;g=U(199,j|0,f&65535,g+1|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break Q}if(!g){break R}x[31785]=0;g=P(235,k|0,e+32|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break E}if(!g){break S}b=x[j>>2];x[31785]=0;O(236,Vb(b,f)|0,e+32|0);b=x[31785];x[31785]=0;if((b|0)!=1){break S}break E}b=N()|0;break d}b=N()|0;break d}b=x[j>>2];x[31785]=0;S(242,Vb(b,f)|0,1,k|0);b=x[31785];x[31785]=0;if((b|0)==1){break E}}ub(k);f=f+1|0;continue}break}break E}b=N()|0;break d}kd(n);kd(m);break b}b=N()|0;ub(k);break d}b=N()|0;break d}r=r+1|0;continue}}b=N()|0;break c}b=N()|0;break c}b=N()|0;break d}b=N()|0}kd(n);kd(m)}tb(o);Q(b|0);p()}f=1}tb(o)}fb=e+272|0;return f|0}function sK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,F=0,G=0,H=E(0),I=0;e=fb-144|0;fb=e;d=Tb(e,0,144);x[d+76>>2]=-1;x[d+44>>2]=a;x[d+32>>2]=1202;x[d+84>>2]=a;s=c;a=0;j=fb-304|0;fb=j;a:{b:{c:{d:{if(x[d+4>>2]){break d}Oy(d);if(x[d+4>>2]){break d}break c}h=y[b|0];if(!h){break a}e:{f:{g:{h:{while(1){i:{c=h&255;j:{if(pl(c)){while(1){h=b;b=b+1|0;if(pl(y[h+1|0])){continue}break}Fi(d,0,0);while(1){b=x[d+4>>2];k:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break k}b=ud(d)}if(pl(b)){continue}break}b=x[d+4>>2];c=x[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;e=b;g=m+x[d+124>>2]|0;c=b>>31;b=n+x[d+120>>2]|0;g=c+(b>>>0<n>>>0?g+1|0:g)|0;n=b+e|0;m=n>>>0<b>>>0?g+1|0:g;break j}l:{m:{n:{if((c|0)==37){e=y[b+1|0];if((e|0)==42){break n}if((e|0)!=37){break m}}Fi(d,0,0);o:{if(y[b|0]==37){while(1){c=x[d+4>>2];p:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;h=y[c|0];break p}h=ud(d)}if(pl(h)){continue}break}b=b+1|0;break o}c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;h=y[c|0];break o}h=ud(d)}if(y[b|0]!=(h|0)){b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}if((h|0)>=0){break a}f=0;if(t){break a}break c}c=x[d+4>>2]-x[d+44>>2]|0;i=c;m=m+x[d+124>>2]|0;e=c>>31;c=n+x[d+120>>2]|0;f=e+(c>>>0<n>>>0?m+1|0:m)|0;n=c+i|0;m=n>>>0<c>>>0?f+1|0:f;h=b;break j}l=0;b=b+2|0;break l}if(!(!Kh(e)|y[b+2|0]!=36)){c=fb-16|0;x[c+12>>2]=s;f=c;c=e-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+s|0;x[f+8>>2]=c+4;l=x[c>>2];b=b+3|0;break l}l=x[s>>2];s=s+4|0;b=b+1|0}c=0;while(1){e=y[b|0];if(Kh(e)){b=b+1|0;c=(D(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){p=0;r=(l|0)!=0;e=y[b+1|0];b=b+1|0;a=0}h=b+1|0;k=3;f=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=y[b+1|0]==104;h=b?e:h;k=b?-2:-1;break q;case 43:e=b+2|0;b=y[b+1|0]==108;h=b?e:h;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;h=b}e=y[h|0];b=(e&47)==3;u=b?1:k;q=b?e|32:e;s:{if((q|0)==91){break s}t:{if((q|0)!=110){if((q|0)!=99){break t}c=(c|0)<=1?1:c;break s}tK(l,u,n,m);break j}Fi(d,0,0);while(1){b=x[d+4>>2];u:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;b=y[b|0];break u}b=ud(d)}if(pl(b)){continue}break}b=x[d+4>>2];e=x[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;x[d+4>>2]=b}b=b-x[d+44>>2]|0;i=b;g=m+x[d+124>>2]|0;e=b>>31;b=n+x[d+120>>2]|0;m=e+(b>>>0<n>>>0?g+1|0:g)|0;n=b+i|0;m=n>>>0<b>>>0?m+1|0:m}i=c;o=c>>31;Fi(d,c,o);b=x[d+4>>2];v:{if((b|0)!=x[d+104>>2]){x[d+4>>2]=b+1;break v}if((ud(d)|0)<0){break f}}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(q-88|0){default:b=q-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:vK(j+8|0,d,u,0);c=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]!=(0-c|0)|x[d+124>>2]!=(0-((c>>31)+((c|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((q|16)==115){Tb(j+32|0,-1,257);v[j+32|0]=0;if((q|0)!=115){break x}v[j+65|0]=0;v[j+46|0]=0;w[j+42>>1]=0;w[j+44>>1]=0;break x}g=y[h+1|0];e=(g|0)==94;Tb(j+32|0,e,257);v[j+32|0]=0;b=e?h+2|0:h+1|0;B:{C:{D:{e=y[(e?2:1)+h|0];if((e|0)!=45){if((e|0)==93){break D}k=(g|0)!=94;break B}k=(g|0)!=94;v[j+78|0]=k;break C}k=(g|0)!=94;v[j+126|0]=k}b=b+1|0}h=b;while(1){e=y[h|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=y[h+1|0];if(!f|(f|0)==93){break E}g=h+1|0;b=y[h-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;v[b+(j+32|0)|0]=k;e=y[g|0];if(e>>>0>b>>>0){continue}break}}h=g}v[(e+j|0)+33|0]=k;h=h+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}i=0;g=0;e=0;f=0;A=0;z=fb-16|0;fb=z;G:{if((b|0)==1){x[31660]=28;break G}while(1){c=x[d+4>>2];H:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break H}c=ud(d)}if(pl(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}A=(c|0)==45?-1:0;c=x[d+4>>2];if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break I}c=ud(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=x[d+4>>2];O:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break O}c=ud(d)}if((c&-33)==88){b=16;c=x[d+4>>2];P:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break P}c=ud(d)}if(y[c+95633|0]<16){break M}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}Fi(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>y[c+95633|0]){break N}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}Fi(d,0,0);x[31660]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=D(b,10)+e|0;f=b>>>0<429496729;c=x[d+4>>2];Q:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break Q}c=ud(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}i=b}R:{if(e>>>0>9){break R}b=sua(i,0,10,0);k=hb;f=e;while(1){g=k;i=b+f|0;g=i>>>0<f>>>0?g+1|0:g;b=(g|0)==429496729&i>>>0>=2576980378|g>>>0>429496729;c=x[d+4>>2];S:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break S}c=ud(d)}e=c-48|0;if(b|e>>>0>9){break R}b=sua(i,g,10,0);f=e;k=hb;if((k|0)==-1&(e^-1)>>>0>=b>>>0|(k|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){f=y[c+95633|0];if(f>>>0<b>>>0){while(1){e=D(b,e)+f|0;i=e>>>0<119304647;c=x[d+4>>2];T:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break T}c=ud(d)}f=y[c+95633|0];if(i&f>>>0<b>>>0){continue}break}i=e}if(b>>>0<=f>>>0){break L}o=b;while(1){e=sua(i,g,o,0);k=hb;f=f&255;if((k|0)==-1&(f^-1)>>>0<e>>>0){break L}g=k;i=e+f|0;g=i>>>0<f>>>0?g+1|0:g;c=x[d+4>>2];U:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break U}c=ud(d)}f=y[c+95633|0];if(b>>>0<=f>>>0){break L}Hf(z,o,0,0,0,i,g,0,0);if(!(x[z+8>>2]|x[z+12>>2])){continue}break}break L}k=v[(D(b,23)>>>5&7)+95889|0];e=y[c+95633|0];if(e>>>0<b>>>0){while(1){f=f<<k|e;i=f>>>0<134217728;c=x[d+4>>2];V:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break V}c=ud(d)}e=y[c+95633|0];if(i&e>>>0<b>>>0){continue}break}i=f}if(b>>>0<=e>>>0){break L}o=k&31;if((k&63)>>>0>=32){f=0;o=-1>>>o|0}else{f=-1>>>o|0;o=f|(1<<o)-1<<32-o}if(!f&i>>>0>o>>>0){break L}while(1){F=e&255;c=i;e=k&31;if((k&63)>>>0>=32){g=c<<e;c=0}else{g=(1<<e)-1&c>>>32-e|g<<e;c=c<<e}i=F|c;c=x[d+4>>2];W:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break W}c=ud(d)}e=y[c+95633|0];if(b>>>0<=e>>>0){break L}if((g|0)==(f|0)&i>>>0<=o>>>0|g>>>0<f>>>0){continue}break}}if(y[c+95633|0]>=b>>>0){break K}while(1){c=x[d+4>>2];X:{if((c|0)!=x[d+104>>2]){x[d+4>>2]=c+1;c=y[c|0];break X}c=ud(d)}if(y[c+95633|0]<b>>>0){continue}break}x[31660]=68;i=-1;g=-1;A=0}b=x[d+116>>2];if((b|0)>0|(b|0)>=0){x[d+4>>2]=x[d+4>>2]-1}b=A;e=b^i;i=e-b|0;c=b>>31;g=(c^g)-((b>>>0>e>>>0)+c|0)|0}fb=z+16|0;c=x[d+4>>2]-x[d+44>>2]|0;if(x[d+120>>2]==(0-c|0)&x[d+124>>2]==(0-((c>>31)+((c|0)!=0)|0)|0)){break g}if(!(!l|(q|0)!=112)){x[l>>2]=i;break w}tK(l,u,i,g);break w}if(!l){break w}c=x[j+16>>2];i=x[j+20>>2];b=x[j+8>>2];e=x[j+12>>2];Y:{switch(u|0){case 0:G=l,H=uG(b,e,c,i),B[G>>2]=H;break w;case 1:G=l,I=kx(b,e,c,i),C[G>>3]=I;break w;case 2:break Y;default:break w}}x[l>>2]=b;x[l+4>>2]=e;x[l+8>>2]=c;x[l+12>>2]=i;break w}k=(q|0)!=99;c=k?31:c+1|0;Z:{if((u|0)==1){e=l;if(r){e=Ed(c<<2);if(!e){break h}}x[j+296>>2]=0;x[j+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=x[d+4>>2];$:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break $}e=ud(d)}if(!y[(e+j|0)+33|0]){break _}v[j+27|0]=e;e=gt(j+28|0,j+27|0,1,j+296|0);if((e|0)==-2){continue}p=0;if((e|0)==-1){break f}if(a){x[(b<<2)+a>>2]=x[j+28>>2];b=b+1|0}if(!r|(b|0)!=(c|0)){continue}break}f=1;b=c;c=b<<1|1;e=sv(a,c<<2);if(e){continue}break e}break}p=0;c=a;if(j+296|0?x[j+296>>2]:0){break f}break Z}if(r){b=0;e=Ed(c);if(!e){break h}while(1){a=e;while(1){e=x[d+4>>2];aa:{if((e|0)!=x[d+104>>2]){x[d+4>>2]=e+1;e=y[e|0];break aa}e=ud(d)}if(!y[(e+j|0)+33|0]){c=0;p=a;break Z}v[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}f=1;b=c;c=b<<1|1;e=sv(a,c);if(e){continue}break}p=a;a=0;break e}b=0;if(l){while(1){a=x[d+4>>2];ba:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ba}a=ud(d)}if(y[(a+j|0)+33|0]){v[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;p=a;break Z}}}while(1){a=x[d+4>>2];ca:{if((a|0)!=x[d+104>>2]){x[d+4>>2]=a+1;a=y[a|0];break ca}a=ud(d)}if(y[(a+j|0)+33|0]){continue}break}a=0;p=0;c=0}e=x[d+4>>2];g=x[d+116>>2];if((g|0)>0|(g|0)>=0){e=e-1|0;x[d+4>>2]=e}e=e-x[d+44>>2]|0;g=e+x[d+120>>2]|0;f=x[d+124>>2]+(e>>31)|0;f=e>>>0>g>>>0?f+1|0:f;if(!(f|g)|!(k|(g|0)==(i|0)&(f|0)==(o|0))){break i}if(r){x[l>>2]=a}da:{if((q|0)==99){break da}if(c){x[(b<<2)+c>>2]=0}if(!p){p=0;break da}v[b+p|0]=0}a=c}b=x[d+4>>2]-x[d+44>>2]|0;e=b;m=m+x[d+124>>2]|0;c=b>>31;b=n+x[d+120>>2]|0;g=c+(b>>>0<n>>>0?m+1|0:m)|0;n=b+e|0;m=n>>>0<b>>>0?g+1|0:g;t=((l|0)!=0)+t|0}b=h+1|0;h=y[h+1|0];if(h){continue}break a}break}a=c;break g}f=1;p=0;a=0;break e}f=r;break b}f=r}if(t){break b}}t=-1}if(!f){break a}Db(p);Db(a)}fb=j+304|0;fb=d+144|0;return t}function aoa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;i=fb-192|0;fb=i;if(!_u(a)){e=i+40|0;QV(e,a);f=i+168|0;hf(f,e,128,2);e=i+180|0;Ec(e,f);zc(b+492|0,e);tb(e)}w[c+34>>1]=z[c+34>>1]&65489;k=i+180|0;h=fb-32|0;fb=h;a:{b:{switch(y[a+128|0]-4|0){default:x[h+28>>2]=0;Qj(k,0,h+28|0);break a;case 0:case 4:break b}}v[h+28|0]=y[a+129|0];v[h+24|0]=100;e=h+24|0;f=y[Ub(h+28|0,e)|0];v[h+24|0]=y[a+130|0];v[h+20|0]=100;e=y[Ub(e,h+20|0)|0];x[h+28>>2]=e;c:{if(y[a+140|0]&16){g=Cb(y[a+150|0]|y[a+151|0]<<8);n=Cb(y[a+152|0]|y[a+153|0]<<8);j=x[c>>2];s=+(j>>>0)/6553600;f=gr(s*+((g|f<<16)>>>0));x[h+24>>2]=j-f;t=h,u=gr(s*+((n|e<<16)>>>0)),x[t+20>>2]=u;t=h,u=x[Gb(h+24|0,h+20|0)>>2],x[t+28>>2]=u;break c}g=x[c>>2];n=x[c+20>>2];if(!ge(g,n)){break c}j=g>>>7|0;f=D(j,(f<<7>>>0)/100|0);x[h+24>>2]=g-f;x[h+20>>2]=D(j,(e<<7>>>0)/100|0);e=x[Gb(h+24|0,h+20|0)>>2];j=z[c+34>>1];g=D(Xd(j),g);d:{if(j&1){bc(h+12|0,n,g);n=x[h+12>>2];j=Xd(z[c+34>>1]);g=n+(D(j,e+f|0)<<1)|0;m=w[n+(D(f,j)<<1)>>1];j=0-j<<1;while(1){e:{f:{if(e){o=w[g>>1]-m|0;n=o>>31;if((n^o)-n>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;g=g+j|0;continue}break}break d}bc(h+4|0,n,g);n=x[h+4>>2];j=Xd(z[c+34>>1]);m=0-j|0;g=n+D(j,e+f|0)|0;j=v[n+D(f,j)|0];while(1){g:{h:{if(e){o=v[g|0]-j|0;n=o>>31;if((n^o)-n>>>0>=6){break h}}else{e=0}break g}e=e-1|0;g=g+m|0;continue}break}}x[h+28>>2]=e}Qj(k,f,h+28|0)}fb=h+32|0;n=ec(k);if(!(!x[n>>2]|y[a+128|0]!=4)){w[c+34>>1]=z[c+34>>1]|2;e=x[i+180>>2];x[c+4>>2]=e;x[c+8>>2]=e+x[n>>2]}e=y[a+134|0];if((e-1&255)>>>0<=198){v[i+40|0]=e;v[i+168|0]=100;e=(y[Ub(i+40|0,i+168|0)|0]<<7>>>0)/100|0}else{e=128}v[i+39|0]=e;v[i+40|0]=64;e=i+39|0;f=i+40|0;t=c,u=y[af(e,f)|0]>>>1|0,w[t+32>>1]=u;v[i+40|0]=64;t=b,u=y[Ub(e,f)|0],x[t+4>>2]=u;x[c+24>>2]=40460;_l(c,+v[a+139|0]/12+ +(0-y[a+143|0]|0)+ +v[a+138|0]/1536);v[b+34|0]=y[a+142|0]&2?2:1;if(y[a+142|0]&2){gk(b,127,1);fk(b,0,1)}i:{if(!ge(x[c>>2],x[c+20>>2])){break i}b=y[a+140|0];if(b&1){b=x[c>>2];e=x[c+20>>2];j:{if(!ge(b,e)|b>>>0<2){break j}k:{l:{switch($k(z[c+34>>1])-1|0){case 3:f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){wc(e+(f<<2)|0,e+(b+(f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){uR(e+(f<<1)|0,e+(b+(f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}f=0;g=b>>>1|0;while(1){if((f|0)!=(g|0)){og(e+f|0,e+(b+(f^-1)|0)|0);f=f+1|0;continue}break}}Mj(c,d)}b=y[a+140|0]}if(b&4){m:{e=x[c>>2];b=x[c+20>>2];if(!ge(e,b)){break m}f=z[c+34>>1];e=D(Xd(f),e);n:{o:{switch(Cn(f)-1|0){case 1:f=0;while(1){if((e|0)!=(f|0)){g=b+(f<<1)|0;w[g>>1]=z[g>>1]^-1;f=f+1|0;continue}break};break n;case 0:break o;default:break m}}f=0;while(1){if((e|0)!=(f|0)){g=b+f|0;v[g|0]=y[g|0]^-1;f=f+1|0;continue}break}}Mj(c,d)}}b=0;b=y[a+170|0]!=2|y[a+171|0]>100?b:y[a+172|0]<101;e=z[c+34>>1];if(!(!(b|y[a+160|0]!=0|y[a+141|0])|e&1)){f=Xu(x[c>>2],Xd(e)<<1&254);if(!f){break i}e=f;g=x[c>>2];h=z[c+34>>1];j=D(Xd(h),g);k=x[c+20>>2];g=Rk(g,h);h=fb-16|0;fb=h;x[h+12>>2]=j;vc(h+12|0,g);g=x[h+12>>2];while(1){if(g){w[e>>1]=v[k|0]<<8;k=k+1|0;e=e+2|0;g=g-1|0;continue}break}fb=h+16|0;w[c+34>>1]=z[c+34>>1]|1;OV(c,f,x[c>>2],d)}p:{if(v[a+141|0]>=0){break p}bc(i+40|0,x[c+20>>2],D(x[c>>2],Xd(z[c+34>>1])));e=0;q:while(1){if((0-v[a+141|0]|0)<=(e|0)){break p}g=x[i+40>>2];f=w[g>>1];t=i,u=vb(g),x[t+168>>2]=u;h=$m(x[i+40>>2],x[i+44>>2]);while(1){g=x[i+168>>2];if(Ib(g,h)){f=od(w[g>>1]-od(f,1)|0,1);w[g>>1]=f;Wd(i+168|0);continue}else{e=e+1|0;continue q}}}}r:{if(!b){break r}bc(i+40|0,x[c+20>>2],D(x[c>>2],Xd(z[c+34>>1])));f=x[i+44>>2];b=(f|0)/2|0;e=b;k=e>>31;h=y[a+172|0];g=y[a+171|0];b=h-g|0;l=e;e=0-(g>>>0>h>>>0)<<24|b>>>8;j=b<<24;h=l+j|0;b=e+k|0;f=Fc(tua(h,h>>>0<j>>>0?b+1|0:b,f,f>>31),hb);t=i,u=vb(x[i+40>>2]),x[t+168>>2]=u;k=f>>31;b=g<<24;e=b>>31;j=$m(x[i+40>>2],x[i+44>>2]);while(1){g=x[i+168>>2];if(!Ib(g,j)){break r}h=w[g>>1];m=sua(b,e,h,h>>31);h=hb;m=m+838860800|0;h=m>>>0<838860800?h+1|0:h;t=g,u=Fc(tua(m,h,1677721600,0),hb),w[t>>1]=u;e=e+k|0;b=b+f|0;e=b>>>0<f>>>0?e+1|0:e;Wd(i+168|0);continue}}s:{if(!y[a+160|0]){break s}bc(i+168|0,x[c+20>>2],D(x[c>>2],Xd(z[c+34>>1])));f=y[a+163|0];j=y[a+162|0];b=0;k=0;g=0;if(y[a+161|0]>=2){g=x[i+172>>2];e=(g|0)/2|0;h=e;m=e>>31;e=y[a+164|0];k=0-(e>>>0<j>>>0)|0;e=e-j|0;l=h;h=k<<23|e>>>9;o=e<<23;k=l+o|0;e=h+m|0;k=Fc(tua(k,k>>>0<o>>>0?e+1|0:e,g,g>>31),hb);g=x[i+172>>2];e=(g|0)/2|0;h=e;o=e>>31;e=y[a+165|0];m=0-(e>>>0<f>>>0)|0;e=e-f|0;p=h;h=m<<23|e>>>9;l=e<<23;m=p+l|0;e=h+o|0;g=Fc(tua(m,m>>>0<l>>>0?e+1|0:e,g,g>>31),hb)}f=f<<23;h=j<<23;e=y[a+160|0];t=i,u=vb(x[i+168>>2]),x[t+32>>2]=u;m=(i+40|0)+((e&2)<<2)|0;o=$m(x[i+168>>2],x[i+172>>2]);e=0;while(1){j=x[i+32>>2];if(!Ib(j,o)){break s}l=(w[j>>1]>>1)-e|0;x[i+48>>2]=l;p=l;l=(h|0)/8388608|0;b=od(D(p,l),8)+b|0;x[i+44>>2]=b;e=od(D(b,l),6)+e|0;e=od(od(D(e,(f|0)/8388608|0),6)+e|0,2);x[i+40>>2]=e;t=j,u=dd(x[m>>2]),w[t>>1]=u;f=f+g|0;h=h+k|0;Wd(i+32|0);continue}}t:{if(v[a+141|0]<=0){break t}bc(i+40|0,x[c+20>>2],D(x[c>>2],Xd(z[c+34>>1])));e=0;u:while(1){if(v[a+141|0]<=(e|0)){break t}b=x[i+40>>2];f=w[b>>1];t=i,u=vb(b),x[t+168>>2]=u;g=$m(x[i+40>>2],x[i+44>>2]);while(1){b=x[i+168>>2];if(Ib(b,g)){f=((w[b>>1]<<1)+f|0)/3|0;w[b>>1]=f;Wd(i+168|0);continue}else{e=e+1|0;continue u}}}}b=x[c+20>>2];f=z[c+34>>1];e=D(x[c>>2],Xd(f));v:{if(f&1){bc(i+24|0,b,e);p=x[i+28>>2];b=fb-16|0;fb=b;o=x[i+24>>2];e=vb(o);m=$m(o,p);l=fb-16|0;fb=l;j=fb-16|0;fb=j;x[j+12>>2]=e;gc(j+4|0,l+15|0,l+14|0);q=b+8|0;g=Qj(q,e,j+12|0);w:{if(mc(e,m)){break w}r=Wd(j+12|0);e=x[r>>2];if(mc(e,m)){break w}f=x[g>>2];h=Ql(e,f);x[(h?0:4)+g>>2]=e;f=h?e:f;k=g+4|0;while(1){h=Wd(r);e=x[h>>2];if(!Ib(e,m)){break w}h=x[Wd(h)>>2];if(mc(h,m)){if(!Ql(e,f)){g=k;if(Ql(e,x[g>>2])){break w}}x[g>>2]=e;break w}x:{if(Ql(h,e)){if(Ql(h,f)){x[g>>2]=h;f=h}if(Ql(e,x[k>>2])){continue}break x}if(Ql(e,f)){x[g>>2]=e;f=e}e=h;if(Ql(e,x[k>>2])){continue}}x[k>>2]=e;continue}}fb=j+16|0;fb=l+16|0;x[b+4>>2]=0-w[x[b+8>>2]>>1];t=b,u=w[x[ec(q)>>2]>>1],x[t>>2]=u;y:{e=x[We(b+4|0,b)>>2];if((e|0)>32766|!e){break y}f=vb(o);x[b+4>>2]=f;g=$m(o,p);while(1){if(!Ib(f,g)){break y}w[f>>1]=(D(w[f>>1],32767)|0)/(e|0);f=x[Wd(b+4|0)>>2];continue}}break v}bc(i+16|0,b,e);p=x[i+20>>2];b=fb-16|0;fb=b;o=x[i+16>>2];e=vb(o);m=Tk(o,p);l=fb-16|0;fb=l;j=fb-16|0;fb=j;x[j+12>>2]=e;gc(j+4|0,l+15|0,l+14|0);q=b+8|0;g=Qj(q,e,j+12|0);z:{if(mc(e,m)){break z}r=je(j+12|0);e=x[r>>2];if(mc(e,m)){break z}f=x[g>>2];h=Rl(e,f);x[(h?0:4)+g>>2]=e;f=h?e:f;k=g+4|0;while(1){h=je(r);e=x[h>>2];if(!Ib(e,m)){break z}h=x[je(h)>>2];if(mc(h,m)){if(!Rl(e,f)){g=k;if(Rl(e,x[g>>2])){break z}}x[g>>2]=e;break z}A:{if(Rl(h,e)){if(Rl(h,f)){x[g>>2]=h;f=h}if(Rl(e,x[k>>2])){continue}break A}if(Rl(e,f)){x[g>>2]=e;f=e}e=h;if(Rl(e,x[k>>2])){continue}}x[k>>2]=e;continue}}fb=j+16|0;fb=l+16|0;x[b+4>>2]=0-v[x[b+8>>2]];t=b,u=v[x[ec(q)>>2]],x[t>>2]=u;B:{e=x[We(b+4|0,b)>>2];if((e|0)>126|!e){break B}f=vb(o);x[b+4>>2]=f;g=Tk(o,p);while(1){if(!Ib(f,g)){break B}v[f|0]=(D(v[f|0],127)|0)/(e|0);f=x[je(b+4|0)>>2];continue}}}fb=b+16|0;C:{if((y[a+134|0]-101&255)>>>0>98){break C}f=z[c+34>>1];e=D(x[c>>2],Xd(f));b=x[c+20>>2];if(f&1){x[i+8>>2]=b;x[i+12>>2]=(b+(e<<1)|0)-b>>1;g=x[i+12>>2];b=y[a+134|0];h=fb-16|0;fb=h;k=x[i+8>>2];f=vb(k);x[h+12>>2]=f;b=(3276800-(b<<14)|0)/100|0;j=0-b|0;e=32768-b|0;k=$m(k,g);while(1){if(Ib(f,k)){g=w[f>>1];D:{if((g|0)>(b|0)){l=e+((D(b,g-b|0)|0)/(e|0)|0)|0;break D}l=((D(b,b+g|0)|0)/(e|0)|0)-e|0;if((g|0)<(j|0)){break D}l=(D(e,g)|0)/(b|0)|0}t=f,u=dd(l),w[t>>1]=u;f=x[Wd(h+12|0)>>2];continue}break}fb=h+16|0;break C}b=lo(i,b,b+e|0);g=x[b>>2];k=x[b+4>>2];b=y[a+134|0];h=fb-16|0;fb=h;f=vb(g);x[h+12>>2]=f;b=(3276800-(b<<14)|0)/100|0;j=0-b|0;e=32768-b|0;k=Tk(g,k);while(1){if(Ib(f,k)){g=v[f|0]<<8;E:{if((g|0)>(b|0)){l=e+((D(b,g-b|0)|0)/(e|0)|0)|0;break E}l=((D(b,b+g|0)|0)/(e|0)|0)-e|0;if((g|0)<(j|0)){break E}l=(D(e,g)|0)/(b|0)|0}t=f,u=UX((l|0)/256|0),v[t|0]=u;f=x[je(h+12|0)>>2];continue}break}fb=h+16|0}NV(c);if(y[a+128|0]!=8){break i}b=y[a+131|0];if(!b){break i}e=x[n>>2];if(!e){break i}f=x[i+180>>2];t=wb(c+68|0,0),u=f+D(e,b+1|0)|0,x[t>>2]=u;b=x[i+180>>2];x[c+12>>2]=b;x[c+16>>2]=b+x[n>>2];h=x[n>>2];g=y[a+131|0];if(h>>>0>268435456/(g>>>0)>>>0){break i}f=x[c>>2];e=D(g,h);if(f>>>0>268435456-e>>>0){break i}f=e+f|0;e=$k(z[c+34>>1]);j=Xu(f,e);if(!j){break i}k=b+D(h,g+1|0)|0;x[c>>2]=f;b=j;j=x[c+20>>2];g=x[i+180>>2];h=yc(b,j,D(e,g+x[n>>2]|0));m=j+D(e,g)|0;a=y[a+131|0];b=0;while(1){if((a|0)==(b|0)){yc(h+D(e,k)|0,j+D(e,g+x[n>>2]|0)|0,D(e,f-k|0));OV(c,h,f,d)}else{b=b+1|0;o=x[n>>2];yc(h+D(e,g+D(b,o)|0)|0,m,D(e,o));continue}break}}fb=i+192|0}function qja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-720|0;fb=d;xc(b);a:{b:{c:{d:{if(!yi(b,d+712|0)){break d}if(!iR(x[d+712>>2],x[d+716>>2])){break d}if(!Cr(b,d+708|0)){break d}g=x[d+708>>2];if(!hR(g)){break d}e:{if((g|0)==1179012417){f=1;e=1313423693;break e}if((g|0)!=538987841){break d}f=2;e=1414090313}m=Fe(d+688|0,b);j=Nb(d+676|0);f:{g:{h:{i:{j:{k:{l:{if(!c){x[31785]=0;V(901,d+112|0,m|0,f|0,e|0);b=x[31785];x[31785]=0;if((b|0)!=1){break l}a=N()|0;break a}x[31785]=0;S(902,d+112|0,m|0,f|0);b=x[31785];x[31785]=0;if((b|0)==1){break k}}b=d+112|0;jv(j,b);fe(b);x[31785]=0;S(903,d+656|0,j|0,e|0);b=x[31785];x[31785]=0;if((b|0)!=1){x[31785]=0;b=R(175,x[d+656>>2])|0;e=x[31785];x[31785]=0;if((e|0)==1){break j}f=0;if(!b){break f}x[31785]=0;b=P(904,d+656|0,d+583|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break j}if(!b){break f}b=y[d+648|0];if(!b){break f}x[31785]=0;f=U(153,x[d+656>>2],x[d+664>>2],b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break j}if(!((c|0)!=0&f)){break f}x[31785]=0;O(249,a|0,8388608);b=x[31785];x[31785]=0;if((b|0)==1){break j}x[a+480208>>2]=y[d+647|0]<<4&16^28;w[d+112>>1]=y[d+648|0];w[d+464>>1]=127;q=a,r=z[Mc(d+112|0,d+464|0)>>1],w[q+480188>>1]=r;x[a+480196>>2]=y[d+649|0];x[a+480204>>2]=D(y[d+650|0],1e4);x[a+480200>>2]=y[d+655|0]<<1;x[31785]=0;O(133,a+1298344|0,((g|0)!=1179012417?17143:17177)|0);b=x[31785];x[31785]=0;if((b|0)==1){break j}x[31785]=0;b=P(1,d+568|0,13339)|0;e=x[31785];x[31785]=0;if((e|0)==1){break h}yb(a+1298356|0,b);tb(b);b=d+112|0;q=a+1298404|0,r=x[Gc(b,4)>>2],x[q>>2]=r;e=d+464|0;uC(e,2,d+583|0);x[31785]=0;O(221,b|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break i}b=d+112|0;yb(a+1298308|0,b);tb(b);k=(g|0)==1179012417;b=0;while(1){m:{n:{o:{if(z[a+480188>>1]<=b>>>0){b=vb(x[j>>2]);f=vb(x[j+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=b;while(1){p:{if(!Ib(b,f)){break p}if(S_(1380209231,x[b>>2],x[b+4>>2])){break p}b=x[rn(e+12|0)>>2];continue}break}fb=e+16|0;if(Ib(b,vb(x[j+4>>2]))){break o}break g}f=(b<<5)+a|0;l=f+480280|0;Ye(l);x[31785]=0;e=R(200,d+656|0)|0;h=x[31785];x[31785]=0;q:{r:{if((h|0)!=1){if(k){break q}if(e>>>0<129){break r}break n}a=N()|0;break b}w[f+480284>>1]=e<<1;break m}if(e<<24>>24<0){break n}x[d+112>>2]=e<<2;x[d+464>>2]=256;q=f+480284|0,r=x[pd(d+112|0,d+464|0)>>2],w[q>>1]=r;break m}x[31785]=0;S(903,d+112|0,j|0,1380209231);b=x[31785];x[31785]=0;s:{if((b|0)!=1){x[31785]=0;b=R(200,d+112|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break s}e=y[a+484376|0];f=x[a+484360>>2];x[31785]=0;aa(351,Wb(f,e)|0,d+112|0,b+1&255,255,254);b=x[31785];x[31785]=0;if((b|0)==1){break s}ub(d+112|0);break g}a=N()|0;break b}a=N()|0;ub(d+112|0);break b}x[l>>2]=1024}b=b+1|0;continue}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}t:{if(!(c&1)){break t}w[d+48>>1]=0;x[31785]=0;S(905,d+528|0,j|0,1414807888);b=x[31785];x[31785]=0;if((b|0)==1){break c}b=x[d+532>>2];e=x[d+528>>2];x[31785]=0;f=a+484344|0;O(226,f|0,Lf(e,b)&65535);b=x[31785];x[31785]=0;u:{if((b|0)!=1){q=d,r=vb(x[d+528>>2]),x[q+76>>2]=r;k=vb(x[d+532>>2]);l=(g|0)!=1179012417;v:{w:{x:{y:{z:{while(1){b=x[d+76>>2];if(!Ib(b,k)){k=a+484348|0;b=0;break v}b=Fe(d+112|0,b);x[31785]=0;e=R(200,b|0)|0;h=x[31785];x[31785]=0;if((h|0)!=1){x[31785]=0;w[d+452>>1]=e;e=R(154,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break z}x[31785]=0;S(188,d+464|0,b|0,e|0);e=x[31785];x[31785]=0;if((e|0)==1){break y}e=ic(d+548|0,d+464|0);x[31785]=0;h=x[e+12>>2];x[d+8>>2]=x[e+8>>2];x[d+12>>2]=h;x[d+16>>2]=x[e+16>>2];h=x[e+4>>2];x[d>>2]=x[e>>2];x[d+4>>2]=h;V(906,d|0,z[d+452>>1],l|0,a|0);e=x[31785];x[31785]=0;if((e|0)==1){break x}ub(d+464|0);q=d,r=z[se(d+48|0,d+452|0)>>1],w[q+48>>1]=r;ub(b);Xf(d+76|0);continue}break}a=N()|0;break w}a=N()|0;break w}a=N()|0;break w}a=N()|0;ub(d+464|0)}ub(b);break u}while(1){e=b&65535;if(e>>>0>=z[d+48>>1]){Qc(d+528|0);break t}A:{if(!Ge(x[a+484344>>2],x[k>>2],e)){x[31785]=0;U(199,f|0,e|0,64)|0;e=x[31785];x[31785]=0;if((e|0)==1){break A}}b=b+1|0;continue}break}a=N()|0;break u}a=N()|0}Qc(d+528|0);break b}B:{C:{D:{if((g|0)==1179012417){x[31785]=0;S(905,d+76|0,j|0,1414745673);b=x[31785];x[31785]=0;if((b|0)==1){break C}q=d,r=vb(x[d+76>>2]),x[q+100>>2]=r;g=c&2;k=d+472|0;l=vb(x[d+80>>2]);e=a+480190|0;while(1){b=x[d+100>>2];if(!Ib(b,l)){Qc(d+76|0);break B}c=Fe(d+528|0,b);x[31785]=0;b=P(907,c|0,d+112|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){E:{if(!b){break E}b=y[d+113|0];if((b|0)==255){break E}x[31785]=0;f=U(254,a|0,b+1|0,0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break D}if(!f){break E}h=z[e>>1];b=0;x[31785]=0;S(908,d+112|0,f|0,h|0);f=x[31785];x[31785]=0;if((f|0)==1){break D}while(1){if(y[d+142|0]<=b>>>0){break E}F:{if(!si(z[e>>1])){break F}x[31785]=0;f=P(909,c|0,d+464|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break D}if(!f){break F}f=z[e>>1]+1|0;w[e>>1]=f;if(x[d+464>>2]!=1347240275){break F}h=d+452|0;_i(h,2,k);x[31785]=0;O(221,d+48|0,h|0);h=x[31785];x[31785]=0;G:{if((h|0)!=1){f=f&65535;h=d+48|0;zc(((f<<5)+a|0)+946304|0,h);tb(h);x[31785]=0;f=(D(f,104)+a|0)+484380|0;S(910,d+464|0,d+112|0,f|0);h=x[31785];x[31785]=0;if((h|0)==1){break D}if(!g){break G}h=d+48|0;gR(h,z[d+502>>1]);x[31785]=0;U(218,h|0,f|0,c|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){break F}break D}break D}h=z[f+34>>1];f=x[f>>2];x[31785]=0;P(186,c|0,Rk(f,h)|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break D}}b=b+1|0;continue}}ub(c);Xf(d+100|0);continue}break}break D}x[31785]=0;S(905,d+452|0,j|0,1179011410);b=x[31785];x[31785]=0;if((b|0)!=1){q=d,r=vb(x[d+452>>2]),x[q+448>>2]=r;k=c&2;l=d+468|0;h=vb(x[d+456>>2]);f=a+480190|0;H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{while(1){b=x[d+448>>2];if(!Ib(b,h)){Qc(d+452|0);break B}c=Fe(d+528|0,b);x[31785]=0;b=R(154,c|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break Q}R:{S:{if((b|0)!=538986817){break S}x[31785]=0;b=P(911,c|0,d+440|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break P}if(!(b&x[d+440>>2]==1414745673)){break S}x[31785]=0;b=P(912,c|0,d+112|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break O}if(!b){break S}b=y[d+117|0];if((b|0)==255){break S}x[31785]=0;b=U(254,a|0,b+1|0,0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break N}if(!b){break S}e=z[f>>1];x[31785]=0;S(913,d+112|0,b|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break N}x[31785]=0;S(902,d+464|0,c|0,2);b=x[31785];x[31785]=0;if((b|0)==1){break R}x[31785]=0;S(905,d+100|0,d+464|0,1179011410);b=x[31785];x[31785]=0;if((b|0)==1){break M}fe(d+464|0);q=d,r=vb(x[d+100>>2]),x[q+96>>2]=r;n=vb(x[d+104>>2]);T:{U:{while(1){b=x[d+96>>2];if(!Ib(b,n)){break T}b=Fe(d+76|0,b);x[31785]=0;e=R(154,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break L}V:{W:{if((e|0)!=538989377){break W}e=z[f>>1];if(!si(e)){break W}g=y[d+436|0]|y[d+437|0]<<8;i=g-1|0;v[d+436|0]=i;v[d+437|0]=i>>>8;if(!g){ub(b);break T}i=e+1|0;w[f>>1]=i;x[31785]=0;e=P(911,b|0,d+68|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break K}if(!(e&x[d+68>>2]==1347240275)){break U}x[31785]=0;S(188,d+464|0,b|0,x[d+72>>2]);e=x[31785];x[31785]=0;X:{if((e|0)!=1){g=d+464|0;e=ic(d+48|0,g);ub(g);x[31785]=0;g=P(914,e|0,g|0)|0;o=x[31785];x[31785]=0;if((o|0)==1){break V}if(g){break X}ub(e);ub(b);break T}a=N()|0;break I}g=d+24|0;Te(g,2,l);x[31785]=0;O(221,d+36|0,g|0);g=x[31785];x[31785]=0;if((g|0)==1){break J}g=i&65535;i=d+36|0;zc(((g<<5)+a|0)+946304|0,i);tb(i);x[31785]=0;g=(D(g,104)+a|0)+484380|0;S(915,d+464|0,d+112|0,g|0);i=x[31785];x[31785]=0;if((i|0)==1){break V}Y:{if(!k){break Y}x[31785]=0;P(152,e|0,x[d+464>>2]+4|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break V}i=d+36|0;gR(i,z[d+504>>1]);x[31785]=0;U(218,i|0,g|0,e|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){break Y}break J}ub(e)}ub(b);Xf(d+96|0);continue}break}break J}ub(b)}Qc(d+100|0)}ub(c);Xf(d+448|0);continue}break}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;break H}a=N()|0;fe(d+464|0);break H}a=N()|0;break I}a=N()|0;break I}a=N()|0;ub(e)}ub(b);Qc(d+100|0)}ub(c);Qc(d+452|0);break b}a=N()|0;break b}a=N()|0;ub(c);Qc(d+76|0);break b}a=N()|0;break b}f=1}ub(d+656|0);fe(j);ub(m)}fb=d+720|0;return f|0}a=N()|0}ub(d+656|0)}fe(j);ub(m);Q(a|0);p()}function A0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;e=fb-224|0;fb=e;xc(b);a:{if(!Cr(b,e+220|0)){break a}x[e+200>>2]=0;x[e+204>>2]=0;x[e+192>>2]=0;x[e+196>>2]=0;x[e+184>>2]=0;x[e+188>>2]=0;x[e+176>>2]=0;x[e+180>>2]=0;b:{c:{if(!QE(e+220|0)){break c}if(!Mb(x[b>>2],x[b+8>>2],32)){break c}rw(b,e+176|0);break b}m=1;if(!PE(e+220|0)){break a}}j=e+171|0;f=OE(y[e+223|0]);d=fb-32|0;fb=d;x[d+28>>2]=f;x[d+8>>2]=5;g=x[b>>2];h=x[b+8>>2];f=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(g,h,f)){f=jf(b)}l=d+8|0;ck(l,j);k=gc(d+16|0,x[d+8>>2],f);h=x[k>>2];kc(d,x[b>>2],x[b+8>>2],h,x[k+4>>2]);ck(l,j);Tb(x[d+8>>2]+f|0,0,5-f|0);Yb(b,x[d+28>>2]);fb=d+32|0;if(!f){break a}if(!NE(e+171|0,y[e+223|0])){break a}if(!c){n=1;break a}j=e+223|0;Bd(a,2048);ag(a);d:{e:{f:{g:{h:{i:{j:{k:{l:{if(m){d=fb-16|0;fb=d;f=e+12|0;l=uc(d+4|0,3913);Yc(f,l);tb(l);fb=d+16|0;x[31785]=0;S(212,e+80|0,f|0,j|0);d=x[31785];x[31785]=0;if((d|0)==1){break j}d=e+80|0;yb(a+1298344|0,d);tb(d);Eb(e+12|0);f=uc(d,11159);yb(a+1298356|0,f);break l}d=e+12|0;Te(d,2,e+176|0);f=e+80|0;Ec(f,d);yb(a+1298308|0,f);tb(f);l=fb-16|0;fb=l;k=uc(l+4|0,3964);Yc(d,k);tb(k);fb=l+16|0;x[31785]=0;S(212,f|0,d|0,j|0);d=x[31785];x[31785]=0;if((d|0)==1){break k}d=e+80|0;yb(a+1298344|0,d);tb(d);Eb(e+12|0);f=uc(d,11163);yb(a+1298356|0,f)}tb(f);B=a+1298404|0,C=x[Gc(e+80|0,4)>>2],x[B>>2]=C;f=a+480188|0;w[f>>1]=y[e+175|0];w[a+480190>>1]=y[e+171|0];d=y[e+223|0];m:{n:{if(d>>>0>=9){o:{if(d>>>0>=11){f=(d|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break o}j=Aw(b);p:{if((j|0)==100){x[((d<<5)+a|0)+480280>>2]=256;break p}x[e+80>>2]=(j<<1)+128;x[e+12>>2]=0;x[e+156>>2]=256;B=((d<<5)+a|0)+480284|0,C=x[bk(e+80|0,e+12|0,e+156|0)>>2],w[B>>1]=C}d=d+1|0;continue}}f=e+80|0;d=fb-16|0;fb=d;q:{if(!Mb(x[b>>2],x[b+8>>2],16)){zE(f);break q}Br(d+8|0,f);md(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d=0;while(1){if((d|0)==16){break o}w[((d<<5)+a|0)+480284>>1]=v[(e+80|0)+d|0]&1?64:192;d=d+1|0;continue}}if(y[e+223|0]<13){break n}d=e+80|0;xw(d,b);f=Ic(d);d=y[e+80|0];if(d>>>0<=31){v[e+80|0]=125;d=125}x[a+480204>>2]=D(d,1e4);x[a+480196>>2]=y[f|0];break m}w[f>>1]=4;Ch(a,1)}x[a+480196>>2]=6;x[a+480204>>2]=125e4}tg(Wb(x[a+484360>>2],y[a+484376|0]),y[e+172|0]);l=Nb(e+156|0);f=y[e+223|0];t=x[b+8>>2]+((f>>>0>13)<<1)|0;d=0;r:{if(f>>>0<14){break r}x[31785]=0;O(213,l|0,y[e+172|0]);f=x[31785];x[31785]=0;if((f|0)!=1){break r}d=N()|0;break g}while(1){if(y[e+172|0]<=d>>>0){j=0;if(y[e+223|0]!=10){break h}h=x[b+8>>2];g=a+480190|0;d=1;while(1){j=z[g>>1]>=(d&65535)>>>0;if(!j){break i}x[31785]=0;f=P(214,b|0,e+80|0)|0;k=x[31785];x[31785]=0;if((k|0)!=1){if(f){f=0;s:{if(y[e+171|0]<(y[e+126|0]|y[e+127|0]<<8|(y[e+128|0]<<16|y[e+129|0]<<24))>>>0|y[e+80|0]>1){break s}k=y[e+130|0]|y[e+131|0]<<8|(y[e+132|0]<<16|y[e+133|0]<<24);if(k>>>0>1048576|y[e+136|0]>64|k>>>0<(y[e+137|0]|y[e+138|0]<<8|(y[e+139|0]<<16|y[e+140|0]<<24))>>>0){break s}f=k>>>0>=(y[e+141|0]|y[e+142|0]<<8|(y[e+143|0]<<16|y[e+144|0]<<24))>>>0}if(!f){break i}}d=d+1|0;continue}break}d=N()|0;break g}B=_b(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],d),C=d,w[B>>1]=C;t:{if(y[e+223|0]>=14){x[31785]=0;f=R(192,b|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break t}B=_b(x[l>>2],d),C=f,w[B>>1]=C}f=z[a+480188>>1];x[31785]=0;P(186,b|0,f<<1)|0;f=x[31785];x[31785]=0;if((f|0)==1){break t}d=d+1|0;continue}break}d=N()|0;break g}d=N()|0;Eb(e+12|0);break f}d=N()|0;Eb(e+12|0);break f}x[31785]=0;P(152,b|0,h|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break h}d=N()|0;break g}n=a+480190|0;d=z[n>>1];x[31785]=0;x[e+80>>2]=0;k=U(215,e+68|0,d|0,e+80|0)|0;d=x[31785];x[31785]=0;u:{v:{w:{x:{if((d|0)!=1){i=j?59:65;h=e+81|0;d=1;y:{while(1){f=d&65535;if(f>>>0>z[n>>1]){j=Nb(e+56|0);x[31785]=0;n=U(216,b|0,j|0,y[e+173|0]|y[e+174|0]<<8)|0;d=x[31785];x[31785]=0;z:{if((d|0)!=1){if(!n){break d}d=0;f=0;h=x[j>>2];if(!mc(h,x[j+4>>2])){f=vb(h);i=vb(x[j+4>>2]);h=fb-16|0;fb=h;A:{if(!Ib(f,i)){break A}x[h+12>>2]=f;while(1){g=x[Wd(h+12|0)>>2];if(!Ib(g,i)){break A}f=_k(y[f|0]|y[f+1|0]<<8,y[g|0]|y[g+1|0]<<8)?g:f;continue}}fb=h+16|0;f=y[f|0]|y[f+1|0]<<8}x[31785]=0;g=P(217,e+32|0,f|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break z}B:{while(1){if((d|0)==(f|0)){if(!(c&2)){break x}o=ad(e+12|0,8,1,0,m?2:1);q=a+480190|0;d=z[q>>1];i=1;C:{D:{E:while(1){s=i&65535;if(s>>>0>(d&65535)>>>0){break x}d=x[b+8>>2];h=x[b>>2];x[31785]=0;d=U(153,h|0,d|0,1)|0;h=x[31785];x[31785]=0;if((h|0)==1){break C}if(!d){break x}u=x[b+8>>2];h=0;F:while(1){d=z[q>>1];if(h>>>0>=d>>>0){i=i+1|0;continue E}if(x[wb(x[k>>2],h)>>2]!=(s|0)){h=h+1|0;continue}x[31785]=0;P(152,b|0,u|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){x[31785]=0;h=h+1|0;d=D(h,104)+a|0;r=d+484380|0;U(218,o|0,r|0,b|0)|0;A=x[31785];x[31785]=0;if((A|0)==1){break D}if(!m){continue}bc(e+80|0,x[d+484400>>2],x[r>>2]);B=e,C=vb(x[e+80>>2]),x[B+8>>2]=C;r=Tk(x[e+80>>2],x[e+84>>2]);while(1){d=x[e+8>>2];if(!Ib(d,r)){continue F}v[d|0]=y[d|0]^128;je(e+8|0);continue}}break}break}d=N()|0;break w}d=N()|0;break w}d=N()|0;break w}x[31785]=0;h=R(192,b|0)|0;i=x[31785];x[31785]=0;G:{if((i|0)==1){break G}x[31785]=0;P(186,b|0,1)|0;i=x[31785];x[31785]=0;if((i|0)==1){break G}if(h){x[31785]=0;S(188,e+12|0,b|0,D(h,3)+(y[e+223|0]==1?3:0)|0);h=x[31785];x[31785]=0;if((h|0)==1){break B}i=e+12|0;h=ic(e+80|0,i);hd($g(x[g>>2],d),h);ub(h);ub(i)}d=d+1|0;continue}break}d=N()|0;break w}d=N()|0;break w}d=N()|0;break v}d=N()|0;break v}H:{I:{if(y[e+223|0]<=9){x[31785]=0;O(219,b|0,e+80|0);g=x[31785];x[31785]=0;J:{K:{if((g|0)==1){break K}x[31785]=0;O(220,e+80|0,(D(f,104)+a|0)+484380|0);g=x[31785];x[31785]=0;if((g|0)==1){break K}g=e+56|0;Te(g,2,h);x[31785]=0;O(221,e+12|0,g|0);g=x[31785];x[31785]=0;if((g|0)==1){break J}g=e+12|0;zc(((f<<5)+a|0)+946304|0,g);tb(g);B=wb(x[k>>2],f-1|0),C=y[e+126|0]|y[e+127|0]<<8|(y[e+128|0]<<16|y[e+129|0]<<24),x[B>>2]=C;break I}d=N()|0;break u}d=N()|0;break u}if(m){x[31785]=0;O(222,b|0,e+80|0);g=x[31785];x[31785]=0;L:{M:{if((g|0)==1){break M}x[31785]=0;O(223,e+80|0,(D(f,104)+a|0)+484380|0);g=x[31785];x[31785]=0;if((g|0)==1){break M}x[31785]=0;g=P(37,e+44|0,22485)|0;o=x[31785];x[31785]=0;if((o|0)==1){break L}zc(((f<<5)+a|0)+946304|0,g);tb(g);B=wb(x[k>>2],f-1|0),C=y[e+82|0]|y[e+83|0]<<8|(y[e+84|0]<<16|y[e+85|0]<<24),x[B>>2]=C;break I}d=N()|0;break u}d=N()|0;break u}x[31785]=0;S(224,b|0,e+80|0,i|0);g=x[31785];x[31785]=0;if((g|0)==1){break H}x[31785]=0;S(225,e+80|0,(D(f,104)+a|0)+484380|0,j|0);g=x[31785];x[31785]=0;if((g|0)==1){break H}g=e+56|0;Te(g,2,h);x[31785]=0;O(221,e+12|0,g|0);g=x[31785];x[31785]=0;if((g|0)==1){break y}g=e+12|0;zc(((f<<5)+a|0)+946304|0,g);tb(g);B=wb(x[k>>2],f-1|0),C=y[e+126|0]|y[e+127|0]<<8|(y[e+128|0]<<16|y[e+129|0]<<24),x[B>>2]=C}d=d+1|0;continue}break}d=N()|0;break u}d=N()|0;break u}d=N()|0;break g}if(!(c&1)){break e}x[31785]=0;m=a+484344|0;O(226,m|0,y[e+172|0]);c=x[31785];x[31785]=0;N:{if((c|0)!=1){h=a+480188|0;a=0;while(1){O:{if(y[e+172|0]<=a>>>0){break e}d=64;c=x[l>>2];if(Xc(c,x[l+4>>2])>>>0>a>>>0){d=z[_b(c,a)>>1]}x[31785]=0;c=U(199,m|0,a&65535,d&65535)|0;d=x[31785];x[31785]=0;if((d|0)==1){break N}P:{if(c){c=z[h>>1];x[31785]=0;P(152,b|0,D(((y[e+223|0]>13)<<1)+(c<<1)|0,a)+t|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break N}c=Nb(e+80|0);d=z[h>>1];x[31785]=0;i=U(216,b|0,c|0,d|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break P}d=0;Q:{if(!i){break Q}while(1){if(z[h>>1]<=d>>>0){break Q}R:{i=_b(x[c>>2],d);i=(y[i|0]|y[i+1|0]<<8)-1|0;if((i&65535)>>>0>=(y[e+173|0]|y[e+174|0]<<8)>>>0){break R}i=_b(x[j>>2],i);i=(y[i|0]|y[i+1|0]<<8)-1&65535;if(i>>>0>=f>>>0){break R}o=x[m>>2];q=x[g>>2];x[31785]=0;S(227,Vb(o,a)|0,d&65535,$g(q,i)|0);i=x[31785];x[31785]=0;if((i|0)!=1){break R}break O}d=d+1|0;continue}}kd(c)}a=a+1|0;continue}}break}d=N()|0;kd(c);break w}d=N()|0;break w}d=N()|0}Qc(g)}kd(j)}sc(k)}kd(l)}Q(d|0);p()}Qc(g)}kd(j);sc(k);kd(l)}fb=e+224|0;return n|0}function K1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,B=0;e=fb-1456|0;fb=e;xc(b);zp(a);a:{b:{c:{if(!$r(b,e+1432|0)){break c}if(!tG(e+1432|0)){break c}if(!c){j=1;break c}if(!sm(x[b>>2],y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))){break c}if(!sm(x[b>>2],(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+((y[e+1444|0]|y[e+1445|0]<<8)<<2)|0)){break c}fx(a);w=e,B=ex(),x[w+68>>2]=B;c=e+68|0;dx(hj(x[a+4>>2])+32|0,c);_r(c);m=x[hj(x[a+4>>2])+32>>2];x[e+1428>>2]=y[e+1446|0]|y[e+1447|0]<<8|(y[e+1448|0]<<16|y[e+1449|0]<<24);w=e,B=hh(x[b>>2]),x[w+1168>>2]=B;x[e+1136>>2]=214748364;d=e+1168|0;w=e,B=D(x[Gb(d,e+1136|0)>>2],20),x[w+68>>2]=B;ko(m,x[Gb(e+1428|0,c)>>2]);Tb(d,0,256);s=Nb(e+1156|0);while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{j=(y[e+1444|0]|y[e+1445|0]<<8)>>>0<=t>>>0;if(!j){x[31785]=0;c=P(152,b|0,(y[e+1450|0]|y[e+1451|0]<<8|(y[e+1452|0]<<16|y[e+1453|0]<<24))+(t<<2)|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break s}if(!c){break h}c=x[b+8>>2];d=x[b>>2];x[31785]=0;c=U(153,d|0,c|0,4)|0;d=x[31785];x[31785]=0;if((d|0)==1){break s}if(!c){break h}x[31785]=0;c=R(154,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break r}x[31785]=0;d=P(152,b|0,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break r}if(!d){break h}x[31785]=0;d=P(155,b|0,e+1136|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break q}if(!d){break h}x[31785]=0;d=U(156,b|0,s|0,y[e+1148|0]|y[e+1149|0]<<8)|0;f=x[31785];x[31785]=0;if((f|0)==1){break q}if(!d){break h}f=x[s>>2];g=x[b>>2];x[31785]=0;d=y[e+1148|0]|y[e+1149|0]<<8;g=R(157,g|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break p}i=c+20|0;if(g>>>0<=i+(d<<3)>>>0){break h}c=d?f:0;f=y[e+1148|0]|y[e+1149|0]<<8;g=i+(f<<3)|0;d=0;i=y[e+1150|0]|y[e+1151|0]<<8;if(!(i&1)){while(1){if(d>>>0>=f>>>0){break d}if(!c){break h}f=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);i=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31785]=0;f=ba(158,i|0,f|0,m|0,x[e+1428>>2])|0;i=x[31785];x[31785]=0;if((i|0)==1){break o}if(!f){break h}x[31785]=0;f=P(152,b|0,g|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break o}if(!f){break h}f=gc(e+1128|0,xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24)),y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24));i=x[f>>2];f=x[f+4>>2];x[31785]=0;Rn(159,e+68|0,b,i,f);f=x[31785];x[31785]=0;if((f|0)==1){break n}if(x[e+72>>2]!=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))){break h}d=d+1|0;c=c+8|0;f=y[e+1148|0]|y[e+1149|0]<<8;continue}}t:{if(i&4){if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31785]=0;d=ba(158,f|0,d|0,m|0,x[e+1428>>2])|0;f=x[31785];x[31785]=0;if((f|0)==1){break m}if(!d){break h}n=xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));l=(y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))&-2;if(!l){break h}x[31785]=0;f=y[e+1154|0]|y[e+1155|0]<<8;d=P(152,b|0,g+(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break l}if(!d){break h}d=x[b+8>>2];g=x[b>>2];x[31785]=0;d=U(153,g|0,d|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break l}if(!d){break h}x[31785]=0;S(160,e+48|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);d=x[31785];x[31785]=0;if((d|0)==1){break b}d=e+48|0;k=Zr(e+68|0,d);ub(d);r=0;i=0;while(1){g=0;u:{while(1){if((i&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}x[31785]=0;d=P(161,k|0,f+1|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break u}h=f&15;o=z[(h<<1)+24576>>1];v:{w:{if(o>>>0<=d>>>0){x[31785]=0;h=y[h+24624|0];q=P(161,k|0,h|0)|0;u=x[31785];x[31785]=0;if((u|0)==1){break u}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&15;break v}x[31785]=0;d=P(161,k|0,4)|0;h=x[31785];x[31785]=0;if((h|0)==1){break u}if((d|0)==15){x[31785]=0;h=P(161,k|0,1)|0;d=x[31785];x[31785]=0;if((d|0)==1){break u}d=65535;if(!h){break w}break e}d=d+65520|0}if(d>>>0>65535){break v}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;q=g+n|0;h=y[e+1150|0]|y[e+1151|0]<<8;x:{if(h&2){r=d+r|0;d=r;break x}d=h&512?d:d^32768}o=d>>>8|0;h=h&1024;v[q+1|0]=h?d:o;v[q|0]=h?o:d;g=g+2|0}if(g>>>0<l>>>0){continue}break}i=i+1|0;if(i>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break e}d=(i<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);l=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31785]=0;g=ba(158,g|0,l|0,m|0,x[e+1428>>2])|0;l=x[31785];x[31785]=0;if((l|0)==1){break u}if(!g){break t}l=(y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24))&-2;if(!l){break t}n=xb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=T(29088)|0;if((gb|0)==($(29088)|0)){Y(j|0)|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;if((c|0)!=1){break e}j=N()|0}ub(k);break a}if(!c){break h}d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31785]=0;d=ba(158,f|0,d|0,m|0,x[e+1428>>2])|0;f=x[31785];x[31785]=0;if((f|0)==1){break k}if(!d){break h}r=xb(x[m>>2],y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24));if((y[e+1152|0]|y[e+1153|0]<<8)>>>0>256){break h}n=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[e+1154|0]|y[e+1155|0]<<8;x[31785]=0;d=P(152,b|0,g|0)|0;g=x[31785];x[31785]=0;y:{z:{if((g|0)!=1){if(!d){break h}d=gc(e+40|0,e+1168|0,y[e+1152|0]|y[e+1153|0]<<8);g=x[d>>2];d=x[d+4>>2];x[31785]=0;Rn(162,e+68|0,b,g,d);d=x[31785];x[31785]=0;if((d|0)==1){break z}d=y[e+1152|0]|y[e+1153|0]<<8;if(d>>>0>A[e+72>>2]){break h}g=x[b+8>>2];i=x[b>>2];x[31785]=0;d=U(153,i|0,g|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-d|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){break y}}j=N()|0;break a}j=N()|0;break a}if(!d){break h}x[31785]=0;S(160,e+48|0,b|0,(y[e+1140|0]|y[e+1141|0]<<8|(y[e+1142|0]<<16|y[e+1143|0]<<24))-(y[e+1152|0]|y[e+1153|0]<<8)|0);d=x[31785];x[31785]=0;if((d|0)==1){break f}d=e+48|0;k=Zr(e+68|0,d);ub(d);l=0;i=0;while(1){g=0;A:{while(1){if((l&65535)>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}x[31785]=0;d=P(161,k|0,f+1|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break A}h=f&7;o=y[h+24608|0];B:{C:{if(o>>>0<=d>>>0){x[31785]=0;h=y[h+24616|0];q=P(161,k|0,h|0)|0;u=x[31785];x[31785]=0;if((u|0)==1){break A}d=q+(d-o<<h)|0;if((d|0)!=(f|0)){f=d&7;break B}x[31785]=0;d=P(161,k|0,3)|0;h=x[31785];x[31785]=0;if((h|0)==1){break A}if((d|0)==7){x[31785]=0;h=P(161,k|0,1)|0;d=x[31785];x[31785]=0;if((d|0)==1){break A}d=255;if(!h){break C}break g}d=d+248|0}if(d>>>0>255){break B}}d=y[(e+1168|0)+d|0];h=d+i|0;q=d;d=(y[e+1150|0]|y[e+1151|0]<<8)&2;v[g+r|0]=d?h:q;i=d?h:i;g=g+1|0}if(g>>>0<n>>>0){continue}break}l=l+1|0;if(l>>>0>=(y[e+1148|0]|y[e+1149|0]<<8)>>>0){break g}d=(l<<3)+c|0;g=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[31785]=0;g=ba(158,g|0,n|0,m|0,x[e+1428>>2])|0;n=x[31785];x[31785]=0;if((n|0)==1){break A}if(!g){break j}n=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);r=xb(x[m>>2],y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24));continue}break}j=T(29088)|0;if((gb|0)==($(29088)|0)){Y(j|0)|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;if((c|0)!=1){break g}j=N()|0}ub(k);break a}ub(k);break h}le(e+24|0,x[m>>2],x[m+4>>2]);kf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Jd(e+16|0);x[31785]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;b=dg(163,e+68|0,x[e+32>>2],x[e+36>>2],e+8|0);c=x[31785];x[31785]=0;if((c|0)==1){break i}hd(hj(x[a+4>>2])+12|0,b);ub(b);break h}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}j=N()|0;break a}ub(k);break h}j=N()|0;break a}ze(s);break c}ub(k);break d}j=N()|0;break a}ub(k)}t=t+1|0;continue}}fb=e+1456|0;return j|0}j=N()|0}ze(s);Q(j|0);p()}function Npa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;e=fb-368|0;fb=e;a:{if(!bd(b,1080)){break a}if(!Yq(b,e+364|0)){break a}l=RX(e+344|0);if(!QX(e+364|0,l)){break a}d=z[l+10>>1];if(!d|d>>>0>127){break a}if(!c){K=1;break a}L=1;Bd(a,1);t=a+480188|0;g=z[l+10>>1];w[t>>1]=g;s=y[l+14|0];M=y[l+13|0];i=y[l+12|0];if(!me(e+364|0,25482)){L=me(e+364|0,25487)}if(y[l+15|0]){Lb(a+1074312|0,5,1);g=z[a+480188>>1]}d=e+364|0;u=me(d,16934);m=1;if(!me(d,17714)){m=me(e+364|0,13694)}B=(g&65535)==8&(M|0)!=0;bd(b,0);d=y[l+16|0];h=fb-16|0;fb=h;b:{g=e+324|0;if(!Xw(b,g)|!d){break b}Vw(h+8|0,g);d=0;while(1){if(d>>>0>=20){break b}n=x[h+8>>2];og(xb(n,d),xb(n,d|1));d=d+2|0;continue}}fb=h+16|0;h=e+312|0;hf(h,g,20,3);d=e+180|0;Ec(d,h);yb(a+1298308|0,d);tb(d);w[a+480190>>1]=31;n=(i|0)!=0;r=a+480188|0;g=1;h=0;i=u;while(1)if((g|0)==32){K=A[l+4>>2]>=j>>>0;if(!K){break a}d=y[l+16|0];g=fb-16|0;fb=g;c:{k=e+180|0;if(!AC(b,k)|!d){break c}FC(g+8|0,k);d=0;while(1){if(d>>>0>=130){break c}k=x[g+8>>2];og(xb(k,d),xb(k,d|1));d=d+2|0;continue}}fb=g+16|0;bd(b,z[l+8>>1]);g=y[e+181|0];d=128;k=a+484376|0;_v(Wb(x[a+484360>>2],y[k|0]),e+182|0,128);i=!g&i;m=i?h:0;h=y[e+180|0];d:{if(h>>>0>128){break d}d=h;if(d){break d}h=x[Wb(x[a+484360>>2],y[a+484376|0])>>2];g=128;while(1){d=g;if(d>>>0<2){d=1;break d}g=d-1|0;if(!z[_b(h,g)>>1]){continue}break}}j=NX(b,Wb(x[a+484360>>2],y[k|0]),d&65535,f,t,m,0);F=1;e:{if(!(i&z[a+480188>>1]==8)){F=(s|0)!=0;break e}x[l>>2]=11284}f:{if(!B){break f}f=Wb(x[a+484360>>2],y[a+484376|0]);aa=e,ba=vb(x[f>>2]),x[aa+312>>2]=ba;h=vb(x[f+4>>2]);while(1){f=x[e+312>>2];if(!Ib(f,h)){break f}w[f>>1]=z[f>>1]>>>1;Wd(e+312|0);continue}}f=a+484376|0;_e(Wb(x[a+484360>>2],y[f|0]),y[e+181|0]);T=d-1|0;d=y[e+181|0];g:{if((T&65535)>>>0>=d>>>0){g=z[t>>1];if((d|0)!=120|(g|0)!=4){break g}}_e(Wb(x[a+484360>>2],y[f|0]),0);g=z[a+480188>>1]}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;s=0;x[a+480208>>2]=0;aa=a,ba=Xb(256/((g&65535)>>>0)|0,32,128),x[aa+480228>>2]=ba;Ch(a,0);v[e+179|0]=0;h:{if(n&1){q=1;k=1;break h}q=1;m=0;n=0;h=u;i:while(1){o=n&65535;if(o>>>0<j>>>0){k=0;g=0;while(1)if((g|0)==256){n=n+1|0;continue i}else{d=Jg(e+312|0);MX(e+160|0,b,!o&y[l+16|0]!=0);f=x[e+160>>2];x[e+172>>2]=f;x[e+64>>2]=f;f=e+92|0;Yo(f,e- -64|0,d);i=Ic(f);r=vD(y[d|0]);j:{k:{l:{m:{d=y[e+92|0];if((d-7&255)>>>0<3){h=0;break m}f=y[i|0];if(!((d|0)!=14|f>>>0<=1)){h=0;break l}if(!((d|0)==15&(f&255)>>>0>31)){h=r?h:0;if((d|0)!=13){break m}k=k+1|0;if((k&65535)>>>0<2){break j}}h=0;break j}if((d|0)==8){break k}if((d|0)!=14){break j}f=y[i|0]}if((f&240)!=128){break j}v[e+80|0]=f<<4;aa=e,ba=y[af(e+179|0,e+80|0)|0],v[aa+179|0]=ba;break j}aa=e,ba=y[af(e+179|0,i)|0],v[aa+179|0]=ba;d=v[i|0];if((d|0)>=0){s=1;break j}m=(d|0)!=-92&d>>>0>4294967183|m}q=q&r;g=g+1|0;continue}}break}d=s^-1;s=0;s=(d|m)&1?s:y[e+179|0]>47;k=h&1}bd(b,z[l+8>>1]);d=z[a+480188>>1];E=a+484344|0;O=j+B&65535;$f(E,O);V=B?4:d;r=a+1074312|0;$=c&1;m=0;n=0;o=0;n:{o:{p:{q:{while(1){if((m|0)==(O|0)){break p}r:{if(B){d=(m&65534)>>>1|0;f=m&1;if(!f){if(!bh(E,d,64)){break p}}i=f<<2;d=Vb(x[E>>2],d);break r}if(!bh(E,m&65535,64)){break p}i=0;d=Vb(x[E>>2],m)}h=0;i=gd(x[d>>2],x[x[d+48>>2]+12>>2],0,i);if(!$){o=0;G=0;break o}d=z[t>>1];v[e+92|0]=0;f=d;d=e+92|0;H=Vv(e+312|0,f,d);f=z[t>>1];x[31785]=0;v[e+92|0]=0;I=U(603,e+160|0,f|0,d|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){R=0;s:{t:while(1){u:{if((R|0)==64){break s}g=0;f=0;W=0;while(1){if((g|0)==(V|0)){R=R+1|0;o=f&W|o;i=D(z[t>>1],6)+i|0;continue t}d=y[l+16|0];x[31785]=0;S(604,e+92|0,b|0,!m&(d|0)!=0);d=x[31785];x[31785]=0;if((d|0)!=1){d=x[e+92>>2];x[e+156>>2]=d;x[e+60>>2]=d;j=e+80|0;h=D(g,6)+i|0;Yo(j,e+60|0,h);d=y[e+80|0];J=Ic(j);j=y[J|0];if(d|j){v:{if(!(!M|(d&255)!=14)){d=0;v[J|0]=0;v[e+80|0]=0;j=y[J|0];break v}if(!M|(d&255)!=15|(j&255)>>>0<32){break v}j=31;v[J|0]=31;d=y[e+80|0]}Mf(h,d&255,j&255)}d=1;w:{x:{y:{z:{A:{j=y[h+3|0];switch(j-14|0){case 2:break w;case 0:break z;case 3:break A;default:break y}}n=y[h+5|0]<100|n;W=1;break x}if(!k){break x}v[h+5|0]=0;break x}if((j|0)==9&s){d=y[h+5|0];if((d|0)==164){v[h+3|0]=20;v[h+5|0]=145;break x}aa=h,ba=Zg(d<<1),v[aa+5|0]=ba;break x}if((j|0)!=19){break x}d=y[h+5|0];if(d>>>0>15){break x}j=!(d&1);d=(j^X)&1;X=d?j:X;G=d+G|0}d=f}B:{if(!y[h|0]){f=y[h+1|0];if(!f|B){break B}j=y[xb(x[H>>2],g)|0];if(!j|(f|0)==(j|0)){break B}j=xb(x[I>>2],g);f=y[j|0]+1|0;v[j|0]=f;if((f&255)>>>0<4){break B}x[31785]=0;U(269,r|0,85,1)|0;f=x[31785];x[31785]=0;if((f|0)!=1){break B}break u}aa=xb(x[I>>2],g),ba=0,v[aa|0]=ba}f=y[h+1|0];if(f){aa=xb(x[H>>2],g),ba=f,v[aa|0]=ba}g=g+1|0;f=d;continue}break}}break}i=N()|0;dc(I);break q}dc(I);dc(H);m=m+1|0;continue}break}i=N()|0}dc(H);break n}h=n}C:{D:{E:{if((q^-1|Y)&1){break E}F:{if(me(e+364|0,16934)){break F}if(me(e+364|0,17719)){break F}if(!me(e+364|0,13684)){break E}}x[a+480208>>2]=x[a+480208>>2]|2162688;d=Lb(Lb(Lb(r,85,1),91,1),92,1);G:{if(y[e+179|0]>47){break G}d=Lb(d,84,1);if(y[e+181|0]==127){break G}Lb(d,83,1)}if(!((G|0)>6|F)){break D}break C}if(!(q&1)){if(!(y[e+181|0]==127&(T&65535)>>>0<129&u)){break C}x[l>>2]=8514;break C}if((G|0)>6|F){break C}}x[a+480208>>2]=x[a+480208>>2]|8388608}if((u|F)==1){Lb(r,89,1)}if(L){Lb(r,84,1)}i=0;H:{if(!(c&2)){break H}bd(b,z[l+8>>1]+(D(O,V)<<8)|0);f=(q&u^1|Z)&1;g=1;while(1){if((g|0)==32){i=i&1;break H}n=D(g,104)+a|0;c=n+484380|0;d=x[c>>2];if(d){j=2;if(!L){d=LX(b,13948);j=d?10:0;i=d?1:i;d=x[c>>2]}k=ad(e+312|0,8,1,0,j);d=gD(k,d)+x[b+8>>2]|0;if(!f){aa=c,ba=x[_c(c,n+484388|0)>>2],x[aa>>2]=ba}qg(k,c,b);bd(b,d)}g=g+1|0;continue}}I:{J:{if(!u){if(!((me(e+364|0,17719)&h^-1|o)&1)){break J}break I}if((h^-1|o)&1){break I}}b=KX(e+128|0,0);c=x[b+20>>2];x[e+48>>2]=x[b+16>>2];x[e+52>>2]=c;c=x[b+12>>2];x[e+40>>2]=x[b+8>>2];x[e+44>>2]=c;c=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=c;b=e+312|0;qv(b,a,0,e+32|0);_=C[x[e+312>>2]>>3];Ui(b);if(!(_>=480)){break I}c=Lb(r,5,1);b=JX(e+104|0,_);d=x[b+20>>2];x[e+24>>2]=x[b+16>>2];x[e+28>>2]=d;d=x[b+12>>2];x[e+16>>2]=x[b+8>>2];x[e+20>>2]=d;d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;b=e+312|0;qv(b,a,0,e+8|0);d=y[x[e+312>>2]+26|0];Ui(b);if(d){Yf(c,5);break I}x[l>>2]=17286}f=e+364|0;d=f;b=ec(d);c=d;while(1){if((b|0)!=(d|0)){h=y[d|0];v[c|0]=h>>>0<=32?32:h;c=c+1|0;d=d+1|0;continue}break}cg(e+92|0,17039);x[31785]=0;b=U(45,e+68|0,f|0,b|0)|0;c=x[31785];x[31785]=0;K:{L:{M:{N:{O:{if((c|0)!=1){x[31785]=0;S(605,e+80|0,1,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break O}x[31785]=0;S(142,e+312|0,e+92|0,e+80|0);c=x[31785];x[31785]=0;if((c|0)==1){break N}c=e+312|0;yb(a+1298344|0,c);tb(c);tb(e+80|0);tb(b);Eb(e+92|0);b=uc(c,12407);yb(a+1298356|0,b);tb(b);b=x[l>>2];if(b){$h(a+1298368|0,b)}aa=a+1298404|0,ba=x[Gc(e+312|0,28)>>2],x[aa>>2]=ba;if(i){break K}break a}i=N()|0;break L}i=N()|0;break M}i=N()|0;tb(e+80|0)}tb(b)}Eb(e+92|0);break n}b=uc(e+312|0,17338);x[31785]=0;P(77,a+1298368|0,b|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){tb(b);break a}i=N()|0;tb(b)}Q(i|0);p()}else{d=y[l+16|0];k=fb-16|0;fb=k;P:{q=e+180|0;if(!GX(b,q)|!d){break P}rv(k+8|0,q);d=0;while(1){if(d>>>0>=30){break P}o=x[k+8>>2];og(xb(o,d),xb(o,d|1));d=d+2|0;continue}}fb=k+16|0;k=D(g,104)+a|0;d=k+484380|0;q=GC(q,d,((g<<5)+a|0)+946304|0,z[r>>1]==4);d=x[d>>2];Q:{if(m){v[k+484417|0]=0-(y[e+204|0]<<3);break Q}n=d>>>0<65536&n}k=Cb(y[e+202|0]|y[e+203|0]<<8);R:{if(k){Y=!Cb(y[e+208|0]|y[e+209|0]<<8)|Y;break R}Z=y[e+205|0]==64|Z}o=i&1;i=0;S:{if(!o){break S}h=(k<<1)+h|0;o=y[e+204|0];i=!o;if(o|!k){break S}i=y[e+205|0]==64}j=j+q|0;f=d+f|0;g=g+1|0;continue}}fb=e+368|0;return K|0}function tta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;e=fb+-64|0;fb=e;xc(a);a:{b:{if(b>>>0<=2){H=e,I=be(a),v[H+56|0]=I;Yb(a,2);b=eh(a);v[e+58|0]=b;v[e+59|0]=b>>>8;b=Mg(a);v[e+60|0]=b;v[e+61|0]=b>>>8;v[e+62|0]=b>>>16;v[e+63|0]=b>>>24;break b}ap(a,e+56|0);if(b>>>0>5){break a}}v[e+57|0]=0}c:{q=d+484344|0;E=Hd(y[e+58|0]|y[e+59|0]<<8,1,1024);o=RD(q,E);if((o|0)==65535){break c}b=Vb(x[d+484344>>2],o);m=gd(x[b>>2],x[x[b+48>>2]+12>>2],0,0);f=z[d+480188>>1];w[e+12>>1]=f-1;w[e+44>>1]=y[e+56|0];F=z[Mc(e+12|0,e+44|0)>>1];g=F+1|0;b=g&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){v[c+13|0]=y[e+57|0]>>>4;b=y[c+12|0];v[e+12|0]=0;b=(b|0)!=0;u=Vv(e+44|0,g,e+12|0);G=d+480188|0;d:while(1){if((k|0)==(E|0)){dc(u);break c}e:{f:{f=xb(x[u>>2],0);d=y[f|0];g:{if(!d){x[31785]=0;f=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}g=f<<24>>24;if((g|0)<0){x[31785]=0;f=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}H=xb(x[u>>2],0),I=f,v[H|0]=I}v[e+12|0]=0;h:{i:{f=g&63;if(!f){break i}x[31785]=0;i=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break h}v[e+12|0]=i;j:{k:{switch(f-1|0){case 0:v[c+12|0]=0;v[e+40|0]=1;H=c,I=y[af(e+40|0,e+12|0)|0],v[H+14|0]=I;v[c+15|0]=0;break j;case 1:if(!i){break i}v[c+15|0]=i;v[c+12|0]=1;b=y[c+13|0];if(!b){break j}v[c+14|0]=D(D(b,i),15);break j;case 2:v[c+13|0]=i>>>4;if(i>>>0>=16){b=y[c+12|0];i=0;x[e+40>>2]=0;x[e+36>>2]=0;s=0;if(b){break g}break f}i=0;v[c+12|0]=0;x[e+40>>2]=0;x[e+36>>2]=0;s=0;if(b&1){break g}break f;case 3:s=0;x[e+40>>2]=0;x[e+36>>2]=0;if(b&1){break g}break f;case 5:if(!i){break i}b=(y[c+12|0]?15:14)+c|0;d=y[b|0];v[b|0]=d>>>0>=256-i>>>0?-1:d+i|0;break j;case 6:break k;default:break i}}if(!i){break i}b=(y[c+12|0]?15:14)+c|0;d=y[b|0];v[b|0]=d>>>0<=i+1>>>0?1:d-i|0}i=0;x[e+40>>2]=0;x[e+36>>2]=0;break g}i=0;x[e+40>>2]=0;x[e+36>>2]=0;s=0;if(b&1){break g}break f}break e}v[f|0]=d-1;i=0;x[e+40>>2]=0;x[e+36>>2]=0;s=0;if(!(b&1)){break f}}d=y[c+13|0];b=y[c+12|0];if(b){s=0;if(!d){break f}}l:{if(b){x[e+12>>2]=1;x[e+32>>2]=D(d,y[c+15|0])<<1;d=x[We(e+12|0,e+32|0)>>2];break l}d=D(y[c+14|0],30)+30|0}b=255;f=0;m=0;while(1){m:{if(b){g=D(b,d);m=(g|0)/48|0;if(g-1536>>>0>=10752){break m}f=b}x[e+36>>2]=m;x[e+40>>2]=f;Ee(e+36|0,32,255);s=1;x[e+12>>2]=1;H=c,I=x[We(e+12|0,e+40|0)>>2],v[H+16|0]=I;break f}b=b-1|0;continue}}B=k-1|0;C=1;b=Vb(x[q>>2],o);b=gd(x[b>>2],x[x[b+48>>2]+12>>2],k,1);while(1){h=C&65535;if(h>>>0>F>>>0){if(s){b=e+12|0;we(Vb(x[q>>2],o),Vh($o(Ue(Le(b,17,y[e+36|0]),k),0)));we(Vb(x[q>>2],o),Vh(Ue(Le(b,16,y[e+40|0]),k)))}if(i>>>0>=16){we(Vb(x[q>>2],o),$_(Ue(Le(e+12|0,20,i>>>4|224),k)))}b=i&15;if(b){we(Vb(x[q>>2],o),$_(Ue(Le(e+12|0,20,Hd((D(b,y[c+16|0])>>>0)/15&255,1,15)|96),k)))}k=k+1|0;b=0;continue d}n:{o:{p:{q:{r:{f=xb(x[u>>2],h);d=y[f|0];if(!d){x[31785]=0;f=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}g=f<<24>>24;if((g|0)<0){x[31785]=0;f=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}H=xb(x[u>>2],h),I=f,v[H|0]=I}m=1;l=g&255;if(l&64){x[31785]=0;f=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}v[b+1|0]=f;m=!f}if(!(l&32)){f=y[b|0];break r}x[31785]=0;f=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}v[b|0]=f;if((f-1&255)>>>0<=107){d=bm(f+24|0);v[b|0]=d;H=Vc(x[c>>2],h),I=d,v[H+1|0]=I;f=y[b|0];break o}if((f+127&255)>>>0<=107){d=bm((f&127)+24|0);H=Vc(x[c>>2],h),I=d,v[H|0]=I;v[b|0]=0;break q}if((f|0)!=255){break r}f=254;break p}v[f|0]=d-1;break n}if(f&255){break o}}if(!y[b+1|0]){f=0;break o}f=y[Vc(x[c>>2],h)+1|0];v[b+1|0]=0}v[b|0]=f}if(zd(f)){H=Vc(x[c>>2],h),I=0,v[H+5|0]=I}v[e+31|0]=0;v[e+30|0]=0;if(l&16){v[b+2|0]=1;x[31785]=0;f=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}v[b+4|0]=f+2>>>2}f=0;A=0;t=0;s:{if(!(l&8)){break s}x[31785]=0;g=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}x[31785]=0;t=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}t:{switch(g-1|0){case 0:v[b|0]=254;break s;case 1:v[b|0]=255;break s;case 2:d=Vc(x[c>>2],h);v[b|0]=y[d+1|0];v[d+5|0]=0;break s;case 3:d=Uv(t,y[c+16|0]);t=d?d|-48:0;A=d?20:0;if(y[b|0]){break s}d=Vc(x[c>>2],h);v[b|0]=y[d+1|0];v[d+5|0]=0;break s;case 4:v[e+12|0]=1;H=e,I=Uv(t,y[c+16|0]),v[H+32|0]=I;t=y[af(e+12|0,e+32|0)|0];H=Vc(x[c>>2],h),I=0,v[H+5|0]=I;A=15;break s;case 5:case 6:case 7:case 8:u:{if(!k){break u}if((g|0)==y[Vc(x[c>>2],h)+4|0]){break u}if(!we(Vb(x[q>>2],o),qn($o(Ue(Le(e+12|0,20,(g+122|160)&255),B),h)))){break u}H=Vc(x[c>>2],h),I=g,v[H+4|0]=I}d=Vc(x[c>>2],h);if(!y[b|0]){v[b|0]=y[d+1|0]}v[d+5|0]=0;A=10;break s;case 9:break t;default:break s}}d=Vc(x[c>>2],h);g=y[d+5|0];v[d+5|0]=g^1;t=g?-98:-97;A=20}v:{w:{x:{if(!(l&4)){break x}x[31785]=0;r=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}x[31785]=0;j=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}v[e+31|0]=j;g=1;f=1;y:{switch(r-1|0){case 0:QD(e+12|0,j<<24>>24<<3,128);d=y[b|0];if(zd(d)){H=b,I=bm(d+x[e+12>>2]|0),v[H|0]=I}v[e+31|0]=y[e+16|0]^128;f=35;break x;case 1:d=Uv(j,y[c+16|0]);v[e+31|0]=d;if(!d){break w}v[e+31|0]=d|208;f=20;break v;case 3:case 4:H=e,I=__(j,y[c+16|0],1),v[H+31|0]=I;f=(r|0)==4?2:3;break v;case 5:if(!y[b|0]){H=b,I=y[Vc(x[c>>2],h)|0],v[H|0]=I}H=e,I=__(j,y[c+16|0],0),v[H+31|0]=I;f=4;break v;case 6:H=b,I=bm(j+25|0),v[H|0]=I;v[e+31|0]=255;f=4;break v;case 7:case 8:case 9:z:{if(!k){break z}if((r|0)==y[Vc(x[c>>2],h)+2|0]){break z}if(!we(Vb(x[q>>2],o),qn($o(Ue(Le(e+12|0,20,(r-8|48)&255),B),h)))){break z}H=Vc(x[c>>2],h),I=r,v[H+2|0]=I}H=e,I=PD(j,y[c+16|0]),v[H+31|0]=I;f=5;break v;case 10:H=e,I=Z_(j,y[c+16|0]),v[H+31|0]=I;f=18;break v;case 11:d=Uv(j,y[c+16|0]);v[e+31|0]=d;if(d){v[e+31|0]=d|192;f=20;break v}v[b|0]=254;break w;case 2:break v;default:break y}}f=0}g=0;break v}f=0}n=0;r=1;A:{if(l&2){x[31785]=0;j=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}x[31785]=0;l=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}v[e+30|0]=l;n=9;r=0;d=0;B:{switch(j-1|0){case 0:case 1:d=1;H=e,I=Y_(l,y[c+16|0],(j|0)==1),v[H+30|0]=I;n=11;break A;case 2:H=e,I=Z_(l,y[c+16|0]),v[H+30|0]=I;d=1;n=18;break A;case 3:case 4:case 5:C:{if(!k){break C}if((j|0)==y[Vc(x[c>>2],h)+3|0]){break C}if(!we(Vb(x[q>>2],o),qn($o(Ue(Le(e+12|0,20,(j-4|64)&255),B),h)))){break C}H=Vc(x[c>>2],h),I=j,v[H+3|0]=I}H=e,I=PD(l,y[c+16|0]),v[H+30|0]=I;d=1;n=8;break A;case 7:case 8:H=e,I=Y_(l,y[c+16|0],(j|0)==8),v[H+30|0]=I;d=1;n=29;break A;case 9:H=e,I=PD(l,y[c+16|0]),v[H+30|0]=I;d=1;n=27;break A;case 6:break A;default:break B}}n=0;r=1}d=0}if(g){X_(b,k,z[G>>1],f,e+31|0)}if(d){X_(b,k,z[G>>1],n,e+30|0)}D:{E:{F:{G:{H:{if(!m){break H}if(!zd(y[b|0])){break H}if(!f){break G}if(!r|(f|0)==4){break H}v[e+30|0]=255;n=4}d=b+2|0;if(y[b+2|0]!=1){break D}if(f){break F}v[e+31|0]=y[b+4|0];f=13;break E}v[e+31|0]=255;d=b+2|0;f=4;if(y[b+2|0]!=1){break D}}if(n){break D}v[e+30|0]=y[b+4|0];n=13}v[d|0]=0}g=Jg(e+12|0);sn(e+32|0,g,f,y[e+31|0],n,y[e+30|0]);I:{if(y[d|0]){break I}f=y[e+14|0];if(!f){break I}v[b+2|0]=f;v[b+4|0]=y[e+16|0]}m=y[e+15|0];J:{if(A){sn(e+32|0,g,m&255,y[e+17|0],A,t&255);K:{if(y[d|0]){break K}d=y[e+14|0];if(!d){break K}v[b+2|0]=d;v[b+4|0]=y[e+16|0]}m=y[e+15|0];break J}if(!(m&255)){break n}}v[b+3|0]=m;v[b+5|0]=y[e+17|0]}b=b+6|0;C=C+1|0;continue}}break}a=N()|0;dc(u);Q(a|0);p()}else{v[m+D(b,6)|0]=254;b=b+1|0;continue}}fb=e- -64|0;return o|0}function GQ(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;k=fb-336|0;fb=k;n=h;p=i&65535;o=d;m=e&65535;u=(e^i)&-2147483648;s=i>>>16&32767;q=e>>>16&32767;a:{b:{if(s-32767>>>0>4294934529&q-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){r=d;u=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){r=h;u=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;u=2147450880;break a}u=u|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));r=b?0:r;u=b?2147450880:u;b=0;c=0;break a}if(!(f|h|(e|g))){u=u|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){d=!(m|o);i=d;j=d?b:o;d=d<<6;i=G(i?c:m);d=d+((i|0)==32?G(j)+32|0:i)|0;Vf(k+320|0,b,c,o,m,d-15|0);v=16-d|0;o=x[k+328>>2];m=x[k+332>>2];c=x[k+324>>2];b=x[k+320>>2]}if(e>>>0>65535){break b}d=!(n|p);h=d;i=d?f:n;d=d<<6;h=G(h?g:p);d=d+((h|0)==32?G(i)+32|0:h)|0;Vf(k+304|0,f,g,n,p,d-15|0);v=(d+v|0)-16|0;n=x[k+312>>2];p=x[k+316>>2];f=x[k+304>>2];g=x[k+308>>2]}e=p|65536;C=e;D=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=e;i=0-d|0;h=j;j=1963258675-(j+((d|0)!=0)|0)|0;Hf(k+288|0,d,h,0,0,i,j,0,0);d=x[k+296>>2];Hf(k+272|0,0-d|0,0-(x[k+300>>2]+((d|0)!=0)|0)|0,0,0,i,j,0,0);d=x[k+280>>2];i=d<<1|x[k+276>>2]>>>31;d=x[k+284>>2]<<1|d>>>31;Hf(k+256|0,i,d,0,0,e,h,0,0);j=x[k+264>>2];Hf(k+240|0,i,d,0,0,0-j|0,0-(x[k+268>>2]+((j|0)!=0)|0)|0,0,0);i=x[k+248>>2];j=i<<1|x[k+244>>2]>>>31;d=x[k+252>>2]<<1|i>>>31;Hf(k+224|0,j,d,0,0,e,h,0,0);i=x[k+232>>2];Hf(k+208|0,j,d,0,0,0-i|0,0-(x[k+236>>2]+((i|0)!=0)|0)|0,0,0);d=x[k+216>>2];i=d<<1|x[k+212>>2]>>>31;d=x[k+220>>2]<<1|d>>>31;Hf(k+192|0,i,d,0,0,e,h,0,0);j=x[k+200>>2];Hf(k+176|0,i,d,0,0,0-j|0,0-(x[k+204>>2]+((j|0)!=0)|0)|0,0,0);i=e;e=x[k+184>>2];d=h;n=e<<1|x[k+180>>2]>>>31;h=n-1|0;e=(x[k+188>>2]<<1|e>>>31)-!n|0;Hf(k+160|0,i,d,0,0,h,e,0,0);d=h;Hf(k+144|0,f<<15,g<<15|f>>>17,0,0,d,e,0,0);t=k+112|0;z=x[k+168>>2];h=x[k+172>>2];n=x[k+160>>2];i=x[k+152>>2];l=n+i|0;p=x[k+164>>2];j=p+x[k+156>>2]|0;j=i>>>0>l>>>0?j+1|0:j;i=j;j=(p|0)==(j|0)&l>>>0<n>>>0|j>>>0<p>>>0;p=j+z|0;j=j>>>0>p>>>0?h+1|0:h;n=!i&l>>>0>1|(i|0)!=0;h=n+p|0;j=n>>>0>h>>>0?j+1|0:j;Hf(t,d,e,0,0,0-h|0,0-(((h|0)!=0)+j|0)|0,0,0);Hf(k+128|0,1-l|0,0-((l>>>0>1)+i|0)|0,0,0,d,e,0,0);K=(q-s|0)+v|0;e=x[k+116>>2];t=e;d=x[k+112>>2];j=e<<1|d>>>31;n=d<<1;q=j;d=j;h=x[k+140>>2];B=h;e=x[k+136>>2];j=h<<1|e>>>31;i=e<<1|x[k+132>>2]>>>31;h=i+n|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;y=d;z=d;l=0;j=m|65536;L=j;M=o;d=o;j=j<<1|d>>>31;O=d<<1;P=j;F=j;d=sua(y,l,j,0);j=hb;H=d;w=j;v=b<<1;d=c<<1|b>>>31;s=d;j=0;p=j;i=h-13927|0;y=(e|0)==(y|0)&i>>>0<h>>>0|e>>>0>y>>>0;e=(e|0)==(q|0)&h>>>0<n>>>0|e>>>0<q>>>0;d=x[k+120>>2];h=x[k+124>>2]<<1|d>>>31;d=d<<1|t>>>31;j=h;l=B>>>31|0;d=l+d|0;j=d>>>0<l>>>0?j+1|0:j;h=d;d=d+e|0;l=h>>>0>d>>>0?j+1|0:j;e=d;d=d+y|0;l=e>>>0>d>>>0?l+1|0:l;e=d-1|0;y=l-!d|0;q=0;j=sua(s,p,y,q);d=j+H|0;h=hb+w|0;h=d>>>0<j>>>0?h+1|0:h;t=(w|0)==(h|0)&d>>>0<H>>>0|h>>>0<w>>>0;j=0;B=e;N=c>>>31|0;E=N|o<<1;w=0;e=sua(e,j,E,w);o=e+d|0;j=hb+h|0;l=0;j=e>>>0>o>>>0?j+1|0:j;n=j;d=(j|0)==(h|0)&d>>>0>o>>>0|h>>>0>j>>>0;e=d;d=d+t|0;l=e>>>0>d>>>0?1:l;e=sua(F,p,y,q);d=e+d|0;j=hb+l|0;t=d;d=d>>>0<e>>>0?j+1|0:j;e=sua(F,p,B,w);m=hb;h=e;e=sua(E,w,y,q);l=h+e|0;j=hb+m|0;j=e>>>0>l>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&h>>>0>l>>>0|j>>>0<m>>>0;m=t+e|0;d=d+j|0;d=m>>>0<e>>>0?d+1|0:d;t=m;m=d;e=0;d=e+o|0;j=l+n|0;j=d>>>0<e>>>0?j+1|0:j;e=j;h=(j|0)==(n|0)&d>>>0<o>>>0|j>>>0<n>>>0;j=m;l=h;h=h+t|0;j=l>>>0>h>>>0?j+1|0:j;I=h;l=j;t=d;m=d;o=e;H=i;d=sua(i,0,E,w);h=hb;e=d;i=sua(z,r,s,r);d=d+i|0;j=hb+h|0;j=d>>>0<i>>>0?j+1|0:j;i=(h|0)==(j|0)&d>>>0<e>>>0|h>>>0>j>>>0;h=j;J=v&-2;e=sua(B,w,J,0);n=e+d|0;j=hb+j|0;j=e>>>0>n>>>0?j+1|0:j;e=j;d=(j|0)==(h|0)&d>>>0>n>>>0|h>>>0>j>>>0;h=0;i=d+i|0;d=(i>>>0<d>>>0?1:h)+o|0;j=l;m=i+m|0;d=m>>>0<i>>>0?d+1|0:d;i=d;d=(d|0)==(o|0)&m>>>0<t>>>0|d>>>0<o>>>0;h=d;d=d+I|0;j=h>>>0>d>>>0?j+1|0:j;Q=d;t=j;d=sua(F,p,H,r);I=hb;F=d;h=sua(y,q,J,r);d=d+h|0;j=hb+I|0;o=d;p=sua(z,r,E,w);l=d+p|0;h=d>>>0<h>>>0?j+1|0:j;d=h+hb|0;d=l>>>0<p>>>0?d+1|0:d;q=l;j=sua(s,r,B,w);p=l+j|0;l=hb+d|0;l=j>>>0>p>>>0?l+1|0:l;B=0;E=(d|0)==(l|0)&p>>>0<q>>>0|d>>>0>l>>>0;j=(h|0)==(I|0)&o>>>0<F>>>0|h>>>0<I>>>0;d=(d|0)==(h|0)&o>>>0>q>>>0|d>>>0<h>>>0;d=d+j|0;d=d+E|0;h=l;q=h+m|0;j=(d|B)+i|0;j=h>>>0>q>>>0?j+1|0:j;o=j;d=(i|0)==(j|0)&m>>>0>q>>>0|i>>>0>j>>>0;j=t;h=d;d=d+Q|0;j=h>>>0>d>>>0?j+1|0:j;B=d;i=j;d=sua(z,r,J,r);z=hb;m=d;h=sua(s,r,H,r);d=d+h|0;j=hb+z|0;j=d>>>0<h>>>0?j+1|0:j;t=0;h=(j|0)==(z|0)&d>>>0<m>>>0|j>>>0<z>>>0;m=j;d=j+n|0;j=(h|t)+e|0;j=d>>>0<m>>>0?j+1|0:j;h=j;m=(e|0)==(j|0)&d>>>0<n>>>0|e>>>0>j>>>0;j=p;p=0;n=p+d|0;l=h+j|0;j=0;l=n>>>0<p>>>0?l+1|0:l;d=(h|0)==(l|0)&d>>>0>n>>>0|h>>>0>l>>>0;e=d;d=d+m|0;j=(e>>>0>d>>>0?1:j)+o|0;l=i;e=d;d=d+q|0;j=e>>>0>d>>>0?j+1|0:j;e=j;h=(o|0)==(j|0)&d>>>0<q>>>0|j>>>0<o>>>0;i=h;h=h+B|0;l=i>>>0>h>>>0?l+1|0:l;i=l;c:{if((l|0)==131071|l>>>0<131071){M=O|N;L=w|P;Hf(k+80|0,d,e,h,i,f,g,D,C);l=x[k+84>>2];p=l;j=b<<17;n=0;m=x[k+88>>2];c=n-m|0;b=x[k+80>>2];l=(l|b)!=0;o=c-l|0;m=(j-(x[k+92>>2]+(m>>>0>n>>>0)|0)|0)-(c>>>0<l>>>0)|0;n=0-b|0;p=0-(((b|0)!=0)+p|0)|0;b=K+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;Hf(k+96|0,d,e,h,i,f,g,D,C);o=x[k+100>>2];s=o;v=x[k+104>>2];n=0-v|0;l=x[k+96>>2];m=(o|l)!=0;o=n-m|0;m=((b<<16)-(x[k+108>>2]+(p>>>0<v>>>0)|0)|0)-(m>>>0>n>>>0)|0;n=0-l|0;p=0-(((l|0)!=0)+s|0)|0;v=b;s=c;b=K+16383|0}if((b|0)>=32767){u=u|2147418112;b=0;c=0;break a}d:{if((b|0)>0){l=m<<1|o>>>31;o=o<<1|p>>>31;m=l;v=h;s=i&65535|b<<16;l=p<<1|n>>>31;i=n<<1;break d}if((b|0)<=-113){b=0;c=0;break a}Vm(k- -64|0,d,e,h,i,1-b|0);Vf(k+48|0,v,s,M,L,b+112|0);d=x[k+64>>2];e=x[k+68>>2];v=x[k+72>>2];s=x[k+76>>2];Hf(k+32|0,f,g,D,C,d,e,v,s);b=x[k+40>>2];c=x[k+56>>2];l=x[k+36>>2];o=b<<1|l>>>31;n=c-o|0;m=x[k+60>>2]-((x[k+44>>2]<<1|b>>>31)+(c>>>0<o>>>0)|0)|0;b=x[k+32>>2];h=l<<1|b>>>31;j=b<<1;i=x[k+52>>2];c=x[k+48>>2];b=(h|0)==(i|0)&j>>>0>c>>>0|h>>>0>i>>>0;o=n-b|0;m=m-(b>>>0>n>>>0)|0;l=i-((c>>>0<j>>>0)+h|0)|0;i=c-j|0}b=i;Hf(k+16|0,f,g,D,C,3,0,0,0);Hf(k,f,g,D,C,5,0,0,0);c=0;h=l+c|0;j=d&1;b=b+j|0;h=i>>>0>b>>>0?h+1|0:h;i=b;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;l=m;b=(c|0)==(h|0)&b>>>0<j>>>0|c>>>0>h>>>0;f=b+o|0;l=b>>>0>f>>>0?l+1|0:l;j=e;b=(l|0)==(C|0);b=b&(f|0)==(D|0)?g:b&f>>>0>D>>>0|l>>>0>C>>>0;c=b;b=b+d|0;j=c>>>0>b>>>0?j+1|0:j;c=j;d=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;j=s;e=d;d=d+v|0;j=e>>>0>d>>>0?j+1|0:j;g=d;e=x[k+20>>2];m=(e|0)==(h|0)&A[k+16>>2]<i>>>0|e>>>0<h>>>0;e=x[k+28>>2];d=x[k+24>>2];e=j>>>0<2147418112&((d|0)==(f|0)&(e|0)==(l|0)?m:(e|0)==(l|0)&d>>>0<f>>>0|e>>>0<l>>>0);d=c;m=e;e=b+e|0;d=m>>>0>e>>>0?d+1|0:d;b=(c|0)==(d|0)&b>>>0>e>>>0|c>>>0>d>>>0;c=b;b=b+g|0;j=c>>>0>b>>>0?j+1|0:j;g=b;c=x[k+4>>2];h=(c|0)==(h|0)&A[k>>2]<i>>>0|c>>>0<h>>>0;c=x[k+12>>2];b=x[k+8>>2];b=j>>>0<2147418112&((b|0)==(f|0)&(c|0)==(l|0)?h:(c|0)==(l|0)&b>>>0<f>>>0|c>>>0<l>>>0);c=b;b=b+e|0;l=c>>>0>b>>>0?d+1|0:d;c=l;e=(d|0)==(l|0)&b>>>0<e>>>0|d>>>0>l>>>0;d=j;f=e;e=e+g|0;d=f>>>0>e>>>0?d+1|0:d;r=e|r;u=d|u}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=r;x[a+12>>2]=u;fb=k+336|0}function FO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-32|0;fb=f;d=Cc(f+20|0,11621);e=oh(c,d);tb(d);a:{b:{c:{d:{e:{if(e){io(a,x[b+24>>2]+1298356|0);break e}d=Cc(f+20|0,11015);e=oh(c,d);tb(d);if(e){io(a,x[b+24>>2]+1298344|0);break e}d=Cc(f+20|0,11451);e=oh(c,d);tb(d);if(e){io(a,x[b+24>>2]+1298392|0);break e}d=Cc(f+20|0,11007);e=oh(c,d);tb(d);if(e){io(a,x[b+24>>2]+1298380|0);break e}d=Cc(f+20|0,8263);e=oh(c,d);tb(d);if(e){d=f+20|0;c=x[x[b+24>>2]+480184>>2];b=31296;f:{g:{while(1){if((b|0)==31344){break g}if((c|0)!=x[b>>2]){b=b+12|0;continue}break}c=fb-32|0;fb=c;e=c+8|0;Ew(e,x[b+8>>2]);x[31785]=0;S(126,c+20|0,0,e|0);b=x[31785];x[31785]=0;h:{i:{j:{if((b|0)!=1){x[31785]=0;O(12,d|0,c+20|0);b=x[31785];x[31785]=0;if((b|0)==1){break j}Sb(c+20|0);tb(c+8|0);fb=c+32|0;break h}a=N()|0;break i}a=N()|0;Sb(c+20|0)}tb(c+8|0);Q(a|0);p()}break f}Fb(d)}x[31785]=0;O(1068,a|0,d|0);a=x[31785];x[31785]=0;if((a|0)==1){break d}tb(f+20|0);break e}d=Cc(f+20|0,10992);e=oh(c,d);tb(d);if(e){h=x[x[b+24>>2]+480184>>2];c=fb-48|0;fb=c;b=31296;i=lg(c+36|0);l=f+20|0;d=Fb(l);while(1){if((b|0)!=31344){if(x[b>>2]==(h|0)){x[31785]=0;e=P(1,c+24|0,x[b+4>>2])|0;g=x[31785];x[31785]=0;k:{l:{m:{n:{o:{p:{if((g|0)!=1){x[31785]=0;S(895,c+16|0,i|0,e|0);g=x[31785];x[31785]=0;if((g|0)==1){break n}if(!y[c+20|0]){break k}if(!yd(x[d+4>>2],y[d+11|0])){x[31785]=0;g=P(1,c+4|0,18592)|0;k=x[31785];x[31785]=0;if((k|0)==1){break p}x[31785]=0;P(77,d|0,g|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break o}tb(g)}x[31785]=0;P(77,d|0,e|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){break k}b=N()|0;break m}b=N()|0;break l}b=N()|0;break m}b=N()|0;tb(g);break m}b=N()|0}tb(e)}tb(d);qR(i);Q(b|0);p()}tb(e)}b=b+12|0;continue}break}qR(i);fb=c+48|0;x[31785]=0;O(1068,a|0,l|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}d=Cc(f+20|0,8329);e=oh(c,d);tb(d);if(e){io(a,x[b+24>>2]+1298368|0);break e}d=Cc(f+20|0,5640);e=oh(c,d);tb(d);if(e){io(a,x[b+24>>2]+1298320|0);break e}d=Cc(f+20|0,12025);e=oh(c,d);tb(d);if(e){c=f+20|0;fg(c,x[b+24>>2]+1298308|0);b=x[b+24>>2];x[31785]=0;S(1062,a|0,b|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}d=Cc(f+20|0,11394);e=oh(c,d);tb(d);if(e){g=x[b+24>>2];b=g+1298412|0;d=x[b+4>>2];q:{if(!mc(x[b>>2],d)){b=fb-32|0;fb=b;x[b+8>>2]=0;x[b+12>>2]=0;x[b+16>>2]=0;x[b>>2]=0;x[b+4>>2]=0;x[b+24>>2]=0;x[b+28>>2]=0;c=1;e=d-40|0;r:{if(x[e>>2]!=x[b>>2]|x[e+4>>2]!=x[b+4>>2]|(x[e+8>>2]!=x[b+8>>2]|x[e+12>>2]!=x[b+12>>2])){break r}if(x[e+16>>2]!=x[b+16>>2]){break r}c=x[e+24>>2]!=x[b+24>>2]|x[e+28>>2]!=x[b+28>>2]}fb=b+32|0;if(c){break q}}Fb(a);break e}i=f+20|0;g=x[g+1298408>>2];d=fb-512|0;fb=d;h=x[e+32>>2];s:{if(h){c=2147483647;j=De(+(h>>>0)/18.2);b=-1;t:{if(j>=0x8000000000000000){break t}c=-2147483648;b=0;if(j<=-0x8000000000000000){break t}if(F(j)<0x8000000000000000){c=F(j)>=1?~~(j>0?H(J(j*2.3283064365386963e-10),4294967295):K((j-+(~~j>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~j>>>0;break t}b=0}if((g|0)==1){g=x[e+28>>2];x[d+184>>2]=x[e+24>>2];x[d+188>>2]=g;g=x[e+20>>2];x[d+176>>2]=x[e+16>>2];x[d+180>>2]=g;g=x[e+12>>2];x[d+168>>2]=x[e+8>>2];x[d+172>>2]=g;g=x[e+4>>2];x[d+160>>2]=x[e>>2];x[d+164>>2]=g;ou(d+480|0,d+160|0);e=x[d+508>>2];x[d+152>>2]=x[d+504>>2];x[d+156>>2]=e;e=x[d+500>>2];x[d+144>>2]=x[d+496>>2];x[d+148>>2]=e;e=x[d+492>>2];x[d+136>>2]=x[d+488>>2];x[d+140>>2]=e;e=x[d+484>>2];x[d+128>>2]=x[d+480>>2];x[d+132>>2]=e;e=d+448|0;g=NA(oS(d+128|0),hb);c=c+hb|0;h=b;b=b+g|0;c=h>>>0>b>>>0?c+1|0:c;mS(e,nS(b,c),hb);b=x[d+476>>2];x[d+120>>2]=x[d+472>>2];x[d+124>>2]=b;b=x[d+468>>2];x[d+112>>2]=x[d+464>>2];x[d+116>>2]=b;b=x[d+460>>2];x[d+104>>2]=x[d+456>>2];x[d+108>>2]=b;b=x[d+452>>2];x[d+96>>2]=x[d+448>>2];x[d+100>>2]=b;WM(i,d+96|0);break s}g=x[e+28>>2];x[d+312>>2]=x[e+24>>2];x[d+316>>2]=g;g=x[e+20>>2];x[d+304>>2]=x[e+16>>2];x[d+308>>2]=g;g=x[e+12>>2];x[d+296>>2]=x[e+8>>2];x[d+300>>2]=g;g=x[e+4>>2];x[d+288>>2]=x[e>>2];x[d+292>>2]=g;ou(d+416|0,d+288|0);e=x[d+444>>2];x[d+280>>2]=x[d+440>>2];x[d+284>>2]=e;e=x[d+436>>2];x[d+272>>2]=x[d+432>>2];x[d+276>>2]=e;e=x[d+428>>2];x[d+264>>2]=x[d+424>>2];x[d+268>>2]=e;e=x[d+420>>2];x[d+256>>2]=x[d+416>>2];x[d+260>>2]=e;e=d+352|0;g=NA(oS(d+256|0),hb);c=c+hb|0;h=b;b=b+g|0;c=h>>>0>b>>>0?c+1|0:c;mS(e,nS(b,c),hb);b=x[d+380>>2];x[d+248>>2]=x[d+376>>2];x[d+252>>2]=b;b=x[d+372>>2];x[d+240>>2]=x[d+368>>2];x[d+244>>2]=b;b=x[d+364>>2];x[d+232>>2]=x[d+360>>2];x[d+236>>2]=b;b=x[d+356>>2];x[d+224>>2]=x[d+352>>2];x[d+228>>2]=b;ou(d+384|0,d+224|0);b=x[d+412>>2];x[d+216>>2]=x[d+408>>2];x[d+220>>2]=b;b=x[d+404>>2];x[d+208>>2]=x[d+400>>2];x[d+212>>2]=b;b=x[d+396>>2];x[d+200>>2]=x[d+392>>2];x[d+204>>2]=b;b=x[d+388>>2];x[d+192>>2]=x[d+384>>2];x[d+196>>2]=b;eO(i,d+192|0);break s}if((g|0)==1){b=x[e+28>>2];x[d+56>>2]=x[e+24>>2];x[d+60>>2]=b;b=x[e+20>>2];x[d+48>>2]=x[e+16>>2];x[d+52>>2]=b;b=x[e+12>>2];x[d+40>>2]=x[e+8>>2];x[d+44>>2]=b;b=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=b;ou(d+320|0,d+32|0);b=x[d+348>>2];x[d+24>>2]=x[d+344>>2];x[d+28>>2]=b;b=x[d+340>>2];x[d+16>>2]=x[d+336>>2];x[d+20>>2]=b;b=x[d+332>>2];x[d+8>>2]=x[d+328>>2];x[d+12>>2]=b;b=x[d+324>>2];x[d>>2]=x[d+320>>2];x[d+4>>2]=b;WM(i,d);break s}b=x[e+28>>2];x[d+88>>2]=x[e+24>>2];x[d+92>>2]=b;b=x[e+20>>2];x[d+80>>2]=x[e+16>>2];x[d+84>>2]=b;b=x[e+12>>2];x[d+72>>2]=x[e+8>>2];x[d+76>>2]=b;b=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=b;eO(i,d- -64|0)}fb=d+512|0;x[31785]=0;O(1068,a|0,i|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}d=Cc(f+20|0,12294);e=oh(c,d);tb(d);if(e){WU(f+20|0,x[b+24>>2]+1298332|0);u:{if(!yd(x[f+24>>2],y[f+31|0])){break u}d=x[x[b+24>>2]+480180>>2];v:{w:{if((d|0)==33554432){break w}c=1;if((d|0)==32){break v}if((d|0)==16384){break w}if((d|0)==16777216){break v}}c=2}x:{switch(c-1|0){case 0:x[31785]=0;O(1069,f+8|0,b|0);c=x[31785];x[31785]=0;if((c|0)!=1){c=f+8|0;yb(f+20|0,c);tb(c);break u}break b;case 1:break x;default:break u}}x[31785]=0;O(1070,f+8|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=f+8|0;d=yb(f+20|0,c);tb(c);if(!yd(x[f+24>>2],y[f+31|0])){break u}x[31785]=0;O(1069,f+8|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=f+8|0;yb(d,c);tb(c)}b=x[b+24>>2];x[31785]=0;S(1062,a|0,b|0,f+20|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(f+20|0);break e}break b}d=Cc(f+20|0,5492);e=oh(c,d);tb(d);if(e){c=f+20|0;WU(c,x[b+24>>2]+1298332|0);b=x[b+24>>2];x[31785]=0;S(1062,a|0,b|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(f+20|0);break e}c=N()|0;tb(f+20|0);break a}h=c;c=Cc(f+20|0,7355);d=oh(h,c);tb(c);if(d){a=Fb(a);m=f,n=vb(x[b+68>>2]),x[m+20>>2]=n;b=vb(x[b+72>>2]);c=1;while(1){d=x[f+20>>2];if(!Ib(d,b)){break e}if(!(c&1)){x[31785]=0;P(994,a|0,22460)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}}x[31785]=0;P(845,a|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}Uq(f+20|0);c=0;continue}}Cc(a,22485)}fb=f+32|0;return}c=N()|0;tb(f+20|0);break a}c=N()|0;tb(a);break a}c=N()|0;tb(f+20|0)}Q(c|0);p()}function mpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0;d=fb-1328|0;fb=d;xc(b);e=fb-16|0;fb=e;mX(e+8|0,d+220|0);h=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(h|0)){Yb(b,x[e+12>>2])}fb=e+16|0;a:{if((h|0)!=(j|0)){break a}if(!oX(d+220|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(nX(y[d+1324|0]|y[d+1325|0]<<8|(y[d+1326|0]<<16|y[d+1327|0]<<24)),hb))){break a}if(!c){l=1;break a}xc(b);b=Fe(d+220|0,b);x[31785]=0;O(645,d+208|0,b|0);e=x[31785];x[31785]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){ub(b);x[31785]=0;S(646,d+196|0,d+208|0,1196314451);b=x[31785];x[31785]=0;if((b|0)==1){break i}x[31785]=0;S(646,d+184|0,d+208|0,1280331091);b=x[31785];x[31785]=0;if((b|0)==1){break h}if(mc(x[d+196>>2],x[d+200>>2])){break b}if(!mc(x[d+184>>2],x[d+188>>2])){break g}break b}c=N()|0;ub(b);break d}c=N()|0;break e}c=N()|0;break f}x[31785]=0;O(249,a|0,1);b=x[31785];x[31785]=0;j:{if((b|0)!=1){ag(a);x[a+480188>>2]=4;x[a+480208>>2]=25231360;F=d,G=vb(x[d+184>>2]),x[F+52>>2]=G;f=c&2;m=vb(x[d+188>>2]);e=a+480190|0;k:{l:{while(1){h=x[d+52>>2];if(!Ib(h,m)){break l}b=z[e>>1];if(!si(b)){break l}b=b+1|0;w[e>>1]=b;x[31785]=0;b=D(b&65535,104)+a|0;j=b+484380|0;O(282,j|0,1);i=x[31785];x[31785]=0;m:{n:{if((i|0)!=1){x[31785]=0;i=P(647,h|0,d+220|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break n}if(!i){break c}if(lv(d+220|0)){break m}break c}c=N()|0;break j}c=N()|0;break j}x[31785]=0;i=P(37,d+172|0,d+220|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break k}zc(((z[e>>1]<<5)+a|0)+946304|0,i);tb(i);i=y[d+256|0]|y[d+257|0]<<8|(y[d+258|0]<<16|y[d+259|0]<<24);x[j>>2]=i;x[b+484388>>2]=i;x[b+484384>>2]=y[d+252|0]|y[d+253|0]<<8|(y[d+254|0]<<16|y[d+255|0]<<24);i=b+484414|0;w[i>>1]=z[i>>1]|2;w[b+484410>>1]=255;o:{if(f){b=ad(d+24|0,8,1,0,0);x[31785]=0;U(218,b|0,j|0,h|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break o}}Xf(d+52|0);continue}break}c=N()|0;break j}F=d,G=vb(x[d+196>>2]),x[F+168>>2]=G;q=a+484344|0;r=c&1;s=a+484360|0;C=vb(x[d+200>>2]);n=a+484376|0;o=a+480190|0;t=a+484380|0;u=a+946304|0;c=1;l=1;while(1){p:{q:{r:{s:{t:{u:{v:{b=x[d+168>>2];if(!Ib(b,C)){break v}if(!(c&1)){x[31785]=0;c=R(277,s|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break u}if(!c){break v}}gj(Wb(x[a+484360>>2],y[n|0]));x[31785]=0;c=P(648,b|0,d+220|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break t}if(!(c&!(y[d+1306|0]|y[d+1307|0]<<8))|(y[d+1308|0]|y[d+1309|0]<<8|(y[d+1310|0]<<16|y[d+1311|0]<<24))-5>>>0<4294967292){break c}c=y[n|0];e=x[a+484360>>2];x[31785]=0;O(649,d+156|0,d+220|0);h=x[31785];x[31785]=0;if((h|0)==1){break t}e=Wb(e,c);c=d+156|0;gp(e,c);tb(c);w:{if(r){x[31785]=0;S(188,d+52|0,b|0,y[d+1316|0]|y[d+1317|0]<<8|(y[d+1318|0]<<16|y[d+1319|0]<<24));b=x[31785];x[31785]=0;if((b|0)!=1){break w}c=N()|0;break j}x[31785]=0;b=R(171,d+116|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break s}eG(d+52|0,b)}b=d+52|0;m=ic(d+136|0,b);ub(b);if(!r){ub(d+116|0)}Tb(d+52|0,0,64);c=1;x:{y:{z:{while(1){if((c|0)==32){break z}b=(D(c,34)+d|0)+186|0;e=b+32|0;zn(d+8|0,e);A:{B:{if(Pj(y[x[d+8>>2]])){break B}h=y[b- -64|0];if(h>>>0>15){break y}b=y[b+65|0];if(b>>>0>64){break y}if(!lv(e)){break y}j=b<<2;i=h<<4;h=0;b=1;while(1){f=b&65535;e=z[o>>1];if(f>>>0<=e>>>0){x[31785]=0;S(650,d+24|0,x[d+8>>2],x[d+12>>2]);e=x[31785];x[31785]=0;if((e|0)==1){break A}e=fb-32|0;fb=e;g=d+24|0;ue(e+24|0,g);jX(e+16|0,((f<<5)+a|0)+946304|0);k=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=k;k=pC(x[e+24>>2],x[e+28>>2],e+8|0);fb=e+32|0;tb(g);C:{if(k){break C}F=_b(d+52|0,c),G=b,w[F>>1]=G;e=D(f,104)+a|0;f=e+484410|0;g=z[f>>1];if((g|0)!=255){h=b;if(y[e+484417|0]!=(i&255)|(g|0)!=(j|0)){break C}}v[e+484417|0]=i;w[f>>1]=j;break B}b=b+1|0;continue}break}h=h&65535;if(!h){break B}if(!si(e)){break B}b=e+1|0;w[o>>1]=b;F=_b(d+52|0,c),G=b,w[F>>1]=G;b=D(z[o>>1],104)+t|0;hn(b);e=D(h,104)+t|0;f=Oo(b,e);w[b+30>>1]=j;v[b+37|0]=i;dY(f,e);e=(h<<5)+u|0;h=x[e+4>>2];b=(z[o>>1]<<5)+u|0;x[b>>2]=x[e>>2];x[b+4>>2]=h;h=x[e+28>>2];x[b+24>>2]=x[e+24>>2];x[b+28>>2]=h;h=x[e+20>>2];x[b+16>>2]=x[e+16>>2];x[b+20>>2]=h;h=x[e+12>>2];x[b+8>>2]=x[e+8>>2];x[b+12>>2]=h}c=c+1|0;continue}break}break r}i=0;x[d+48>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;e=64;j=65535;E=y[d+1308|0]|y[d+1309|0]<<8;h=0;D:while(1){E:{if(h){break E}b=x[m>>2];x[31785]=0;b=U(153,b|0,x[d+144>>2],1)|0;c=x[31785];x[31785]=0;if((c|0)==1){break x}if(b){break E}c=j;b=e;break q}b=e+1|0;F:{if(e>>>0<63){e=b;break F}x[31785]=0;j=P(370,q|0,64)|0;c=x[31785];x[31785]=0;if((c|0)==1){break x}c=65535;if((j|0)==65535){break q}b=y[n|0];c=x[a+484360>>2];e=0;x[31785]=0;O(540,Wb(c,b)|0,j|0);b=x[31785];x[31785]=0;if((b|0)==1){break x}}b=0;c=Vb(x[q>>2],j&65535);c=gd(x[c>>2],x[x[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(E|0)){continue D}f=(d+24|0)+D(b,7)|0;g=y[f+6|0];G:{if(g){v[f+6|0]=g-1;g=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=g;v[c+5|0]=g>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;h=h-1|0;break G}g=x[m>>2];x[31785]=0;g=U(153,g|0,x[d+144>>2],1)|0;k=x[31785];x[31785]=0;if((k|0)==1){break r}if(!g){break G}if(x[d+144>>2]==(y[d+1312|0]|y[d+1313|0]<<8|(y[d+1314|0]<<16|y[d+1315|0]<<24))){i=Wb(x[a+484360>>2],y[n|0]);_e(i,UD(x[i>>2],x[i+4>>2]));i=e}x[31785]=0;g=R(200,m|0)|0;k=x[31785];x[31785]=0;H:{if((k|0)!=1){g=g<<24>>24;if((g|0)>=0){break H}g=g&127;v[f+6|0]=g;k=y[f+4|0]|y[f+5|0]<<8;v[c+4|0]=k;v[c+5|0]=k>>>8;f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[c|0]=f;v[c+1|0]=f>>>8;v[c+2|0]=f>>>16;v[c+3|0]=f>>>24;h=g+h|0;break G}break r}if((g-1&255)>>>0<=35){v[c|0]=g+48}x[31785]=0;g=R(200,m|0)|0;k=x[31785];x[31785]=0;I:{J:{if((k|0)!=1){g=g<<24>>24;F=c,G=y[_b(d+52|0,g&31)|0],v[F+1|0]=G;if((g|0)>=0){break J}v[c+3|0]=y[f+3|0];v[c+5|0]=y[f+5|0];break I}break r}x[31785]=0;O(201,d+8|0,m|0);g=x[31785];x[31785]=0;K:{if((g|0)!=1){g=y[d+8|0];if(g>>>0>19){break I}A=g<<1;B=y[A+25552|0];v[c+3|0]=B;k=y[Ic(d+8|0)|0];v[c+5|0]=k;if((B|0)!=16|k>>>0<32){break K}v[c+3|0]=17;break I}break r}if(819137>>>g&1){break I}v[c+5|0]=y[A+25553|0]|k&15}g=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[f|0]=g;v[f+1|0]=g>>>8;v[f+2|0]=g>>>16;v[f+3|0]=g>>>24;g=y[c+4|0]|y[c+5|0]<<8;v[f+4|0]=g;v[f+5|0]=g>>>8}c=c+6|0;b=b+1|0;continue}}}l=0;break p}break r}ak(s,0);x[31785]=0;b=P(1,d+220|0,6487)|0;c=x[31785];x[31785]=0;L:{if((c|0)!=1){yb(a+1298344|0,b);tb(b);x[31785]=0;b=P(1,d+52|0,6824)|0;c=x[31785];x[31785]=0;if((c|0)==1){break L}yb(a+1298356|0,b);tb(b);F=a+1298404|0,G=x[Gc(d+24|0,4)>>2],x[F>>2]=G;l=1;break b}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;break j}c=N()|0;ub(m);break j}M:{if(!((i|0)!=0|b>>>0<63)){break M}c=c&65535;if((c|0)==65535){break M}we(Vb(x[q>>2],c),Vh(Ue(Le(d+8|0,14,i&255),b)))}c=32}ub(m);if(c>>>0<32){break b}Xf(d+168|0);c=0;continue}}c=N()|0;break j}c=N()|0}Qc(d+184|0)}Qc(d+196|0)}fe(d+208|0)}Q(c|0);p()}l=0}Qc(d+184|0);Qc(d+196|0);fe(d+208|0)}fb=d+1328|0;return l|0}function iga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=E(0),k=E(0),l=0,m=0,n=0,o=E(0),p=0,q=0,r=0,s=0,t=0,u=E(0),w=E(0),z=0,A=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=E(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=E(0),Z=0,_=0,$=E(0);a:{if(!y[a+5046|0]){break a}g=B[a+4268>>2];IP(a);if(g==B[a+4268>>2]){break a}Lz(a)}b:{if(!y[a+5045|0]){break b}if(!wi(a+44|0)){break b}i=x[a+44>>2];p=Hc(i,0);q=Hc(i,1);i=x[a+56>>2];l=Hc(i,0);m=Hc(i,1);c:{if(!(!y[a+5044|0]|(!d|y[a+4264|0]&2))){B[l>>2]=B[a+5036>>2];B[m>>2]=B[a+5040>>2];v[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;t=a+4864|0;U=a+4504|0;V=a+4960|0;W=a+4868|0;X=a+4892|0;C=a+4628|0;D=a+4604|0;Q=a+4916|0;F=a+4532|0;G=a+4508|0;H=a+4772|0;I=a+4748|0;R=a+4940|0;J=a+4676|0;K=a+4652|0;L=a+4724|0;M=a+4700|0;S=a+4844|0;N=a+4580|0;O=a+4556|0;T=a+4820|0;d:{while(1){if(!r){break d}g=B[p>>2];g=E(E(E(B[a+5008>>2]-g)*B[a+4276>>2])+g);B[a+5008>>2]=g;_=Nc(x[a+4864>>2],x[W>>2],x[a+4880>>2]),$=g,B[_>>2]=$;g=B[q>>2];g=E(E(E(B[a+5012>>2]-g)*B[a+4276>>2])+g);B[a+5012>>2]=g;_=Nc(x[a+4888>>2],x[X>>2],x[a+4904>>2]),$=g,B[_>>2]=$;g=E(E(E(E(E(mi(t,x[a+4356>>2])*E(.6800000071525574))+E(mi(t,x[a+4360>>2])*E(-.5)))-E(mi(t,x[a+4364>>2])*E(.6200000047683716)))+E(mi(t,x[a+4368>>2])*E(-.5)))-E(mi(t,x[a+4372>>2])*E(.6200000047683716)));if(v[a+4264|0]&1){e=g;g=E(B[Nc(x[a+4816>>2],x[T>>2],x[a+4836>>2])>>2]+E(e*E(.6180340051651001)));_=Nc(x[a+4816>>2],x[T>>2],x[a+4832>>2]),$=E(e-E(g*E(.6180340051651001))),B[_>>2]=$}u=B[a+4280>>2];_=a,$=E(mi(t,x[a+4352>>2])+B[a+5020>>2]),B[_+5020>>2]=$;e=E(mi(s,x[a+4376>>2])+B[a+5024>>2]);B[a+5024>>2]=e;f=B[a+5020>>2];h=E(E(E(B[a+4980>>2]-B[Nc(x[a+4624>>2],x[C>>2],x[a+4644>>2])>>2])*B[a+4444>>2])+B[Nc(x[a+4624>>2],x[C>>2],x[a+4644>>2])>>2]);B[a+4980>>2]=h;P=E(h*B[a+4440>>2]);k=E(e*E(.7070000171661377));j=E(f*E(-.7070000171661377));f=E(k+j);h=B[a+4272>>2];e=E(P+E(f*h));_=Nc(x[a+4624>>2],x[C>>2],x[a+4640>>2]),$=E(f-E(h*e)),B[_>>2]=$;f=E(E(E(B[a+4976>>2]-B[Nc(x[a+4600>>2],x[D>>2],x[a+4620>>2])>>2])*B[a+4436>>2])+B[Nc(x[a+4600>>2],x[D>>2],x[a+4620>>2])>>2]);B[a+4976>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4432>>2])+E(e*h));_=Nc(x[a+4600>>2],x[D>>2],x[a+4616>>2]),$=E(e-E(h*f)),B[_>>2]=$;w=E(E(e*E(-.15000000596046448))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){e=E(E(E(B[a+4972>>2]-B[Nc(x[a+4576>>2],x[N>>2],x[a+4596>>2])>>2])*B[a+4428>>2])+B[Nc(x[a+4576>>2],x[N>>2],x[a+4596>>2])>>2]);B[a+4972>>2]=e;h=B[a+4272>>2];e=E(E(e*B[a+4424>>2])+E(f*h));_=Nc(x[a+4576>>2],x[N>>2],x[a+4592>>2]),$=E(f-E(h*e)),B[_>>2]=$;f=E(E(E(B[a+4968>>2]-B[Nc(x[a+4552>>2],x[O>>2],x[a+4572>>2])>>2])*B[a+4420>>2])+B[Nc(x[a+4552>>2],x[O>>2],x[a+4572>>2])>>2]);B[a+4968>>2]=f;h=B[a+4272>>2];f=E(E(f*B[a+4416>>2])+E(e*h));_=Nc(x[a+4552>>2],x[O>>2],x[a+4568>>2]),$=E(e-E(h*f)),B[_>>2]=$;w=E(E(E(e*E(.3499999940395355))+w)+E(f*E(-.3799999952316284)))}_=Nc(x[a+4912>>2],x[Q>>2],x[a+4928>>2]),$=f,B[_>>2]=$;e=E(B[Nc(x[a+4912>>2],x[Q>>2],x[a+4932>>2])>>2]*B[a+4496>>2]);B[a+5028>>2]=E(E(B[a+5028>>2]-e)*B[a+4500>>2])+e;e=E(E(E(B[a+4964>>2]-B[Nc(x[a+4528>>2],x[F>>2],x[a+4548>>2])>>2])*B[a+4412>>2])+B[Nc(x[a+4528>>2],x[F>>2],x[a+4548>>2])>>2]);B[a+4964>>2]=e;f=B[a+5028>>2];o=B[a+4272>>2];h=E(E(f*o)+E(e*B[a+4408>>2]));_=Nc(x[a+4528>>2],x[F>>2],x[a+4544>>2]),$=E(f-E(o*h)),B[_>>2]=$;e=E(E(E(B[a+4960>>2]-B[Nc(x[a+4504>>2],x[G>>2],x[a+4524>>2])>>2])*B[a+4404>>2])+B[Nc(x[a+4504>>2],x[G>>2],x[a+4524>>2])>>2]);B[a+4960>>2]=e;f=E(e*B[a+4400>>2]);e=B[a+4272>>2];o=E(f+E(h*e));_=Nc(x[a+4504>>2],x[G>>2],x[a+4520>>2]),$=E(h-E(e*o)),B[_>>2]=$;B[a+5020>>2]=o;e=E(E(E(E(E(mi(s,x[a+4380>>2])*E(.7070000171661377))+E(mi(s,x[a+4384>>2])*E(-.6000000238418579)))-E(mi(s,x[a+4388>>2])*E(.5)))+E(mi(s,x[a+4392>>2])*E(-.6000000238418579)))-E(mi(s,x[a+4396>>2])*E(.5)));if(v[a+4264|0]&1){f=e;e=E(B[Nc(x[a+4840>>2],x[S>>2],x[a+4860>>2])>>2]+E(e*E(.6180340051651001)));_=Nc(x[a+4840>>2],x[S>>2],x[a+4856>>2]),$=E(f-E(e*E(.6180340051651001))),B[_>>2]=$}Y=B[a+4280>>2];f=E(E(E(B[a+5004>>2]-B[Nc(x[a+4768>>2],x[H>>2],x[a+4788>>2])>>2])*B[a+4492>>2])+B[Nc(x[a+4768>>2],x[H>>2],x[a+4788>>2])>>2]);B[a+5004>>2]=f;P=E(f*B[a+4488>>2]);f=E(j-k);j=B[a+4272>>2];k=E(P+E(f*j));_=Nc(x[a+4768>>2],x[H>>2],x[a+4784>>2]),$=E(f-E(j*k)),B[_>>2]=$;f=E(E(E(B[a+5e3>>2]-B[Nc(x[a+4744>>2],x[I>>2],x[a+4764>>2])>>2])*B[a+4484>>2])+B[Nc(x[a+4744>>2],x[I>>2],x[a+4764>>2])>>2]);B[a+5e3>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4480>>2])+E(k*j));_=Nc(x[a+4744>>2],x[I>>2],x[a+4760>>2]),$=E(k-E(j*f)),B[_>>2]=$;k=E(E(E(h*E(.3799999952316284))+E(k*E(-.15000000596046448)))+E(f*E(-.20000000298023224)));if(v[a+4264|0]&1){h=E(E(E(B[a+4996>>2]-B[Nc(x[a+4720>>2],x[L>>2],x[a+4740>>2])>>2])*B[a+4476>>2])+B[Nc(x[a+4720>>2],x[L>>2],x[a+4740>>2])>>2]);B[a+4996>>2]=h;j=B[a+4272>>2];h=E(E(h*B[a+4472>>2])+E(f*j));_=Nc(x[a+4720>>2],x[L>>2],x[a+4736>>2]),$=E(f-E(j*h)),B[_>>2]=$;f=E(E(E(B[a+4992>>2]-B[Nc(x[a+4696>>2],x[M>>2],x[a+4716>>2])>>2])*B[a+4468>>2])+B[Nc(x[a+4696>>2],x[M>>2],x[a+4716>>2])>>2]);B[a+4992>>2]=f;j=B[a+4272>>2];f=E(E(f*B[a+4464>>2])+E(h*j));_=Nc(x[a+4696>>2],x[M>>2],x[a+4712>>2]),$=E(h-E(j*f)),B[_>>2]=$;k=E(E(E(h*E(.3499999940395355))+k)+E(f*E(-.3799999952316284)))}Z=q+4|0;n=p+4|0;h=E(g*u);w=E(w-E(o*E(.3799999952316284)));o=E(e*Y);_=Nc(x[a+4936>>2],x[R>>2],x[a+4952>>2]),$=f,B[_>>2]=$;g=E(B[Nc(x[a+4936>>2],x[R>>2],x[a+4956>>2])>>2]*B[a+4496>>2]);B[a+5032>>2]=E(E(B[a+5032>>2]-g)*B[a+4500>>2])+g;g=E(E(E(B[a+4988>>2]-B[Nc(x[a+4672>>2],x[J>>2],x[a+4692>>2])>>2])*B[a+4460>>2])+B[Nc(x[a+4672>>2],x[J>>2],x[a+4692>>2])>>2]);B[a+4988>>2]=g;e=B[a+5032>>2];f=B[a+4272>>2];g=E(E(e*f)+E(g*B[a+4456>>2]));_=Nc(x[a+4672>>2],x[J>>2],x[a+4688>>2]),$=E(e-E(f*g)),B[_>>2]=$;f=B[a+4284>>2];e=E(E(E(B[a+4984>>2]-B[Nc(x[a+4648>>2],x[K>>2],x[a+4668>>2])>>2])*B[a+4452>>2])+B[Nc(x[a+4648>>2],x[K>>2],x[a+4668>>2])>>2]);B[a+4984>>2]=e;u=B[a+4272>>2];e=E(E(e*B[a+4448>>2])+E(g*u));_=Nc(x[a+4648>>2],x[K>>2],x[a+4664>>2]),$=E(g-E(u*e)),B[_>>2]=$;B[a+5024>>2]=e;e=E(-e);u=B[a+4288>>2];i=U;e:{f:{while(1){if((i|0)==(V|0)){g:{e=E(o+E(E(E(e*E(.3799999952316284))+k)*u));g=E(h+E(E(E(g*E(.3799999952316284))+w)*f));if(!(y[a+4264|0]&2)){break g}p=n;n=Z;break f}}else{z=x[i+16>>2];A=z-1|0;x[i+16>>2]=A;if((z|0)<=0){x[i+16>>2]=A+x[i+12>>2]}z=x[i+20>>2];A=z-1|0;x[i+20>>2]=A;if((z|0)<=0){x[i+20>>2]=A+x[i+12>>2]}i=i+24|0;continue}break}B[l>>2]=E(g+B[a+5036>>2])*E(.5);B[m>>2]=E(e+B[a+5040>>2])*E(.5);B[a+5040>>2]=e;B[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;B[l>>2]=g;B[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}v[a+5044|0]=1}n=a;a=x[a+56>>2];Li(n,b,c,Hc(a,0),Hc(a,1),d)}}function Vna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;g=fb-256|0;fb=g;d=fb-112|0;fb=d;f=Fe(g+76|0,c);x[31785]=0;n=R(171,f+20|0)|0;c=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){x[31785]=0;q=R(171,f+40|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break B}x[31785]=0;r=R(171,f+60|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break A}x[31785]=0;i=R(171,f+80|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break z}x[31785]=0;o=R(171,f+100|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break y}x[31785]=0;k=R(171,f+120|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break x}j=Nb(f+140|0);xc(f);x[f+172>>2]=1873739776;w[f+176>>1]=0;x[31785]=0;e=P(813,f|0,d+100|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break w}if(!e){break n}e=x[d+100>>2];if((e|0)!=1414744396&(e|0)!=1179011410){break n}c=x[d+108>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}v[f+176|0]=(e|0)==1414744396;x[31785]=0;S(814,d+88|0,f|0,2);c=x[31785];x[31785]=0;if((c|0)==1){break v}h=x[d+88>>2];C:{if(sr(h,x[d+92>>2])>>>0<4){break C}c=lA(h,1);e=x[c>>2];c=x[c+4>>2];ti(d+36|0,e,c);if(x[d+36>>2]!=1635017060){break C}ti(d+60|0,e,c);if(!(v[d+64|0]&1)){break C}c=lA(h,2);ti(d+16|0,x[c>>2],x[c+4>>2]);if(y[d+20|0]|y[d+21|0]<<8|(y[d+22|0]<<16|y[d+23|0]<<24)){break C}c=lA(h,3);ti(d+80|0,x[c>>2],x[c+4>>2]);if(x[d+80>>2]){break C}x[31785]=0;P(152,f|0,12)|0;c=x[31785];x[31785]=0;if((c|0)==1){break u}x[31785]=0;S(814,d+36|0,f|0,1);c=x[31785];x[31785]=0;if((c|0)==1){break t}c=d+36|0;jv(d+88|0,c);fe(c)}x[31785]=0;S(815,d+60|0,d+88|0,544501094);c=x[31785];x[31785]=0;if((c|0)==1){break s}x[31785]=0;e=P(816,d+60|0,f+156|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break k}if(!e){break o}e=z[f+156>>1];if((e|0)!=1){break q}x[31785]=0;e=R(205,d+60|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break r}break k}e=N()|0;break b}e=N()|0;break c}e=N()|0;break d}e=N()|0;break e}e=N()|0;break f}e=N()|0;break g}e=N()|0;break h}e=N()|0;break h}e=N()|0;break i}e=N()|0;break i}e=N()|0;break i}if((e|0)==4){x[31785]=0;h=R(195,d+60|0)|0;c=x[31785];x[31785]=0;D:{if((c|0)!=1){x[31785]=0;e=R(195,d+60|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break D}if((h|0)!=2|(e|0)!=1){break p}v[f+177|0]=1;break p}e=N()|0;break j}e=N()|0;break j}e=z[f+156>>1]}if((e&65535)!=65534){break p}x[31785]=0;e=P(817,d+60|0,d+36|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break l}if(!e){break o}c=y[d+56|0]|y[d+57|0]<<8|(y[d+58|0]<<16|y[d+59|0]<<24);x[d+8>>2]=y[d+52|0]|y[d+53|0]<<8|(y[d+54|0]<<16|y[d+55|0]<<24);x[d+12>>2]=c;c=y[d+48|0]|y[d+49|0]<<8|(y[d+50|0]<<16|y[d+51|0]<<24);x[d>>2]=y[d+44|0]|y[d+45|0]<<8|(y[d+46|0]<<16|y[d+47|0]<<24);x[d+4>>2]=c;c=d+16|0;x[c>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);w[c+4>>1]=y[d+4|0]|y[d+5|0]<<8;w[c+6>>1]=y[d+6|0]|y[d+7|0]<<8;s=c,t=dA(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24),y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24)),x[s+8>>2]=t;x[c+12>>2]=hb;w[f+172>>1]=x[c>>2]}x[31785]=0;S(815,d+36|0,d+88|0,1635017060);c=x[31785];x[31785]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=d+36|0;m=hd(n,c);ub(c);c=x[m>>2];x[31785]=0;e=R(175,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break k}if(!e){x[31785]=0;S(815,d+36|0,d+88|0,544039792);c=x[31785];x[31785]=0;if((c|0)==1){break J}c=d+36|0;hd(m,c);ub(c)}x[31785]=0;S(815,d+36|0,d+88|0,1952670054);c=x[31785];x[31785]=0;if((c|0)==1){break I}x[31785]=0;e=R(154,d+36|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break H}x[f+152>>2]=e;ub(d+36|0);if(x[f+152>>2]?z[f+156>>1]==17:0){break E}h=z[f+158>>1];e=lR(h,z[f+170>>1]);if(!e){break E}c=z[f+168>>1];if((c>>>0)/(h>>>0)>>>0<e<<1>>>0?c:0){break G}c=x[m>>2];x[31785]=0;e=R(157,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break k}c=lR(z[f+158>>1],z[f+170>>1]);break F}e=N()|0;break j}e=N()|0;break j}e=N()|0;break j}e=N()|0;ub(d+36|0);break j}c=x[m>>2];x[31785]=0;e=R(157,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break k}c=z[f+168>>1]}x[f+152>>2]=(e>>>0)/((c&65535)>>>0)}x[31785]=0;e=P(818,f|0,d+88|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break k}w[f+174>>1]=e;x[31785]=0;O(819,f|0,d+88|0);c=x[31785];x[31785]=0;if((c|0)==1){break k}x[31785]=0;S(815,d+36|0,d+88|0,1886221175);c=x[31785];x[31785]=0;if((c|0)==1){break m}c=d+36|0;hd(o,c);ub(c)}ub(d+60|0);fe(d+88|0)}fb=d+112|0;break a}e=N()|0;break j}e=N()|0;break j}e=N()|0}ub(d+60|0)}fe(d+88|0)}fe(j);ub(k)}ub(o)}ub(i)}ub(r)}ub(q)}ub(n)}ub(f);Q(e|0);p()}c=x[f+20>>2];x[31785]=0;e=R(748,c|0)|0;c=x[31785];x[31785]=0;K:{L:{if((c|0)!=1){M:{if(!e|(z[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=z[f+170>>1];P:{if(!c){if((Ck(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Ck(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}e=Ck(f);c=28848;while(1){Q:{R:{if((c|0)!=28872){if((e|0)!=x[c>>2]){break R}}else{c=28872}break Q}c=c+4|0;continue}break}if((c|0)==28872){break M}Du(a,b);x[31785]=0;e=P(37,g- -64|0,22485)|0;c=x[31785];x[31785]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=zc(((b<<5)+a|0)+946304|0,e);tb(e);x[31785]=0;e=D(b,104)+a|0;i=e+484380|0;O(282,i|0,0);c=x[31785];x[31785]=0;if((c|0)==1){break W}x[i>>2]=x[f+152>>2];x[e+484404>>2]=x[f+160>>2];c=x[a+1298404>>2];x[31785]=0;V(749,f|0,i|0,c|0,h|0);c=x[31785];x[31785]=0;if((c|0)==1){break W}Fe(g+44|0,f+20|0);e=z[f+158>>1];j=ad(g+40|0,8,e>>>0>1?2:1,0,0);c=Ck(f);if((c|0)!=17|e>>>0>2){break U}vc(i,268435456);c=D(b,104)+a|0;b=c+484414|0;w[b>>1]=z[b>>1]&65470|((e|0)==2)<<6|1;if(Bh(i)){break V}break S}l=N()|0;break K}l=N()|0;break K}j=x[c+484400>>2];h=x[i>>2];k=Fe(g+20|0,g+44|0);e=z[f+158>>1];c=z[f+168>>1];x[31785]=0;b=x[k+12>>2];x[g+8>>2]=x[k+8>>2];x[g+12>>2]=b;x[g+16>>2]=x[k+16>>2];b=x[k+4>>2];x[g>>2]=x[k>>2];x[g+4>>2]=b;aa(750,j|0,h|0,g|0,c|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break L}Mj(i,a);break T}if((c|0)==85){x[31785]=0;c=U(577,a|0,b|0,g+44|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(lV(z[f+156>>1])){break Z}_:{if(!Ad(y[f+177|0])){break _}if((Ck(f)|0)!=1|z[f+170>>1]!=32|z[f+168>>1]!=e<<2){break _}ed(j,32);b=12;break Y}if((Ck(f)|0)!=1|z[f+170>>1]!=24|z[f+168>>1]!=e<<2){break Z}ed(j,32);b=13;break Y}if((Ck(f)&65534)!=6){break X}ed(j,16);b=(Ck(f)|0)==6?17:16}ug(j,b);x[31785]=0;U(218,j|0,i|0,g+44|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break T}break L}e=z[f+170>>1];c=e-1|0;b=c&-8;h=b&31;ed(j,(c>>>0>=64?8:(b&63)>>>0>=32?1074268168>>>h|0:((1<<h)-1&1074268168)<<32-h|538447880>>>h)&255);if(e>>>0<9){ug(j,1)}if((Ck(f)|0)==3){ug(j,3)}x[31785]=0;U(218,j|0,i|0,g+44|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break L}}RB(i,x[a+480180>>2]);Mj(i,a);l=1}ub(g+44|0)}kV(f);fb=g+256|0;return l|0}l=N()|0;break K}l=N()|0;ub(g+44|0)}kV(f);Q(l|0);p()}function xta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-272|0;fb=e;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if(!c$(b,e+206|0)){break m}if(!e$(e+206|0)){break m}if(!c){d=1;break m}Bd(a,131072);d=fb-16|0;fb=d;i=e+120|0;f=uc(d+4|0,3930);Yc(i,f);tb(f);fb=d+16|0;x[31785]=0;S(212,e+160|0,i|0,e+210|0);d=x[31785];x[31785]=0;n:{o:{p:{if((d|0)!=1){d=e+160|0;yb(a+1298344|0,d);tb(d);i=e+120|0;Eb(i);f=uc(d,11159);yb(a+1298356|0,f);tb(f);o=a+1298404|0,q=x[Gc(d,4)>>2],x[o>>2]=q;dE(i,3,e+219|0);Ec(d,i);yb(a+1298308|0,d);tb(d);Zj(i,3,e+249|0);Xv(d,4,i);yb(a+1298320|0,d);tb(d);d=bp(d);o=d,q=Hd(y[e+269|0],1,31),x[o+8>>2]=q;o=d,q=Hd(y[e+270|0],1,12),x[o+4>>2]=q;x[d>>2]=y[e+271|0]+1900;i=a+1298412|0;Wv(i);VD(i,d);m=e+128|0;i=Nb(e+148|0);q:{r:{s:{while(1){d=x[b+8>>2];f=x[b>>2];x[31785]=0;d=U(153,f|0,d|0,8)|0;f=x[31785];x[31785]=0;t:{u:{v:{w:{x:{if((f|0)!=1){if(!d){break q}x[31785]=0;O(313,b|0,e- -64|0);d=x[31785];x[31785]=0;if((d|0)==1){break x}d=x[e+68>>2];y:{g=y[e+210|0];switch(g-3|0){case 1:break w;case 0:break y;default:break v}}f=2;if(x[e+64>>2]!=1431389523){break u}break t}b=N()|0;break b}b=N()|0;break b}f=4;if(x[e+64>>2]!=1431389523){break u}break t}f=0;if(g>>>0>7){break t}}d=x[e+64>>2]==1146113363?-1:d;f=0}g=x[e+68>>2];x[e+120>>2]=x[e+64>>2];x[e+124>>2]=g;x[31785]=0;S(188,e+100|0,b|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break s}ic(m,e+100|0);x[31785]=0;O(314,i|0,e+120|0);d=x[31785];x[31785]=0;if((d|0)==1){break r}Fd(e+120|0);ub(e+100|0);x[31785]=0;P(186,b|0,f|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){continue}break}b=N()|0;break b}b=N()|0;break b}b=N()|0;Fd(e+120|0);ub(e+100|0);break b}x[31785]=0;m=R(171,e+120|0)|0;b=x[31785];x[31785]=0;z:{A:{B:{if((b|0)!=1){x[31785]=0;S(315,e+100|0,i|0,1431389523);b=x[31785];x[31785]=0;if((b|0)==1){break B}d=e+100|0;b=hd(m,d);ub(d);w[e+98>>1]=0;w[e+96>>1]=65534;if(y[e+210|0]<3){break z}x[31785]=0;d=R(192,b|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){break A}break d}b=N()|0;break b}b=N()|0;break c}w[e+98>>1]=d;if(y[e+210|0]<4){break z}x[31785]=0;d=R(192,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}w[e+96>>1]=y[e+210|0]==4?d?d:-2:d}d=y[a+484376|0];f=x[a+484360>>2];x[31785]=0;g=R(205,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}x[31785]=0;S(241,Wb(f,d)|0,b|0,g>>>1|0);d=x[31785];x[31785]=0;if((d|0)==1){break d}d=Wb(x[a+484360>>2],y[a+484376|0]);d=UD(x[d>>2],x[d+4>>2]);Pf(e+98|0,d);Pf(e+96|0,d);x[31785]=0;S(315,e+100|0,i|0,1414807888);d=x[31785];x[31785]=0;if((d|0)==1){break e}d=e+100|0;b=hd(b,d);ub(d);d=x[b>>2];x[31785]=0;d=R(175,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}if(!(c&1)|d^1){break n}x[31785]=0;O(316,b|0,e+8|0);d=x[31785];x[31785]=0;if((d|0)==1){break f}o=a+480188|0,q=Hd(y[e+10|0],1,32)+1|0,w[o>>1]=q;x[31785]=0;d=P(217,e+84|0,z[e+8>>1])|0;f=x[31785];x[31785]=0;if((f|0)==1){break g}o=e,q=vb(x[d>>2]),x[o+44>>2]=q;g=vb(x[d+4>>2]);C:{D:{E:{while(1){h=x[e+44>>2];if(!Ib(h,g)){f=z[a+480188>>1];x[31785]=0;f=P(317,e+100|0,f|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){break C}b=N()|0;break o}x[31785]=0;f=y[e+210|0]<3?9:8;P(186,b|0,f-4|0)|0;j=x[31785];x[31785]=0;if((j|0)!=1){x[31785]=0;j=R(154,b|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break E}Eh(b,f);x[31785]=0;S(188,e- -64|0,b|0,f+j|0);f=x[31785];x[31785]=0;if((f|0)==1){break D}j=h;f=e- -64|0;h=ic(e+100|0,f);hd(j,h);ub(h);ub(f);Xf(e+44|0);continue}break}b=N()|0;break o}b=N()|0;break o}b=N()|0;break o}g=a+484376|0;h=Wb(x[a+484360>>2],y[g|0]);h=dm(x[h>>2],x[h+4>>2]);x[31785]=0;l=a+484344|0;O(226,l|0,h|0);h=x[31785];x[31785]=0;if((h|0)!=1){g=Wb(x[a+484360>>2],y[g|0]);o=e,q=vb(x[g>>2]),x[o+64>>2]=q;h=vb(x[g+4>>2]);while(1){g=x[e+64>>2];if(!Ib(g,h)){g=Wb(x[a+484360>>2],y[a+484376|0]);h=z[e+96>>1];F:{if(!$i(g,h)){break F}j=x[g>>2];k=z[e+98>>1];if(!k){if(UD(j,x[g+4>>2])>>>0<=h>>>0){break F}}g=Vb(x[l>>2],z[_b(j,h)>>1]);we(g,qn(Ue(Le(e- -64|0,12,k&255),x[g+12>>2]-1|0)))}Nk(f);Qc(d);break n}j=x[d>>2];n=Lf(j,x[d+4>>2]);k=z[g>>1];if(n>>>0>k>>>0){x[31785]=0;j=ba(318,$g(j,k)|0,y[e+210|0],f|0,a|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break p}w[g>>1]=j}Wd(e- -64|0);continue}}break p}b=N()|0;Eb(e+120|0);break a}b=N()|0;Nk(f)}Qc(d);break c}x[31785]=0;S(315,e- -64|0,i|0,1196641603);d=x[31785];x[31785]=0;if((d|0)==1){break k}d=e- -64|0;b=hd(b,d);ub(d);d=x[b>>2];x[31785]=0;d=R(175,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}if(d){x[31785]=0;P(186,b|0,1)|0;d=x[31785];x[31785]=0;if((d|0)==1){break d}x[31785]=0;d=R(205,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}x[31785]=0;aa(319,a+1298332|0,b|0,d|0,40,0);d=x[31785];x[31785]=0;if((d|0)==1){break d}}x[31785]=0;S(315,e- -64|0,i|0,1146113363);d=x[31785];x[31785]=0;if((d|0)==1){break h}x[31785]=0;S(315,e+44|0,i|0,1229999443);d=x[31785];x[31785]=0;if((d|0)==1){break l}d=e+44|0;b=hd(b,d);ub(d);x[31785]=0;d=R(200,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break j}h=a+480190|0;w[h>>1]=d;j=!(c&2);f=1;G:{while(1){H:{c=f&65535;if(c>>>0>(d&65535)>>>0){break G}d=30;I:{J:{K:{if(y[e+210|0]>=2){x[31785]=0;d=R(200,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break K}}x[31785]=0;S(320,b|0,((c<<5)+a|0)+946304|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break K}x[31785]=0;O(321,b|0,e+28|0);d=x[31785];x[31785]=0;if((d|0)==1){break J}x[31785]=0;g=D(c,104)+a|0;l=g+484380|0;O(322,e+28|0,l|0);c=x[31785];x[31785]=0;if((c|0)==1){break J}d=y[e+210|0];if(d>>>0>=8){x[31785]=0;O(323,b|0,g+484423|0);c=x[31785];x[31785]=0;if((c|0)==1){break J}d=y[e+210|0]}x[31785]=0;P(186,b|0,((d&255)>>>0>1?6:2)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break J}x[31785]=0;c=R(154,e- -64|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){x[31785]=0;S(188,e+8|0,e- -64|0,c|0);c=x[31785];x[31785]=0;if((c|0)!=1){break I}}b=N()|0;break i}b=N()|0;break i}b=N()|0;break i}d=e+8|0;c=ic(e+44|0,d);ub(d);d=x[c>>2];x[31785]=0;d=R(175,d|0)|0;k=x[31785];x[31785]=0;if((k|0)!=1){L:{if(j|d^1){break L}d=ad(e+8|0,w[g+484414>>1]&1?16:8,1,0,(y[e+43|0]&12)==4?7:0);x[31785]=0;U(218,d|0,l|0,c|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break L}break H}ub(c);f=f+1|0;d=z[h>>1];continue}}break}b=N()|0;ub(c);break i}ag(a);x[a+480204>>2]=12e5;x[a+480208>>2]=24;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+480228>>2]=48;x[a+480232>>2]=48;x[31785]=0;d=1;U(269,a+1074312|0,114,1)|0;a=x[31785];x[31785]=0;if((a|0)==1){break j}ub(e- -64|0);ub(b);fe(i)}fb=e+272|0;return d|0}b=N()|0;break i}b=N()|0;break c}b=N()|0}ub(e- -64|0);break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}ub(m)}fe(i)}Q(b|0);p()}function apa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;d=fb-288|0;fb=d;xc(b);a:{b:{c:{d:{if(!kv(b,d+192|0)){break d}if(!fX(d+192|0)){break d}if(!Mb(x[b>>2],x[b+8>>2],Bc(dX(d+192|0),hb))){break d}if(!c){h=1;break d}if(!bd(b,y[d+196|0])){break d}Bd(a,268435456);ag(a);x[a+480208>>2]=4;Lb(a+1074312|0,114,1);f=d+84|0;i=uc(f,15469);yb(a+1298344|0,i);tb(i);i=uc(f,10292);yb(a+1298356|0,i);tb(i);G=a+1298404|0,H=x[Gc(f,4)>>2],x[G>>2]=H;i=d+16|0;hf(i,d+198|0,48,3);Ec(f,i);yb(a+1298308|0,f);tb(f);f=y[d+246|0];w[a+480188>>1]=f+1;x[a+480228>>2]=y[d+249|0];x[a+480204>>2]=D(y[d+250|0],1e4);x[a+480196>>2]=y[d+251|0];while(1){if((e|0)==(f|0)){e:{w[a+480190>>1]=y[d+284|0];e=y[d+286|0]|y[d+287|0]<<8;i=fb-16|0;fb=i;f=d+180|0;x[f>>2]=0;x[f+4>>2]=0;rc(f+8|0);Nd(i+8|0,x[zb(i+4|0,f)>>2]);f:{g:{if(e){x[31785]=0;O(665,f|0,e|0);g=x[31785];x[31785]=0;if((g|0)==1){break g}WC(f,e)}e=i+8|0;Md(e);_g(e);fb=i+16|0;break f}a=N()|0;_g(i+8|0);Q(a|0);p()}x[31785]=0;i=f;S(660,b|0,f|0,y[d+286|0]|y[d+287|0]<<8);f=x[31785];x[31785]=0;if((f|0)==1){break b}A=Nb(d+168|0);s=Nb(d+156|0);x[31785]=0;U(424,b|0,A|0,y[d+285|0])|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}x[31785]=0;U(424,b|0,s|0,y[d+284|0])|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}t=c&2;u=d+122|0;n=d+90|0;f=0;h:{while(1){e=f;if(e>>>0>=y[d+284|0]){h=1;if(!(c&1)){break e}x[d+68>>2]=0;o=a+484376|0;gj(Wb(x[a+484360>>2],y[o|0]));G=d,H=vb(x[i>>2]),x[G+64>>2]=H;t=a+484344|0;B=vb(x[i+4>>2]);C=a+484348|0;break h}x[31785]=0;f=e+1|0;g=D(f,104)+a|0;j=g+484380|0;O(282,j|0,0);h=x[31785];x[31785]=0;i:{if((h|0)!=1){h=wb(x[s>>2],e);h=y[h|0]|y[h+1|0]<<8|(y[h+2|0]<<16|y[h+3|0]<<24);if(!h){continue}x[31785]=0;h=P(152,b|0,h|0)|0;k=x[31785];x[31785]=0;j:{if((k|0)==1){break j}if(!h){continue}x[31785]=0;h=P(661,b|0,d+84|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break j}if(!h){continue}h=d+72|0;Te(h,2,n);x[31785]=0;O(221,d+16|0,h|0);h=x[31785];x[31785]=0;if((h|0)==1){break c}h=d+16|0;zc(((f<<5)+a|0)+946304|0,h);tb(h);k=d+72|0;Lk(k,2,u);x[31785]=0;O(221,h|0,k|0);h=x[31785];x[31785]=0;if((h|0)==1){break c}h=d+16|0;ye(g+484423|0,h);tb(h);h=y[d+134|0];if(h>>>0<=15){w[g+484408>>1]=D(h,17);h=g+484414|0;w[h>>1]=z[h>>1]|32}v[d+16|0]=y[d+135|0];v[d+72|0]=64;G=g+484412|0,H=y[Ub(d+16|0,d+72|0)|0],w[G>>1]=H;x[g+484404>>2]=y[d+137|0]|y[d+138|0]<<8;q=g+484384|0;k=y[d+143|0]|y[d+144|0]<<8|(y[d+145|0]<<16|y[d+146|0]<<24);x[q>>2]=k;m=g+484388|0;h=y[d+147|0]|y[d+148|0]<<8|(y[d+149|0]<<16|y[d+150|0]<<24);x[m>>2]=h;l=y[d+151|0]|y[d+152|0]<<8|(y[d+153|0]<<16|y[d+154|0]<<24);x[j>>2]=l;o=y[d+136|0];if(o&1){k=k>>>1|0;x[q>>2]=k;h=h>>>1|0;x[m>>2]=h;x[j>>2]=l>>>1}k:{if(h>>>0<=k>>>0){break k}g=g+484414|0;h=z[g>>1];w[g>>1]=h|2;if(!(o&2)){break k}w[g>>1]=h|6}Xk(j);if(!t){continue}e=wb(x[s>>2],e);e=y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24);x[31785]=0;P(152,b|0,e+y[d+88|0]|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){break i}}break c}break c}e=ad(d+16|0,v[d+136|0]&1?16:8,1,0,1);x[31785]=0;U(218,e|0,j|0,b|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){continue}break}break c}while(1){l:{m:{k=x[d+64>>2];if(!Ib(k,B)){b=x[d+68>>2];c=b&63;if(!c){break m}f=Wb(x[a+484360>>2],y[a+484376|0]);b=b>>>6&65535;if(!$i(f,b)){break m}b=z[_b(x[f>>2],b)>>1];f=x[t>>2];x[31785]=0;O(662,Vb(f,b)|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break m}break c}c=y[k+3|0];if(y[k+2|0]>y[d+246|0]|c>>>0>=y[d+285|0]){break l}c=wb(x[A>>2],c);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[31785]=0;c=P(152,b|0,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}if(!c){break l}x[31785]=0;O(663,b|0,d+84|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}e=y[d+88|0];if(!e){break l}c=y[k|0]|y[k+1|0]<<8;v[d+16|0]=y[d+89|0];v[d+72|0]=y[d+246|0]-y[k+2|0];u=y[Ub(d+16|0,d+72|0)|0];x[d+60>>2]=c+e;G=d,H=x[_c(d+68|0,d+60|0)>>2],x[G+68>>2]=H;x[d+40>>2]=0;x[d+44>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;g=c&63;n=c>>>6|0;q=0;while(1){if((e&255)>>>0<=q>>>0){break l}e=Wb(x[a+484360>>2],y[o|0]);j=g>>>0>63;n=j+n|0;c=n&65535;if(Xc(x[e>>2],x[e+4>>2])>>>0<=c>>>0){x[31785]=0;O(333,e|0,n+1&65535);f=x[31785];x[31785]=0;if((f|0)==1){break c}x[31785]=0;f=P(370,t|0,64)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}e=Wb(x[a+484360>>2],y[o|0]);G=_b(x[e>>2],c),H=f,w[G>>1]=H}l=x[a+484344>>2];f=x[C>>2];m=z[_b(x[e>>2],c)>>1];if(!Ge(l,f,m)){break l}f=0;c=Vb(l,m);l=j?0:g;e=gd(x[c>>2],x[x[c+48>>2]+12>>2],l,y[k+2|0]);n:{while(1){if((f|0)==(u|0)){c=y[d+89|0];if(c>>>0<=u>>>0){break n}x[31785]=0;P(186,b|0,D(c-u|0,5)|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break n}break c}x[31785]=0;O(664,d+72|0,b|0);c=x[31785];x[31785]=0;if((c|0)!=1){c=d+72|0;j=Ic(c);E=Ze(c);r=cj(c);F=ec(c);g=0;c=y[d+72|0];if((c-1&255)>>>0<=142){g=(D((c&240)>>>4|0,12)+(c&15)|0)+13|0;v[(d+16|0)+f|0]=g}v[e|0]=g;c=y[j|0];v[e+2|0]=1;v[e+1|0]=c;c=y[E|0];o:{if((c|0)!=255){v[e+4|0]=c;break o}v[e+2|0]=0}c=y[r|0];p:{if(c>>>0>22){break p}v[e+3|0]=y[c+25600|0];j=y[F|0];v[e+5|0]=j;c=e+5|0;q:{switch(y[r|0]-4|0){case 3:v[c|0]=j&3|64;break p;case 4:v[c|0]=j&3|48;break p;case 7:g=x[i>>2];if(oc(g,x[i+4>>2])>>>0<=j>>>0){break p}r=c;c=wb(g,j);c=y[c|0]|y[c+1|0]<<8;v[r|0]=c>>>6;g=Vb(x[a+484344>>2],m);g=gd(x[g>>2],x[x[g+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[g+5|0]=c&63;v[g+3|0]=14;break p;case 8:r=c;c=x[d+60>>2];v[r|0]=c>>>6;g=Vb(x[a+484344>>2],m);g=gd(x[g>>2],x[x[g+48>>2]+12>>2],l,z[a+480188>>1]-1&65535);v[g+5|0]=c&63;v[g+3|0]=14;break p;case 10:v[c|0]=j&15|128;break p;case 12:v[d+15|0]=15;G=c,H=y[Ub(c,d+15|0)|0]|208,v[G|0]=H;break p;case 13:v[d+15|0]=15;G=c,H=y[Ub(c,d+15|0)|0]|192,v[G|0]=H;break p;case 14:v[d+15|0]=15;G=c,H=y[Ub(c,d+15|0)|0]|224,v[G|0]=H;break p;case 0:case 16:case 17:if(!(j&15)){break p}g=j&240;if(!g|(g|0)==240){break p}v[c|0]=j|15;break p;case 9:case 18:break q;default:break p}}if(g&255){break p}v[e|0]=y[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}g=l+1|0;q=q+1|0;e=y[d+88|0];continue}}a=Wb(x[a+484360>>2],y[a+484376|0]);G=d,H=vb(x[a>>2]),x[G+84>>2]=H;b=vb(x[a+4>>2]);g=65535;while(1){a=x[d+84>>2];if(!Ib(a,b)){break e}if(z[a>>1]==65535){r:{if((g&65535)!=65535){break r}x[31785]=0;g=P(370,t|0,64)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break r}break c}w[a>>1]=g}Wd(d+84|0);continue}}Pe(d- -64|0);continue}}}else{w[((e<<5)+a|0)+480284>>1]=D(y[(d+e|0)+252|0],17);e=e+1|0;continue}break}sc(s);sc(A);sc(i)}fb=d+288|0;return h|0}a=N()|0;sc(s);sc(A);break a}a=N()|0}sc(i);Q(a|0);p()}function SL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;i=fb-208|0;fb=i;a:{b:{if(g){pf(i+196|0,f,32);x[31785]=0;U(545,i+184|0,f|0,32)|0;h=x[31785];x[31785]=0;if((h|0)!=1){break b}f=N()|0;break a}Fb(i+196|0);Fb(i+184|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(zt(c)){h=x[b+24>>2];j=x[h+484344>>2];if(Ge(j,x[h+484348>>2],c&65535)){break j}}x[31785]=0;S(1172,a|0,i+196|0,i+184|0);a=x[31785];x[31785]=0;if((a|0)!=1){break i}f=N()|0;break c}c=Vb(j,c);if(!(!((e|0)<0|x[c+12>>2]<=(d|0)|(d|0)<0)&z[h+480188>>1]>e>>>0)){x[31785]=0;S(1172,a|0,i+196|0,i+184|0);a=x[31785];x[31785]=0;if((a|0)!=1){break i}f=N()|0;break c}c=gd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);rf(i+196|0);rf(i+184|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=y[c|0];if(!zd(d)){if(!Cl(d)){break A}}e=y[c+1|0];h=x[b+24>>2];x[31785]=0;V(1173,i+160|0,h|0,d|0,e|0);d=x[31785];x[31785]=0;e=1;if((d|0)==1){break y}x[31785]=0;O(1068,i+172|0,i+160|0);d=x[31785];x[31785]=0;if((d|0)!=1){break z}f=N()|0;break v}e=0;x[31785]=0;P(37,i+172|0,16972)|0;d=x[31785];x[31785]=0;if((d|0)==1){break x}}x[31785]=0;d=P(845,i+196|0,i+172|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break w}tb(i+172|0);if(e){tb(i+160|0)}e=9978;h=y[c|0];if(!zd(h)){e=Cl(h)?10288:16972}x[31785]=0;h=P(37,i+172|0,e|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break u}x[31785]=0;e=P(845,i+184|0,h|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break t}tb(h);if(f-6>>>0>4294967290){break l}x[31785]=0;h=P(37,i+148|0,18645)|0;j=x[31785];x[31785]=0;if((j|0)==1){break s}x[31785]=0;j=P(845,d|0,h|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break r}tb(h);x[31785]=0;h=P(37,i+136|0,18645)|0;l=x[31785];x[31785]=0;if((l|0)==1){break q}x[31785]=0;l=P(845,e|0,h|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break p}tb(h);h=c+1|0;B:{if(y[c+1|0]){x[31785]=0;O(562,i+124|0,h|0);k=x[31785];x[31785]=0;if((k|0)!=1){break B}break d}x[31785]=0;P(37,i+124|0,16977)|0;k=x[31785];x[31785]=0;if((k|0)==1){break d}}x[31785]=0;k=P(845,j|0,i+124|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break o}j=i+124|0;tb(j);h=y[h|0];x[31785]=0;h=P(37,j|0,(h?10811:16977)|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break n}x[31785]=0;l=P(845,l|0,h|0)|0;j=x[31785];x[31785]=0;if((j|0)!=1){break m}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0;tb(i+172|0);if(!e){break c}}tb(i+160|0);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;tb(i+124|0);break c}f=N()|0;break c}tb(h);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{j=Sg(y[c|0]);O:{if(j){x[31785]=0;m=P(37,i+100|0,18645)|0;h=x[31785];x[31785]=0;if((h|0)==1){break N}h=y[c+4|0];n=y[c+2|0];x[31785]=0;o=i,q=Hj(n,h)&255,x[o+76>>2]=q;O(561,i+88|0,i+76|0);h=x[31785];x[31785]=0;if((h|0)==1){break M}h=0;x[31785]=0;S(1024,i+112|0,m|0,i+88|0);m=x[31785];x[31785]=0;if((m|0)!=1){break O}f=N()|0;break G}h=y[c+2|0];if(h){h=dR(x[x[x[b+24>>2]+8>>2]+88>>2],h);x[31785]=0;h=U(545,i+100|0,1,h|0)|0;m=x[31785];x[31785]=0;if((m|0)==1){break E}x[31785]=0;O(562,i+88|0,c+4|0);m=x[31785];x[31785]=0;if((m|0)==1){break L}x[31785]=0;S(1024,i+112|0,h|0,i+88|0);m=x[31785];x[31785]=0;h=1;if((m|0)!=1){break O}f=N()|0;break J}h=0;x[31785]=0;P(37,i+112|0,16976)|0;m=x[31785];x[31785]=0;if((m|0)==1){break e}}x[31785]=0;k=P(845,k|0,i+112|0)|0;m=x[31785];x[31785]=0;if((m|0)==1){break K}tb(i+112|0);if(h){tb(i+88|0);tb(i+100|0)}if(j){tb(i+88|0);tb(i+100|0)}h=5508;if(!Sg(y[c|0])){h=y[c+2|0]?5504:16976}x[31785]=0;h=P(37,i+112|0,h|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break D}x[31785]=0;j=P(845,l|0,h|0)|0;l=x[31785];x[31785]=0;if((l|0)!=1){break C}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break F}f=N()|0;break I}f=N()|0;tb(i+112|0);if(!h){break H}}tb(i+88|0)}tb(i+100|0)}if(!j){break c}}tb(i+88|0)}tb(i+100|0);break c}f=N()|0;break c}f=N()|0;break c}tb(h);if(f-13>>>0>4294967283){break l}x[31785]=0;h=P(37,i+76|0,18645)|0;l=x[31785];x[31785]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){x[31785]=0;l=P(845,k|0,h|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break Z}tb(h);x[31785]=0;h=P(37,i- -64|0,18645)|0;k=x[31785];x[31785]=0;if((k|0)==1){break Y}x[31785]=0;j=P(845,j|0,h|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break X}tb(h);_:{if(Sg(y[c|0])){h=y[c+5|0];k=y[c+3|0];b=0;x[31785]=0;o=i,q=Hj(k,h)&4095,x[o+16>>2]=q;O(1174,i+52|0,i+16|0);h=x[31785];x[31785]=0;if((h|0)!=1){break _}f=N()|0;break c}h=y[c+3|0];if(h){b=cR(x[x[x[b+24>>2]+8>>2]+84>>2],h);x[31785]=0;b=U(545,i+40|0,1,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break W}x[31785]=0;O(562,i+28|0,c+5|0);h=x[31785];x[31785]=0;if((h|0)==1){break V}x[31785]=0;S(1024,i+52|0,b|0,i+28|0);h=x[31785];x[31785]=0;b=1;if((h|0)!=1){break _}f=N()|0;break S}b=0;x[31785]=0;P(37,i+52|0,16972)|0;h=x[31785];x[31785]=0;if((h|0)==1){break U}}x[31785]=0;P(845,l|0,i+52|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break T}tb(i+52|0);if(b){tb(i+28|0);tb(i+40|0)}b=11182;if(!Sg(y[c|0])){b=y[c+3|0]?11182:16972}x[31785]=0;b=P(37,i+52|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break Q}x[31785]=0;P(845,j|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break P}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;tb(h);break c}f=N()|0;break c}f=N()|0;break R}f=N()|0;break c}f=N()|0;tb(i+52|0);if(!b){break c}}tb(i+28|0)}tb(i+40|0);break c}f=N()|0;break c}tb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Wc(x[d+4>>2],y[d+11|0]);da:{if(b>>>0>f>>>0){x[31785]=0;V(124,i+16|0,d|0,0,f|0);b=x[31785];x[31785]=0;if((b|0)!=1){b=i+16|0;yb(d,b);tb(b);break da}f=N()|0;break c}if(!g){break da}x[31785]=0;b=U(545,i+16|0,f-b|0,32)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ca}x[31785]=0;P(845,d|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break ba}tb(b)}b=Wc(x[e+4>>2],y[e+11|0]);if(b>>>0<=f>>>0){break $}x[31785]=0;V(124,i+4|0,e|0,0,f|0);b=x[31785];x[31785]=0;if((b|0)==1){break aa}b=i+4|0;yb(e,b);tb(b);break k}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}if(!g){break k}x[31785]=0;b=U(545,i+4|0,f-b|0,32)|0;c=x[31785];x[31785]=0;if((c|0)==1){break h}x[31785]=0;P(845,e|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break g}tb(b)}x[31785]=0;S(1172,a|0,d|0,e|0);a=x[31785];x[31785]=0;if((a|0)==1){break f}}tb(i+184|0);tb(i+196|0);fb=i+208|0;return}f=N()|0;break c}f=N()|0;tb(b);break c}f=N()|0;break c}f=N()|0;break c}f=N()|0}tb(i+184|0)}tb(i+196|0);Q(f|0);p()}function Isa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;d=fb-256|0;fb=d;xc(b);f=fb-16|0;fb=f;h=d+99|0;b_(f+8|0,h);i=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);j=x[f+4>>2];if((j|0)==(i|0)){Yb(b,x[f+12>>2])}fb=f+16|0;f=(i|0)==(j|0);if(!f){a_(h)}a:{if(!f){break a}if(!c_(d+99|0)){break a}if(!c){e=1;break a}Bd(a,x[((y[d+215|0]|y[d+216|0]<<8)<<2)+24992>>2]);x[a+480208>>2]=x[a+480208>>2]|16777216;e=d+36|0;f=uc(e,13192);yb(a+1298344|0,f);tb(f);f=uc(e,10323);yb(a+1298356|0,f);tb(f);f=fb-16|0;fb=f;i=d+4|0;h=uc(f+4|0,4409);Yc(i,h);tb(h);fb=f+16|0;x[31785]=0;V(232,e|0,i|0,y[d+178|0],d+175|0);e=x[31785];x[31785]=0;b:{if((e|0)!=1){e=d+36|0;yb(a+1298368|0,e);tb(e);f=d+4|0;Eb(f);$h(a+1298392|0,((y[d+215|0]|y[d+216|0]<<8)<<2)+25040|0);$h(a+1298380|0,x[((y[d+215|0]|y[d+216|0]<<8)<<2)+25088>>2]);A=a+1298404|0,B=x[Gc(e,4)>>2],x[A>>2]=B;Te(f,2,d+103|0);Ec(e,f);yb(a+1298308|0,e);tb(e);Te(f,2,d+135|0);Ec(e,f);c:{if(er(e,9760)){x[31785]=0;S(261,d+4|0,4,d+36|0);e=x[31785];x[31785]=0;if((e|0)==1){break c}e=d+4|0;yb(a+1298320|0,e);tb(e)}tb(d+36|0);w[a+480188>>1]=32;d:{while(1){if((g|0)!=32){f=(g<<5)+a|0;i=f+480280|0;Ye(i);e=y[(d+g|0)+180|0];e:{if(e>>>0<=15){x[d+36>>2]=e<<4|8;x[d+4>>2]=256;A=f+480284|0,B=x[pd(d+36|0,d+4|0)>>2],w[A>>1]=B;break e}if((e|0)!=16){if((e|0)!=255){break e}w[a+480188>>1]=g;break d}w[f+480284>>1]=128;x[i>>2]=256}g=g+1|0;continue}break}g=z[a+480188>>1]}e=0;if(!(g&65535)){break a}x[d+36>>2]=y[d+212|0]<<2;x[d+4>>2]=256;A=a,B=x[Gb(d+36|0,d+4|0)>>2],x[A+480200>>2]=B;x[a+480196>>2]=y[d+213|0];x[a+480204>>2]=D(y[d+214|0],1e4);if(bd(b,y[d+217|0]|y[d+218|0]<<8|(y[d+219|0]<<16|y[d+220|0]<<24))){Wk(Wb(x[a+484360>>2],y[a+484376|0]),b,y[d+221|0]+1|0,255,254)}if(!bd(b,y[d+227|0]|y[d+228|0]<<8|(y[d+229|0]<<16|y[d+230|0]<<24))){break a}l=a+480190|0;g=y[d+235|0]+1|0;w[l>>1]=g;n=d+68|0;m=a+480180|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(g&65535)>>>0){break g}e=fb-16|0;fb=e;f=d+36|0;bc(e+8|0,f,62);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Yb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){Tb(f,0,62)}if(!e){break g}g=0;e=D(j,104)+a|0;k=e+484380|0;jd(k,0);h=d+24|0;Te(h,2,d+36|0);f=d+4|0;Ec(f,h);zc(((j<<5)+a|0)+946304|0,f);tb(f);Lk(h,2,n);Ec(f,h);ye(e+484423|0,f);tb(f);f=y[d+94|0]|y[d+95|0]<<8;x[e+484404>>2]=f;if(!on(x[m>>2])){break f}while(1){if((g|0)==16){break f}if((f|0)==z[(g<<1)+25136>>1]){v[e+484417|0]=g<<4;break f}else{g=g+1|0;continue}}}h:{if(!(c&2)){break h}if(!bd(b,y[d+231|0]|y[d+232|0]<<8|(y[d+233|0]<<16|y[d+234|0]<<24))){break h}g=1;e=a+480190|0;while(1){f=g&65535;if(f>>>0>z[e>>1]){break h}f=D(f,104)+a|0;qg(ad(d+36|0,w[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);g=g+1|0;continue}}o=a+484344|0;$f(o,y[d+226|0]+1|0);j=wD(dr(a));bd(b,y[d+222|0]|y[d+223|0]<<8|(y[d+224|0]<<16|y[d+225|0]<<24));s=c&1;t=a+480188|0;u=a+480180|0;h=0;l=1;i:{j:{k:{while(1){if(y[d+226|0]<h>>>0){if(x[a+480180>>2]==1){break k}c=x[a+480208>>2]&-8454145;break j}l:{e=eh(b);if(e>>>0>=3){c=d+4|0;ce(c,b,e-2|0);i=ic(d+36|0,c);ub(c);m:{if(!s){break m}c=x[i>>2];x[31785]=0;c=R(175,c|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break l}if(!c){break m}x[31785]=0;c=U(199,o|0,h&65535,64)|0;e=x[31785];x[31785]=0;if((e|0)==1){break l}k=0;if(!c){break m}while(1){if((k|0)==64){break m}c=Vb(x[o>>2],h);Ve(d+4|0,x[c>>2],x[x[c+48>>2]+12>>2],k);n:{o:while(1){x[31785]=0;c=R(200,i|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break i}if(!c){break n}e=c&31;if(e>>>0>=z[t>>1]){break n}g=Vc(x[d+4>>2],e);if(c&32){x[31785]=0;O(201,d+24|0,i|0);e=x[31785];x[31785]=0;if((e|0)==1){break i}f=Ic(d+24|0);e=y[d+24|0];if(e){e=(e&127)-1|0;v[d+24|0]=e;e=(D((e&240)>>>4|0,12)+(e&15)|0)+13|0;v[g|0]=e;l=vD(e)&l}v[g+1|0]=y[f|0]}if(!(c&64)){continue}v[g+2|0]=0;v[g+3|0]=0;n=g+5|0;while(1){c=x[i>>2];x[31785]=0;c=U(153,c|0,x[d+44>>2],2)|0;e=x[31785];x[31785]=0;if((e|0)==1){break i}if(!c){continue o}q=y[g+5|0];c=y[g+3|0];x[31785]=0;O(201,d+24|0,i|0);e=x[31785];x[31785]=0;if((e|0)!=1){f=y[Ic(d+24|0)|0];v[g+5|0]=f;r=y[d+24|0];e=y[(r&31)+25168|0];v[g+3|0]=e;p:{q:{r:{s:{t:{switch(e-2|0){case 0:case 1:if(f>>>0<224){break p}m=223;if(x[u>>2]!=1){break s}break p;case 11:v[d+3|0]=64;e=y[Ub(n,d+3|0)|0];v[n|0]=e;if(!Lv(x[j+88>>2],1)){break p}v[g+4|0]=e;v[g+2|0]=1;v[g+5|0]=q;v[g+3|0]=c;e=c;break r;case 17:u:{switch(((f&240)>>>4|0)-8|0){case 0:v[g+3|0]=2;v[g+5|0]=f&15|224;break p;case 1:v[g+3|0]=3;v[g+5|0]=f&15|224;break p;default:break u}}if(Zi(x[j+84>>2],19)){break p}xr(g);e=y[g+3|0];break r;case 13:c=x[j+84>>2];if(Zi(c,15)){break p}if(!Zi(c,19)){break p}v[g+3|0]=19;v[g+5|0]=f&15|144;break p;case 18:m=145;if((f|0)==1){break s}if((f&240)==128){if(Zi(x[j+84>>2],20)){break q}v[g+3|0]=19;break p}v[g+3|0]=0;break p;case 4:case 5:break t;default:break r}}m=f&240;if(!m){break p}}v[n|0]=m}if((e&255)!=20){break p}}e=y[g+5|0];if(y[g+2|0]|(e&240)!=128){break p}v[g+2|0]=2;v[g+5|0]=q;v[g+3|0]=c;v[g+4|0]=(((e&15)<<6|8)>>>0)/15}if(!(r&32)){continue o}continue}break}break}break i}k=k+1|0;continue}}ub(i)}h=h+1|0;continue}break}break i}c=x[a+480208>>2]&-8454145|(z[a+480188>>1]==4?l&1?8454144:0:0)}x[a+480208>>2]=c;e=1;if(!(y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24))){break a}if(!bd(b,y[d+236|0]|y[d+237|0]<<8|(y[d+238|0]<<16|y[d+239|0]<<24))){break a}MD(a+1298332|0,b,y[d+240|0]|y[d+241|0]<<8|(y[d+242|0]<<16|y[d+243|0]<<24),4);break a}g=N()|0;ub(i);break b}w[e+484412>>1]=64;f=y[d+81|0]|y[d+82|0]<<8|(y[d+83|0]<<16|y[d+84|0]<<24);x[k>>2]=f;g=y[d+93|0];if(g&2){h=e+484414|0;w[h>>1]=z[h>>1]|1;x[k>>2]=f>>>1}x[e+484384>>2]=y[d+85|0]|y[d+86|0]<<8|(y[d+87|0]<<16|y[d+88|0]<<24);x[e+484388>>2]=(y[d+89|0]|y[d+90|0]<<8|(y[d+91|0]<<16|y[d+92|0]<<24))-1;if(g&1){f=e+484414|0;w[f>>1]=z[f>>1]|2}v:{w:{if(!(g&4)){break w}f=y[d+96|0];if((f|0)==255){break w}v[d+4|0]=f;v[d+24|0]=64;A=e+484410|0,B=y[Ub(d+4|0,d+24|0)|0]<<2,w[A>>1]=B;break v}f=e+484414|0;w[f>>1]=z[f>>1]|32768}x:{if(g&8){g=e+484414|0;f=z[g>>1]|32;w[g>>1]=f;j=e+484408|0;e=y[d+97|0];if(e>>>0<=15){x[d+24>>2]=256;x[d+4>>2]=e<<4|8;h=x[pd(d+4|0,d+24|0)>>2]}else{h=128}w[j>>1]=h;w[g>>1]=f&65279|((e|0)==16)<<8;break x}w[e+484408>>1]=128}i=i+1|0;g=z[l>>1];continue}}g=N()|0;tb(d+36|0);break b}g=N()|0;Eb(d+4|0)}Q(g|0);p()}fb=d+256|0;return e|0}function W6(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(ji(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+72>>2]=1241;b=l+72|0;s=Ae(l+104|0,l+112|0,b);m=x[s>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);q=Fb(l+60|0);o=Fb(l+48|0);n=Fb(l+36|0);r=Fb(l+24|0);b=x[d>>2];x[31785]=0;ka(1251,c|0,b|0,l+92|0,l+88|0,l+84|0,u|0,q|0,o|0,n|0,l+20|0);b=x[31785];x[31785]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+20>>2];e=0;k=0;while(1){c:{d:{e:{f:{g:{if((e|0)==4){break g}x[31785]=0;b=P(1225,a|0,l+524|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}if(b){break g}h:{i:{j:{k:{l:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31785]=0;b=R(1226,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=U(1252,h|0,1,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}if(b){x[31785]=0;O(1253,l+12|0,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){x[31785]=0;O(36,r|0,x[l+12>>2]);b=x[31785];x[31785]=0;if((b|0)!=1){break k}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break h;case 2:break i;case 3:break j;case 0:break l;default:break c}}if((e|0)==3){break c}}while(1){x[31785]=0;b=P(1225,a|0,l+524|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}if(b){break c}b=x[a>>2];x[31785]=0;b=R(1226,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=U(1252,h|0,1,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}if(!b){break c}x[31785]=0;O(1253,l+12|0,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){x[31785]=0;O(36,r|0,x[l+12>>2]);b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}break a}m:{if(!Bb(x[o+4>>2],y[o+11|0])){break m}b=x[a>>2];x[31785]=0;b=R(1226,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}if((b|0)!=x[Sd(o,0)>>2]){break m}x[31785]=0;R(1228,a|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}v[g|0]=0;k=Bb(x[o+4>>2],y[o+11|0])>>>0>1?o:k;break c}n:{if(!Bb(x[n+4>>2],y[n+11|0])){break n}b=x[a>>2];x[31785]=0;b=R(1226,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}if((b|0)!=x[Sd(n,0)>>2]){break n}x[31785]=0;R(1228,a|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}v[g|0]=1;k=Bb(x[n+4>>2],y[n+11|0])>>>0>1?n:k;break c}o:{b=Bb(x[o+4>>2],y[o+11|0]);if(!b){break o}if(!Bb(x[n+4>>2],y[n+11|0])){break o}x[f>>2]=x[f>>2]|4;a=0;break d}c=b;b=Bb(x[n+4>>2],y[n+11|0]);if(!(c|b)){break c}v[g|0]=!b;break c}if(!((e|0)==2&y[l+95|0]!=0|(e>>>0<2|k|A))){k=0;break c}c=zb(l+12|0,wd(q));p:{if(!e|y[(e+l|0)+91|0]>1){break p}q:{while(1){b=kl(q);d=x[c>>2];if(!Ib(d,b)){break q}b=x[d>>2];x[31785]=0;b=U(1252,h|0,1,b|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){if(!b){break q}Pe(c);continue}break}break a}b=wd(q);b=wv(x[c>>2],b);if(Bb(x[r+4>>2],y[r+11|0])>>>0>=b>>>0){d=Ek(kl(r),0-b|0);t=kl(r);z=wd(q);b=fb-16|0;fb=b;x[b+8>>2]=z;x[b+12>>2]=d;while(1){r:{z=Ib(d,t);if(!z){break r}if(!mc(x[d>>2],x[x[b+8>>2]>>2])){break r}d=Pe(b+12|0);Pe(b+8|0);d=x[d>>2];continue}break}fb=b+16|0;if(z^1){break p}}C=c,D=x[zb(l+8|0,wd(q))>>2],x[C>>2]=D}x[l+8>>2]=x[c>>2];s:{while(1){b=kl(q);if(!Ib(x[l+8>>2],b)){break s}x[31785]=0;b=P(1225,a|0,l+524|0)|0;c=x[31785];x[31785]=0;t:{if((c|0)==1){break t}if(b){break s}b=x[a>>2];x[31785]=0;b=R(1226,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break t}if((b|0)!=x[x[l+8>>2]>>2]){break s}x[31785]=0;R(1228,a|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}Pe(l+8|0);continue}break}break a}if(!A){break c}b=kl(q);if(!Ib(x[l+8>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}b=0;z=x[l+84>>2];c=m;u:{while(1){v:{x[31785]=0;d=P(1225,a|0,l+524|0)|0;t=x[31785];x[31785]=0;if((t|0)==1){break v}if(d){break u}d=x[a>>2];x[31785]=0;t=R(1226,d|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}x[31785]=0;d=U(1252,h|0,64,t|0)|0;B=x[31785];x[31785]=0;if((B|0)==1){break a}w:{if(d){d=x[j>>2];if((d|0)==x[l+520>>2]){x[31785]=0;S(1254,i|0,j|0,l+520|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}d=x[j>>2]}x[j>>2]=d+4;x[d>>2]=t;b=b+1|0;break w}if(!Bb(x[u+4>>2],y[u+11|0])|!b|(t|0)!=(z|0)){break u}if(x[l+96>>2]==(m|0)){x[31785]=0;S(1247,s|0,l+100|0,l+96|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c;b=0}x[31785]=0;R(1228,a|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){continue}}break}break a}if(!b|x[s>>2]==(c|0)){break f}if(x[l+96>>2]==(c|0)){x[31785]=0;S(1247,s|0,l+100|0,l+96|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}c=x[l+100>>2]}m=c+4|0;x[l+100>>2]=m;x[c>>2]=b;break e}x[l+20>>2]=w;x:{if(!k){break x}b=k;k=1;while(1){if(Bb(x[b+4>>2],y[b+11|0])>>>0<=k>>>0){break x}x[31785]=0;c=P(1225,a|0,l+524|0)|0;d=x[31785];x[31785]=0;y:{if((d|0)==1){break y}z:{if(!c){c=x[a>>2];x[31785]=0;c=R(1226,c|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break y}if((c|0)==x[Sd(b,k)>>2]){break z}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31785]=0;R(1228,a|0)|0;c=x[31785];x[31785]=0;k=k+1|0;if((c|0)!=1){continue}}break}break a}a=1;b=x[s>>2];if((b|0)==(m|0)){break d}a=0;x[l+12>>2]=0;Qf(u,b,m,l+12|0);if(x[l+12>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}m=c}A:{if((w|0)<=0){break A}x[31785]=0;b=P(1225,a|0,l+524|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}B:{if(!b){b=x[a>>2];x[31785]=0;b=R(1226,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}if((b|0)==x[l+88>>2]){break B}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31785]=0;b=R(1228,a|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break A}x[31785]=0;c=P(1225,b|0,l+524|0)|0;d=x[31785];x[31785]=0;C:{if((d|0)==1){break C}D:{if(!c){c=x[b>>2];x[31785]=0;c=R(1226,c|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break C}x[31785]=0;c=U(1252,h|0,64,c|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break C}if(c){break D}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31785]=0;S(1254,i|0,j|0,l+520|0);c=x[31785];x[31785]=0;if((c|0)==1){break C}}c=x[b>>2];x[31785]=0;c=R(1226,c|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break C}d=x[j>>2];x[j>>2]=d+4;x[d>>2]=c;x[31785]=0;R(1228,b|0)|0;c=x[31785];x[31785]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}Sb(r);Sb(n);Sb(o);Sb(q);tb(u);Kc(s);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;Sb(r);Sb(n);Sb(o);Sb(q);tb(u);Kc(s);Q(a|0);p()}function XS(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,C=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=E(0),R=E(0),S=0,T=0,U=0,V=E(0),W=0;k=fb-48|0;fb=k;l=b+223848|0;Uj(l,Tj(e,Ii(e,Lo(e),0))+1|0);le(k+40|0,x[l>>2],x[b+223852>>2]);gc(k+32|0,e,Tj(e,Ii(e,Lo(e),0)));F=x[k+32>>2];G=x[k+36>>2];l=0;i=fb-16|0;fb=i;H=a+906300|0;u=a+1074312|0;g=D(c,872)+b|0;I=g+1415|0;J=g+1304|0;K=g+1392|0;q=g+1368|0;s=g+1364|0;L=g+1336|0;M=g+1308|0;N=g+1300|0;O=g+1280|0;P=g+1402|0;n=g+1466|0;Q=E(y[n|0]);R=E(f>>>0);C=g+616|0;o=x[g+1272>>2];S=a+480188|0;p=1;j=255;while(1){if((m|0)!=(G|0)&A[k+44>>2]>l>>>0){h=y[xb(F,m)|0];e=h-48|0;a:{b:{if((e&255)>>>0<=9){break b}if((h-65&255)>>>0<=5){e=h-55|0;break b}c:{d:{e:{switch(h-97|0){case 2:f:{e=lm(a,b,c,3,0)-1|0;if((e&255)>>>0>249){break f}e=x[rd(H,e)>>2];if(!e){break f}e=WA(e,46200,43256);if(!e){break f}e=ib[x[x[e>>2]+192>>2]](e,C,c)|0;h=(e|0)!=255;e=h?e:0;if(h|!o){break b}break c}if(o){break c}e=0;break b;case 21:g:{if(!Pb(u,28)){e=0;if(!Pb(u,1)){break g}}e=w[K>>1]}h=D(x[q>>2],x[s>>2]);e=D(x[a+1074456>>2],e+x[J>>2]|0);e=Xb((Fc(tua(sua(h,h>>31,e,e>>31),hb,1048576,0),hb)|0)/2|0,1,127);break d;case 20:e=D(x[q>>2],x[s>>2]);h=e;t=e>>31;e=D(x[a+1074456>>2],x[L>>2]);e=Xb((Fc(tua(sua(h,t,e,e>>31),hb,67108864,0),hb)|0)/2|0,1,127);break d;case 23:x[i>>2]=x[M>>2]/2;x[i+12>>2]=127;e=x[pd(i,i+12|0)>>2];break d;case 24:x[i>>2]=x[N>>2]/2;x[i+12>>2]=127;e=x[pd(i,i+12|0)>>2];break d;case 0:e=0;if(!o){break d}h=z[o+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!o){break d}h=z[o+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=x[O>>2]>>>8|0;break d;case 7:e=(z[S>>1]<=c>>>0?y[P|0]-1|0:c)&127;break d;case 12:e=y[g+704|0]>>>7|0;break d;case 15:e=0;if(!o){break d}h=y[o+30|0];if(!h){break d}e=h-1&127;break d;case 25:h:{if(!d|v[n|0]<0){break h}i:{if(l>>>0<3){break i}e=x[k+40>>2];if(y[xb(e,l-3|0)|0]!=240){break i}if(y[xb(e,l-2|0)|0]>239){break h}}r=rq(b,Q,R);j:{if(r<E(4294967296)&r>=E(0)){e=~~r>>>0;break j}e=0}v[n|0]=e;j=128;break d}j=(j&255)==255?f:j;e=f;break d;case 18:k:{if(!l){e=0;break k}h=x[k+40>>2];e=l;while(1){e=e-1|0;t=xb(h,e);if(!e){break k}if(y[t|0]!=240){continue}break}}if(l-e>>>0<5){break a}t=x[k+40>>2];if(y[xb(t,e)|0]!=240){break a}e=e+5|0;h=0;while(1){if((e|0)!=(l|0)){h=y[xb(t,e)|0]+h|0;e=e+1|0;continue}break};e=0-h&127;break d;case 13:break e;default:break a}}e=y[I|0];e=zd(e)?e-1|0:0}h=p^-1;p=1;l=(h&1)+l|0;T=xb(x[k+40>>2],l),U=e,v[T|0]=U;l=l+1|0;break a}e=z[C+786>>1];h=(e?e-1|0:c)&15;e=y[o+31|0];l:{if((e|0)==17){break l}h=Nj(e)?e-1&15:0}e=h}h=xb(x[k+40>>2],l);v[h|0]=(p&1?0:y[h|0]<<4)|e;p=p^1;l=(p&1)+l|0}m=m+1|0;continue}else{if(j<<24>>24>=0){v[n|0]=j}bc(i,x[k+40>>2],((p^-1)&1)+l|0);e=x[i+4>>2];x[k+40>>2]=x[i>>2];x[k+44>>2]=e;fb=i+16|0}break}o=x[k+44>>2];l=0;m:while(1){p=0;while(1){e=l;n:{o:{p:{q:{while(1){if(A[k+44>>2]<=e>>>0){break n}f=x[k+40>>2];i=xb(f,e);g=v[i|0];if((g|0)==-16){g=e;if(o-g>>>0>=4){l=4;if((y[xb(f,e+1|0)|0]&254)==240){break o}}r:{while(1){g=g+1|0;if(o>>>0<=g>>>0){break r}if(y[xb(f,g)|0]!=247){continue}break}l=(g-e|0)+1|0;if(l){break o}}T=xb(f,o),U=247,v[T|0]=U;o=o+1|0;l=o-e|0;break p}if((g|0)<0){break q}if(p&255){e=e-1|0;T=xb(f,e),U=p,v[T|0]=U;continue}break}l=l+1|0;continue m}T=k,U=$U(g&255),x[T+20>>2]=U;x[k+28>>2]=o-e;l=x[Gb(k+20|0,k+28|0)>>2]}if(!l){break n}f=x[k+40>>2];i=xb(f,e)}u=y[i|0];jr(k+20|0,f,x[k+44>>2],e,l);f=gc(k+12|0,x[k+20>>2],x[k+24>>2]);g=x[f+4>>2];x[k>>2]=x[f>>2];x[k+4>>2]=g;i=fb-32|0;fb=i;j=x[k+4>>2];s:{if(!j){break s}m=Ad(y[b+223884|0]);t:{f=x[k>>2];n=xb(f,0);g=y[n|0]-250|0;if(g>>>0>5|!(1<<g&37)){break t}h=z[a+480188>>1];g=0;while(1){if((g|0)==(h|0)){break t}q=(D(g,872)+b|0)+1453|0;v[q|0]=127;v[q+1|0]=0;g=g+1|0;continue}}u:{if((j|0)!=4|y[n|0]!=240){break u}g=y[xb(f,1)|0];if((g&254)!=240){break u}j=(D(c,872)+b|0)+616|0;n=xb(f,2);q=y[xb(f,3)|0];f=q<<24>>24;s=(g|0)!=241&(f|0)>=0;n=y[n|0];if(!(!s|n)){g=D(c,872)+b|0;n=g+1453|0;if(d){f=xh(rq(b,E(y[n|0]),E((f&255)>>>0)))}v[n|0]=f;v[g+1412|0]=0;f=wq(a,j,!(x[g+704>>2]&32768),256);if((f|0)<0|!(y[g+705|0]&2)){break s}g=x[a+1298300>>2];if(m|xd(g)^1){break s}Bq(g,c,f>>>2&255,1);break s}h=n<<24>>24;if(s&(h|0)==1){g=D(c,872)+b|0;m=g+1454|0;if(d){f=xh(rq(b,E(y[m|0]),E((f&255)>>>0)))}v[m|0]=f;v[g+1411|0]=0;wq(a,j,!(x[g+704>>2]&32768),256);break s}if(!((g|0)==241|(h|0)!=2)){if(f>>>0>31){break s}g=D(c,872)+b|0;v[g+1461|0]=(f&240)>>>4;wq(a,j,!(x[g+704>>2]&32768),256);break s}if(!((g|0)==241|(h|0)!=3)){n=(f|0)<0;f=lm(a,b,c,3,0)-1|0;if(n|(f&255)>>>0>249){break s}v[i+24|0]=f;g=a+906300|0;j=f&255;f=x[rd(g,j)>>2];if(!f){break s}r=E(E(127-q|0)/E(127));if(m){j=0;g=fb-16|0;fb=g;T=g,U=Vj(i+24|0),x[T+4>>2]=U;f=fb-16|0;fb=f;n=b+223860|0;h=VA(n,f+12|0,y[i+24|0]);m=x[h>>2];if(!m){j=fb-16|0;fb=j;m=ec(n);q=zh(f,Dc(24),Kg(j+8|0,m));m=x[q>>2];s=y[x[g+4>>2]];x[m+20>>2]=0;v[m+16|0]=s;T=ec(q),U=1,v[T+4|0]=U;fb=j+16|0;Xg(n,x[f+12>>2],h,x[f>>2]);m=ie(f);Xl(f);j=1}Wg(g+8|0,x[zb(f,m)>>2],j);fb=f+16|0;f=qd(x[g+8>>2]);fb=g+16|0;B[f+4>>2]=r;break s}if(!d){pu(x[f+20>>2],r);break s}g=rd(g,j);pu(x[f+20>>2],rq(b,B[g+144>>2],r));break s}if((g|0)!=241&(h|0)>=0){break s}h=lm(a,b,c,3,0)-1|0;if((f|0)<0|(h&255)>>>0>249){break s}j=x[rd(a+906300|0,h&255)>>2];if(!j){break s}g=(g|0)!=241?n&127:n+128|0;r=E(E((f&255)>>>0)/E(127));if(m){T=lT(b+223872|0,CS(i+24|0,h,g)),V=r,B[T>>2]=V;break s}f=x[j>>2];if(!d){ib[x[f+44>>2]](j,g,r);break s}U=j,W=g,V=rq(b,E(ib[x[f+48>>2]](j,g)),r),T=x[x[j>>2]+44>>2],ib[T](U|0,W|0,E(V));break s}if(m){break s}m=z[a+480188>>1];v:{if(m>>>0>c>>>0){g=c+1|0;break v}g=z[(D(c,872)+b|0)+1402>>1];if(!g){break s}}if(y[(D(c,872)+b|0)+707|0]&4|m>>>0<(g&65535)>>>0){break s}g=lm(a,b,c,3,0)-1|0;if((g&255)>>>0>249){break s}g=x[rd(a+906300|0,g)>>2];if(!g){break s}m=y[n|0];if((m|0)==240){kf(i+16|0,x[k>>2],x[k+4>>2]);f=x[x[g>>2]+72>>2];j=x[i+20>>2];x[i>>2]=x[i+16>>2];x[i+4>>2]=j;ib[f|0](g,i)|0;break s}T=i,W=$U(m),x[T+24>>2]=W;x[i+12>>2]=j;j=i+24|0;m=x[Gb(j,i+12|0)>>2];x[i+24>>2]=0;yc(j,f,m);ib[x[x[g>>2]+68>>2]](g,x[i+24>>2])|0}fb=i+32|0;p=u>>>0<240?u:p;l=e+l|0;continue}break}break}fb=k+48|0}function b7(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;l=fb-528|0;fb=l;x[l+520>>2]=k;x[l+524>>2]=b;a:{b:{if(qh(a,l+524|0)){x[f>>2]=x[f>>2]|4;a=0;break b}x[l+76>>2]=1241;b=l+76|0;t=Ae(l+104|0,l+112|0,b);m=x[t>>2];x[l+100>>2]=m;x[l+96>>2]=m+400;u=Fb(b);r=Fb(l- -64|0);q=Fb(l+52|0);o=Fb(l+40|0);s=Fb(l+28|0);b=x[d>>2];x[31785]=0;ka(1244,c|0,b|0,l+92|0,l+91|0,l+90|0,u|0,r|0,q|0,o|0,l+24|0);b=x[31785];x[31785]=0;if((b|0)!=1){x[j>>2]=x[i>>2];A=e&512;w=x[l+24>>2];k=h;B=y[l+95|0];C=y[l+91|0];D=y[l+90|0];c=m;e=0;d=0;while(1){c:{d:{e:{f:{if((e|0)==4){break f}x[31785]=0;b=P(1210,a|0,l+524|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}if(b){break f}b=0;g:{h:{i:{j:{k:{switch(v[(l+92|0)+e|0]){case 1:if((e|0)==3){break c}b=x[a>>2];x[31785]=0;b=R(1211,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}if(Ef(x[k+8>>2],1,b)){x[31785]=0;O(1245,l+16|0,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){x[31785]=0;O(118,s|0,v[l+16|0]);b=x[31785];x[31785]=0;if((b|0)!=1){break j}}break a}x[f>>2]=x[f>>2]|4;a=0;break d;case 4:break g;case 2:break h;case 3:break i;case 0:break k;default:break c}}if((e|0)==3){break c}}while(1){x[31785]=0;b=P(1210,a|0,l+524|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}if(b){break c}b=x[a>>2];x[31785]=0;b=R(1211,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}if(!Ef(x[k+8>>2],1,b)){break c}x[31785]=0;O(1245,l+16|0,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){x[31785]=0;O(118,s|0,v[l+16|0]);b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}break a}l:{if(!Bb(x[q+4>>2],y[q+11|0])){break l}b=x[a>>2];x[31785]=0;b=R(1211,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}if(y[cc(q,0)|0]!=(b&255)){break l}x[31785]=0;R(1213,a|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}v[g|0]=0;d=Bb(x[q+4>>2],y[q+11|0])>>>0>1?q:d;break c}m:{if(!Bb(x[o+4>>2],y[o+11|0])){break m}b=x[a>>2];x[31785]=0;b=R(1211,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}if(y[cc(o,0)|0]!=(b&255)){break m}x[31785]=0;R(1213,a|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}v[g|0]=1;d=Bb(x[o+4>>2],y[o+11|0])>>>0>1?o:d;break c}n:{b=Bb(x[q+4>>2],y[q+11|0]);if(!b){break n}if(!Bb(x[o+4>>2],y[o+11|0])){break n}x[f>>2]=x[f>>2]|4;a=0;break d}h=b;b=Bb(x[o+4>>2],y[o+11|0]);if(!(h|b)){break c}v[g|0]=!b;break c}if(!(e>>>0<2|d|((e|0)==2&(B|0)!=0|A))){d=0;break c}h=zb(l+16|0,wd(r));o:{if(!e|y[(e+l|0)+91|0]>1){break o}while(1){p:{b=yf(r);n=x[h>>2];if(!Ib(n,b)){break p}if(!Ef(x[k+8>>2],1,v[n|0])){break p}je(h);continue}break}b=wd(r);b=zk(x[h>>2],b);if(Bb(x[s+4>>2],y[s+11|0])>>>0>=b>>>0){n=KC(yf(s),b);E=yf(s);z=wd(r);b=fb-16|0;fb=b;x[b+8>>2]=z;x[b+12>>2]=n;while(1){z=Ib(n,E);if(!(!z|y[n|0]!=y[x[b+8>>2]])){n=je(b+12|0);je(b+8|0);n=x[n>>2];continue}break}fb=b+16|0;if(z^1){break o}}F=h,G=x[zb(l+12|0,wd(r))>>2],x[F>>2]=G}x[l+12>>2]=x[h>>2];q:{while(1){b=yf(r);if(!Ib(x[l+12>>2],b)){break q}x[31785]=0;b=P(1210,a|0,l+524|0)|0;h=x[31785];x[31785]=0;r:{if((h|0)==1){break r}if(b){break q}b=x[a>>2];x[31785]=0;b=R(1211,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break r}if(y[x[l+12>>2]]!=(b&255)){break q}x[31785]=0;R(1213,a|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}je(l+12|0);continue}break}break a}if(!A){break c}b=yf(r);if(!Ib(x[l+12>>2],b)){break c}x[f>>2]=x[f>>2]|4;a=0;break d}s:{while(1){t:{x[31785]=0;h=P(1210,a|0,l+524|0)|0;n=x[31785];x[31785]=0;if((n|0)==1){break t}if(h){break s}h=x[a>>2];x[31785]=0;n=R(1211,h|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}u:{if(Ef(x[k+8>>2],64,n)){h=x[j>>2];if((h|0)==x[l+520>>2]){x[31785]=0;S(1246,i|0,j|0,l+520|0);h=x[31785];x[31785]=0;if((h|0)==1){break a}h=x[j>>2]}x[j>>2]=h+1;v[h|0]=n;b=b+1|0;break u}if(!Bb(x[u+4>>2],y[u+11|0])|!b|(n&255)!=(D|0)){break s}if(x[l+96>>2]==(c|0)){x[31785]=0;S(1247,t|0,l+100|0,l+96|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}c=x[l+100>>2]}m=c+4|0;x[l+100>>2]=m;x[c>>2]=b;c=m;b=0}x[31785]=0;R(1213,a|0)|0;h=x[31785];x[31785]=0;if((h|0)!=1){continue}}break}break a}if(!(!b|x[t>>2]==(m|0))){if(x[l+96>>2]==(m|0)){x[31785]=0;S(1247,t|0,l+100|0,l+96|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}m=x[l+100>>2]}c=m+4|0;x[l+100>>2]=c;x[m>>2]=b;m=c}if((w|0)<=0){break e}x[31785]=0;b=P(1210,a|0,l+524|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}v:{if(!b){b=x[a>>2];x[31785]=0;b=R(1211,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}if((b&255)==(C|0)){break v}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31785]=0;b=R(1213,a|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}while(1){if((w|0)<=0){w=0;break e}x[31785]=0;c=P(1210,b|0,l+524|0)|0;h=x[31785];x[31785]=0;w:{if((h|0)==1){break w}x:{if(!c){c=x[b>>2];x[31785]=0;c=R(1211,c|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break w}if(Ef(x[k+8>>2],64,c)){break x}}x[f>>2]=x[f>>2]|4;a=0;break d}if(x[j>>2]==x[l+520>>2]){x[31785]=0;S(1246,i|0,j|0,l+520|0);c=x[31785];x[31785]=0;if((c|0)==1){break w}}c=x[b>>2];x[31785]=0;c=R(1211,c|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break w}h=x[j>>2];x[j>>2]=h+1;v[h|0]=c;x[31785]=0;R(1213,b|0)|0;c=x[31785];x[31785]=0;w=w-1|0;if((c|0)!=1){continue}}break}break a}x[l+24>>2]=w;y:{if(!d){break y}k=1;while(1){if(Bb(x[d+4>>2],y[d+11|0])>>>0<=k>>>0){break y}x[31785]=0;b=P(1210,a|0,l+524|0)|0;c=x[31785];x[31785]=0;z:{if((c|0)==1){break z}A:{if(!b){b=x[a>>2];x[31785]=0;b=R(1211,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break z}if(y[cc(d,k)|0]==(b&255)){break A}}x[f>>2]=x[f>>2]|4;a=0;break d}x[31785]=0;R(1213,a|0)|0;b=x[31785];x[31785]=0;k=k+1|0;if((b|0)!=1){continue}}break}break a}a=1;b=x[t>>2];if((b|0)==(m|0)){break d}a=0;x[l+16>>2]=0;Qf(u,b,m,l+16|0);if(x[l+16>>2]){x[f>>2]=x[f>>2]|4;break d}a=1;break d}c=m;if(x[j>>2]!=x[i>>2]){break c}x[f>>2]=x[f>>2]|4;a=0}tb(s);tb(o);tb(q);tb(r);tb(u);Kc(t);break b}e=e+1|0;continue}}break a}fb=l+528|0;return a|0}a=N()|0;tb(s);tb(o);tb(q);tb(r);tb(u);Kc(t);Q(a|0);p()}function Koa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-272|0;fb=d;xc(b);e=fb-16|0;fb=e;f=d+126|0;QW(e+8|0,f);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Yb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){PW(f)}a:{b:{c:{d:{if(!e){break d}if(!RW(d+126|0)){break d}if(!c){i=1;break d}Bd(a,4194304);e=d+40|0;g=uc(e,17245);yb(a+1298344|0,g);tb(g);g=uc(e,10147);yb(a+1298356|0,g);tb(g);n=a+1298404|0,o=x[Gc(e,4)>>2],x[n>>2]=o;n=a,o=Hd(y[d+204|0]|y[d+205|0]<<8,y[d+206|0]|y[d+207|0]<<8,127),w[n+480188>>1]=o;g=y[d+195|0];x[a+480228>>2]=(g|0)==255?48:g;x[a+480196>>2]=y[d+193|0];x[a+480204>>2]=D(y[d+194|0],1e4);g=d+104|0;hf(g,d+130|0,59,3);Ec(e,g);yb(a+1298308|0,e);tb(e);e=y[d+208|0]|y[d+209|0]<<8|(y[d+210|0]<<16|y[d+211|0]<<24);e:{if(e>>>0<5){break e}if(!bd(b,e-4|0)){break e}if(!ek(b,14386)){break e}Wk(Wb(x[a+484360>>2],y[a+484376|0]),b,y[d+198|0]|y[d+199|0]<<8,65535,65535)}f:{e=y[d+212|0]|y[d+213|0]<<8|(y[d+214|0]<<16|y[d+215|0]<<24);if(e>>>0<5){break f}if(!bd(b,e-4|0)){break f}if(!ek(b,13887)){break f}e=0;while(1){if((e|0)==32){break f}g=(e<<5)+a|0;Ye(g+480280|0);n=g+480284|0,o=((((be(b)^-1)&15)<<8|8)>>>0)/15|0,w[n>>1]=o;e=e+1|0;continue}}e=y[d+220|0]|y[d+221|0]<<8|(y[d+222|0]<<16|y[d+223|0]<<24);g:{if(e>>>0<5){break g}if(!bd(b,e-4|0)){break g}if(!ek(b,14220)){break g}e=d+40|0;ce(e,b,(y[d+202|0]|y[d+203|0]<<8)<<6);k=c&2;h=a+480190|0;g=ic(d+104|0,e);ub(e);j=d+53|0;e=0;h:{while(1){if((e&65535)>>>0>=(y[d+202|0]|y[d+203|0]<<8)>>>0){break h}x[31785]=0;f=P(693,g|0,d+40|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break b}if(!f){break h}f=y[d+85|0]|y[d+86|0]<<8;w[d+38>>1]=f;i:{j:{if((f-1&65535)>>>0>3998){break j}f=D(f,104)+a|0;i=f+484380|0;if(ge(x[i>>2],x[f+484400>>2])){break j}n=h,o=z[se(h,d+38|0)>>1],w[n>>1]=o;x[31785]=0;O(694,d+40|0,i|0);f=x[31785];x[31785]=0;if((f|0)==1){break i}f=d+12|0;RZ(f,1,j);x[31785]=0;O(221,d+24|0,f|0);f=x[31785];x[31785]=0;if((f|0)==1){break b}f=d+24|0;zc(((z[d+38>>1]<<5)+a|0)+946304|0,f);tb(f);if(!k){break j}x[31785]=0;P(152,b|0,y[d+77|0]|y[d+78|0]<<8|(y[d+79|0]<<16|y[d+80|0]<<24))|0;f=x[31785];x[31785]=0;if((f|0)==1){break i}i=1;l=d+24|0;f=y[d+87|0];m=ad(l,f&4?16:8,1,0,0);k:{l:{if(f&8){break l}i=2;if(f&16){break l}if(f&127){break k}}ug(m,i)}x[31785]=0;U(218,l|0,(D(z[d+38>>1],104)+a|0)+484380|0,b|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){break j}break b}e=e+1|0;continue}break}break b}ub(g)}i=1;if(!(c&1)){break d}m:{c=y[d+216|0]|y[d+217|0]<<8|(y[d+218|0]<<16|y[d+219|0]<<24);if(c>>>0<5){break m}if(!bd(b,c-4|0)){break m}if(!ek(b,13737)){break m}k=a+484344|0;$f(k,y[d+200|0]|y[d+201|0]<<8);f=0;while(1){if((y[d+200|0]|y[d+201|0]<<8)>>>0<=f>>>0){break m}if(!Cr(b,d+24|0)){break m}n:{e=z[d+24>>1];if(e>>>0>3){c=d+104|0;ce(c,b,(e+15&131056)-4|0);g=ic(d+40|0,c);ub(c);x[31785]=0;c=U(199,k|0,f&65535,y[d+26|0])|0;e=x[31785];x[31785]=0;if((e|0)==1){break n}h=0;o:{if(!c){break o}while(1){p:{c=x[g>>2];x[31785]=0;e=U(153,c|0,x[d+48>>2],1)|0;c=x[31785];x[31785]=0;q:{if((c|0)!=1){c=y[d+26|0];if(!(e&c>>>0>(h&255)>>>0)){break p}x[31785]=0;c=R(200,g|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}e=c<<24>>24;if(e){break q}h=h+1|0;continue}break c}c=x[a+484344>>2];w[d+104>>1]=e&31;w[d+12>>1]=z[a+480188>>1]-1;c=Vb(c,f);c=gd(x[c>>2],x[x[c+48>>2]+12>>2],h,z[Mc(d+104|0,d+12|0)>>1]);if((e|0)<0){x[31785]=0;O(201,d+104|0,g|0);j=x[31785];x[31785]=0;if((j|0)==1){break c}v[c|0]=y[d+104|0]+36;n=c,o=y[Ic(d+104|0)|0],v[n+1|0]=o}e=e&255;if(e&64){v[c+2|0]=1;x[31785]=0;j=R(200,g|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break c}v[d+104|0]=j;v[d+12|0]=64;n=c,o=y[Ub(d+104|0,d+12|0)|0],v[n+4|0]=o}if(!(e&32)){continue}x[31785]=0;O(201,d+104|0,g|0);e=x[31785];x[31785]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{if((e|0)!=1){e=y[Ic(d+104|0)|0];v[c+5|0]=e;switch(y[d+104|0]-1|0){case 71:break s;case 70:break t;case 69:break u;case 60:break v;case 59:break w;case 52:break x;case 51:break y;case 50:break z;case 49:break A;case 42:break B;case 41:break C;case 40:break D;case 39:break E;case 30:break F;case 29:break G;case 22:break H;case 21:break I;case 20:break J;case 19:break K;case 16:break L;case 15:break M;case 14:break N;case 13:break O;case 12:break P;case 11:break Q;case 10:break R;case 9:break S;case 3:break T;case 2:break U;case 1:break V;case 0:break W;default:break r}}break c}v[c+3|0]=11;v[c+5|0]=e<<4|15;continue}v[c+3|0]=11;v[c+5|0]=e<<4;continue}v[c+3|0]=11;v[c+5|0]=e|240;continue}v[c+3|0]=11;v[c+5|0]=e&15;continue}v[c+3|0]=2;v[c+5|0]=e|240;continue}v[c+3|0]=2;continue}v[c+3|0]=3;v[c+5|0]=e|240;continue}v[c+3|0]=3;continue}v[c+3|0]=4;continue}v[c+3|0]=20;v[c+5|0]=e|16;continue}v[c+3|0]=6;v[c+5|0]=e<<4;continue}v[c+3|0]=6;v[c+5|0]=e&15;continue}v[c+3|0]=5;continue}v[c+3|0]=20;v[c+5|0]=e|48;continue}v[c+3|0]=7;v[c+5|0]=e<<4;continue}v[c+3|0]=7;v[c+5|0]=e&15;continue}v[c+3|0]=8;continue}v[c+3|0]=20;v[c+5|0]=e|64;continue}v[c+3|0]=10;x[31785]=0;e=R(200,g|0)|0;j=x[31785];x[31785]=0;if((j|0)!=1){v[c+5|0]=e;x[31785]=0;P(186,g|0,1)|0;c=x[31785];x[31785]=0;if((c|0)!=1){continue}}break c}v[c+3|0]=15;v[c+5|0]=e&15;continue}v[c+3|0]=20;v[c+5|0]=e|192;continue}v[c+3|0]=20;v[c+5|0]=e|208;continue}v[c+3|0]=12;continue}v[c+3|0]=14;continue}v[c+3|0]=20;v[c+5|0]=e|176;continue}v[c+3|0]=20;v[c+5|0]=e|224;continue}v[c+3|0]=16;continue}v[c+3|0]=17;continue}v[c+3|0]=1;continue}v[c+3|0]=20;v[c+5|0]=e&15|32;continue}v[c+3|0]=20;v[c+5|0]=e&15|128;continue}v[c+3|0]=0;continue}break}if((c|0)==64){break o}we(Vb(x[k>>2],f),Vh(Ue(Le(d+104|0,14,0),c-1|0)))}ub(g)}f=f+1|0;continue}break}break c}c=y[d+224|0]|y[d+225|0]<<8|(y[d+226|0]<<16|y[d+227|0]<<24);if(!c){break d}bd(b,c);MD(a+1298332|0,b,eh(b),4)}fb=d+272|0;return i|0}a=N()|0;break a}a=N()|0}ub(g);Q(a|0);p()}function Uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-48|0;fb=g;d=x[b>>2];x[31785]=0;f=R(175,d|0)|0;d=x[31785];x[31785]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(f){h=Nb(g+36|0);x[31785]=0;e=(c|0)!=0;f=U(869,h|0,b|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}d=2;g:{h:{i:{j:{if(f){break j}x[31785]=0;f=U(870,h|0,b|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}d=3;if(f){break j}x[31785]=0;f=U(871,h|0,b|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}d=4;if(f){break j}f=0;x[31785]=0;i=U(872,h|0,b|0,e|0)|0;e=x[31785];x[31785]=0;d=1;if((e|0)==1){break e}if(!i){break i}}if(!c){d=1;f=0;break h}f=x[h>>2];if(!mc(f,x[h+4>>2])){Nw(b,f+12|0)}f=d}d=30160;k:{while(1){e=d;if((e|0)!=30724){i=x[e+8>>2];k=(i>>1)+a|0;d=x[e+4>>2];d=i&1?x[x[k>>2]+d>>2]:d;x[31785]=0;i=U(d|0,k|0,b|0,c|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break c}d=e+12|0;if(!i){continue}break k}break}x[a+480180>>2]=0;x[a+480184>>2]=0}if(!c){d=(e|0)!=30724;f=0;break h}if(!(x[a+480184>>2]|!f)){x[a+480184>>2]=f}x[31785]=0;f=1;O(808,a+1298264|0,1);e=x[31785];x[31785]=0;d=1;if((e|0)==1){break g}}RR(h);if(f){break f}break a}break c}x[31785]=0;O(249,a|0,0);d=x[31785];x[31785]=0;if((d|0)==1){break d}x[31785]=0;O(808,a+1298264|0,1);d=x[31785];x[31785]=0;if((d|0)==1){break d}x[a+1074304>>2]=19988519;x[a+1298408>>2]=0}d=0;while(1){if((d|0)==127){d=1;while(1){f=d&65535;if(f>>>0>z[a+480190>>1]){f=0;k=a+480180|0;d=0;l:{while(1){e=d&65535;if(e>>>0>z[a+480192>>1]){m:{w[a+480192>>1]=f;d=a+480204|0;if(A[a+480204>>2]>=1e4){break m}x[d>>2]=125e4;break l}}else{e=x[((e<<2)+a|0)+900380>>2];if(e){i=x[k>>2];vc(e,65536);vc(e+4|0,64);vc(e+8|0,256);Pf(e+28|0,16384);If(e+30|0,128);If(e+31|0,17);if(y[e+16|0]>=4){v[e+16|0]=0}if(y[e+17|0]>=5){v[e+17|0]=0}if(y[e+18|0]>=3){v[e+18|0]=0}If(e+19|0,64);If(e+20|0,100);j=224;f=v[e+26|0];n:{if((f|0)>=-32){j=32;if((f|0)<33){break n}}v[e+26|0]=j}If(e+23|0,64);If(e+24|0,64);TB(e+48|0,64);TB(e+68|0,64);TB(e+88|0,(i|0)==4096?255:64);f=e+108|0;j=0;while(1){if((j|0)==128){if(!kp(y[e+14|0])){v[e+14|0]=5}if(y[e+34|0]>=251){v[e+34|0]=0}}else{o:{if(y[xb(f,j)|0]){if(y[xb(f,j)|0]<121){break o}}n=xb(f,j),o=j+1|0,v[n|0]=o}j=j+1|0;continue}break}f=d}d=d+1|0;continue}break}vc(d,65535e4)}if(!x[a+480196>>2]){x[a+480196>>2]=6}e=a+480216|0;f=a+480220|0;d=x[a+480216>>2];if(!(d|y[a+480224|0]!=2)){x[e>>2]=1;d=1}if(A[a+480220>>2]<d>>>0){x[f>>2]=d}vc(e,65536);vc(f,65536);vc(a+480200|0,256);p:{f=a+480248|0;if(!mc(x[f>>2],x[a+480252>>2])){d=x[e>>2];x[31785]=0;O(873,f|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break p}}x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];d=x[a+480220>>2];f=a+1074408|0;x[f>>2]=x[a+480216>>2];x[f+4>>2]=d;x[a+1074456>>2]=x[a+480200>>2];fB(a+1074376|0);d=a+1074446|0;w[d>>1]=0;w[d+2>>1]=0;w[d+4>>1]=0;w[d+6>>1]=65535;x[a+1074392>>2]=-2;d=a+1074384|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074380>>2]=0;d=a+1074424|0;x[d>>2]=0;x[d+4>>2]=0;x[a+1074432>>2]=0;d=a+1074396|0;x[d>>2]=0;x[d+4>>2]=0;if(on(x[a+480180>>2])){x[31785]=0;P(270,a+1074312|0,7)|0;d=x[31785];x[31785]=0;if((d|0)==1){break p}}w[a+480276>>1]=0;oq(a);n=g,o=vb(x[a+484360>>2]),x[n+36>>2]=o;f=vb(x[a+484364>>2]);q:{while(1){r:{e=x[g+36>>2];if(!Ib(e,f)){if(x[a+480180>>2]){break r}d=0;break a}x[31785]=0;W(874,e|0);d=x[31785];x[31785]=0;if((d|0)==1){break q}if(Xc(x[e>>2],x[e+4>>2])>>>0<=z[e+28>>1]){_e(e,0)}av(g+36|0);continue}break}iu(a+8|0,dr(a));if(x[a+1074308>>2]){x[31785]=0;W(875,a|0);d=x[31785];x[31785]=0;if((d|0)==1){break p}}m=Nb(g+36|0);s:{t:{if((c&12)!=12){break t}k=a+906300|0;i=a+1298472|0;d=0;u:{v:{w:{x:{y:{z:{while(1){if((d|0)==250){break t}A:{l=rd(k,d);e=l+16|0;B:{if(!Pi(x[e>>2],x[l+20>>2])){break B}x[31785]=0;O(876,l|0,a|0);c=x[31785];x[31785]=0;C:{if((c|0)!=1){h=x[l>>2];if(!h){break C}f=x[l+148>>2];c=x[x[h>>2]+56>>2];x[31785]=0;O(c|0,h|0,f|0);c=x[31785];x[31785]=0;if((c|0)!=1){break B}}a=N()|0;break s}j=vb(x[m>>2]);f=vb(x[m+4>>2]);h=fb-16|0;fb=h;x[h+12>>2]=j;while(1){D:{if(!Ib(j,f)){break D}c=x[j>>2];if((y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24))==(y[l+20|0]|y[l+21|0]<<8|(y[l+22|0]<<16|y[l+23|0]<<24))){c=(y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24))==(y[l+16|0]|y[l+17|0]<<8|(y[l+18|0]<<16|y[l+19|0]<<24))}else{c=0}if(c){break D}j=x[Pe(h+12|0)>>2];continue}break}fb=h+16|0;if(Ib(j,vb(x[m+4>>2]))){break B}x[31785]=0;x[g+24>>2]=e;O(877,m|0,g+24|0);c=x[31785];x[31785]=0;if((c|0)==1){break A}x[31785]=0;f=P(1,g+12|0,18521)|0;c=x[31785];x[31785]=0;if((c|0)==1){break z}x[31785]=0;O(878,g|0,l|0);c=x[31785];x[31785]=0;if((c|0)==1){break y}x[31785]=0;S(2,g+24|0,f|0,g|0);c=x[31785];x[31785]=0;if((c|0)==1){break x}c=x[i>>2];x[31785]=0;S(389,c|0,2,g+24|0);c=x[31785];x[31785]=0;if((c|0)==1){break w}tb(g+24|0);tb(g);tb(f)}d=d+1|0;continue}break}a=N()|0;break s}a=N()|0;break s}a=N()|0;break u}a=N()|0;break v}a=N()|0;tb(g+24|0)}tb(g)}tb(f);break s}c=y[a+1074368|0];x[31785]=0;O(879,a|0,c|0);a=x[31785];x[31785]=0;d=1;if((a|0)!=1){sc(m);break a}a=N()|0}sc(m);break b}a=N()|0;break b}a=N()|0;break b}i=D(f,104)+a|0;k=i+484380|0;E:{if(ge(x[k>>2],x[i+484400>>2])){Mj(k,a);break E}e=i+484414|0;f=z[e>>1];if(f&16384){break E}x[k>>2]=0;x[k+4>>2]=0;x[k+16>>2]=0;x[k+8>>2]=0;x[k+12>>2]=0;w[e>>1]=f&65505}f=i+484412|0;if(z[f>>1]>=65){w[f>>1]=64}F:{G:{if(!(y[i+484415|0]&2)){break G}if(!Ak(x[a+1298300>>2])){break G}x[31785]=0;W(880,a|0);f=x[31785];x[31785]=0;if((f|0)==1){break F}}d=d+1|0;continue}break}a=N()|0;break b}e=(d<<5)+a|0;Pf(e+480286|0,64);f=e+480284|0;if(z[f>>1]>=257){w[f>>1]=128}f=e+480288|0;if(y[f|0]>=251){v[f|0]=0}Jo((D(d,872)+a|0)+1074992|0,a,d&65535,134217728);d=d+1|0;continue}}break c}a=N()|0;break b}a=N()|0;RR(h)}ub(b);Q(a|0);p()}ub(b);fb=g+48|0;return d|0}function zu(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;n=fb-16|0;fb=n;x[n+12>>2]=c;a:{if((c|0)<=0){break a}h=x[b+104>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{i=x[b+656>>2];k:{if(!(!i|x[a+480180>>2]!=16777216)){k=x[i+44>>2]!=0;break k}if(!i){break j}}if((c|0)>128){break i}l=c-1|0;m=z[_b(i+236|0,l)>>1];l:{if((m-1&65535)>>>0<=3998){h=(D(m,104)+a|0)+484380|0;break l}if(!Pb(a+1074312|0,43)){break l}if(!Gj(x[b+656>>2])){break a}}m=y[xb(i+108|0,l)|0];x[n+12>>2]=m;if(m>>>0<=120){break h}c=m;break i}m=c;l=0;if(c>>>0<121){break g}}m:{if(!(x[a+480180>>2]&16777248?(c|0)!=255:0)){yo(a,b);if(d){break m}if(!Pb(a+1074312|0,100)|!(y[a+480208|0]&4)|!y[b+789|0]){break m}x[b+88>>2]=x[b+88>>2]&-6145;break m}if(!z[a+480192>>1]){break m}x[b+88>>2]=x[b+88>>2]|4096}n:{if((c|0)!=254){break n}c=x[b+88>>2];d=a+480180|0;if(!(!(c&512)|x[d>>2]!=2)){x[b+88>>2]=c|2048;break n}x[b+88>>2]=c|2101248;o:{if(x[d>>2]&16777248){if(!z[a+480192>>1]){break o}if(Pb(a+1074312|0,50)){break o}}x[b+688>>2]=0}if(Pb(a+1074312|0,50)){x[b+8>>2]=0;x[b+12>>2]=0}x[b+696>>2]=0}if(!Pb(a+1074312|0,20)){break a}v[b+797|0]=0;v[b+802|0]=0;break a}l=0;if(!k){break g}if(d){l=y[b+797|0];if(l){break f}}x[b+708>>2]=0;l=1}if(d){break e}if(!(!(x[a+480180>>2]&1048588)|!h)){w[b+770>>1]=v[h+36|0];w[b+772>>1]=v[h+37|0];break d}if(h){break d}h=0;q=1;break c}l=D((x[x[i+44>>2]+36>>2]<<16>>16)+1|0,(m<<16>>16)-(l<<16>>16)|0)-x[b+852>>2]|0;x[b+708>>2]=l;x[b+852>>2]=0-l;l=1}q=!h;k=1;if(Pi(x[b+8>>2],x[b+12>>2])){break b}p:{k=a+1074312|0;if(!Pb(k,54)){break p}if(Gj(x[b+656>>2])){if(!Pb(k,117)){break p}}x[b+700>>2]=0;break a}k=(Pb(k,39)^-1)&d;break b}if(!Pb(a+1074312|0,24)){break c}x[b+704>>2]=x[h+24>>2]}k=0}q:{if(on(x[a+480180>>2])){x[n+12>>2]=w[b+770>>1]+m;Ee(n+12|0,12,131);break q}sX(n+12|0)}j=a+1074312|0;r:{if(Pb(j,34)){d=bm(c);break r}d=x[n+12>>2]}v[b+797|0]=d;v[b+851|0]=y[b+851|0]&183|64;if(!(x[a+480180>>2]&16777250?0:k)){v[b+803|0]=0}p=vh(a,x[n+12>>2],w[b+772>>1],x[b+704>>2]);v[b+831|0]=0;if(Pb(j,48)){SS(a,b,i,h)}s:{if(!Pb(j,115)|!i){break s}d=y[i+26|0];if(!d){break s}if(!z[b+784>>1]){w[b+784>>1]=z[b+692>>1]+1}RS(b+692|0,c,d,y[i+27|0])}t:{if(k|e^1){break t}x[b+776>>2]=0;x[b+780>>2]=0;if(!i){break t}if(Pb(j,29)){v[b+798|0]=y[i+16|0]}if(!(y[i+60|0]&8)){Fj(b+724|0)}if(!(y[i+80|0]&8)){Fj(b+732|0)}if(!(y[i+100|0]&8)){Fj(b+740|0)}if(y[i+20|0]){c=((D(wu(xo(a)),y[i+20|0])<<16>>16)/64|0)+1<<16>>16;u:{if(Pb(j,28)){d=x[b+752>>2];break u}d=(x[b+688>>2]+1|0)/2|0}w[b+776>>1]=(D(d,c)|0)/199}v:{if(!y[i+19|0]){break v}r=b,s=(D(wu(xo(a)),y[i+19|0])<<16>>16)/32|0,w[r+778>>1]=s;if(Pb(j,28)|z[b+784>>1]){break v}w[b+784>>1]=z[b+692>>1]+1}m=y[i+23|0];if(m){d=wu(xo(a));c=y[b+837|0];v[b+796|0]=c+1;w[b+780>>1]=(D((D(m,d+1|0)<<16>>16)/128<<16>>16,c)+1|0)/128}m=y[i+24|0];if(!m){break t}d=wu(xo(a));c=y[b+838|0];v[b+795|0]=c+1;w[b+782>>1]=(D(c,(D(m,d+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(q){break a}w:{x:{if(!p){d=0;break x}if(!(k&x[b+700>>2]!=0)){x[b+700>>2]=p}y:{z:{if(!l){if(!k){if(Pb(j,69)){break z}if(Pb(j,46)|x[a+480180>>2]==1){break z}}x[b+708>>2]=p;v[b+851|0]=y[b+851|0]&239}if(!k){break z}if(x[b+76>>2]|y[a+480180|0]&2){break y}}x[b+104>>2]=h;c=x[h>>2];x[b+84>>2]=c;x[b+76>>2]=c;x[b+80>>2]=0;x[b>>2]=0;x[b+4>>2]=0;A:{B:{C:{if(!(y[a+480210|0]&32)){if(!Pb(j,96)|y[b+789|0]){break B}o=x[b>>2];c=x[b+76>>2];break C}if(y[b+789|0]){break B}}x[n+8>>2]=c-1;c=x[Gb(b+660|0,n+8|0)>>2];x[b>>2]=o;x[b+4>>2]=c;break A}x[b+660>>2]=0}c=z[h+34>>1];o=c&1023;d=o|x[b+88>>2]&-525056;x[b+88>>2]=d;D:{E:{if(c&8){x[b+80>>2]=x[h+12>>2];c=x[h+16>>2];x[b+88>>2]=(o&16?d|4:d&-524295)|2;x[b+84>>2]=c;if(A[b+76>>2]>c>>>0){break E}break D}if(!(o&2)){break D}x[b+80>>2]=x[h+4>>2];c=x[h+8>>2];x[b+84>>2]=c;if(A[b+76>>2]<=c>>>0){break D}}x[b+76>>2]=c}F:{if(!(r=0,s=Pb(j,83),t=x[b+80>>2],t?r:s)){c=x[b+76>>2];break F}c=x[h>>2];x[b+84>>2]=c;x[b+76>>2]=c}d=x[b+88>>2];if(!(!(d&128)|!c)){x[b+4>>2]=c-1;x[b+88>>2]=d|128}G:{if(y[b+822|0]>3){break G}c=Pb(j,21);o=x[a+480180>>2];H:{I:{if(!(c|!(o&16777248))){d=16;if(y[a+480208|0]&4){break I}break H}d=32;if((o|0)==16){break H}}if(o&67633152){break G}d=0}v[b+819|0]=d}if(Pb(j,21)|y[b+825|0]>3){break y}v[b+820|0]=0}d=x[b>>2];if(A[b+76>>2]<=A[b+4>>2]){c=x[b+80>>2];x[b>>2]=d;x[b+4>>2]=c}d=0;if(!k){break x}d=1;if(!(x[a+480180>>2]&17301536)|(x[b+696>>2]?0:y[b+89|0]&16)){break x}c=1;if(!(y[a+480208|0]&8)){break w}c=1;if(!y[b+789|0]){break w}}if(!(x[b+696>>2]|(!(x[a+480180>>2]&17301536)|!(y[b+89|0]&16)))){Wm(b);if(!Pb(j,21)){v[b+818|0]=0;x[b+756>>2]=0}x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}J:{if(!d){h=y[b+789|0];break J}h=y[b+789|0];if(!(y[a+480208|0]&8)){break J}c=1;if(!(h&255)){break w}}if(!(h&255?0:x[a+480180>>2]&1048580)){x[b+696>>2]=65536;x[b+88>>2]=x[b+88>>2]&-4097}c=d}d=c;K:{if(!(!d|!Pb(j,40)|(y[b+789|0]?y[a+480208|0]&8:0))){c=x[b+88>>2]&-4194305;break K}c=x[b+88>>2]&-4196353}x[b+88>>2]=c;L:{if(d){break L}w[b+842>>1]=65535;v[b+851|0]=y[b+851|0]|2;x[b+88>>2]=c&-6324225|2097152;M:{if(Pb(j,23)){break M}if(Pb(j,22)){break M}if(Pb(j,52)){break M}if(Pb(j,71)){break M}v[b+839|0]=0;v[b+808|0]=0}if(e){v[b+818|0]=0;x[b+756>>2]=0}x[b+20>>2]=0;x[b+24>>2]=0;if(!(y[b+89|0]&2)){break L}if(!xd(x[a+1298300>>2])|(g|0)==65535){break L}if(Pb(j,111)){yk(x[a+1298300>>2],g);break L}if(!Pb(j,110)){break L}FB(x[a+1298300>>2],g,0,1,0)}c=x[b+88>>2];N:{O:{P:{if(f){x[b+88>>2]=c&-1025;break P}if(!(c&1024)){break P}if(y[a+24618|0]&16){break O}}a=x[b+104>>2];if(!(!a|!(y[a+35|0]&4)|f)){break O}a=x[b+656>>2];if(!a|(!(y[a+15|0]&2)|f)){break N}}x[b+700>>2]=0}if(d){break a}w[b+136>>1]=0;x[b+132>>2]=4194304;x[b+112>>2]=0;x[b+116>>2]=0}fb=n+16|0}function U4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=td(a,c);x[a>>2]=112216;f=gJ(a+8|0);x[31785]=0;e=P(73,a+152|0,b|0)|0;b=x[31785];x[31785]=0;a:{b:{c:{d:{e:{if((b|0)!=1){x[31785]=0;b=ca(107)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}b=x[b>>2];c=0;x[31785]=0;b=P(1310,f|0,b+8|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}while(1){f:{d=x[b>>2];if(oc(d,x[a+12>>2])>>>0<=c>>>0){x[31785]=0;c=R(859,12)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break f}break e}d=x[wb(d,c)>>2];if(d){cl(d)}c=c+1|0;continue}break}x[31785]=0;b=U(1311,c|0,e|0,0)|0;d=x[31785];x[31785]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((d|0)!=1){x[31785]=0;O(1312,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,12)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=U(1313,c|0,e|0,0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break t}x[31785]=0;O(1314,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,20)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=U(1315,c|0,e|0,0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break s}x[31785]=0;O(1316,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,12)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=U(1317,c|0,e|0,0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break r}x[31785]=0;O(1318,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=R(859,8)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}b=td(b,0);x[b>>2]=114164;x[b>>2]=119776;x[31785]=0;O(1319,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,12)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=P(1320,c|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break q}x[31785]=0;O(1321,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=R(859,8)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}b=td(b,0);x[b>>2]=114312;x[b>>2]=119984;x[31785]=0;O(1322,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=R(859,8)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}b=td(b,0);x[b>>2]=114544;x[b>>2]=120088;x[31785]=0;O(1323,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=R(859,8)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}b=td(b,0);x[b>>2]=114428;x[b>>2]=120192;x[31785]=0;O(1324,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=R(859,8)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}b=td(b,0);x[b>>2]=114660;x[b>>2]=120296;x[31785]=0;O(1325,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,24)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=U(1326,c|0,e|0,0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break p}x[31785]=0;O(1327,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,28)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=U(1328,c|0,e|0,0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break o}x[31785]=0;O(1329,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,72)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=P(1330,c|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break n}x[31785]=0;O(1331,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,72)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=P(1332,c|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break m}x[31785]=0;O(1333,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,76)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=P(1334,c|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break l}x[31785]=0;O(1335,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,76)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=P(1336,c|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break k}x[31785]=0;O(1337,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,544)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=P(1338,c|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break j}x[31785]=0;O(1339,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,544)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=P(1340,c|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break i}x[31785]=0;O(1341,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,12)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=P(1342,c|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break h}x[31785]=0;O(1343,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;c=R(859,12)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=P(1344,c|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break g}x[31785]=0;O(1345,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=R(859,8)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}b=RI(b,0);x[b>>2]=119624;x[31785]=0;O(1346,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;b=R(859,8)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}b=QI(b,0);x[b>>2]=119700;x[31785]=0;O(1347,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}return a|0}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}b=T(0)|0;Db(c);break d}a=N()|0;break c}b=T(0)|0}Y(b|0)|0;c=0;while(1){b=x[f>>2];if(oc(b,x[a+12>>2])>>>0<=c>>>0){x[31785]=0;X(87);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}tb(e);break c}b=x[wb(b,c)>>2];if(b){rm(b)}c=c+1|0;continue}}Yx(f);Q(a|0);p()}T(0)|0;Rb()}p()}function l9(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0,E=0;n=fb-560|0;fb=n;x[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){u=1;C=5316;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){u=1;C=5319;break a}u=e&1;C=u?5322:5317;E=!u}b:{if((g&2146435072)==2146435072){g=u+3|0;Rf(a,32,c,g,e&-65537);Ff(a,C,u);d=f&32;Ff(a,b!=b?d?9988:13892:d?11147:14263,3);Rf(a,32,c,g,e^8192);p=(c|0)<(g|0)?g:c;break b}z=n+16|0;c:{d:{e:{b=mL(b,n+44|0);b=b+b;if(b!=0){g=x[n+44>>2];x[n+44>>2]=g-1;A=f|32;if((A|0)!=97){break e}break c}A=f|32;if((A|0)==97){break c}l=x[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;x[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}s=(n+48|0)+((l|0)>=0?288:0)|0;h=s;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}x[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;i=s;break f}i=s;d=l;while(1){q=(d|0)>=29?29:d;g=h-4|0;g:{if(i>>>0>g>>>0){break g}d=0;while(1){k=x[g>>2];B=d;d=q&31;if((q&63)>>>0>=32){p=k<<d;d=0}else{p=(1<<d)-1&k>>>32-d;d=k<<d}B=B+d|0;k=p+r|0;d=uua(B,d>>>0>B>>>0?k+1|0:k,1e9,0);k=sua(d,hb,-1e9,0)+B|0;x[g>>2]=k;g=g-4|0;if(i>>>0<=g>>>0){continue}break}if(!d){break g}i=i-4|0;x[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!x[h>>2]){continue}}break}d=x[n+44>>2]-q|0;x[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){w=((m+25>>>0)/9|0)+1|0;r=(A|0)==102;while(1){d=0-d|0;p=(d|0)>=9?9:d;h:{if(g>>>0<=i>>>0){h=x[i>>2];break h}q=1e9>>>p|0;k=-1<<p^-1;d=0;h=i;while(1){B=d;d=x[h>>2];x[h>>2]=B+(d>>>p|0);d=D(q,d&k);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=x[i>>2];if(!d){break h}x[g>>2]=d;g=g+4|0}d=p+x[n+44>>2]|0;x[n+44>>2]=d;i=(!h<<2)+i|0;h=r?s:i;g=g-h>>2>(w|0)?h+(w<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=i>>>0){break i}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break i}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=(m-((A|0)!=102?d:0)|0)-((A|0)==103&(m|0)!=0)|0;if((h|0)<(D(g-s>>2,9)-9|0)){q=h+9216|0;k=(q|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(k<<2)|0)-4048|0;h=10;p=q+D(k,-9)|0;if((p|0)<=7){while(1){h=D(h,10);p=p+1|0;if((p|0)!=8){continue}break}}q=x[l>>2];w=(q>>>0)/(h>>>0)|0;r=D(w,h);k=l+4|0;j:{if((q|0)==(r|0)&(k|0)==(g|0)){break j}q=q-r|0;k:{if(!(w&1)){b=9007199254740992;if(!(v[l-4|0]&1)|((h|0)!=1e9|i>>>0>=l>>>0)){break k}}b=9007199254740994}t=(g|0)==(k|0)?1:1.5;k=h>>>1|0;t=k>>>0>q>>>0?.5:(k|0)==(q|0)?t:1.5;if(!(y[C|0]!=45|E)){t=-t;b=-b}x[l>>2]=r;if(b+t==b){break j}d=h+r|0;x[l>>2]=d;if(d>>>0>=1e9){while(1){x[l>>2]=0;l=l-4|0;if(l>>>0<i>>>0){i=i-4|0;x[i>>2]=0}d=x[l>>2]+1|0;x[l>>2]=d;if(d>>>0>999999999){continue}break}}d=D(s-i>>2,9);h=10;k=x[i>>2];if(k>>>0<10){break j}while(1){d=d+1|0;h=D(h,10);if(k>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){k=g;q=g>>>0<=i>>>0;if(!q){g=k-4|0;if(!x[g>>2]){continue}}break}l:{if((A|0)!=103){l=e&8;break l}h=m?m:1;g=(h|0)>(d|0)&(d|0)>-5;m=(g?d^-1:-1)+h|0;f=(g?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(q){break m}l=x[k-4>>2];if(!l){break m}p=10;g=0;if((l>>>0)%10|0){break m}while(1){h=g;g=g+1|0;p=D(p,10);if(!((l>>>0)%(p>>>0)|0)){continue}break}g=h^-1}h=D(k-s>>2,9);if((f&-33)==70){l=0;g=(g+h|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+h|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}p=-1;q=l|m;if(((q?2147483645:2147483646)|0)<(m|0)){break b}r=(((q|0)!=0)+m|0)+1|0;h=f&-33;n:{if((h|0)==70){if((r^2147483647)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=co((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;v[g|0]=48;if((z-g|0)<2){continue}break}}w=g-2|0;v[w|0]=f;v[g-1|0]=(d|0)<0?45:43;g=z-w|0;if((g|0)>(r^2147483647)){break b}}d=g+r|0;if((d|0)>(u^2147483647)){break b}r=d+u|0;Rf(a,32,c,r,e);Ff(a,C,u);Rf(a,48,c,r,e^65536);o:{p:{q:{if((h|0)==70){f=n+16|0;d=f|8;l=f|9;h=i>>>0>s>>>0?s:i;i=h;while(1){g=co(x[i>>2],0,l);r:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}v[n+24|0]=48;g=d}Ff(a,g,l-g|0);i=i+4|0;if(s>>>0>=i>>>0){continue}break}if(q){Ff(a,16978,1)}if((m|0)<=0|i>>>0>=k>>>0){break q}while(1){g=co(x[i>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}Ff(a,g,(m|0)>=9?9:m);g=m-9|0;i=i+4|0;if(k>>>0<=i>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}s=i>>>0<k>>>0?k:i+4|0;f=n+16|0;d=f|8;k=f|9;h=i;while(1){g=co(x[h>>2],0,k);if((k|0)==(g|0)){v[n+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;v[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}Ff(a,g,1);g=g+1|0;if(!(l|m)){break t}Ff(a,16978,1)}f=k-g|0;Ff(a,g,(f|0)>(m|0)?m:f);m=m-f|0;h=h+4|0;if(s>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}Rf(a,48,m+18|0,18,0);Ff(a,w,z-w|0);break o}g=m}Rf(a,48,g+9|0,9,0)}Rf(a,32,c,r,e^8192);p=(c|0)<(r|0)?r:c;break b}l=(f<<26>>31&9)+C|0;u:{if(d>>>0>11){break u}g=12-d|0;t=16;while(1){t=t*16;g=g-1|0;if(g){continue}break}if(y[l|0]==45){b=-(t+(-b-t));break u}b=b+t-t}s=u|2;i=f&32;h=x[n+44>>2];g=h>>31;g=co((g^h)-g|0,0,z);if((z|0)==(g|0)){v[n+15|0]=48;g=n+15|0}m=g-2|0;v[m|0]=f+15;v[g-1|0]=(h|0)<0?45:43;g=e&8;h=n+16|0;while(1){f=h;if(F(b)<2147483648){k=~~b}else{k=-2147483648}v[h|0]=i|y[k+93728|0];b=(b-+(k|0))*16;h=f+1|0;if(!(!(g|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){v[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}p=-1;g=z-m|0;f=g+s|0;if((2147483645-f|0)<(d|0)){break b}k=f;f=n+16|0;i=h-f|0;d=d?(i-2|0)<(d|0)?d+2|0:i:i;h=k+d|0;Rf(a,32,c,h,e);Ff(a,l,s);Rf(a,48,c,h,e^65536);Ff(a,f,i);Rf(a,48,d-i|0,0,0);Ff(a,m,g);Rf(a,32,c,h,e^8192);p=(c|0)<(h|0)?h:c}fb=n+560|0;return p|0}function Asa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;v[j+127|0]=d;a:{if(!c|(e|0)<0&c>>>0>=176){break a}v[b+5|0]=d;v[j+8|0]=15;l=j+127|0;p=j+8|0;k=p;o=y[Ub(l,k)|0];v[j+8|0]=14;l=y[Ub(l,k)|0];x[j+8>>2]=d+31>>>5;x[j+120>>2]=14;r=j+120|0;n=x[pd(k,r)>>2];x[j+8>>2]=d+127>>>7;x[j+120>>2]=14;q=c&15;k=q<<8|d;p=pd(p,r);b:{switch((c>>>4|0)-2|0){case 0:v[b+2|0]=1;x[j+8>>2]=k>>>2;x[j+120>>2]=64;s=b,t=x[pd(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 1:v[b+2|0]=1;if(!k){v[b+4|0]=0;break a}s=j,t=tD(k)>>>2|0,x[s+8>>2]=t;x[j+120>>2]=64;s=b,t=x[pd(j+8|0,j+120|0)>>2],v[s+4|0]=t;break a;case 2:v[b+3|0]=9;v[b+5|0]=k>>>4;break a;case 3:v[b+3|0]=23;v[b+5|0]=k+1>>>5;break a;case 4:v[b+3|0]=23;if(k){a=Zg(tD(k)>>>5|0)}else{a=0}v[b+5|0]=a;break a;case 5:v[b+5|0]=q;v[b+3|0]=15;break a;case 6:v[b+3|0]=15;if((e|0)>=0){if(y[b+2|0]){break a}v[b+2|0]=2;s=b,t=Fc(((q<<6|7)>>>0)/15|0,0),v[s+4|0]=t;break a}v[b+2|0]=1;v[b+5|0]=q;v[b+4|0]=d+3>>>2;break a;case 7:v[b+3|0]=10;c:{if((e|0)>5){break c}if(!k){v[b+5|0]=1;break a}c=br(a,f,g);if(!c){break c}a=ri(a,c);c=z[a+34>>1];if(c&1){k=k>>>1|0;x[j+120>>2]=k}if(!(c&2)){break c}c=x[a>>2];if(c>>>0>=k<<8>>>0){break c}x[j+120>>2]=x[a+4>>2]+8>>>8;vc(j+120|0,c-1>>>8|0);k=x[j+120>>2]}v[b+5|0]=k;if(y[b+2|0]|k>>>0<256){break a}v[b+2|0]=15;x[j+116>>2]=k>>>8;Kv(j+8|0);x[j+112>>2]=9;s=b,t=x[Gb(j+116|0,j+112|0)>>2],v[s+4|0]=t;break a;default:break b}}k=x[p>>2];d:{switch(c-160|0){default:e:{switch(c-1|0){case 0:case 1:case 2:case 3:case 6:case 10:case 14:Mf(b,c,d);f:{switch(y[b+3|0]-16|0){case 1:x[h>>2]=D(y[b+5|0],1e4);break a;case 0:break f;default:break a}}a=y[b+5|0];if(!a){break a}x[i>>2]=a;break a;case 4:v[b+3|0]=4;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=8;break a;case 5:v[b+3|0]=5;if(y[b+2|0]){break a}v[b+4|0]=0;v[b+2|0]=11;break a;case 7:if(!zd(y[b|0])|!d){break a}v[b+3|0]=35;v[b+5|0]=(d>>>1&120|128)-(d<<3&120);e=a+480192|0;if(z[e>>1]){break a}w[j+8>>1]=255;c=z[Mc(a+480190|0,j+8|0)>>1];w[e>>1]=c;b=1;while(1){d=b&65535;if(d>>>0>(c&65535)>>>0){break a}c=jE(a,d,d);if(c){v[c+33|0]=2;d=(d<<5)+a|0;f=d+946304|0;g=x[f+4>>2];x[c+492>>2]=x[f>>2];x[c+496>>2]=g;f=d+946312|0;g=x[f+4>>2];x[c+500>>2]=x[f>>2];x[c+504>>2]=g;f=d+946320|0;g=x[f+4>>2];x[c+508>>2]=x[f>>2];x[c+512>>2]=g;d=d+946328|0;f=x[d+4>>2];x[c+516>>2]=x[d>>2];x[c+520>>2]=f;gk(c,127,1);fk(c,0,1)}b=b+1|0;c=z[e>>1];continue};case 8:v[b+3|0]=19;v[b+5|0]=o|208;break a;case 9:v[b+3|0]=25;break a;case 11:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|64;break a;case 12:v[b+3|0]=14;break a;case 13:if(d>>>0>2){break a}v[b+3|0]=19;v[b+5|0]=d|112;break a;case 15:v[b+3|0]=1;break a;case 16:case 17:v[b+3|0]=19;v[b+5|0]=l|c<<4;break a;case 18:v[b+3|0]=15;break a;case 19:v[b+3|0]=11;v[b+5|0]=l<<4;break a;case 20:v[b+5|0]=l;v[b+3|0]=11;break a;case 23:v[b+3|0]=6;v[b+5|0]=l<<4;break a;case 24:v[b+5|0]=l;v[b+3|0]=6;break a;case 27:v[b+3|0]=7;v[b+5|0]=l<<4;break a;case 28:break e;default:break a}}v[b+5|0]=l;v[b+3|0]=7;break a;case 0:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4;break a;case 1:if(!d){break a}v[b+5|0]=n;v[b+3|0]=24;break a;case 4:v[b+3|0]=11;v[b+5|0]=l<<4|15;break a;case 5:v[b+3|0]=11;v[b+5|0]=l|240;break a;case 6:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n<<4|15;break a;case 7:if(!d){break a}v[b+3|0]=24;v[b+5|0]=n|240;break a;case 8:if(!d){break a}v[b+3|0]=16;x[i>>2]=d;break a;case 9:if((e|0)>5){break a}a=x[h>>2];if(a>>>0<1e4){break a}v[b+3|0]=17;m=122925/(+(a>>>0)/1e4)+ +((d<<1)-256|0);s=b,t=Zl(245850/(m+m)),v[s+5|0]=t;break a;case 10:v[b+3|0]=19;v[b+5|0]=o|224;break a;case 12:v[b+3|0]=28;v[b+5|0]=o|16;break a;case 13:v[b+3|0]=28;v[b+5|0]=o|32;break a;case 14:v[b+3|0]=29;v[b+5|0]=l<<3&240;break a;case 15:v[b+3|0]=29;v[b+5|0]=(l&254)>>>1;break a;case 16:v[b+3|0]=18;break a;case 17:v[b+3|0]=19;v[b+5|0]=o|176;break a;case 18:case 19:v[b+3|0]=20;v[b+5|0]=d?120:119;break a;case 20:v[b+3|0]=20;v[b+5|0]=d?125:123;break a;case 21:v[b+3|0]=20;v[b+5|0]=d?122:121;break a;case 22:v[b+3|0]=20;v[b+5|0]=d?126:123;break a;case 26:v[b+3|0]=10;v[b+5|0]=d+15>>>4;break a;case 27:v[b+5|0]=1;v[b+3|0]=10;break a;case 30:case 31:if(!d|(!g|!f)){break a}o=x[h>>2];if(o>>>0<1e4){break a}l=x[i>>2];if(!l){break a}i=br(a,f,g);if(!i){break a}k=ri(a,i);n=z[k+34>>1];g:{if(!(n&2)){i=x[k>>2];break g}i=x[k+8>>2]-((e|0)<6?x[k+4>>2]:0)|0;if(!(n&4)){break g}i=i<<((e|0)>5)}if(!i|(e|0)<6&i>>>0<1024){break a}n=x[k+24>>2];if(!n){break a}h:{if(z[a+480192>>1]<g>>>0){break h}a=x[((g<<2)+a|0)+900380>>2];if(!a){break h}m=+(y[xb(a+108|0,f-1|0)|0]-f|0)}a=(c|0)==190;m=zi(m/12+(a?(e|0)<6?+v[k+37|0]/-1536:-0:-0))*+(n>>>0);if(a){v[b+3|0]=17;a=Zl(m*.5*(+(D(d,l)>>>0)*2.5)/+(i>>>0));v[b+5|0]=a;x[h>>2]=D(a,1e4);break a}m=Jv(dK(+(i>>>0)/m/(+(D(d,l)>>>0)*2.5/(+(o>>>0)/1e4)))*12+61,1,120);i:{if(m<4294967296&m>=0){a=~~m>>>0;break i}a=0}c=zd(y[b|0]);v[b|0]=a;m=(m-J(m))*64+128;j:{if(m<4294967296&m>=0){a=~~m>>>0;break j}a=0}v[b+5|0]=a;if((a|0)!=128){v[b+3|0]=35}if(c){break a}if(!y[b+2|0]){v[b+4|0]=9;v[b+2|0]=11;break a}v[b+5|0]=255;v[b+3|0]=4;break a;case 32:a=d>>>4|0;if(a-1>>>0>1){break a}v[b+3|0]=20;v[b+5|0]=a-99;break a;case 34:v[b+3|0]=21;v[b+5|0]=d<<2;break a;case 35:v[b+3|0]=21;s=b,t=Zg(tD(d<<4)>>>6|0),v[s+5|0]=t;break a;case 36:case 38:v[b+3|0]=22;v[b+5|0]=k<<4;break a;case 37:case 39:v[b+5|0]=k;v[b+3|0]=22;break a;case 40:v[b+3|0]=22;v[b+5|0]=l<<4|15;break a;case 2:case 3:case 11:case 23:case 24:case 25:case 28:case 29:case 33:break a;case 41:break d}}v[b+3|0]=22;v[b+5|0]=l|240}fb=j+128|0}function uoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;d=fb-224|0;fb=d;xc(b);a:{if(!pv(b,d+160|0)){break a}if(!sW(d+160|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(rW(d+160|0),hb))){break a}if(!c){e=1;break a}Bd(a,256);f=d+148|0;Zj(f,2,d+160|0);e=d+56|0;Ec(e,f);yb(a+1298308|0,e);tb(e);f=y[d+210|0]|y[d+211|0]<<8;x[a+480260>>2]=64;x[a+480264>>2]=32767;w[a+480188>>1]=4;w[a+480190>>1]=f;Lb(a+1074312|0,107,1);f=y[d+203|0];f=f?f:96;j=jC(f);x[a+480196>>2]=f>>>4;x[a+480204>>2]=j;v[d+56|0]=64;r=a,s=y[Ub(d+202|0,e)|0]<<2,x[r+480200>>2]=s;e=0;b:{c:{d:{e:{f:{g:{while(1){if((e|0)==4){h:{j=Nb(d+148|0);l=Nb(d+136|0);x[31785]=0;P(152,b|0,(y[d+192|0]|y[d+193|0]<<8)<<4)|0;e=x[31785];x[31785]=0;i:{if((e|0)==1){break i}x[31785]=0;U(216,b|0,j|0,y[d+208|0]|y[d+209|0]<<8)|0;e=x[31785];x[31785]=0;if((e|0)==1){break i}x[31785]=0;P(152,b|0,(y[d+194|0]|y[d+195|0]<<8)<<4)|0;e=x[31785];x[31785]=0;if((e|0)==1){break i}x[31785]=0;U(216,b|0,l|0,y[d+210|0]|y[d+211|0]<<8)|0;e=x[31785];x[31785]=0;if((e|0)==1){break i}x[31785]=0;P(152,b|0,((y[d+196|0]|y[d+197|0]<<8)<<4)+32|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break i}e=a+484376|0;f=y[e|0];g=x[a+484360>>2];x[31785]=0;O(333,Wb(g,f)|0,y[d+212|0]|y[d+213|0]<<8);f=x[31785];x[31785]=0;if((f|0)==1){break i}e=Wb(x[a+484360>>2],y[e|0]);r=d,s=vb(x[e>>2]),x[r+56>>2]=s;e=vb(x[e+4>>2]);j:{while(1){f=x[d+56>>2];if(!Ib(f,e)){e=0;if(!uW(Wb(x[a+484360>>2],y[a+484376|0]))){break b}g=c&2;k=d+57|0;e=1;break j}x[31785]=0;g=R(200,b|0)|0;k=x[31785];x[31785]=0;k:{if((k|0)==1){break k}w[f>>1]=g;x[31785]=0;P(186,b|0,4)|0;f=x[31785];x[31785]=0;if((f|0)==1){break k}Wd(d+56|0);continue}break}b=N()|0;break c}l:{m:{n:{o:{while(1){f=e&65535;if(f>>>0>(y[d+210|0]|y[d+211|0]<<8)>>>0){break l}h=_b(x[l>>2],f-1|0);h=y[h|0]|y[h+1|0]<<8;x[31785]=0;h=P(152,b|0,h<<4)|0;i=x[31785];x[31785]=0;p:{if((i|0)!=1){if(h){break p}e=0;break b}b=N()|0;break c}x[31785]=0;P(702,b|0,d+56|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break o}x[31785]=0;h=(D(f,104)+a|0)+484380|0;S(703,d+56|0,h|0,0);i=x[31785];x[31785]=0;if((i|0)==1){break o}i=d+28|0;Lk(i,2,k);x[31785]=0;O(221,d+40|0,i|0);i=x[31785];x[31785]=0;if((i|0)==1){break n}i=((f<<5)+a|0)+946304|0;f=d+40|0;zc(i,f);tb(f);q:{r:{if(!g|!(y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24))){break r}f=HW(d+56|0);x[31785]=0;f=P(152,b|0,f|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break m}if(!f){break r}f=d+40|0;GW(f,y[d+86|0],y[d+87|0],1);x[31785]=0;U(218,f|0,h|0,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break q}}e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}v[d+27|0]=1;i=0;e=x[j>>2];s:{if(mc(e,x[j+4>>2])|(y[d+188|0]|y[d+189|0]<<8)==26){break s}f=y[e|0]|y[e+1|0]<<8;e=0;x[31785]=0;f=P(152,b|0,f<<4)|0;g=x[31785];x[31785]=0;if((g|0)==1){break h}if(!f){break b}x[31785]=0;e=R(192,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break h}if((e|0)!=(y[d+188|0]|y[d+189|0]<<8)){break s}v[d+27|0]=0;i=1}n=c&1;if(n){x[31785]=0;O(226,a+484344|0,y[d+208|0]|y[d+209|0]<<8);c=x[31785];x[31785]=0;if((c|0)==1){break h}}k=a+484344|0;o=a+480188|0;f=0;while(1){t:{if(!n|(y[d+208|0]|y[d+209|0]<<8)>>>0<=f>>>0){break t}x[31785]=0;c=U(199,k|0,f&65535,64)|0;e=x[31785];x[31785]=0;if((e|0)==1){break g}if(!c){break t}c=_b(x[j>>2],f);c=y[c|0]|y[c+1|0]<<8;x[31785]=0;c=P(152,b|0,c<<4)|0;e=x[31785];x[31785]=0;if((e|0)==1){break g}e=0;if(!c){break b}if(i){x[31785]=0;c=R(192,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break g}if(c>>>0>2112){break b}}w[d+12>>1]=65535;x[d+28>>2]=63;c=Vb(x[k>>2],f);Ve(d+40|0,x[c>>2],x[x[c+48>>2]+12>>2],0);u:while(1){c=e;while(1){if(c>>>0<=63){x[31785]=0;e=R(200,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break f}h=e<<24>>24;if(!h){e=64;if(c>>>0>62){continue u}e=Vb(x[k>>2],f);g=x[e>>2];h=x[x[e+48>>2]+12>>2];e=c+1|0;Ve(d+56|0,g,h,e);c=x[d+60>>2];x[d+40>>2]=x[d+56>>2];x[d+44>>2]=c;continue u}e=Jg(d+56|0);g=h&31;if(g>>>0<z[o>>1]){e=Vc(x[d+40>>2],g)}m=h&255;if(m&32){x[31785]=0;O(201,d+25|0,b|0);g=x[31785];x[31785]=0;v:{w:{x:{if((g|0)!=1){q=Ic(d+25|0);g=y[d+25|0];if(g>>>0>239){break x}g=EW((D(g>>>4|0,12)+(g&15)|0)+37|0);break w}b=N()|0;break c}y:{switch(g-254|0){case 0:break w;case 1:break y;default:break v}}g=0}v[e|0]=g}v[e+1|0]=y[q|0]}if(m&64){x[31785]=0;g=R(200,b|0)|0;m=x[31785];x[31785]=0;if((m|0)==1){break e}v[d+25|0]=g;v[e+2|0]=1;v[d+24|0]=64;r=e,s=y[Ub(d+25|0,d+24|0)|0],v[r+4|0]=s}if((h|0)>=0){continue}x[31785]=0;O(201,d+25|0,b|0);g=x[31785];x[31785]=0;if((g|0)==1){break d}r=e,s=y[Ic(d+25|0)|0],v[r+5|0]=s;tW(e,y[d+25|0],c,255,d+12|0,d+28|0);continue}break}break}c=z[d+12>>1];if((c|0)!=65535){we(Vb(x[k>>2],f),qn(Ue(Le(d+56|0,12,c&255),x[d+28>>2])))}f=f+1|0;continue}break}x[31785]=0;b=P(1,d+56|0,6108)|0;c=x[31785];x[31785]=0;z:{A:{B:{if((c|0)!=1){yb(a+1298344|0,b);tb(b);x[31785]=0;b=P(1,d+40|0,5294)|0;c=x[31785];x[31785]=0;if((c|0)==1){break B}yb(a+1298356|0,b);tb(b);r=a+1298404|0,s=x[Gc(d+28|0,4)>>2],x[r>>2]=s;x[31785]=0;O(705,d+12|0,4425);b=x[31785];x[31785]=0;if((b|0)==1){break A}x[31785]=0;S(212,d+28|0,d+12|0,d+27|0);b=x[31785];x[31785]=0;if((b|0)==1){break z}b=a+1298368|0;a=d+28|0;yb(b,a);tb(a);Eb(d+12|0);e=1;break b}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;Eb(d+12|0);break c}b=N()|0;break c}}else{f=(e<<5)+a|0;Ye(f+480280|0);w[f+480284>>1]=e&1?64:192;e=e+1|0;continue}break}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0;break c}b=N()|0}kd(l);kd(j);Q(b|0);p()}kd(l);kd(j)}fb=d+224|0;return e|0}function Eo(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0;h=z[a+480192>>1]>=c>>>0?x[((c<<2)+a|0)+900380>>2]:h;r=x[b+752>>2];a:{j=y[b+802|0];b:{if(!j){if(Pb(a+1074312|0,11)){break b}}c:{d:{if(!h){break d}if(!zd(j)){break d}e:{g=h+236|0;j=j-1|0;if(z[_b(g,j)>>1]){break e}if(!Pb(a+1074312|0,43)){break e}if(Nj(y[h+31|0])){break e}x[b+656>>2]=h;return}if(y[xb(h+108|0,j)|0]>120){break b}j=z[_b(g,j)>>1];n=(j-1&65535)>>>0<3999?(D(j,104)+a|0)+484380|0:0;break c}if(!z[a+480192>>1]){n=(D(c,104)+a|0)+484380|0;break c}if(j>>>0>250){break b}if(!Pb(a+1074312|0,43)){break c}if(h){if(Nj(y[h+31|0])){break c}}v[b+803|0]=0;x[b+656>>2]=0;return}j=x[b+104>>2];m=(j|0)!=0&(j|0)!=(n|0);g=x[b+656>>2];p=!h|x[a+480180>>2]!=16777216?p:x[h+44>>2]!=0;o=d^1;j=(g|0)!=(h|0);if((o|j|m)==1){w[b+774>>1]=0}i=!m;if(!(i|(j|!(d&p)))){break b}f:{if(i|o){break f}l=a+1074312|0;if(!(!Pb(l,32)|!(y[a+480208|0]&8))){n=x[b+8>>2]|x[b+12>>2]?x[b+104>>2]:n}q=x[a+480180>>2];g:{h:{if(!(q&1048580?j|!h:1)|(q|0)==268435456){break h}if((q|0)==1){if(Pi(x[b+8>>2],x[b+12>>2])){break h}}if(!Pb(l,79)){break g}if(!Pi(x[b+8>>2],x[b+12>>2])){break g}}k=1}if(!Pb(l,119)|z[a+480192>>1]){break f}v[b+851|0]=y[b+851|0]|2}i:{if(!x[b+16>>2]|(i|(j|!z[a+480192>>1]))){break i}if(!Pb(a+1074312|0,87)){break i}k=zd(y[b+788|0])^1|k}l=(g|0)!=(h|0);j:{if(Pi(x[b+8>>2],x[b+12>>2])|!(x[a+480180>>2]&16777248)){break j}if(h){if(Nj(y[h+31|0])){break j}}l=1}k:{l:{if(!(m|l)|!d){break l}if(!Pb(a+1074312|0,61)){break l}i=x[b+656>>2];g=x[b+104>>2];j=0;if(i|g){break k}}x[b+656>>2]=h;g=n;i=h;j=l}m:{n:{o:{if(!e){break o}p:{if(y[a+480180|0]&3){if(g){if(ge(x[g>>2],x[g+20>>2])){break p}}if(!Gj(i)){break o}}if(!g){break n}}if(w[g+34>>1]<0){break o}x[b+688>>2]=z[g+30>>1]}h=(g|0)!=0;if(!(k&m)|!g){break m}if(Pb(a+1074312|0,85)){w[b+772>>1]=v[g+37|0]}h=1;if(x[a+480180>>2]!=2){break m}if(!ge(x[g>>2],x[g+20>>2])){break m}x[b+704>>2]=x[g+24>>2];break m}if(!(!i|!y[i+34|0])){h=x[b+688>>2];if(i){h=x[i+4>>2]<<2}x[b+688>>2]=h;h=0;break m}h=0;x[b+688>>2]=0}if(k){break b}v[b+803|0]=0;q:{if(!i){break q}if(s=(B=Pb(a+1074312|0,29),C=1,E=g,E?B:C),t=0,u=(j|y[i+34|0]!=0)!=1,u?s:t){break q}v[b+798|0]=y[i+16|0]}k=64;x[b+752>>2]=64;if(g){k=z[g+32>>1];x[b+752>>2]=k}if(i){x[b+752>>2]=D(x[i+4>>2],k)>>>6}r:{if(!(x[a+480180>>2]&1048580?e:1)){break r}if(Pb(a+1074312|0,48)){break r}SS(a,b,i,g)}s:{t:{u:{if(!f){break u}v:{w:{x:{y:{z:{A:{B:{C:{f=a+1074312|0;if(Pb(f,19)){if(!x[b+76>>2]){e=1;break B}if(!(!c|o)){e=(y[a+480208|0]&8)>>>3|0;if(e){break B}break C}e=0;if(c){break C}break B}D:{c=x[a+480180>>2]&17301536;e=1;E:{if(!d|!c){break E}c=1;e=1;if(y[a+480208|0]&8){break E}e=1;if(!x[b+76>>2]){break E}if(!(y[b+89|0]&16)){break D}e=!x[b+696>>2]}if(!c|(j|!i)){break z}if(!e){break v}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(c&6144){break y}break A}if((j|!i)!=1){break v}break w}if(d){break B}if(!(y[b+89|0]&24)){e=0;break B}e=(y[a+480208|0]&4)>>>2|0}if(j|!x[b+696>>2]){break z}if(!e){break w}c=x[b+88>>2];x[b+88>>2]=c|2097152;if(!i){break x}if(c&2048){break y}}if(!(y[i+60|0]&8)){Fj(b+724|0)}if(!(y[i+80|0]&8)){Fj(b+732|0)}if(y[i+100|0]&8){break x}Fj(b+740|0);break x}if(!e){break w}x[b+88>>2]=x[b+88>>2]|2097152;if(!i){break x}}Wm(b)}if(Pb(f,21)){break u}v[b+818|0]=0;x[b+756>>2]=0;break u}if(!i){break t}}if(v[i+60|0]&1){break u}if(Pb(f,32)){Fj(b+724|0);break u}Wm(b)}c=0;if(g){break s}if(!i){break a}c=1;if(Nj(y[i+31|0])){break s}break a}c=0;if(!g){break a}}F:{if(!(!d|(h^1|x[b+104>>2]!=(g|0)))){e=x[a+480180>>2];if(x[b+76>>2]?e&16777250:0){break b}G:{H:{if((e|0)!=4){break H}if(!Pb(a+1074312|0,40)|y[b+789|0]){break H}e=x[b+88>>2];break G}e=x[b+88>>2]&-6145}x[b+88>>2]=e&-640;break F}x[b+88>>2]=x[b+88>>2]&-6145;e=a+1074312|0;I:{J:{if(!Pb(e,18)){h=-640;if(j|(x[a+480180>>2]&16777248|x[b+104>>2]!=(g|0))){break J}break I}h=-640;if((j|x[b+104>>2]!=(g|0))!=1){break I}}h=-768}x[b+88>>2]=x[b+88>>2]&h;if(!i){break F}v[b+730|0]=y[i+60|0];v[b+738|0]=y[i+80|0];v[b+746|0]=y[i+100|0];K:{if((y[i+100|0]&17)!=17){break K}if(Pb(e,36)|y[b+837|0]){break K}v[b+837|0]=127}e=y[i+21|0];if(Cd(e)){s=b,t=Sh(e),v[s+837|0]=t}e=y[i+22|0];if(!Cd(e)){break F}s=b,t=Sh(e),v[s+838|0]=t}if(c){x[b+76>>2]=0;x[b+104>>2]=0;return}L:{if(x[b+76>>2]|!d){break L}c=a+1074312|0;if(!Pb(c,54)){if(!Pb(c,39)){break L}}x[b+8>>2]=0;x[b+12>>2]=0}M:{if(y[b+788|0]!=255){break M}if(!Pb(a+1074312|0,100)|!(y[a+480208|0]>>>2&m)){break M}c=x[b+104>>2];if(c){x[b+88>>2]=x[b+88>>2]|z[c+34>>1]&1023}x[b+752>>2]=r;x[b+688>>2]=z[g+30>>1];if(!(y[g+34|0]&32)){break b}Fq(b,z[g+28>>1],a);return}x[b+104>>2]=g;x[b+76>>2]=x[g>>2];x[b+80>>2]=x[g+4>>2];x[b+84>>2]=x[g+8>>2];c=a+1074312|0;if(!(!Pb(c,83)|x[b+80>>2])){x[b+84>>2]=x[g>>2]}x[b+88>>2]=x[b+88>>2]|z[g+34>>1]&1023;if(Pb(c,21)){v[b+818|0]=0;x[b+756>>2]=0}N:{O:{if(p){x[b+704>>2]=x[g+24>>2];v[b+851|0]=y[b+851|0]|64;d=0;break O}if(!(m|o)){d=x[a+480180>>2];if(d&5){break N}}x[b+704>>2]=x[g+24>>2];d=v[g+37|0]}w[b+772>>1]=d;d=x[a+480180>>2]}if(on(d)){d=v[g+36|0]}else{d=0}w[b+770>>1]=d;if(!(Pb(c,69)|x[a+480180>>2]==1)){x[b+708>>2]=0}x[b+852>>2]=0;h=x[b+88>>2];if(h&8){x[b+80>>2]=x[g+12>>2];x[b+84>>2]=x[g+16>>2];h=h>>>2&4|h|2;x[b+88>>2]=h}P:{if(!(h&2)){h=x[b+76>>2];break P}h=x[b+76>>2];c=x[b+84>>2];if(h>>>0<=c>>>0){break P}x[b+76>>2]=c;h=c}if(!(x[a+480180>>2]&16777248)|A[b+4>>2]<h>>>0){break b}x[b>>2]=0;x[b+4>>2]=0}return}x[b+752>>2]=0;x[b+104>>2]=0}
function Una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;d=fb-176|0;fb=d;xc(c);a:{if(!_o(c,d+164|0)){break a}if(Ob(d+164|0,13918,4)){break a}f=d+172|0;if(Ob(f,14319,4)){if(Ob(f,14423,4)){break a}}e=fb-32|0;fb=e;i=d+152|0;g=Nb(i);b:{c:{d:{e:{f:{while(1){h=x[c+8>>2];j=x[c>>2];x[31785]=0;h=U(153,j|0,h|0,8)|0;j=x[31785];x[31785]=0;if((j|0)==1){break d}if(!h){break e}x[31785]=0;O(832,e+4|0,c|0);h=x[31785];x[31785]=0;if((h|0)!=1){x[31785]=0;O(833,g|0,e+4|0);h=x[31785];x[31785]=0;if((h|0)==1){break f}Fd(e+4|0);continue}break}a=N()|0;break c}a=N()|0;Fd(e+4|0);break c}fb=e+32|0;break b}a=N()|0}fe(g);Q(a|0);p()}x[31785]=0;S(751,d+132|0,i|0,1129270605);c=x[31785];x[31785]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){x[31785]=0;c=P(752,d+132|0,d+114|0)|0;e=x[31785];x[31785]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!$b(z[d+116>>1]|z[d+118>>1]<<16)){break g}if((Cb(z[d+114>>1])-3&65535)>>>0<65534){break g}if((Cb(z[d+120>>1])-65&65535)>>>0<65472){break g}x[d+108>>2]=1162760014;c=1;if(!Ob(f,14423,4)){x[31785]=0;c=P(631,d+132|0,d+108|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break o}if(!c){break g}c=x[d+108>>2]!=1936684916}x[31785]=0;S(751,d+88|0,d+152|0,1397968452);e=x[31785];x[31785]=0;p:{q:{if((e|0)!=1){x[31785]=0;k=P(753,d+88|0,d+80|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break p}if(k){break q}break h}c=N()|0;break j}e=(Cb(z[d+120>>1])-1|0)/8|0;g=e<<3;f=g&31;g=ad(d+76|0,(e>>>0>=8?8:(g&63)>>>0>=32?1074268168>>>f|0:((1<<f)-1&1074268168)<<32-f|538447880>>>f)&255,(Cb(z[d+114>>1])|0)==2?2:1,c,0);c=x[d+108>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}ug(g,3);break r}ug(g,17);ed(g,16);break r}ug(g,16);ed(g,16);break r}ug(g,1)}c=x[d+80>>2];x[31785]=0;c=U(153,x[d+88>>2],x[d+96>>2],$b(c)|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break l}if(c){c=x[d+80>>2];x[31785]=0;P(186,d+88|0,$b(c)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break l}}Du(a,b);x[31785]=0;c=D(b,104)+a|0;i=c+484380|0;O(282,i|0,0);e=x[31785];x[31785]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}s=i,t=$b(z[d+116>>1]|z[d+118>>1]<<16),x[s>>2]=t;j=c+484404|0;c=y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24);f=c<<24|(c&65280)<<8|(c>>>8&65280|c>>>24);h=30-y[d+123|0]|0;e=0;while(1){c=f;if(h&255){f=c>>>1|0;h=h-1|0;e=c;continue}break}x[j>>2]=c+(e&1);x[31785]=0;U(218,g|0,i|0,d+88|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break D}x[31785]=0;S(751,d+56|0,d+152|0,1296126539);c=x[31785];x[31785]=0;if((c|0)==1){break C}x[31785]=0;c=R(175,x[d+56>>2])|0;e=x[31785];x[31785]=0;if((e|0)==1){break B}if(!c){break u}x[31785]=0;S(751,d+16|0,d+152|0,1229869908);c=x[31785];x[31785]=0;if((c|0)==1){break A}x[31785]=0;c=P(754,d+16|0,d+36|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break z}ub(d+16|0);if(!c){break u}x[31785]=0;f=R(276,d+56|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break y}e=Nb(d+16|0);x[31785]=0;O(755,e|0,f|0);c=x[31785];x[31785]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}x[31785]=0;g=P(756,d+56|0,d+4|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break w}if(!g){break x}x[31785]=0;O(757,e|0,d+4|0);g=x[31785];x[31785]=0;if((g|0)==1){break w}x[31785]=0;g=y[d+10|0];P(186,d+56|0,!(g&1)+g|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=N()|0;break k}c=N()|0;break k}c=N()|0;break m}c=N()|0;break m}c=N()|0;ub(d+16|0);break m}c=N()|0;break m}c=Cb(y[d+44|0]|y[d+45|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65511|((c|0)==2)<<4|8}c=Cb(y[d+50|0]|y[d+51|0]<<8);if(c){f=(D(b,104)+a|0)+484414|0;w[f>>1]=z[f>>1]&65529|((c|0)==2?4:2)|2}s=d,t=vb(x[e>>2]),x[s+4>>2]=t;c=D(b,104)+a|0;g=c+484388|0;h=c+484384|0;j=c+484396|0;l=c+484392|0;m=vb(x[e+4>>2]);n=y[d+46|0]|y[d+47|0]<<8;o=y[d+48|0]|y[d+49|0]<<8;q=y[d+52|0]|y[d+53|0]<<8;r=y[d+54|0]|y[d+55|0]<<8;while(1){c=x[d+4>>2];if(!Ib(c,m)){break v}f=Cb(y[c|0]|y[c+1|0]<<8);if((f|0)==(Cb(n)|0)){s=l,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Cb(y[c|0]|y[c+1|0]<<8)}if((Cb(o)|0)==(f|0)){s=j,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Cb(y[c|0]|y[c+1|0]<<8)}if((Cb(q)|0)==(f|0)){s=h,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t;f=Cb(y[c|0]|y[c+1|0]<<8)}if((f|0)==(Cb(r)|0)){s=g,t=$b(y[c+2|0]|y[c+3|0]<<8|(y[c+4|0]<<16|y[c+5|0]<<24)),x[s>>2]=t}x[d+4>>2]=x[d+4>>2]+7;continue}}c=N()|0;xT(e);break m}Xk(i);xT(e)}x[31785]=0;S(751,d+16|0,d+152|0,1312902469);c=x[31785];x[31785]=0;if((c|0)==1){break n}x[31785]=0;c=R(175,x[d+16>>2])|0;e=x[31785];x[31785]=0;E:{if((e|0)==1){break E}F:{if(c){x[31785]=0;c=R(157,x[d+16>>2])|0;e=x[31785];x[31785]=0;if((e|0)==1){break E}x[31785]=0;S(320,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break F}break E}x[31785]=0;c=P(37,d+4|0,22485)|0;e=x[31785];x[31785]=0;if((e|0)==1){break E}zc(((b<<5)+a|0)+946304|0,c);tb(c)}RB(i,x[a+480180>>2]);Mj(i,a);ub(d+16|0);ub(d+56|0);break h}c=N()|0;ub(d+16|0);break m}c=N()|0;break k}c=N()|0;break j}c=N()|0;break j}c=N()|0;break m}c=N()|0;break i}ub(d+56|0);break k}c=N()|0}ub(d+88|0)}ub(d+132|0)}fe(d+152|0);Q(c|0);p()}ub(d+88|0)}ub(d+132|0);fe(d+152|0)}fb=d+176|0;return k|0}function $ra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0;d=fb-1344|0;fb=d;xc(b);g=fb-16|0;fb=g;j=d+768|0;vZ(g+8|0,j);i=x[g+12>>2];kc(g,x[b>>2],x[b+8>>2],x[g+8>>2],x[g+12>>2]);l=x[g+4>>2];if((l|0)==(i|0)){Yb(b,x[g+12>>2])}fb=g+16|0;g=(i|0)==(l|0);if(!g){uZ(j)}a:{if(!g){break a}if(!xZ(d+768|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(wZ(y[d+802|0]|y[d+803|0]<<8,y[d+804|0]|y[d+805|0]<<8),hb))){break a}if(!c){f=1;break a}s=rc(d+764|0);b:{while(1){if((f|0)!=32){g=(f<<5)+a|0;i=g+480280|0;Ye(i);j=(d+768|0)+(f<<4)|0;w[g+480284>>1]=((y[j+78|0]<<8&65280)>>>0)/255;n=d+496|0;Lk(n,1,j- -64|0);l=d+108|0;Ec(l,n);fm(g+480289|0,l);tb(l);c:{d:{switch(y[j+79|0]){case 0:k=e+1|0;break c;case 1:x[i>>2]=1024;k=f+1|0;break c;case 2:break d;default:break b}}x[i>>2]=1024;g=d+108|0;Pc(g,s,f);Uo(g)}e=e+1|0;f=f+1|0;continue}break}Bd(a,33554432);w[a+480188>>1]=k&255;f=d+108|0;e=uc(f,6828);yb(a+1298344|0,e);tb(e);e=uc(f,11155);yb(a+1298356|0,e);tb(e);u=a+1298404|0,B=x[Gc(f,4)>>2],x[u>>2]=B;e:{if(y[d+847|0]){break e}f=1;e=1;while(1){if((f|0)==16){while(1){if((e|0)==16){break e}f=((e<<5)+a|0)+480280|0;x[f>>2]=x[f>>2]&-1025;e=e+1|0;continue}}g=f<<4;f=f+1|0;if(y[(d+g|0)+847|0]==1){continue}break}}f=d+496|0;Te(f,1,d+768|0);e=d+108|0;Ec(e,f);yb(a+1298308|0,e);tb(e);x[a+480208>>2]=x[a+480208>>2]&-17|(y[d+806|0]|y[d+807|0]<<8)<<4&16;x[a+480196>>2]=y[d+816|0];x[a+480204>>2]=D(y[d+817|0],1e4);x[a+480200>>2]=y[d+818|0]<<2;x[a+480228>>2]=y[d+819|0];e=y[d+804|0]|y[d+805|0]<<8;w[a+480190>>1]=0;w[a+480192>>1]=e;sw(b,f);Dr(Wb(x[a+484360>>2],y[a+484376|0]),f,y[d+800|0]|y[d+801|0]<<8,65535,255);q=c&1;if(q){$f(a+484344|0,y[d+802|0]|y[d+803|0]<<8)}n=a+484344|0;t=a+480188|0;f:{while(1){g:{if((y[d+802|0]|y[d+803|0]<<8)>>>0<=h>>>0){l=c&2;s=d+104|0;n=a+480192|0;g=1;c=0;h:while(1){if(z[n>>1]<=(c&65535)>>>0){f=32;break b}c=c+1|0;f=jE(a,c&65535,0);i=!f;e=fb-16|0;fb=e;k=d+108|0;bc(e+8|0,k,384);h=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(h|0)){Yb(b,x[e+12>>2])}fb=e+16|0;e=(h|0)==(j|0);if(!e){Tb(k,0,384)}if(!e|i){continue}k=g&65535;h=fb-32|0;fb=h;j=h+8|0;e=d+108|0;Te(j,1,e);i=h+20|0;Ec(i,j);zc(f+492|0,i);tb(i);i:{if(!(y[e+378|0]|y[e+379|0]<<8)){break i}j=f+236|0;i=0;while(1){x[h+20>>2]=120;x[h+8>>2]=116;if(A[Gb(h+20|0,h+8|0)>>2]<=i>>>0){break i}m=y[(e+i|0)+32|0];u=_b(j,i+12|0),B=k+m|0,w[u>>1]=B;i=i+1|0;continue}}i=y[e+376|0]|y[e+377|0]<<8;v[f+33|0]=1;x[f>>2]=i;nD(e,f+48|0,0);nD(e,f+68|0,1);nD(e,f+88|0,2);e=y[f+100|0];if(e&1){v[f+100|0]=e|16}if(!(x[f>>2]|v[f+60|0]&1)){x[f>>2]=32767}fb=h+32|0;f=0;while(1){e=y[d+486|0]|y[d+487|0]<<8;if(e>>>0<=f>>>0){g=e+g|0;continue h}F_(b,d+44|0);j:{k:{if(Ob(s,15751,4)){break k}e=f+g|0;k=e&65535;if(k>>>0>3999){break k}w[a+480190>>1]=e;i=fb-32|0;fb=i;j=D(k,104)+a|0;e=j+484380|0;jd(e,0);m=i+8|0;ui(m,1,d+44|0);h=i+20|0;Ec(h,m);ye(e+43|0,h);tb(h);m=y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24);x[e>>2]=m;o=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);x[e+4>>2]=o;q=y[d+68|0]|y[d+69|0]<<8|(y[d+70|0]<<16|y[d+71|0]<<24);x[e+8>>2]=q;x[e+24>>2]=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);w[e+30>>1]=y[d+76|0]<<2;w[e+28>>1]=y[d+77|0];h=y[d+92|0];if(h&1){w[e+34>>1]=z[e+34>>1]|2;h=y[d+92|0]}if(h&2){w[e+34>>1]=z[e+34>>1]|4;h=y[d+92|0]}if(h&4){x[e+8>>2]=q>>>1;x[e+4>>2]=o>>>1;x[e>>2]=m>>>1;w[e+34>>1]=z[e+34>>1]|1;h=y[d+92|0]}if(h&8){w[e+34>>1]=z[e+34>>1]|32}fb=i+32|0;h=fb-16|0;fb=h;Fw(h+8|0,j+484423|0);i=d+24|0;pp(i,x[h+8>>2],x[h+12>>2]);fb=h+16|0;zc(((k<<5)+a|0)+946304|0,i);tb(i);h=y[d+60|0]|y[d+61|0]<<8|(y[d+62|0]<<16|y[d+63|0]<<24);if(!h){break k}i=d+4|0;ce(i,b,h);h=ic(d+24|0,i);ub(i);if(l){i=ad(d+4|0,w[j+484414>>1]&1?16:8,1,0,0);x[31785]=0;U(218,i|0,e|0,h|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break j}}ub(h)}f=f+1|0;continue}break}break}a=N()|0;ub(h);break f}e=eh(b);m=eh(b);f=d+44|0;ce(f,b,e-4|0);j=ic(d+108|0,f);ub(f);l:{m:{if(!q){break m}x[31785]=0;f=U(199,n|0,h&65535,m|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break l}if(!f){break m}k=0;i=Jg(d+24|0);while(1){if(k>>>0>=m>>>0){break m}x[31785]=0;l=R(200,j|0)|0;f=x[31785];x[31785]=0;n:{if((f|0)!=1){if(l){break n}k=k+1|0;continue}break g}e=i;o=l&31;if(o>>>0<z[t>>1]){f=Vb(x[n>>2],h);e=gd(x[f>>2],x[x[f+48>>2]+12>>2],k,o)}if(l&32){x[31785]=0;O(201,d+44|0,j|0);f=x[31785];x[31785]=0;if((f|0)==1){break g}g=y[d+44|0];v[e|0]=g;u=e,B=y[Ic(d+44|0)|0],v[u+1|0]=B;o:{p:{if((g|0)==160){f=255;break p}if((g|0)==255){f=0;break p}f=0;g=(D(g>>>4|0,12)+(g&15)|0)+13|0;if(tZ(g)){break o}}g=f}v[e|0]=g}f=l&192;q:{if(!f){break q}if((f|0)==192){x[31785]=0;O(360,d+44|0,j|0);f=x[31785];x[31785]=0;if((f|0)!=1){f=d+44|0;g=Ic(f);l=Ze(f);f=cj(f);r=d+4|0;oD(r,y[d+44|0],y[g|0]);g=Ic(r);r=d+494|0;oD(r,y[l|0],y[f|0]);sn(d+492|0,e,y[d+4|0],y[g|0],y[d+494|0],y[Ic(r)|0]);break q}break g}x[31785]=0;O(201,d+44|0,j|0);f=x[31785];x[31785]=0;r:{s:{if((f|0)!=1){f=d+4|0;oD(f,y[d+44|0],y[Ic(d+44|0)|0]);g=y[Ic(f)|0];f=y[d+4|0];if((f|0)!=13){break s}v[e+2|0]=1;f=e+4|0;break r}break g}v[e+3|0]=f;f=e+5|0}v[f|0]=g}Pc(d+44|0,s,o);if(!Hb(x[x[d+44>>2]>>2],x[d+48>>2])){continue}if(!F$(y[e+3|0],y[e+5|0])){continue}v[e+3|0]=0;continue}}ub(j);h=h+1|0;continue}}break}a=N()|0;ub(j)}Q(a|0);p()}f=f>>>0>31}fb=d+1344|0;return f|0}function Kpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-1824|0;fb=e;xc(b);d=fb-16|0;fb=d;i=e+1224|0;EX(d+8|0,i);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);l=x[d+4>>2];if((l|0)==(f|0)){Yb(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(l|0);if(!d){CX(i)}a:{if(!d){break a}if(!FX(e+1224|0)){break a}if(!EC(b,16,0)){break a}d=e+1240|0;x[e+1216>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=y[e+1228|0]|y[e+1229|0]<<8|(y[e+1230|0]<<16|y[e+1231|0]<<24);x[e+1200>>2]=y[e+1224|0]|y[e+1225|0]<<8|(y[e+1226|0]<<16|y[e+1227|0]<<24);x[e+1204>>2]=d;d=e+1232|0;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);d=y[d+4|0]|y[d+5|0]<<8|(y[d+6|0]<<16|y[d+7|0]<<24);x[e+1208>>2]=f;x[e+1212>>2]=d;Bd(a,1);Lb(Lb(Yf(a+1074312|0,83),84,1),85,1);w[a+480188>>1]=4;x[e+1196>>2]=0;w[a+480190>>1]=15;bd(b,20);k=a+480188|0;g=1;i=1;b:{while(1){c:{if((g|0)==16){d=e+1064|0;if(!AC(b,d)){wC(d)}d=a+484360|0;f=a+484376|0;_v(Wb(x[d>>2],y[f|0]),e+1066|0,128);l=NX(b,Wb(x[d>>2],y[f|0]),y[e+1064|0],h,k,0,1);if(!(y[e+1065|0]|l>>>0>1)){g=0;if(!y[e+1064|0]){break a}}d=(l<<10)+h|0;x[e+1060>>2]=d;x[e+24>>2]=65536;g=0;if(!Mb(x[b>>2],x[b+8>>2],d-x[Gb(e+1060|0,e+24|0)>>2]|0)){break a}if(c){break c}break b}d=e+24|0;yC(b,d);o=d;f=D(g,104)+a|0;l=f+484380|0;d=((g<<5)+a|0)+946304|0;GC(o,l,d,1);m=x[l>>2];d:{if(!y[xb(d,0)|0]){break d}e:{if(Ob(d,16980,3)){if(Ob(d,16984,3)){break e}}if(y[xb(d,5)|0]==58){break d}}i=0}d=Cb(y[e+52|0]|y[e+53|0]<<8);if(d>>>0>=2){o=d<<1;d=Cb(y[e+50|0]|y[e+51|0]<<8);x[f+484388>>2]=o+d;x[f+484384>>2]=d;Xk(l)}f:{if(Cb(y[e+46|0]|y[e+47|0]<<8)>>>0<=4999){if(Cb(y[e+50|0]|y[e+51|0]<<8)>>>0<1e4){break f}}x[e+1064>>2]=5;t=e,u=x[We(e+1196|0,e+1064|0)>>2],x[t+1196>>2]=u}h=h+m|0;g=g+1|0;continue}break}g=y[e+1065|0];if(!g){v[e+1065|0]=120;g=120}g:{if(!Ob(e+1200|0,15093,6)){v[e+1065|0]=120;x[a+480204>>2]=125e4;break g}x[a+480204>>2]=125e4;if((g|0)==120){break g}t=a,u=Xe(1773447.5/(+(240-g|0)*122)*1e4),x[t+480204>>2]=u;if(x[e+1196>>2]>=2){x[e+24>>2]=i&1?4:5;t=e,u=x[We(e+1196|0,e+24|0)>>2],x[t+1196>>2]=u;break g}x[e+24>>2]=i&1?1:2;t=e,u=x[We(e+1196|0,e+24|0)>>2],x[t+1196>>2]=u}x[a+480228>>2]=64;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480208>>2]=x[a+480208>>2]|2097152;f=e+1048|0;Zj(f,3,e+1200|0);d=e+24|0;Ec(d,f);yb(a+1298308|0,d);tb(d);Ch(a,0);f=i&1;o=x[b+8>>2];s=a+484376|0;while(1){h:{if((j&65535)>>>0<l>>>0){d=Wb(x[a+484360>>2],y[s|0]);d=Ib(xC(vb(x[d>>2]),vb(x[d+4>>2]),j),vb(x[d+4>>2]));BX(b,e+24|0);i:{if(d){q=CC(e+24|0,0)+q|0;if(q>>>0>512){break i}}m=0;d=x[e+1196>>2];h=0;i=0;j:while(1){if((i|0)==64){break h}g=0;while(1)if((g|0)==4){i=i+1|0;continue j}else{p=wb(Ud(e+24|0,i),g);n=y[xb(p,2)|0]&15;k=y[xb(p,3)|0];k:{l:{if(!(h&255)){break l}if(Ob(p,25492,4)){break l}h=h+1|0;if((h&255)>>>0<33){break k}d=6;x[e+1196>>2]=6;break k}h=0}m:{n:{o:{p:{switch(n-1|0){case 0:case 1:if((d|0)==1&k>>>0>=32){break n}n=(n|0)!=1;if(!(n|!k|k>>>0>2)){x[e+1048>>2]=2;d=x[We(e+1196|0,e+1048|0)>>2];break o}if(n|(k|0)!=55&(k|0)!=71){break m}if((d|0)<=2){break n}break m;case 10:d=6;break o;case 11:case 12:case 13:x[e+1048>>2]=2;d=x[We(e+1196|0,e+1048|0)>>2];x[e+1196>>2]=d;if((n|0)!=13){break m}m=((i|k)!=0)+m|0;h=1;break m;case 14:break p;default:break m}}x[e+1048>>2]=3;d=x[We(e+1196|0,e+1048|0)>>2]}x[e+1196>>2]=d;break m}x[e+1196>>2]=f;d=f}g=g+1|0;continue}}}g=0;break a}if(!(x[e+1196>>2]!=6|l+32>>>0>=r>>>0)){x[e+1196>>2]=5}bd(b,o);p=c&1;if(p){$f(a+484344|0,l)}n=a+484344|0;k=0;while(1)if((k|0)==(l|0)){g=22485;d=x[e+1196>>2];if(d>>>0<7){g=x[(d<<2)+25504>>2]}d=e+24|0;f=uc(d,8324);yb(a+1298344|0,f);tb(f);f=uc(d,10795);yb(a+1298356|0,f);tb(f);$h(a+1298368|0,g);t=a+1298404|0,u=x[Gc(d,28)>>2],x[t>>2]=u;g=1;if(!(c&2)){break a}while(1){if((g|0)==16){break b}c=D(g,104)+a|0;d=c+484384|0;Yb(b,x[d>>2]);f=x[d>>2];x[d>>2]=0;d=c+484380|0;x[d>>2]=x[d>>2]-f;c=c+484388|0;x[c>>2]=x[c>>2]-f;c=e+24|0;ad(c,8,1,1,0);qg(c,d,b);g=g+1|0;continue}}else{BX(b,e+24|0);q:{if(!p){break q}if(!bh(n,k&65535,64)){break q}i=0;x[e+20>>2]=0;r:while(1){if((i|0)==64){break q}d=Vb(x[n>>2],k);Ve(e+1048|0,x[d>>2],x[x[d+48>>2]+12>>2],i);g=0;while(1)if((g|0)==4){i=i+1|0;continue r}else{d=Vc(x[e+1048>>2],g);f=wb(Ud(e+24|0,i),g);f=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);x[e+8>>2]=f;x[e+12>>2]=f;f=e+18|0;Yo(f,e+8|0,d);m=(e+20|0)+g|0;h=y[e+18|0];f=Ic(f);j=y[f|0];s:{t:{if(!((h|0)!=14?j:0)){v[m|0]=0;if(h|j){break t}break s}j=y[m|0];if(!j){break t}o=j;q=j>>>4|0;j=j>>>0<16;v[d+4|0]=j?o:q;v[d+2|0]=j?4:3}u:{v:{w:{x:{y:{switch(h-12|0){case 1:h=x[e+1196>>2];if((h|0)!=6){v[e+18|0]=10;break w}v[f|0]=0;break x;case 0:v[f|0]=y[f|0]&127;break x;case 2:h=y[f|0];if(h>>>0<=1){j=14;if(x[e+1196>>2]>3){break v}}v[e+18|0]=10;v[m|0]=y[f|0];break x;case 3:break y;default:break x}}v[f|0]=y[f|0]&15}h=x[e+1196>>2]}if((h|0)<2){break u}h=y[f|0];j=y[e+18|0]}Mf(d,j,h&255);break s}h=y[f|0];v[d+5|0]=h;z:{A:{B:{switch(y[e+18|0]){case 0:if(y[f|0]>2){break A}break;case 2:break z;case 1:break A;default:break B}}v[d+3|0]=0;break s}v[d+3|0]=1;break s}f=h&15;if(f){v[d+5|0]=f;v[d+3|0]=2;break s}if(h>>>0<16){break s}v[d+3|0]=3;v[d+5|0]=(h&240)>>>4}g=g+1|0;continue}}}k=k+1|0;continue}}if((m-1&255)>>>0<2){x[e+1196>>2]=6}j=j+1|0;r=(m&255)+r|0;continue}}g=1}fb=e+1824|0;return g|0}function kL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0,E=0,F=0,G=0;j=fb-80|0;fb=j;x[j+76>>2]=b;E=j+55|0;s=j+56|0;a:{b:{c:{d:{e:while(1){k=b;if((p^2147483647)<(h|0)){break d}p=h+p|0;f:{g:{h:{h=k;i=y[h|0];if(i){while(1){i:{b=i&255;j:{if(!b){b=h;break j}if((b|0)!=37){break i}i=h;while(1){if(y[i+1|0]!=37){b=i;break j}h=h+1|0;m=y[i+2|0];b=i+2|0;i=b;if((m|0)==37){continue}break}}h=h-k|0;B=p^2147483647;if((h|0)>(B|0)){break d}if(a){Ff(a,k,h)}if(h){continue e}x[j+76>>2]=b;h=b+1|0;q=-1;i=v[b+1|0];if(!(!Kh(i)|y[b+2|0]!=36)){q=i-48|0;u=1;h=b+3|0}x[j+76>>2]=h;n=0;i=v[h|0];b=i-32|0;k:{if(b>>>0>31){o=h;break k}o=h;b=1<<b;if(!(b&75913)){break k}while(1){o=h+1|0;x[j+76>>2]=o;n=b|n;i=v[h+1|0];b=i-32|0;if(b>>>0>=32){break k}h=o;b=1<<b;if(b&75913){continue}break}}l:{if((i|0)==42){b=v[o+1|0];m:{if(!(!Kh(b)|y[o+2|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;i=o+3|0;u=1;b=x[((v[o+1|0]<<3)+d|0)-384>>2];break m}if(u){break h}i=o+1|0;if(!a){x[j+76>>2]=i;u=0;r=0;break l}b=x[c>>2];x[c>>2]=b+4;u=0;b=x[b>>2]}x[j+76>>2]=i;r=b;if((b|0)>=0){break l}r=0-r|0;n=n|8192;break l}r=jL(j+76|0);if((r|0)<0){break d}i=x[j+76>>2]}h=0;l=-1;n:{if(y[i|0]!=46){b=i;A=0;break n}if(y[i+1|0]==42){b=v[i+2|0];o:{if(!(!Kh(b)|y[i+3|0]!=36)){x[((b<<2)+e|0)-192>>2]=10;b=i+4|0;l=x[((v[i+2|0]<<3)+d|0)-384>>2];break o}if(u){break h}b=i+2|0;l=0;if(!a){break o}i=x[c>>2];x[c>>2]=i+4;l=x[i>>2]}x[j+76>>2]=b;A=(l^-1)>>>31|0;break n}x[j+76>>2]=i+1;l=jL(j+76|0);b=x[j+76>>2];A=1}while(1){t=h;o=28;m=b;h=v[b|0];if(h-123>>>0<4294967238){break c}b=m+1|0;h=y[(h+D(t,58)|0)+93199|0];if(h-1>>>0<8){continue}break}x[j+76>>2]=b;p:{q:{if((h|0)!=27){if(!h){break c}if((q|0)>=0){x[(q<<2)+e>>2]=h;i=(q<<3)+d|0;h=x[i+4>>2];x[j+64>>2]=x[i>>2];x[j+68>>2]=h;break q}if(!a){break f}iL(j- -64|0,h,c,g);break p}if((q|0)>=0){break c}}h=0;if(!a){continue e}}i=n&-65537;n=n&8192?i:n;q=0;z=5306;o=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{h=v[m|0];h=t?(h&15)==3?h&-33:h:h;switch(h-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(h-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((h|0)==83){break w}break g}i=x[j+64>>2];m=x[j+68>>2];z=5306;break z}h=0;I:{switch(t&255){case 0:x[x[j+64>>2]>>2]=p;continue e;case 1:x[x[j+64>>2]>>2]=p;continue e;case 2:k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e;case 3:w[x[j+64>>2]>>1]=p;continue e;case 4:v[x[j+64>>2]]=p;continue e;case 6:x[x[j+64>>2]>>2]=p;continue e;case 7:break I;default:continue e}}k=x[j+64>>2];x[k>>2]=p;x[k+4>>2]=p>>31;continue e}l=l>>>0<=8?8:l;n=n|8;h=120}k=s;F=h&32;i=x[j+64>>2];m=x[j+68>>2];if(i|m){while(1){k=k-1|0;v[k|0]=F|y[(i&15)+93728|0];G=!m&i>>>0>15|(m|0)!=0;t=m;m=m>>>4|0;i=(t&15)<<28|i>>>4;if(G){continue}break}}if(!(n&8)|!(x[j+64>>2]|x[j+68>>2])){break y}z=(h>>>4|0)+5306|0;q=2;break y}h=s;k=x[j+68>>2];m=k;i=x[j+64>>2];if(k|i){while(1){h=h-1|0;v[h|0]=i&7|48;t=!m&i>>>0>7|(m|0)!=0;k=m;m=k>>>3|0;i=(k&7)<<29|i>>>3;if(t){continue}break}}k=h;if(!(n&8)){break y}h=s-k|0;l=(h|0)<(l|0)?l:h+1|0;break y}i=x[j+64>>2];h=x[j+68>>2];m=h;if((h|0)<0){k=0-(m+((i|0)!=0)|0)|0;m=k;i=0-i|0;x[j+64>>2]=i;x[j+68>>2]=k;q=1;z=5306;break z}if(n&2048){q=1;z=5307;break z}q=n&1;z=q?5308:5306}k=co(i,m,s)}if((l|0)<0?A:0){break d}n=A?n&-65537:n;h=x[j+64>>2];i=x[j+68>>2];if(!((h|i)!=0|l)){k=s;l=0;break g}h=!(h|i)+(s-k|0)|0;l=(h|0)<(l|0)?l:h;break g}h=x[j+64>>2];k=h?h:17279;m=l>>>0>=2147483647?2147483647:l;h=Pt(k,0,m);h=h?h-k|0:m;o=h+k|0;if((l|0)>=0){n=i;l=h;break g}n=i;l=h;if(y[o|0]){break d}break g}if(l){i=x[j+64>>2];break u}h=0;Rf(a,32,r,0,n);break t}x[j+12>>2]=0;x[j+8>>2]=x[j+64>>2];i=j+8|0;x[j+64>>2]=i;l=-1}h=0;J:{while(1){k=x[i>>2];if(!k){break J}m=hL(j+4|0,k);k=(m|0)<0;if(!(k|m>>>0>l-h>>>0)){i=i+4|0;h=h+m|0;if(l>>>0>h>>>0){continue}break J}break}if(k){break b}}o=61;if((h|0)<0){break c}Rf(a,32,r,h,n);if(!h){h=0;break t}o=0;i=x[j+64>>2];while(1){k=x[i>>2];if(!k){break t}k=hL(j+4|0,k);o=k+o|0;if(o>>>0>h>>>0){break t}Ff(a,j+4|0,k);i=i+4|0;if(h>>>0>o>>>0){continue}break}}Rf(a,32,r,h,n^8192);h=(h|0)<(r|0)?r:h;continue e}if((l|0)<0?A:0){break d}o=61;h=ib[f|0](a,C[j+64>>3],r,l,n,h)|0;if((h|0)>=0){continue e}break c}v[j+55|0]=x[j+64>>2];l=1;k=E;n=i;break g}i=y[h+1|0];h=h+1|0;continue}}if(a){break a}if(!u){break f}h=1;while(1){a=x[(h<<2)+e>>2];if(a){iL((h<<3)+d|0,a,c,g);p=1;h=h+1|0;if((h|0)!=10){continue}break a}break}p=1;if(h>>>0>=10){break a}while(1){if(x[(h<<2)+e>>2]){break h}h=h+1|0;if((h|0)!=10){continue}break}break a}o=28;break c}m=o-k|0;i=(l|0)>(m|0)?l:m;if((i|0)>(q^2147483647)){break d}o=61;l=i+q|0;h=(l|0)<(r|0)?r:l;if((B|0)<(h|0)){break c}Rf(a,32,h,l,n);Ff(a,z,q);Rf(a,48,h,l,n^65536);Rf(a,48,i,m,0);Ff(a,k,m);Rf(a,32,h,l,n^8192);continue}break}p=0;break a}o=61}x[31660]=o}p=-1}fb=j+80|0;return p}function Era(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=fb-192|0;fb=f;n=ek(b,13933);if(n){if(d){v[d|0]=1}k=a+480204|0;o=a+480216|0;q=a+480220|0;r=a+480224|0;l=a+1074368|0;u=a+480228|0;B=a+480232|0;s=a+480200|0;m=a+480268|0;C=a+1298320|0;E=a+480248|0;F=Ev(a+1074312|0);G=a+480180|0;H=a+484376|0;I=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Mb(x[b>>2],x[b+8>>2],7)){break a}e=Mg(b);g=eh(b);if((e|0)==70791730){Eh(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Mb(x[b>>2],x[b+8>>2],g)){break a}d=f+152|0;ce(d,b,g);h=ic(f+172|0,d);ub(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=B;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=o;if((e|0)==1380991534){break s}d=q;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=u;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}x[31785]=0;S(455,h|0,g|0,f+152|0);d=x[31785];x[31785]=0;if((d|0)==1){break i}x[k>>2]=D(x[f+152>>2],1e4)+(A[k>>2]%1e4|0);break j}x[31785]=0;S(455,h|0,g|0,f+152|0);d=x[31785];x[31785]=0;if((d|0)!=1){d=x[k>>2];x[k>>2]=d-((d>>>0)%1e4|0)+A[f+152>>2]%1e4;break j}e=N()|0;break b}if(c){break j}x[31785]=0;w[f+152>>1]=0;S(456,h|0,g|0,f+152|0);d=x[31785];x[31785]=0;if((d|0)!=1){J=a,K=Hd(z[f+152>>1],z[a+480188>>1],127),w[J+480188>>1]=K;break j}e=N()|0;break b}x[31785]=0;S(457,h|0,g|0,l|0);d=x[31785];x[31785]=0;if((d|0)!=1){break j}break c}x[31785]=0;x[f+152>>2]=0;S(455,h|0,g|0,f+152|0);d=x[31785];x[31785]=0;if((d|0)!=1){x[a+1074304>>2]=x[f+152>>2];break j}e=N()|0;break b}x[31785]=0;x[f+152>>2]=0;S(455,h|0,g|0,f+152|0);d=x[31785];x[31785]=0;if((d|0)==1){break h}d=x[f+152>>2];if(!d){break j}x[a+1074308>>2]=d;break j}d=s}x[31785]=0;S(455,h|0,g|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break c}break j}if(x[G>>2]==4){break j}x[31785]=0;S(456,h|0,g|0,f+152|0);d=x[31785];x[31785]=0;if((d|0)!=1){_e(Wb(x[a+484360>>2],y[H|0]),z[f+152>>1]);break j}e=N()|0;break b}x[31785]=0;S(458,h|0,g|0,m|0);d=x[31785];x[31785]=0;if((d|0)==1){break c}if(kp(y[m|0])){break j}v[m|0]=5;break j}d=Fb(f+152|0);e=x[h>>2];x[31785]=0;e=R(157,e|0)|0;g=x[31785];x[31785]=0;x:{if((g|0)==1){break x}x[31785]=0;S(459,h|0,d|0,e|0);e=x[31785];x[31785]=0;if((e|0)==1){break x}x[31785]=0;S(261,f+140|0,0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break x}e=f+140|0;yb(C,e);tb(e);tb(d);break j}e=N()|0;tb(d);break b}if(g&1|g>>>0>126){break j}d=64;w[f+152>>1]=(g>>>1|0)- -64;w[f+140>>1]=127;e=z[Mc(f+152|0,f+140|0)>>1];i=e>>>0<=64?64:e;while(1){if((d|0)==(i|0)){break j}x[31785]=0;O(201,f+152|0,h|0);e=x[31785];x[31785]=0;if((e|0)==1){break g}e=y[f+152|0];y:{if((e|0)==255){break y}j=y[Ic(f+152|0)|0];g=(d<<5)+a|0;t=g+480284|0;w[t>>1]=128;w[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;x[g>>2]=j;e=e&127;if(e>>>0<65){w[t>>1]=e<<2;break y}if((e|0)!=100){break y}x[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}x[31785]=0;d=R(192,h|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}if(z[I>>1]<=(d-1&65535)>>>0){break j}d=(D(d,104)+a|0)+484448|0;g=kZ(d);while(1){if((d|0)==(g|0)){break j}e=x[h>>2];x[31785]=0;i=U(153,e|0,x[f+180>>2],4)|0;e=x[31785];x[31785]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}x[31785]=0;e=R(154,h|0)|0;i=x[31785];x[31785]=0;if((i|0)!=1){break z}}e=N()|0;break b}x[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}x[31785]=0;O(460,f+140|0,h|0);d=x[31785];x[31785]=0;A:{B:{C:{D:{if((d|0)!=1){x[31785]=0;S(461,f+152|0,x[f+140>>2],x[f+144>>2]);d=x[31785];x[31785]=0;if((d|0)==1){break D}x[31785]=0;d=P(106,f|0,f+152|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break C}tb(f+152|0);dc(f+140|0);e=x[h>>2];x[31785]=0;R(157,e|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break A}x[31785]=0;S(462,d|0,E|0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break A}Af(d);break j}e=N()|0;break b}e=N()|0;break B}e=N()|0;tb(f+152|0)}dc(f+140|0);break b}e=N()|0;Af(d);break b}e=0;g=Ev(F);E:while(1){d=x[h>>2];x[31785]=0;d=U(153,d|0,x[f+180>>2],1)|0;i=x[31785];x[31785]=0;if((i|0)==1){break d}if(!(d&e>>>0<121)){break j}x[31785]=0;i=R(200,h|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>120){break F}x[31785]=0;U(269,g|0,e|0,1)|0;j=x[31785];x[31785]=0;if((j|0)!=1){break F}e=N()|0;break b}e=e+1|0;d=d+1|0;continue}}}x[31785]=0;S(463,h|0,g|0,r|0);d=x[31785];x[31785]=0;if((d|0)==1){break c}}ub(h);continue}break}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0;break b}e=N()|0}ub(h);Q(e|0);p()}b=x[a+8>>2];vp(k,D(x[b+20>>2],1e4),D(x[b+24>>2],1e4));if(y[a+480224|0]>=3){v[r|0]=0}if(y[l|0]>=6){v[l|0]=0}vc(s,256);vc(o,65536);vc(q,65536)}fb=f+192|0;return n|0}function opa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0;e=fb-272|0;fb=e;xc(b);a:{if(!c$(b,e+206|0)){break a}if(!qX(e+206|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(pX(e+206|0),hb))){break a}b:{if(!c){break b}Bd(a,16);f=e+44|0;Zj(f,2,e+210|0);g=e- -64|0;Ec(g,f);yb(a+1298308|0,g);tb(g);k=a+480190|0;w[k>>1]=y[e+236|0];w[a+480188>>1]=y[e+239|0];d=uc(g,8385);yb(a+1298344|0,d);tb(d);d=uc(g,10139);yb(a+1298356|0,d);tb(d);cg(f,4231);d=y[e+209|0];x[e+24>>2]=d>>>4;x[31785]=0;x[e+12>>2]=d&15;V(310,g|0,f|0,e+24|0,e+12|0);d=x[31785];x[31785]=0;c:{d:{if((d|0)!=1){d=e- -64|0;yb(a+1298368|0,d);tb(d);Eb(e+44|0);B=a+1298404|0,C=x[Gc(d,4)>>2],x[B>>2]=C;d=1;while(1){j=d&65535;if(j>>>0>z[k>>1]){d=0;k=a+480188|0;while(1)if(z[k>>1]<=d>>>0){d=e- -64|0;f=fb-16|0;fb=f;i=b;e:{if(!Mb(x[b>>2],x[b+8>>2],128)){b=0;while(1){if((b|0)!=128){Wh(b+d|0);b=b+1|0;continue}break}break e}KY(f+8|0,d);md(f,i,x[f+8>>2],x[f+12>>2])}fb=f+16|0;uw(Wb(x[a+484360>>2],y[a+484376|0]),d,y[e+233|0]+1|0,255,254);d=y[e+238|0];b=e+24|0;ce(b,i,D(y[e+230|0]|y[e+231|0]<<8,192));m=ic(e+44|0,b);ub(b);f:{q=c&1;if(!q){break f}x[31785]=0;O(226,a+484344|0,y[e+232|0]+1|0);b=x[31785];x[31785]=0;if((b|0)!=1){break f}break d}r=d?d:64;s=a+484344|0;t=a+480188|0;b=0;while(1){g:{h:{i:{if(y[e+232|0]<n>>>0){if(!(b&u)){break h}B=e,C=vb(x[a+484344>>2]),x[B+12>>2]=C;j=vb(x[a+484348>>2]);break i}j:{if(q){x[31785]=0;f=U(199,s|0,n&65535,r|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break d}o=0;if(f){break j}}x[31785]=0;P(186,i|0,64)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break g}break d}while(1){k=o&65535;if(k>>>0>31){break g}x[31785]=0;f=R(192,i|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break d}k:{if((f-1&65535)>>>0>=(y[e+230|0]|y[e+231|0]<<8)>>>0|k>>>0>=z[t>>1]){break k}x[31785]=0;P(152,m|0,D(f,192)-192|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break d}f=0;d=Vb(x[s>>2],n);d=gd(x[d>>2],x[x[d+48>>2]+12>>2],0,k);while(1){if((f|0)==(r|0)){break k}k=b;x[31785]=0;O(552,e+24|0,m|0);b=x[31785];x[31785]=0;l:{m:{n:{o:{p:{if((b|0)!=1){b=e+24|0;j=Ic(b);g=Ze(b);b=y[e+24|0];if(b>>>0>=4){v[d|0]=(b>>>2|0)+37;b=y[e+24|0]}v[d+1|0]=b<<4&48|y[j|0]>>>4;b=y[g|0];l=0;g=0;q:{r:{j=y[j|0]&15;switch(j-8|0){case 0:break o;case 2:break q;case 6:break r;default:break p}}j=14;h=(b&240)<<24>>24;if((h|0)<=-17|!(435>>>((h+16&255)>>>4)&1)){break n}break o}b=b&240?b&-16:b;j=10;break n}break d}l=j;g=b}b=g;j=l;if(!((b|j)&255)){break m}}Mf(d,j,b&255);b=1;s:{switch(y[d+3|0]-16|0){case 0:break l;case 1:break s;default:break m}}u=1}b=k}f=f+1|0;d=D(z[t>>1],6)+d|0;continue}}o=o+1|0;continue}}while(1){t:{h=x[e+12>>2];if(Ib(h,j)){l=0;u:while(1){if(A[h+12>>2]<=l>>>0){break t}Ve(e+24|0,x[h>>2],x[x[h+48>>2]+12>>2],l);B=e,C=vb(x[e+24>>2]),x[B+20>>2]=C;f=0;k=pr(x[e+24>>2],x[e+28>>2]);g=0;while(1){b=x[e+20>>2];if(Ib(b,k)){d=1;v:{switch(y[b+3|0]-16|0){case 1:g=1;default:d=f;break;case 0:break v}}ah(e+20|0);f=d;continue}else{l=l+1|0;if(!(f&g&1)){continue u}break h}}}}B=e,C=vb(x[a+484344>>2]),x[B+20>>2]=C;k=vb(x[a+484348>>2]);w:while(1){g=x[e+20>>2];if(!Ib(g,k)){break h}f=0;x:while(1){if(A[g+12>>2]<=f>>>0){nv(e+20|0);continue w}Ve(e+12|0,x[g>>2],x[x[g+48>>2]+12>>2],f);B=e,C=vb(x[e+12>>2]),x[B+8>>2]=C;d=pr(x[e+12>>2],x[e+16>>2]);while(1){y:{b=x[e+8>>2];if(Ib(b,d)){b=y[b+3|0];if((b&254)!=16){break y}b=(b|0)==16;we(g,Ue(Le(e+24|0,b?17:16,b?125:6),f))}f=f+1|0;continue x}ah(e+8|0);continue}}}}nv(e+12|0);continue}}z:{b=y[e+234|0]|y[e+235|0]<<8;if(!b){break z}x[31785]=0;aa(319,a+1298332|0,i|0,b|0,39,1);b=x[31785];x[31785]=0;if((b|0)!=1){break z}break d}A:{if(!(c&2)){break A}d=1;f=a+480190|0;while(1){b=d&65535;if(b>>>0>z[f>>1]){break A}c=D(b,104)+a|0;b=ad(e+24|0,w[c+484414>>1]&1?16:8,1,0,1);x[31785]=0;U(218,b|0,c+484380|0,i|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){d=d+1|0;continue}break}break d}x[a+480260>>2]=64;x[a+480264>>2]=32767;ub(m);break b}n=n+1|0;continue}}else{f=(d<<5)+a|0;Ye(f+480280|0);w[f+480284>>1]=(y[(e+d|0)+240|0]<<4|8)&248;d=d+1|0;continue}}else{i=e- -64|0;SE(b,i);g=fb-16|0;fb=g;h=(D(j,104)+a|0)+484380|0;jd(h,0);w[g+14>>1]=y[i+35|0]<<2;w[g+12>>1]=256;B=h,C=z[Mc(g+14|0,g+12|0)>>1],w[B+30>>1]=C;f=y[i+22|0]|y[i+23|0]<<8|(y[i+24|0]<<16|y[i+25|0]<<24);B:{if(f>>>0<3){break B}x[h>>2]=f;x[h+4>>2]=y[i+26|0]|y[i+27|0]<<8|(y[i+28|0]<<16|y[i+29|0]<<24);x[g+8>>2]=y[i+30|0]|y[i+31|0]<<8|(y[i+32|0]<<16|y[i+33|0]<<24);x[g+4>>2]=1;B=h,C=x[_c(g+8|0,g+4|0)>>2]-1|0,x[B+8>>2]=C;vc(h+8|0,f);l=x[h+8>>2];f=x[h+4>>2];C:{if(l>>>0<=f+4>>>0){x[h+4>>2]=0;x[h+8>>2]=0;l=0;f=0;break C}if(l>>>0<3){break C}w[h+34>>1]=z[h+34>>1]|2}v[h+37|0]=y[i+34|0];B=h,C=iw(0,v[i+34|0]<<4),x[B+24>>2]=C;if(!(v[i+36|0]&1)){break B}x[h+8>>2]=l>>>1;x[h+4>>2]=f>>>1;w[h+34>>1]=z[h+34>>1]|1;x[h>>2]=x[h>>2]>>>1}fb=g+16|0;f=e+24|0;im(f,2,i);g=e+44|0;Ec(g,f);zc(((j<<5)+a|0)+946304|0,g);d=d+1|0;tb(g);continue}}}d=N()|0;Eb(e+44|0);break c}d=N()|0;ub(m)}Q(d|0);p()}d=1}fb=e+272|0;return d|0}function yoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-352|0;fb=d;a:{b:{c:{if(!bd(b,60)){break c}if(!Ap(b,d+332|0)){break c}e=15;if(ev(d+332|0,15)){break b}}if(!bd(b,124)){break a}if(!Ap(b,d+332|0)){break a}e=31;if(!ev(d+332|0,31)){break a}}Bd(a,536870912);w[a+480190>>1]=e;xc(b);d:{while(1){if(z[a+480190>>1]>f>>>0){g=fp(b);x[(d+208|0)+(f<<2)>>2]=g;f=f+1|0;if(g>>>0<=131072){continue}break d}break}Yb(b,20);e=0;w[a+480192>>1]=0;w[a+480188>>1]=4;f=y[d+336|0]|y[d+337|0]<<8;x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480196>>2]=6;o=a,q=Xe(1776930/+(Cb(f)>>>0)*1e4),x[o+480204>>2]=q;x[a+480228>>2]=64;Ch(a,1);m=1;e:while(1){l=m&65535;if(l>>>0<=z[a+480190>>1]){yC(b,d+52|0);f=x[((l<<2)+d|0)+204>>2];h=fb-16|0;fb=h;i=(D(l,104)+a|0)+484380|0;jd(i,1);x[i>>2]=f;v[i+37|0]=y[d+76|0]<<4;v[h+15|0]=y[d+77|0];v[h+14|0]=64;o=i,q=y[Ub(h+15|0,h+14|0)|0]<<2,w[o+30>>1]=q;f:{if(!f){break f}g=Cb(y[d+80|0]|y[d+81|0]<<8);k=Cb(y[d+78|0]|y[d+79|0]<<8);x[i+4>>2]=k;g=(g<<1)+k|0;x[i+8>>2]=g;if(f>>>0<=k>>>0){k=f-1|0;x[i+4>>2]=k}if(f>>>0<g>>>0){x[i+8>>2]=f;g=f}if(!(!(g>>>0<4|g>>>0<k>>>0)&g-k>>>0>3)){x[i+4>>2]=0;x[i+8>>2]=0;break f}if(g>>>0<=k>>>0){break f}w[i+34>>1]=z[i+34>>1]|2}fb=h+16|0;f=0;while(1)if((f|0)==22){if(e>>>0>=128){break d}g=d+184|0;im(g,3,d+52|0);f=d+196|0;Ec(f,g);zc(((l<<5)+a|0)+946304|0,f);m=m+1|0;tb(f);continue e}else{g=(d+52|0)+f|0;if((y[g|0]-1&255)>>>0<=30){v[g|0]=32;e=e+1|0}f=f+1|0;continue}}break}m=1;g:{h:{i:{e=a+946336|0;f=Cc(d+52|0,14115);if(!AW(e,f)){x[31785]=0;g=P(37,d+196|0,14126)|0;i=x[31785];x[31785]=0;if((i|0)==1){break i}m=AW(e,g);tb(g)}tb(f);f=0;g=d+52|0;e=AC(b,g);if(!e){wC(g)}if(!e){break a}g=y[d+52|0];if(!CW(g)){break a}if(!c){break g}w[d+50>>1]=0;while(1)if((f|0)==(g|0)){f=a+484360|0;e=a+484376|0;h=Wb(x[f>>2],y[e|0]);i=y[d+53|0];_e(h,g>>>0>i>>>0?i:0);uw(Wb(x[f>>2],y[e|0]),d+54|0,y[d+52|0],65535,65535);if(z[a+480190>>1]==31){Yb(b,4)}x[d+44>>2]=0;x[d+40>>2]=0;x[d+36>>2]=0;v[d+35|0]=0;n=c&1;if(n){$f(a+484344|0,z[d+50>>1])}l=a+484344|0;i=0;while(1){j:{k:{l:{if(z[d+50>>1]<=i>>>0){if(!(c&2)){break l}f=1;while(1){e=z[a+480190>>1];c=f&65535;if(e>>>0<c>>>0){break k}c=(D(c,104)+a|0)+484380|0;if(x[c>>2]){qg(ad(d+184|0,8,1,0,0),c,b)}f=f+1|0;continue}}m:{if(n){k=0;if(bh(l,i&65535,64)){break m}}Yb(b,1024);break j}n:while(1){if((k|0)==64){break j}f=Vb(x[l>>2],i);Ve(d+184|0,x[f>>2],x[x[f+48>>2]+12>>2],k);f=0;while(1)if((f|0)==4){k=k+1|0;continue n}else{g=Vc(x[d+184>>2],f);e=d+12|0;wn(e,b);o:{p:{q:{r:{if(y[xb(e,0)|0]!=255){break r}v[(d+44|0)+f|0]=0;v[(d+36|0)+f|0]=0;e=xb(d+12|0,1);h=y[e|0];if((h|0)==252&m){v[e|0]=254;break p}switch(h-252|0){case 1:break o;case 2:break p;case 0:break q;default:break r}}e=x[d+12>>2];x[d+28>>2]=e;x[d+8>>2]=e;e=d+33|0;Yo(e,d+8|0,g);h=Ic(e);e=y[g|0];s:{if(!e){break s}v[(d+36|0)+f|0]=0;v[(d+44|0)+f|0]=e;if(e>>>0>48){break s}v[d+27|0]=8;o=d,q=y[af(d+35|0,d+27|0)|0],v[o+35|0]=q}j=y[d+33|0];e=y[h|0];t:{if(j|e){v[g+5|0]=e;u:{v:{w:{switch(j-1|0){case 0:v[g+3|0]=1;break o;case 1:if(e>>>0>=16){v[g+3|0]=3;v[g+5|0]=(e&240)>>>4;break o}if(!e){break v}v[g+5|0]=e;v[g+3|0]=2;break o;case 2:if(y[(d+36|0)+f|0]){break v}v[g+5|0]=0;v[g+3|0]=19;break o;case 3:if(y[(d+36|0)+f|0]){break v}v[g+5|0]=1;v[g+3|0]=19;break o;case 4:h=y[g+1|0];if(!h){break v}v[d+27|0]=63;v[d+26|0]=e+(z[(D(h,104)+a|0)+484410>>1]>>>2|0);e=y[Ub(d+27|0,d+26|0)|0];v[g+5|0]=e;v[g+3|0]=13;if(!y[(d+36|0)+f|0]){break o}h=g+3|0;v[g+4|0]=e;v[g+2|0]=1;break u;case 5:h=g+3|0;j=y[g+1|0];if(!j){break u}v[g+3|0]=13;j=z[(D(j,104)+a|0)+484410>>1]>>>2|0;e=e>>>0<=j>>>0?j-e|0:0;v[g+5|0]=e;if(!y[(d+36|0)+f|0]){break o}v[g+4|0]=e;v[g+2|0]=1;break u;case 6:h=e&15;v[(d+36|0)+f|0]=h;j=y[(d+44|0)+f|0];e=j-((e&240)>>>4|0)|0;v[(d+40|0)+f|0]=e;o=g,q=zW(h,e&255,j),v[o+5|0]=q;v[g+3|0]=3;break o;case 7:h=e&15;v[(d+36|0)+f|0]=h;j=(e&240)>>>4|0;e=y[(d+44|0)+f|0];j=j+e|0;v[(d+40|0)+f|0]=j;o=g,q=zW(h,e,j&255),v[o+5|0]=q;v[g+3|0]=2;break o;case 8:break w;default:break v}}v[d+27|0]=8;o=d,q=y[af(d+35|0,d+27|0)|0],v[o+35|0]=q}h=g+3|0}v[h|0]=0;break t}if(y[g+3|0]){break o}}h=y[(d+36|0)+f|0];if(!h){break o}j=(d+40|0)+f|0;e=y[j|0];if(e){v[(d+44|0)+f|0]=e;v[g+5|0]=h;v[g|0]=e;v[j|0]=0}v[g+3|0]=4;break o}v[g+3|0]=14;v[d+35|0]=9;break o}v[g+3|0]=13}f=f+1|0;continue}}}e=z[a+480190>>1]}x:{y:{if((e&65535)==15){b=d+12|0;cg(b,4438);x[31785]=0;S(212,d+184|0,b|0,d+35|0);b=x[31785];x[31785]=0;if((b|0)!=1){break y}e=N()|0;Eb(d+12|0);break h}x[31785]=0;P(1,d+184|0,12411)|0;b=x[31785];x[31785]=0;if((b|0)==1){break x}}b=d+184|0;yb(a+1298344|0,b);tb(b);if((e&65535)==15){Eb(d+12|0)}$h(a+1298356|0,z[a+480190>>1]==15?5302:15289);o=a+1298404|0,q=x[Gc(d+184|0,28)>>2],x[o>>2]=q;break g}e=N()|0;break h}i=i+1|0;continue}}else{w[d+184>>1]=y[(d+f|0)+54|0]+1;o=d,q=z[se(d+50|0,d+184|0)>>1],w[o+50>>1]=q;f=f+1|0;continue}}e=N()|0;tb(f)}Q(e|0);p()}f=1;break a}f=0}fb=d+352|0;return f|0}function NL(a,b,c,d,e,f){var g=0,h=E(0),i=0,j=0,k=E(0),l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=E(0),A=E(0),C=0,F=0,G=0,H=E(0),I=E(0),J=E(0),K=E(0),L=E(0),M=E(0),N=E(0),O=E(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=D(s,2304)+b|0;u=0;q=(c|0)>0?c:0;n=fb-128|0;x=n+96|0;y=n- -64|0;C=n+32|0;while(1){if((q|0)!=(u|0)){o=G+(u<<2)|0;v=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=B[D(15-j|0,72)+o>>2];g=D(j,72)+o|0;h=B[g+1152>>2];l=E(k+h);m=B[g>>2];z=B[D(31-j|0,72)+o>>2];A=E(m+z);B[p>>2]=l+A;g=D(j,12);k=E(E(k-h)*B[g+87952>>2]);h=E(E(m-z)*B[g+87956>>2]);B[p+64>>2]=k+h;m=E(A-l);l=B[g+87960>>2];B[p+32>>2]=m*l;B[p+96>>2]=l*E(h-k);p=p+4|0;j=j+1|0;continue}break}while(1){if((v|0)!=4){l=B[i+8>>2];m=B[i+20>>2];h=E(l+m);z=B[i+4>>2];A=B[i+24>>2];H=E(z+A);k=E(h+H);I=B[i+12>>2];J=B[i+16>>2];K=E(I+J);L=B[i>>2];M=B[i+28>>2];N=E(L+M);O=E(K+N);B[i>>2]=k+O;B[i+16>>2]=E(O-k)*E(.7071067690849304);k=E(N-K);h=E(E(k+E(H-h))*E(.7071067690849304));B[i+24>>2]=E(k-h)*E(1.3065630197525024);B[i+8>>2]=E(k+h)*E(.5411961078643799);k=E(L-M);h=E(l-m);l=E(z-A);m=E(E(h+l)*E(.7071067690849304));z=E(k+m);A=E(E(I-J)+h);h=E(l+k);l=E(A-E(h*E(.1989123672246933)));h=E(E(l*E(.3826834261417389))+h);B[i+28>>2]=E(z-h)*E(2.562915563583374);B[i+4>>2]=E(z+h)*E(.509795606136322);k=E(k-m);h=E(l-E(h*E(.1989123672246933)));B[i+20>>2]=E(k+h)*E(.8999761939048767);B[i+12>>2]=E(k-h)*E(.601344883441925);i=i+32|0;v=v+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;B[o>>2]=B[p+n>>2];k=B[p+x>>2];i=i+1|0;j=i<<2;h=B[j+x>>2];B[o+72>>2]=E(B[p+y>>2]+k)+h;B[o+144>>2]=B[p+C>>2]+B[j+C>>2];B[o+216>>2]=h+E(k+B[j+y>>2]);o=o+288|0;continue}break}B[o>>2]=B[n+28>>2];k=B[n+124>>2];B[o+72>>2]=B[n+92>>2]+k;h=B[n+60>>2];B[o+216>>2]=k;B[o+144>>2]=h;u=u+1|0;continue}break}s=s+1|0;continue}break}C=yc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=fb-32|0;fb=i;o=C+(s<<8)|0;u=(s<<2)+b|0;B[o+4080>>2]=B[u+1152>>2];f=d-1|0;v=u+D(f,2304)|0;B[o+4084>>2]=B[v+1152>>2];B[o+4088>>2]=B[u>>2];B[o+4092>>2]=B[v>>2];B[o+4336>>2]=B[u+1156>>2];B[o+4340>>2]=B[v+1156>>2];B[o+4344>>2]=B[u+4>>2];B[o+4348>>2]=B[v+4>>2];x=(D(s,G)<<1)+e|0;y=x+(f<<1)|0;yt(y,d,o+244|0);f=d<<6;yt(f+y|0,d,o+500|0);yt(x,d,o+240|0);yt(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=88048;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=D(31-p|0,72);B[j>>2]=B[f+u>>2];B[j+4>>2]=B[f+v>>2];f=f|4;B[j+8>>2]=B[f+u>>2];B[j+12>>2]=B[f+v>>2];f=D(p,72);q=f+76|0;B[j+256>>2]=B[q+u>>2];B[j+260>>2]=B[q+v>>2];f=f+72|0;B[j-248>>2]=B[f+u>>2];B[j-244>>2]=B[f+v>>2];q=p<<2;t=g+o|0;k=B[n+4>>2];h=B[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=B[g+j>>2];m=B[g+t>>2];B[g+(i+16|0)>>2]=E(l*h)-E(k*m);B[i+g>>2]=E(l*k)+E(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=B[n+12>>2];h=B[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=B[n+20>>2];h=B[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=B[n+28>>2];h=B[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=B[n+36>>2];h=B[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=B[n+44>>2];h=B[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(m*k)-E(h*l))+B[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=B[n+52>>2];h=B[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=B[g+t>>2];m=B[g+q>>2];B[r>>2]=B[r>>2]+E(E(l*k)+E(h*m));g=g+(i+16|0)|0;B[g>>2]=E(E(l*h)-E(k*m))+B[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=B[n+60>>2];h=B[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=B[j+q>>2];m=B[g+j>>2];B[t>>2]=B[t>>2]+E(E(l*k)+E(h*m));j=j+(i+16|0)|0;B[j>>2]=E(E(m*k)-E(h*l))+B[j>>2];f=f+1|0;continue}break}f=D(15-p|0,d)<<1;P=f+y|0,Q=xj(B[i+20>>2]),w[P>>1]=Q;j=D(p+17|0,d)<<1;P=j+y|0,Q=xj(B[i+4>>2]),w[P>>1]=Q;P=f+x|0,Q=xj(B[i+16>>2]),w[P>>1]=Q;P=j+x|0,Q=xj(B[i>>2]),w[P>>1]=Q;f=D(47-p|0,d)<<1;P=f+y|0,Q=xj(B[i+28>>2]),w[P>>1]=Q;j=D(p+49|0,d)<<1;P=j+y|0,Q=xj(B[i+12>>2]),w[P>>1]=Q;P=f+x|0,Q=xj(B[i+24>>2]),w[P>>1]=Q;P=j+x|0,Q=xj(B[i+8>>2]),w[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}fb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}B[(s<<2)+a>>2]=B[C+(b+s<<2)>>2];s=s+2|0;continue}}yc(a,C+(b<<2)|0,3840)}}function Fsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;f=fb-272|0;fb=f;xc(b);e=fb-16|0;fb=e;i=f+66|0;ZZ(e+8|0,i);g=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);h=x[e+4>>2];if((h|0)==(g|0)){Yb(b,x[e+12>>2])}fb=e+16|0;e=(g|0)==(h|0);if(!e){YZ(i)}a:{if(!e){break a}if(!$Z(f+66|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(_Z(f+66|0),hb))){break a}b:{if(!c){break b}Bd(a,16777216);ag(a);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+44|0;cr(d,32);g=x[f+56>>2];e=a+1074320|0;x[e>>2]=x[f+52>>2];x[e+4>>2]=g;e=x[f+48>>2];x[a+1074312>>2]=x[f+44>>2];x[a+1074316>>2]=e;Lb(a+1074312|0,114,1);s=a+480188|0,t=Cb(y[f+266|0]|y[f+267|0]<<8),w[s>>1]=t;Ch(a,1);e=uc(d,8561);yb(a+1298368|0,e);tb(e);e=f+24|0;cg(e,3944);x[31785]=0;S(374,d|0,e|0,y[f+69|0]);d=x[31785];x[31785]=0;c:{if((d|0)!=1){d=f+44|0;yb(a+1298344|0,d);tb(d);e=f+24|0;Eb(e);g=uc(d,10799);yb(a+1298356|0,g);tb(g);s=a+1298404|0,t=x[Gc(d,26)>>2],x[s>>2]=t;Te(e,3,f+70|0);Ec(d,e);yb(a+1298308|0,d);tb(d);g=160;while(1){d:{d=g;if(!d){d=0;break d}g=d-1|0;if(y[(f+g|0)+102|0]==32){continue}}break}XZ(a+1298332|0,f+102|0,d,4);o=a+480190|0;d=Cb(y[f+262|0]|y[f+263|0]<<8);w[o>>1]=d;n=1;while(1){e:{f:{g:{h:{i:{e=d&65535;d=n&65535;if(e>>>0<d>>>0){g=a+484360|0;e=a+484376|0;_e(Wb(x[g>>2],y[e|0]),Cb(y[f+270|0]|y[f+271|0]<<8));d=f+24|0;ce(d,b,512);n=ic(f+44|0,d);ub(d);d=y[e|0];g=x[g>>2];i=y[f+268|0]|y[f+269|0]<<8;x[31785]=0;S(279,Wb(g,d)|0,n|0,Cb(i)|0);d=x[31785];x[31785]=0;if((d|0)!=1){break i}d=N()|0;break h}i=D(d,104)+a|0;k=i+484380|0;jd(k,1);Zo(k);b$(b,((d<<5)+a|0)+946304|0,y[f+69|0]==1?32:28);h=1;d=y[f+69|0];if(d>>>0>=3){Yb(b,14);d=uD(b);if((d|0)>=0){e=i+484414|0;w[e>>1]=z[e>>1]|32;s=i+484408|0,t=Bc((((d&65535)<<8)+2047>>>0)/4095|0,0),w[s>>1]=t}d=y[f+69|0]}if((d&255)>>>0>=2){h=Qk(b);s=i+484404|0,t=Qk(b),x[s>>2]=t}d=f+44|0;g=fb-16|0;fb=g;j:{if(!Mb(x[b>>2],x[b+8>>2],12)){x[g>>2]=0;e=d;j=3;while(1){if(j){l=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);v[e|0]=l;v[e+1|0]=l>>>8;v[e+2|0]=l>>>16;v[e+3|0]=l>>>24;j=j-1|0;e=e+4|0;continue}break}break j}kr(g+8|0,d);md(g,b,x[g+8>>2],x[g+12>>2])}fb=g+16|0;e=ec(d);d=Ab(d);l=$b(x[f+44>>2]);x[k>>2]=l;m=i+484384|0;j=$b(y[e|0]|y[e+1|0]<<8|(y[e+2|0]<<16|y[e+3|0]<<24));x[m>>2]=j;q=i+484388|0;r=$b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))+j|0;x[q>>2]=r;e=i+484414|0;if(j){g=z[e>>1];break f}g=z[e>>1];if($b(y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24))>>>0>=3){break f}d=g&-3;break e}d=vb(x[Wb(x[a+484360>>2],y[e|0])>>2]);g=vb(x[Wb(x[a+484360>>2],y[e|0])+4>>2]);e=fb-16|0;fb=e;k:{if(!Ib(d,g)){break k}x[e+12>>2]=d;while(1){i=x[Wd(e+12|0)>>2];if(!Ib(i,g)){break k}d=_k(z[d>>1],z[i>>1])?i:d;continue}}fb=e+16|0;d=z[d>>1];x[31785]=0;l=a+484344|0;q=d+1&65535;O(226,l|0,q|0);d=x[31785];x[31785]=0;if((d|0)!=1){d=y[f+69|0];x[f+20>>2]=x[a+480204>>2];x[f+16>>2]=x[a+480196>>2];o=d>>>0<4?4:5;r=c&1;j=a+480188|0;e=0;while(1){if((e|0)==(q|0)){if(!(c&2)){break g}d=1;c=a+480190|0;while(1){e=d&65535;if(e>>>0>z[c>>1]){break g}e=D(e,104)+a|0;g=ad(f+8|0,w[e+484414>>1]&1?16:8,1,1,0);x[31785]=0;U(218,g|0,e+484380|0,b|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){d=d+1|0;continue}break}d=N()|0;break h}l:{if(!r){break l}d=y[f+264|0]|y[f+265|0]<<8;g=x[b+8>>2];i=z[j>>1];h=x[b>>2];x[31785]=0;d=U(153,h|0,g|0,D(i,D(Cb(d),o))|0)|0;g=x[31785];x[31785]=0;m:{n:{if((g|0)==1){break n}if(!d){break l}d=y[f+264|0]|y[f+265|0]<<8;x[31785]=0;d=U(199,l|0,e&65535,Cb(d)|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break n}if(!d){break l}d=z[j>>1];v[f|0]=0;g=ae(f+8|0,0,f);x[31785]=0;i=U(375,f+24|0,d|0,g|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break m}g=0;o:while(1){if(Cb(y[f+264|0]|y[f+265|0]<<8)>>>0<=g>>>0){kd(i);break l}d=Vb(x[l>>2],e);Ve(f+8|0,x[d>>2],x[x[d+48>>2]+12>>2],g);d=0;while(1){if(z[j>>1]<=d>>>0){g=g+1|0;continue o}k=Vc(x[f+8>>2],d);v[f+4|0]=0;x[31785]=0;x[f>>2]=0;S(376,b|0,f|0,o|0);h=x[31785];x[31785]=0;p:{if((h|0)==1){break p}h=y[f|0];if((h-24&255)>>>0<=59){h=h+13|0;v[k|0]=h;s=_b(x[i>>2],d),t=h,v[s|0]=t}m=y[f+1|0];q:{if(!m){h=_b(x[i>>2],d);break q}v[k+1|0]=m;h=_b(x[i>>2],d);v[h+1|0]=m}m=y[h+1|0];h=y[h|0];x[31785]=0;ya(377,a|0,k|0,y[f+2|0],y[f+3|0],0-y[f+69|0]|0,h|0,m|0,f+20|0,f+16|0);h=x[31785];x[31785]=0;if((h|0)==1){break p}h=y[f+4|0];if(h){v[k+2|0]=1;v[k+4|0]=h+1>>>2}d=d+1|0;continue}break}break}d=N()|0;kd(i);break h}d=N()|0;break h}d=N()|0;break h}e=e+1|0;continue}}d=N()|0}ub(n);break c}ub(n);break b}d=g|2}w[e>>1]=d;if((h|0)==2){w[e>>1]=d|1;x[k>>2]=l>>>1;x[m>>2]=j>>>1;x[q>>2]=r>>>1}s=i+484410|0,t=Qk(b),w[s>>1]=t;d=uD(b);if(d){_l(k,+(d|0)/96)}v[i+484417|0]=d<<4;n=n+1|0;d=z[o>>1];continue}}d=N()|0;Eb(f+24|0)}Q(d|0);p()}d=1}fb=f+272|0;return d|0}function Ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;i=fb-192|0;fb=i;xc(b);a:{if(!zD(b,i+144|0)){break a}if(!qV(i+144|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],Bc(pV(y[i+191|0]),hb))){break a}Bd(a,128);g=i+132|0;Te(g,2,i+159|0);d=i- -64|0;Ec(d,g);yb(a+1298308|0,d);tb(d);e=uc(d,8473);yb(a+1298344|0,e);tb(e);e=uc(d,6076);yb(a+1298356|0,e);tb(e);g=uc(g,18360);x[31785]=0;S(760,d|0,g|0,x[(y[i+158|0]<<2)+25468>>2]);d=x[31785];x[31785]=0;c:{if((d|0)!=1){d=i- -64|0;yb(a+1298368|0,d);tb(d);tb(g);A=a+1298404|0,B=x[Gc(d,4)>>2],x[A>>2]=B;x[a+480208>>2]=12;TD(a+1298332|0,b,y[i+191|0]<<5,32,0);m=a+480190|0;e=be(b);w[m>>1]=e;g=1;while(1){j=g&65535;if(j>>>0>(e&65535)>>>0){Wk(Wb(x[a+484360>>2],y[a+484376|0]),b,256,255,254);g=0;d=be(b);if(d>>>0>=127){break a}f=a+480188|0;w[f>>1]=d+1;d=be(b);while(1)if(z[f>>1]<=g>>>0){o=a+484344|0;r=d+1|0;$f(o,r);e=0;while(1){d:{f=e&65535;if(f>>>0>d>>>0){s=a+480188|0;e:while(1){u=t&65535;g=z[s>>1];if(u>>>0>=g>>>0){d=Mo(i+12|0);v[d+16|0]=0;w[d+14>>1]=0;w[d+12>>1]=g;x[31785]=0;O(762,d|0,g|0);g=x[31785];x[31785]=0;if((g|0)==1){a=N()|0;$e(d);Q(a|0);p()}x[31785]=0;S(761,i+32|0,o|0,d|0);e=x[31785];x[31785]=0;g=1;if((e|0)==1){break d}$e(i+32|0);$e(d);if(!(c&2)){break a}c=a+480190|0;while(1){d=g&65535;if(d>>>0>z[c>>1]){break b}d=D(d,104)+a|0;qg(ad(i- -64|0,w[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);g=g+1|0;continue}}k=0;f=Jg(i- -64|0);f:while(1){g:{if((k|0)!=(r|0)){if(Mb(x[b>>2],x[b+8>>2],5)){break g}}t=t+1|0;continue e}e=0;d=Vb(x[o>>2],k);g=gd(x[d>>2],x[x[d+48>>2]+12>>2],0,u);while(1){h:{i:{if(e>>>0>63){break i}m=y[i+158|0];h=fb-16|0;fb=h;q=1;d=be(b);if((d|0)==252){q=be(b);d=be(b)}v[f|0]=(d-1&255)>>>0<60?d+36|0:0;d=h+12|0;wn(d,b);l=Ic(d);j=Ze(d);d=cj(d);v[f+1|0]=y[h+12|0];n=h+10|0;nV(n,y[l|0]&15,y[j|0],m);j=Ic(n);n=h+8|0;nV(n,y[l|0]>>>4|0,y[d|0],m);m=Ic(n);d=y[h+10|0];n=(d|0)!=10;l=y[h+8|0];j:{if(!(n|(l|0)!=10)){j=y[j|0];d=y[m|0];v[f+3|0]=10;j=j|d<<8;v[f+5|0]=j>>>6;if(j>>>0<16384){break j}v[f+2|0]=15;v[f+4|0]=d>>>6;break j}k:{l:{m:{n:{o:{if(!n){l=y[j|0];n=l<<2;A=j,B=ej(n),v[A|0]=B;if(l>>>0<64){break o}d=y[h+8|0];if(Uh(d)>>>0>=Uh(10)>>>0){break n}v[f+5|0]=n;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=l>>>6;break j}if((l|0)==10){d=y[m|0];l=d<<2;A=m,B=ej(l),v[A|0]=B;if(d>>>0<64){break o}if(Uh(y[h+10|0])>>>0>=Uh(10)>>>0){break o}v[f+5|0]=l;v[f+2|0]=15;v[f+3|0]=10;v[f+4|0]=d>>>6;break j}if((d|0)!=(l|0)){break o}v[h+8|0]=0;break m}d=y[h+8|0]}if((d|0)==13){break l}if(d){break k}d=y[h+10|0]}if((d|0)==13){break k}}og(h+10|0,h+8|0);og(j,m)}gw(h+8|0,m,h+10|0,j);sn(h+6|0,f,y[h+10|0],y[j|0],y[h+8|0],y[m|0])}fb=h+16|0;h=e+q|0;e=h>>>0>64?64-e|0:q;if(!e){break i}while(1){if(!e){break h}d=y[f|0]|y[f+1|0]<<8|(y[f+2|0]<<16|y[f+3|0]<<24);v[g|0]=d;v[g+1|0]=d>>>8;v[g+2|0]=d>>>16;v[g+3|0]=d>>>24;d=y[f+4|0]|y[f+5|0]<<8;v[g+4|0]=d;v[g+5|0]=d>>>8;e=e-1|0;g=D(z[s>>1],6)+g|0;continue}}k=k+1|0;continue f}e=h>>>0>=64?64:h;continue}}}}e=e+1|0;g=0;if(bh(o,f,64)){continue}break a}break}e=N()|0;$e(d);break c}else{e=(g<<5)+a|0;Ye(e+480280|0);h=e+480284|0;p:{if(y[i+158|0]>=51){e=(be(b)<<4|8)&248;break p}e=g&1?192:64}w[h>>1]=e;g=g+1|0;continue}}else{q:{if(y[i+158|0]>=52){d=i- -64|0;if(!J_(b,d)){WD(d)}break q}f=i- -64|0;d=fb-32|0;fb=d;x[d+28>>2]=64;x[d+8>>2]=66;h=x[b>>2];k=x[b+8>>2];e=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(h,k,e)){e=jf(b)}h=d+8|0;Yv(h,f);k=gc(d+16|0,x[d+8>>2],e);o=x[k>>2];kc(d,x[b>>2],x[b+8>>2],o,x[k+4>>2]);Yv(h,f);Tb(x[d+8>>2]+e|0,0,66-e|0);Yb(b,x[d+28>>2]);fb=d+32|0;d=y[i+126|0]|y[i+127|0]<<8;v[i+128|0]=d;v[i+129|0]=d>>>8;v[i+126|0]=171;v[i+127|0]=32}h=fb-32|0;fb=h;f=(D(j,104)+a|0)+484380|0;jd(f,0);Zo(f);k=h+8|0;e=i- -64|0;Lk(k,2,e+32|0);d=h+20|0;Ec(d,k);ye(f+43|0,d);tb(d);d=y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24);k=y[e+52|0]|y[e+53|0]<<8|(y[e+54|0]<<16|y[e+55|0]<<24);r:{if(d>>>0<=k>>>0){break r}x[f>>2]=d-k;x[f+12>>2]=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[h+20>>2]=y[e+48|0]|y[e+49|0]<<8|(y[e+50|0]<<16|y[e+51|0]<<24);A=f,B=x[Gb(h+20|0,f)>>2],x[A+16>>2]=B;w[f+30>>1]=y[e+60|0];x[f+24>>2]=y[e+62|0]|y[e+63|0]<<8;d=y[e+64|0]|y[e+65|0]<<8;if(d){_l(f,+(d<<16>>16)/393216)}d=y[e+61|0];if(d&8){w[f+34>>1]=z[f+34>>1]|8;d=y[e+61|0]}if(d&16){w[f+34>>1]=z[f+34>>1]|16;d=y[e+61|0]}if(!(d&4)){break r}w[f+34>>1]=z[f+34>>1]|1;x[f+12>>2]=x[f+12>>2]>>>1;x[f+16>>2]=x[f+16>>2]>>>1}fb=h+32|0;f=i+52|0;Te(f,2,e);d=i+132|0;Ec(d,f);zc(((j<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);e=z[m>>1];continue}}}e=N()|0;tb(g)}Q(e|0);p()}g=1}fb=i+192|0;return g|0}function Wna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-112|0;fb=d;xc(c);a:{b:{c:{d:{if(!_o(c,d+100|0)){break d}if(Ob(d+100|0,13918,4)){break d}g=d+108|0;e:{if(!Ob(g,13616,4)){break e}if(!Ob(g,13674,4)){break e}if(Ob(g,14381,4)){break d}}e=fb-32|0;fb=e;i=Nb(d+88|0);f:{g:{h:{i:{j:{while(1){h=x[c+8>>2];l=x[c>>2];x[31785]=0;h=U(153,l|0,h|0,8)|0;l=x[31785];x[31785]=0;if((l|0)==1){break h}if(!h){break i}x[31785]=0;O(836,e+4|0,c|0);h=x[31785];x[31785]=0;if((h|0)!=1){x[31785]=0;O(837,i|0,e+4|0);h=x[31785];x[31785]=0;if((h|0)==1){break j}Fd(e+4|0);continue}break}a=N()|0;break g}a=N()|0;Fd(e+4|0);break g}fb=e+32|0;break f}a=N()|0}fe(i);Q(a|0);p()}x[31785]=0;h=R(171,d+68|0)|0;c=x[31785];x[31785]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if((c|0)!=1){i=ad(d- -64|0,8,1,1,0);if(Ob(g,14381,4)){break r}x[31785]=0;S(745,d+44|0,d+88|0,1296581714);c=x[31785];x[31785]=0;if((c|0)==1){break o}x[31785]=0;S(745,d+24|0,d+88|0,1296318804);c=x[31785];x[31785]=0;if((c|0)==1){break c}c=d+24|0;e=hd(h,c);ub(c);x[31785]=0;c=R(746,d+44|0)|0;g=x[31785];x[31785]=0;f=1;if((g|0)==1){break c}if(!c){break s}c=x[e>>2];x[31785]=0;c=R(175,c|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}if(!c){break s}x[31785]=0;j=R(284,d+44|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}x[31785]=0;e=R(276,d+44|0)|0;c=x[31785];x[31785]=0;u:{if((c|0)==1){break u}x[31785]=0;P(186,d+44|0,2)|0;c=x[31785];x[31785]=0;if((c|0)==1){break u}x[31785]=0;m=R(284,d+44|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break t}}break c}f=N()|0;break a}x[31785]=0;O(656,d+24|0,d+44|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}c=QZ(d+24|0);g=Cb(z[d+24>>1]);if(!g){break s}m=(m>>>0)/(g>>>0)|0;f=d+24|0;g=ec(f);k=Ze(f);f=1;g=Cb(y[g|0]|y[g+1|0]<<8);if((g|0)!=(Cb(y[k|0]|y[k+1|0]<<8)+1|0)){break s}if((g|0)==2){mp(i,2)}v:{if((e|0)!=16){if((e|0)!=8){break s}w:{switch(Cb(y[c|0]|y[c+1|0]<<8)|0){case 0:ug(i,1);break v;case 2:ug(i,17);break v;case 3:break w;default:break s}}ug(i,16);break v}if(Cb(y[c|0]|y[c+1|0]<<8)){break s}ed(i,16)}f=0}ub(d+44|0);if(!f){break q}f=0;break k}x[31785]=0;S(745,d+44|0,d+88|0,1447576658);c=x[31785];x[31785]=0;x:{y:{z:{if((c|0)!=1){x[31785]=0;S(745,d+24|0,d+88|0,1128808782);c=x[31785];x[31785]=0;if((c|0)==1){break z}x[31785]=0;S(745,d+4|0,d+88|0,1112491097);c=x[31785];x[31785]=0;if((c|0)==1){break y}c=d+4|0;l=hd(h,c);ub(c);c=x[l>>2];x[31785]=0;e=R(175,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break y}c=0;A:{if(!e){break A}x[31785]=0;e=R(175,x[d+44>>2])|0;c=x[31785];x[31785]=0;if((c|0)==1){break y}c=0;if(!e){break A}x[31785]=0;e=P(747,d+44|0,d+4|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break y}c=0;if(!e){break A}m=Ob(g,13616,4);x[31785]=0;g=R(284,d+24|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break y}if(m){ed(i,16)}if((g|0)==6){mp(i,3)}k=$b(x[d+4>>2]);e=x[d+8>>2];c=x[d+12>>2];j=$b(c);B:{C:{if(j>>>0<33){break C}n=$b(e);if(n>>>0<=j>>>0){break C}if(!((n>>>0)%(j>>>0)|0)){break B}}c=e}e=x[l>>2];x[31785]=0;l=x[d+20>>2];n=z[d+16>>1];j=R(157,e|0)|0;e=x[31785];x[31785]=0;o=1;if((e|0)==1){break y}e=((g|0)==6)+((m|0)!=0)|0;k=k>>>e|0;j=j>>>e|0;q=$b(l);m=Cb(n);c=$b(c)>>>e|0}ub(d+24|0);ub(d+44|0);if(o){break p}break k}f=N()|0;break b}f=N()|0;break x}f=N()|0;ub(d+24|0)}ub(d+44|0);break b}c=0;k=0}Du(a,b);x[31785]=0;f=D(b,104)+a|0;e=f+484380|0;O(282,e|0,0);g=x[31785];x[31785]=0;if((g|0)==1){break n}x[e>>2]=j;c=c+k|0;x[f+484388>>2]=c;x[f+484384>>2]=k;if(!(c>>>0<=k+4>>>0|c>>>0>j>>>0)){c=(D(b,104)+a|0)+484414|0;w[c>>1]=z[c>>1]|2}c=D(b,104)+a|0;x[c+484404>>2]=m>>>0<2?22050:m;g=c+484410|0;c=q+128|0;f=c>>>8|0;w[g>>1]=(c&16776960)>>>0>65536?256:f&65535?f:256;RB(e,x[a+480180>>2]);x[31785]=0;S(745,d+44|0,d+88|0,1312902469);c=x[31785];x[31785]=0;if((c|0)==1){break m}x[31785]=0;c=R(175,x[d+44>>2])|0;f=x[31785];x[31785]=0;if((f|0)==1){break l}D:{E:{if(c){x[31785]=0;c=R(157,x[d+44>>2])|0;f=x[31785];x[31785]=0;if((f|0)==1){break l}x[31785]=0;S(334,d+44|0,((b<<5)+a|0)+946304|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break E}break l}x[31785]=0;c=P(37,d+24|0,22485)|0;f=x[31785];x[31785]=0;if((f|0)==1){break D}zc(((b<<5)+a|0)+946304|0,c);tb(c)}x[31785]=0;U(218,i|0,e|0,h|0)|0;b=x[31785];x[31785]=0;f=1;if((b|0)==1){break l}Mj(e,a);ub(d+44|0);break k}break l}f=N()|0;break b}f=N()|0;break b}f=N()|0;break b}f=N()|0;ub(d+44|0);break b}ub(h);fe(d+88|0)}fb=d+112|0;return f|0}f=N()|0;ub(d+44|0)}ub(h)}fe(d+88|0);Q(f|0);p()}function Rd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=fb-96|0;fb=k;u=i&65535;o=(e^i)&-2147483648;r=e&65535;A=r;R=i>>>16&32767;S=e>>>16&32767;a:{b:{if(R-32767>>>0>4294934529&S-32767>>>0>=4294934530){break b}s=e&2147483647;q=s;j=d;if(!(!d&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){m=d;o=e|32768;break a}s=i&2147483647;p=s;e=h;if(!(!e&(p|0)==2147418112?!(f|g):p>>>0<2147418112)){m=h;o=i|32768;b=f;c=g;break a}if(!(b|j|(q^2147418112|c))){if(!(e|f|(g|p))){o=2147450880;b=0;c=0;break a}o=o|2147418112;b=0;c=0;break a}if(!(e|f|(p^2147418112|g))){e=b|j;d=c|q;b=0;c=0;if(!(d|e)){o=2147450880;break a}o=o|2147418112;break a}if(!(b|j|(c|q))){b=0;c=0;break a}if(!(e|f|(g|p))){b=0;c=0;break a}if((q|0)==65535|q>>>0<65535){j=!(d|r);i=j?b:d;s=j<<6;e=G(i)+32|0;i=G(j?c:r);i=s+((i|0)==32?e:i)|0;Vf(k+80|0,b,c,d,r,i-15|0);t=16-i|0;d=x[k+88>>2];A=x[k+92>>2];c=x[k+84>>2];b=x[k+80>>2]}if(p>>>0>65535){break b}i=!(h|u);e=i?f:h;r=i<<6;j=G(e)+32|0;e=G(i?g:u);e=r+((e|0)==32?j:e)|0;Vf(k- -64|0,f,g,h,u,e-15|0);t=(t-e|0)+16|0;h=x[k+72>>2];u=x[k+76>>2];f=x[k+64>>2];g=x[k+68>>2]}e=f;f=g<<15|f>>>17;i=e<<15;e=0;v=i&-32768;L=c;s=sua(v,e,c,0);e=hb;z=e;M=f;q=b;b=sua(f,0,b,0);i=b+s|0;f=hb+e|0;c=b>>>0>i>>>0?f+1|0:f;j=0;b=sua(q,l,v,l);p=j+b|0;f=i;e=f+hb|0;e=b>>>0>p>>>0?e+1|0:e;r=e;N=(f|0)==(e|0)&j>>>0>p>>>0|e>>>0<f>>>0;O=d;w=sua(v,l,d,0);P=hb;b=sua(L,l,M,l);y=b+w|0;j=hb+P|0;j=b>>>0>y>>>0?j+1|0:j;b=u<<15|h>>>17;B=h<<15|g>>>17;d=sua(B,0,q,l);C=d+y|0;f=hb+j|0;f=d>>>0>C>>>0?f+1|0:f;D=f;d=(c|0)==(z|0)&i>>>0<s>>>0|c>>>0<z>>>0;E=c+C|0;f=d+f|0;f=c>>>0>E>>>0?f+1|0:f;u=f;g=E;c=f;F=A|65536;A=sua(v,l,F,n);Q=hb;d=sua(O,m,M,l);H=d+A|0;e=hb+Q|0;e=d>>>0>H>>>0?e+1|0:e;i=e;I=b|-2147483648;b=sua(I,0,q,l);J=b+H|0;f=hb+e|0;f=b>>>0>J>>>0?f+1|0:f;b=sua(B,m,L,l);z=b+J|0;K=f;f=f+hb|0;s=b>>>0>z>>>0?f+1|0:f;b=0;q=b+g|0;e=c+z|0;v=b>>>0>q>>>0?e+1|0:e;f=v;b=q+N|0;c=b>>>0<q>>>0?f+1|0:f;t=((S+R|0)+t|0)-16383|0;d=sua(I,m,L,l);h=hb;e=sua(F,m,M,l);g=e+d|0;f=hb+h|0;f=e>>>0>g>>>0?f+1|0:f;n=(h|0)==(f|0)&d>>>0>g>>>0|f>>>0<h>>>0;h=f;e=sua(B,m,O,m);d=e+g|0;f=hb+f|0;f=d>>>0<e>>>0?f+1|0:f;e=f;g=(f|0)==(h|0)&d>>>0<g>>>0|f>>>0<h>>>0;f=0;h=g;g=g+n|0;f=h>>>0>g>>>0?1:f;h=g;g=sua(I,m,F,m);h=h+g|0;f=hb+f|0;N=h;g=g>>>0>h>>>0?f+1|0:f;h=d;l=e;e=(j|0)==(P|0)&w>>>0>y>>>0|j>>>0<P>>>0;f=0;j=(j|0)==(D|0)&y>>>0>C>>>0|j>>>0>D>>>0;n=j;j=e+j|0;e=(n>>>0>j>>>0?1:f)+l|0;f=g;d=d+j|0;e=d>>>0<j>>>0?e+1|0:e;n=e;w=d;d=(e|0)==(l|0)&d>>>0<h>>>0|e>>>0<l>>>0;e=d;d=d+N|0;f=e>>>0>d>>>0?f+1|0:f;j=d;g=f;e=sua(B,m,F,m);l=hb;d=sua(I,m,O,m);h=d+e|0;f=hb+l|0;f=d>>>0>h>>>0?f+1|0:f;d=f;f=(l|0)==(f|0)&e>>>0>h>>>0|f>>>0<l>>>0;y=d+j|0;e=f+g|0;e=d>>>0>y>>>0?e+1|0:e;l=y;g=e;e=0;d=e+w|0;f=h+n|0;f=d>>>0<e>>>0?f+1|0:f;e=f;h=(n|0)==(f|0)&d>>>0<w>>>0|f>>>0<n>>>0;f=g;g=h+l|0;f=g>>>0<h>>>0?f+1|0:f;w=g;g=f;h=d;j=e;e=(s|0)==(K|0)&z>>>0<J>>>0|s>>>0<K>>>0;d=(i|0)==(Q|0)&A>>>0>H>>>0|i>>>0<Q>>>0;i=(i|0)==(K|0)&H>>>0>J>>>0|i>>>0>K>>>0;d=d+i|0;d=d+e|0;n=s;i=n+h|0;e=d+j|0;f=g;d=i;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(j|0)&h>>>0>d>>>0|e>>>0<j>>>0;g=h+w|0;f=h>>>0>g>>>0?f+1|0:f;j=g;g=f;h=d;f=0;i=e;n=(u|0)==(v|0)&q>>>0<E>>>0|u>>>0>v>>>0;l=n;n=n+((u|0)==(D|0)&C>>>0>E>>>0|u>>>0<D>>>0)|0;e=e+(l>>>0>n>>>0?1:f)|0;f=g;d=d+n|0;e=d>>>0<n>>>0?e+1|0:e;h=(e|0)==(i|0)&d>>>0<h>>>0|e>>>0<i>>>0;g=h;h=h+j|0;f=g>>>0>h>>>0?f+1|0:f;i=f;c:{if(f&65536){t=t+1|0;break c}j=r>>>31|0;g=0;f=i<<1|h>>>31;h=h<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;f=r<<1|p>>>31;p=p<<1;r=f;f=c<<1|b>>>31;b=b<<1|j;c=f|g}if((t|0)>=32767){o=o|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){g=1-t|0;if(g>>>0<=127){f=t+127|0;Vf(k+48|0,p,r,b,c,f);Vf(k+32|0,d,e,h,i,f);Vm(k+16|0,p,r,b,c,g);Vm(k,d,e,h,i,g);p=x[k+32>>2]|x[k+16>>2]|(x[k+48>>2]|x[k+56>>2]|(x[k+52>>2]|x[k+60>>2]))!=0;r=x[k+36>>2]|x[k+20>>2];b=x[k+40>>2]|x[k+24>>2];c=x[k+44>>2]|x[k+28>>2];d=x[k>>2];e=x[k+4>>2];g=x[k+8>>2];f=x[k+12>>2];break d}b=0;c=0;break a}g=h;f=i&65535|t<<16}m=g|m;o=f|o;if(!(!b&(c|0)==-2147483648?!(p|r):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;e=o;c=j;d=!(j|b);m=d+m|0;o=d>>>0>m>>>0?e+1|0:e;break a}if(b|p|(c^-2147483648|r)){b=d;c=e;break a}f=e;b=d&1;c=b;b=b+d|0;f=c>>>0>b>>>0?f+1|0:f;c=f;d=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;f=o;m=d+m|0;o=m>>>0<d>>>0?f+1|0:f}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=m;x[a+12>>2]=o;fb=k+96|0}function vS(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=fb-16|0;fb=h;a:{if(!zd(d&255)){break a}m=a+1074376|0;j=(m+D(b,872)|0)+616|0;b:{g=z[a+480192>>1];if(!(!(x[a+480180>>2]&17825824)|!g|e)){break b}if(Gj(x[j+656>>2])){break b}c=D(b,872)+a|0;d=c+1075068|0;if(!x[d>>2]){break a}c=x[c+1075080>>2];if(c&1024){break a}e=D(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(x[g>>2]|x[e>>2])){break a}c:{if(!(c&512)){break c}c=x[a+1298300>>2];if(!xd(c)){break c}Jj(c,b,0);break a}c=SA(a,b);if((c|0)==65535){break a}i=D(c,872);c=a+1074992|0;a=i+c|0;sq(a,j);v[a+831|0]=0;v[a+805|0]=0;w[a+786>>1]=b+1;x[a+88>>2]=x[a+88>>2]&-918529;No(a+788|0);x[a+696>>2]=0;x[a+88>>2]=x[a+88>>2]|2101248;x[d>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=c+D(b,872)|0;x[a+92>>2]=0;x[a+96>>2]=0;x[g>>2]=0;x[e>>2]=0;break a}e=D(b,872)+a|0;l=x[e+1075096>>2];c=c>>>0<=g>>>0?c:0;g=x[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}k=d-1|0;c=z[_b(g+236|0,k)>>1];f=a+1074312|0;Kb(h+8|0,f,104);e:{if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){Kb(h,f,34);if(Hb(x[x[h>>2]>>2],x[h+4>>2])){break e}}d=y[xb(g+108|0,k)|0]}if((c-1&65535)>>>0<=3998){l=(D(c,104)+a|0)+484380|0;break d}Kb(h+8|0,f,43);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break d}if(!Nj(y[g+31|0])){break a}}if(y[e+1075081|0]&4){break a}o=b>>>0<=256?256:b;k=a+1074312|0;p=b+1|0;q=a+480188|0;c=b;f:{while(1){if((c|0)==(o|0)){g:{e=0;c=0;if(!Gj(x[j+656>>2])){break f}c=0;if(!zd(y[(D(b,872)+a|0)+1075789|0])){break f}d=lm(a,m,b,2,1)-1|0;c=0;if((d&255)>>>0>249){break f}e=x[rd(a+906300|0,d)>>2];if(e){break g}e=0;c=0;break f}}else{h:{if((b|0)!=(c|0)&z[q>>1]>c>>>0){break h}e=D(c,872)+a|0;if(z[e+1075778>>1]!=(p|0)&(b|0)!=(c|0)){break h}n=e+1075648|0;f=x[n>>2];if(!f){break h}i:{j:{k:{l:{m:{n:{o:{switch(y[f+17|0]-1|0){case 0:if(!d){break h}i=y[e+1075789|0]==(d|0)&(f|0)==(g|0);if(!g){break n}if(i){break k}break h;case 1:if(!l|x[e+1075096>>2]!=(l|0)){break h}if((f|0)==(g|0)){break i}Kb(h+8|0,k,104);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(g){break l}i=(f|0)==(g|0)}if(i){break i}break h}if(!g){break h}i=y[g+34|0];if(!i){break h}if((i|0)==y[f+34|0]){break j}break h}if((f|0)!=(g|0)){break h}}if(!y[g+34|0]){break i}}if(!y[e+1075789|0]|y[f+18|0]>2){break i}f=e+1075793|0;i=y[f|0];if(!i){break i}Um(a,c&65535,i|256,0);v[f|0]=0}f=e+1074992|0;p:{q:{switch(y[x[n>>2]+18|0]){case 0:yo(a,f);x[e+1075680>>2]=0;if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!xd(f)){break p}Jj(f,c&65535,1);break p;case 1:yo(a,f);if(!(y[e+1075081|0]&2)){break p}f=x[a+1298300>>2];if(!xd(f)){break p}yk(f,c&65535);break p;case 2:break q;default:break p}}i=e+1075080|0;f=x[i>>2];x[i>>2]=f|4096;if(!(f&512)){break p}if(!xd(x[a+1298300>>2])){break p}Kb(h+8|0,k,105);if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break p}yk(x[a+1298300>>2],c&65535)}if(x[e+1075680>>2]){break h}x[e+1075688>>2]=0;e=e+1075080|0;x[e>>2]=x[e>>2]|2101248}c=c+1|0;continue}break}d=y[(D(b,872)+a|0)+1075793|0];c=0;if(!d){break f}c=ib[x[x[e>>2]+104>>2]](e,d,b)|0}if(!(Pi(x[j+8>>2],x[j+12>>2])|c)){break a}r:{if(!(c&(e|0)!=0)){break r}c=y[(D(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break r}Um(a,b,255,0);w[(D(b,872)+a|0)+1075792>>1]=0}c=SA(a,b);if((c|0)==65535){break a}f=D(c,872);e=f+a|0;d=e+1075080|0;g=e+1074992|0;s:{if(!(y[e+1075081|0]&2)){break s}e=x[a+1298300>>2];if(!xd(e)){break s}Jj(e,c,1)}l=sq(g,j);e=x[d>>2];g=e&-917505;x[d>>2]=g;i=a+1074992|0;f=i+f|0;v[f+831|0]=0;m=z[a+480188>>1];v[f+805|0]=0;w[f+786>>1]=b>>>0<m>>>0?b+1|0:0;t:{u:{switch(y[(i+D(b,872)|0)+798|0]){case 2:yo(a,l);if(!(y[d+1|0]&2)){break t}e=x[a+1298300>>2];if(!xd(e)){break t}yk(e,b);Kb(h+8|0,k,105);if(!Hb(x[x[h+8>>2]>>2],x[h+12>>2])){break t}GB(x[a+1298300>>2],b,c);break t;case 0:x[(D(c,872)+a|0)+1075688>>2]=0;x[d>>2]=g|4096;if(!(e&512)){break t}e=x[a+1298300>>2];if(!xd(e)){break t}Jj(e,b,1);break t;case 3:x[d>>2]=g|4096;if(!(e&512)){break t}if(!xd(x[a+1298300>>2])){break t}Kb(h+8|0,k,105);e=x[a+1298300>>2];if(Hb(x[x[h+8>>2]>>2],x[h+12>>2])){GB(e,b,c);break t}yk(e,b);break t;case 1:break u;default:break t}}if(!(e&512)){break t}e=x[a+1298300>>2];if(!xd(e)){break t}GB(e,b,c)}c=D(c,872)+a|0;if(!x[c+1075680>>2]){x[c+1075688>>2]=0;x[d>>2]=x[d>>2]|2101248}a=D(b,872)+a|0;x[a+1075068>>2]=0;x[j>>2]=0;x[j+4>>2]=0;a=a+1075084|0;x[a>>2]=0;x[a+4>>2]=0}fb=h+16|0}function gpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-128|0;fb=g;xc(b);a:{b:{c:{d:{e:{if(!iX(b,14244)){break e}k=Nb(g+116|0);j=Nb(g+104|0);x[31785]=0;x[g+96>>2]=0;x[g+100>>2]=0;O(249,a|0,32768);d=x[31785];x[31785]=0;if((d|0)==1){break b}x[31785]=0;d=P(1,g+84|0,8189)|0;i=x[31785];x[31785]=0;if((i|0)==1){break c}yb(a+1298344|0,d);tb(d);x[31785]=0;d=P(1,g+72|0,6080)|0;i=x[31785];x[31785]=0;if((i|0)==1){break d}yb(a+1298356|0,d);tb(d);o=a+1298404|0,q=x[Gc(g+44|0,28)>>2],x[o>>2]=q;m=a+484376|0;i=a+480280|0;while(1){d=x[b+8>>2];f=x[b>>2];x[31785]=0;d=U(153,f|0,d|0,8)|0;f=x[31785];x[31785]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}x[31785]=0;d=P(655,b|0,g- -64|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break m}if(!d){break n}d=x[g+68>>2];x[31785]=0;S(188,g+24|0,b|0,$b(d)|0);d=x[31785];x[31785]=0;if((d|0)==1){break l}d=g+24|0;f=ic(g+44|0,d);ub(d);d=x[f>>2];x[31785]=0;d=R(175,d|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break j}if(d){break k}ub(f)}if(z[a+480188>>1]){break i}i=0;break g}a=N()|0;break a}a=N()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=$b(x[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(z[a+480188>>1]){break f}d=x[f>>2];x[31785]=0;d=R(157,d|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;x[31785]=0;O(656,g+24|0,f|0);e=x[31785];x[31785]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{h=_b(g+24|0,d);e=z[a+480188>>1];v:{if(!Cb(y[h|0]|y[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+96|0;o=xb(h,e),q=1,v[o|0]=q;o=xb(h,z[a+480188>>1]+1|0),q=255,v[o|0]=q;Ye(i+(z[a+480188>>1]<<5)|0);h=z[a+480188>>1];e=h+1|0;w[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;w[l+4>>1]=h>>>0<2?192:64}Ye(i+((e&65535)<<5)|0);e=z[a+480188>>1];w[a+480188>>1]=e+1;w[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(z[a+480190>>1]){break f}x[31785]=0;O(657,f|0,a|0);d=x[31785];x[31785]=0;if((d|0)!=1){break f}break j}d=x[f>>2];x[31785]=0;d=R(157,d|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[31785]=0;d=R(276,f|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break j}o=a,q=Hd(d,1,255),x[o+480196>>2]=q;break f}d=x[f>>2];x[31785]=0;d=R(157,d|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break j}if(d>>>0<2){break f}x[31785]=0;n=R(276,f|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break f}break j}d=y[m|0];e=x[a+484360>>2];h=x[f>>2];x[31785]=0;h=R(157,h|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break j}x[31785]=0;aa(351,Wb(e,d)|0,f|0,h|0,255,254);d=x[31785];x[31785]=0;if((d|0)==1){break j}break f}d=k;if(Lf(x[d>>2],x[d+4>>2])>>>0>=256){break f}break q}if(Lf(x[j>>2],x[j+4>>2])>>>0>3998){break f}d=x[f>>2];x[31785]=0;e=R(157,d|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break j}d=j;if(!e){break f}}x[31785]=0;O(658,d|0,f|0);d=x[31785];x[31785]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}ub(f);break g}a=N()|0;ub(f);break a}x[a+480200>>2]=256;x[a+480204>>2]=125e4;x[a+480260>>2]=452;x[a+480264>>2]=3424;x[a+480228>>2]=48;x[a+480232>>2]=48;b=y[a+484376|0];d=x[a+484360>>2];x[31785]=0;O(333,Wb(d,b)|0,n&65535);b=x[31785];x[31785]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=x[k+4>>2];i=x[k>>2];d=0;x[31785]=0;O(226,a+484344|0,Lf(i,b)&65535);b=x[31785];x[31785]=0;if((b|0)==1){break b}while(1){e=x[k>>2];b=d&65535;if(Lf(e,x[k+4>>2])>>>0<=b>>>0){break w}x[31785]=0;i=x[g+100>>2];f=x[g+96>>2];x[g+16>>2]=f;x[g+20>>2]=i;x[g+8>>2]=f;x[g+12>>2]=i;V(659,$g(e,b)|0,b|0,a|0,g+8|0);b=x[31785];x[31785]=0;if((b|0)!=1){d=d+1|0;continue}break}a=N()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(z[a+480190>>1]<=d>>>0){break g}if(!f|Lf(x[j>>2],x[j+4>>2])>>>0<=b>>>0){break g}c=(D(d,104)+a|0)+484380|0;np(c);x:{if(x[c>>2]){e=x[$g(x[j>>2],b)>>2];x[31785]=0;e=R(157,e|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break h}vc(c,e);e=ad(g+44|0,8,1,1,0);h=x[j>>2];x[31785]=0;U(218,e|0,c|0,$g(h,b)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Qc(j);Qc(k);break e}ub(f);continue}}fb=g+128|0;return i|0}a=N()|0;break a}a=N()|0;break a}a=N()|0}Qc(j);Qc(k);Q(a|0);p()}function n0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-80|0;fb=e;xc(b);a:{if(!Ar(b,11795)){break a}if(!kw(b,e+69|0)){break a}if(!wE(y[e+70|0])){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(vE(e+69|0),hb))){break a}if(!Yb(b,y[e+78|0]|y[e+79|0]<<8)){break a}b:{if(!c){break b}Bd(a,4096);x[a+480208>>2]=12;w[a+480188>>1]=(y[e+71|0]&31)+1;f=a+480190|0;w[f>>1]=y[e+72|0];Ch(a,1);d=e+20|0;i=uc(d,8496);yb(a+1298344|0,i);tb(i);i=uc(d,7125);yb(a+1298356|0,i);tb(i);i=fb-16|0;fb=i;g=uc(i+4|0,4267);Yc(e,g);tb(g);fb=i+16|0;x[31785]=0;V(232,d|0,e|0,y[e+70|0],e+69|0);d=x[31785];x[31785]=0;c:{if((d|0)!=1){d=e+20|0;yb(a+1298368|0,d);tb(d);Eb(e);l=a+1298404|0,m=x[Gc(d,4)>>2],x[l>>2]=m;d=y[e+72|0];i=e+56|0;x[i>>2]=0;x[i+4>>2]=0;Gc(i+8|0,0);if(d){Ir(i,d);uF(i,d,0)}d=1;d:{while(1){g=d&65535;if(g>>>0>z[f>>1]){x[31785]=0;P(233,b|0,a+1298308|0)|0;g=x[31785];x[31785]=0;d=1;e:{if((g|0)==1){break e}g=a+480190|0;while(1){f=d&65535;if(f>>>0>z[g>>1]){d=0;g=a+480188|0;f:{while(1){if(z[g>>1]<=d>>>0){d=0;x[31785]=0;g=a+484344|0;O(226,g|0,y[e+73|0]|y[e+74|0]<<8);f=x[31785];x[31785]=0;if((f|0)==1){break e}break f}f=(d<<5)+a|0;Ye(f+480280|0);x[31785]=0;O(234,b|0,f+480289|0);f=x[31785];x[31785]=0;if((f|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}g:{h:{i:{j:{while(1){if((y[e+73|0]|y[e+74|0]<<8)>>>0<=d>>>0){x[31785]=0;f=R(192,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break h}if(!f){break i}d=x[b+8>>2];g=x[b>>2];x[31785]=0;d=U(153,g|0,d|0,f|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break h}if(d){break j}break i}x[31785]=0;f=P(235,b|0,e+20|0)|0;h=x[31785];x[31785]=0;k:{if((h|0)==1){break k}x[31785]=0;h=U(199,g|0,d&65535,64)|0;j=x[31785];x[31785]=0;if((j|0)==1){break k}if((f&h)==1){f=x[g>>2];x[31785]=0;O(236,Vb(f,d)|0,e+20|0);f=x[31785];x[31785]=0;if((f|0)==1){break k}}d=d+1|0;continue}break}b=N()|0;break d}g=Nb(e+20|0);x[31785]=0;S(237,b|0,g|0,f|0);d=x[31785];x[31785]=0;l:{if((d|0)!=1){d=Fb(e);x[31785]=0;O(117,d|0,f|0);f=x[31785];x[31785]=0;m:{if((f|0)==1){break m}l=e,m=vb(x[g>>2]),x[l+40>>2]=m;h=vb(x[g+4>>2]);while(1){n:{f=x[e+40>>2];if(!Ib(f,h)){x[31785]=0;S(238,e+40|0,20,d|0);f=x[31785];x[31785]=0;if((f|0)==1){break n}h=e+40|0;f=yb(d,h);tb(h);h=Jb(f);j=y[f+11|0];k=x[f+4>>2];x[31785]=0;aa(239,a+1298332|0,h|0,Wc(k,j)|0,76,0);h=x[31785];x[31785]=0;if((h|0)==1){break m}tb(f);dc(g);break i}o:{f=v[f|0];if((f|0)<0){j=x[zb(e+52|0,yf(d))>>2];x[31785]=0;V(240,d|0,j|0,f&127,32);f=x[31785];x[31785]=0;if((f|0)!=1){break o}break m}x[31785]=0;O(118,d|0,f|0);f=x[31785];x[31785]=0;if((f|0)!=1){break o}break m}je(e+40|0);continue}break}}b=N()|0;tb(d);break l}b=N()|0}dc(g);break d}d=y[a+484376|0];g=x[a+484360>>2];x[31785]=0;S(241,Wb(g,d)|0,b|0,y[e+75|0]|y[e+76|0]<<8);d=x[31785];x[31785]=0;if((d|0)==1){break h}f=c&1;h=a+484348|0;d=0;while(1){p:{q:{if((y[e+73|0]|y[e+74|0]<<8)>>>0>d>>>0){g=x[b+8>>2];j=x[b>>2];x[31785]=0;g=U(153,j|0,g|0,4)|0;j=x[31785];x[31785]=0;if((j|0)==1){break p}if(g){break q}}if(!(c&2)){break g}g=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>z[g>>1]){break g}f=D(c,104)+a|0;h=z[f+484414>>1];Kb(e+20|0,x[i>>2],c-1|0);c=ad(e,h&1?16:8,1,0,Hb(x[x[e+20>>2]>>2],x[e+24>>2])?6:0);x[31785]=0;U(218,c|0,f+484380|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}x[31785]=0;g=R(154,b|0)|0;j=x[31785];x[31785]=0;r:{s:{if((j|0)!=1){x[31785]=0;S(188,e|0,b|0,g|0);g=x[31785];x[31785]=0;if((g|0)==1){break s}g=ic(e+20|0,e);ub(e);if(!f){break r}j=x[a+484344>>2];if(!Ge(j,x[h>>2],d&65535)){break r}x[31785]=0;S(242,Vb(j,d)|0,0,g|0);j=x[31785];x[31785]=0;if((j|0)!=1){break r}b=N()|0;ub(g);break d}b=N()|0;break d}b=N()|0;break d}ub(g);d=d+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}$e(i);break b}x[31785]=0;P(243,b|0,((f<<5)+a|0)+946304|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){d=d+1|0;continue}break}b=N()|0;break d}b=N()|0;break d}x[31785]=0;O(244,b|0,e+20|0);h=x[31785];x[31785]=0;t:{if((h|0)==1){break t}x[31785]=0;O(245,e+20|0,(D(g,104)+a|0)+484380|0);h=x[31785];x[31785]=0;if((h|0)==1){break t}h=y[e+36|0];Kb(e,x[i>>2],g-1|0);Df(e,(h&3)!=0);d=d+1|0;continue}break}b=N()|0}$e(i);break c}b=N()|0;Eb(e)}Q(b|0);p()}d=1}fb=e+80|0;return d|0}function Es(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-592|0;fb=e;x[e+572>>2]=6;x[e+576>>2]=364;x[e+564>>2]=11;x[e+568>>2]=161;x[e+556>>2]=23;x[e+560>>2]=31;x[e+548>>2]=59;x[e+552>>2]=55;x[e+584>>2]=0;x[e+588>>2]=0;x[e+580>>2]=-1;v[e+446|0]=c;v[e+445|0]=37;v[e+447|0]=0;f=e+448|0;fa(f|0,100,e+445|0,e+548|0,x[b>>2])|0;h=e+32|0;x[e+28>>2]=h;x[e+16>>2]=0;x[e+20>>2]=0;x[e+12>>2]=f;h=Di(h,e+12|0,100,e+16|0,x[b>>2]);if((h|0)!=-1){l=b+484|0;i=b+460|0;j=b+172|0;k=b+4|0;f=e+32|0;h=f+(h<<2)|0;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){a=x[f>>2];x[31785]=0;a=U(1252,d|0,1,a|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}if(a){x[31785]=0;O(36,g|0,32);a=x[31785];x[31785]=0;if((a|0)==1){break c}while(1){f=f+4|0;if((h|0)==(f|0)){f=h;break b}a=x[f>>2];x[31785]=0;a=U(1252,d|0,1,a|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}if(a){continue}break}break b}x[e+8>>2]=f;x[31785]=0;x[e+4>>2]=0;a=ea(1362,e+8|0,h|0,k|0,j|0,d|0,e+4|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31785]=0;O(36,g|0,37);c=x[31785];x[31785]=0;if((c|0)==1){break c}x[31785]=0;O(36,g|0,((a|0)<84?65:97)|0);a=x[31785];x[31785]=0;if((a|0)!=1){break q}break c}x[31785]=0;x[e+8>>2]=f;a=ea(1362,e+8|0,h|0,j|0,i|0,d|0,e+4|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}a=a-j|0;c=(a|0)/12|0;if((a|0)<=287){x[31785]=0;O(36,g|0,37);f=x[31785];x[31785]=0;if((f|0)==1){break c}x[31785]=0;O(36,g|0,((a|0)<144?66:98)|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}if(m){break q}a=x[Sd((D(c,12)+b|0)+172|0,0)>>2];x[31785]=0;a=U(1252,d|0,64,a|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}if(!a){break q}n=(Jb(g)+(Bb(x[g+4>>2],y[g+11|0])<<2)|0)-4|0,o=109,x[n>>2]=o;break q}if((Bb(x[b+464>>2],y[b+471|0])|0)==(0-Bb(x[b+476>>2],y[b+483|0])|0)){break p}x[31785]=0;x[e+8>>2]=f;a=ea(1362,e+8|0,h|0,i|0,l|0,d|0,e+4|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}if((a-i|0)>23){break p}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;O(36,g|0,112);a=x[31785];x[31785]=0;if((a|0)==1){break c}}f=x[e+8>>2];break b}x[e+8>>2]=f;a=x[f>>2];x[31785]=0;a=U(1252,d|0,64,a|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}if(a){x[31785]=0;a=ba(1363,e+28|0,h|0,e+4|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+28>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=x[f>>2];x[31785]=0;O(36,g|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}f=f+4|0;continue}}a=x[f>>2];x[31785]=0;a=P(1364,d|0,a|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}u:{if((a|0)==37){x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;O(36,g|0,37);break u}a=x[f>>2];x[31785]=0;O(36,g|0,a|0)}a=x[31785];x[31785]=0;if((a|0)==1){break c}f=f+4|0;break b}fb=e+592|0;return}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=89;break d}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=106;break d}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=121;break d}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=83;break d}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=77;break d}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=100;break d}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=72;break d}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=109;break d}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=73;break d}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=117;break d}x[31785]=0;O(36,g|0,37);a=x[31785];x[31785]=0;c=119}if((a|0)==1){break c}x[31785]=0;O(36,g|0,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}f=x[e+28>>2];continue}a=N()|0;Sb(g);Q(a|0);p()}x[e+28>>2]=f;continue}}Yn(12682);p()}function Jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;d=fb-304|0;fb=d;e=-1;a:{b:{c:{if(!pk(x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){b=Gm(d+192|0,b);x[31785]=0;e=P(465,d+180|0,14075)|0;f=x[31785];x[31785]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){x[31785]=0;x[d+160>>2]=83886084;x[d+164>>2]=0;S(466,b|0,e|0,d+160|0);f=x[31785];x[31785]=0;if((f|0)==1){break A}Eb(e);v[d+179|0]=0;x[31785]=0;e=P(465,d+160|0,14887)|0;f=x[31785];x[31785]=0;if((f|0)==1){break z}x[31785]=0;S(467,b|0,d+179|0,e|0);f=x[31785];x[31785]=0;if((f|0)==1){break y}Eb(e);e=Gc(d+156|0,y[d+179|0]?0:c);x[31785]=0;c=P(465,d+144|0,16013)|0;f=x[31785];x[31785]=0;if((f|0)==1){break x}f=x[e>>2];x[31785]=0;V(932,b|0,a+40|0,c|0,f|0);f=x[31785];x[31785]=0;if((f|0)==1){break w}Eb(c);w[d+142>>1]=65535;x[31785]=0;c=P(465,d+128|0,15690)|0;f=x[31785];x[31785]=0;if((f|0)==1){break v}x[31785]=0;U(495,b|0,d+142|0,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break u}Eb(c);w[d+126>>1]=0;x[31785]=0;c=P(465,d+112|0,15525)|0;f=x[31785];x[31785]=0;if((f|0)==1){break t}x[31785]=0;U(495,b|0,d+126|0,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break s}Eb(c);w[a>>1]=z[d+126>>1];x[31785]=0;c=P(465,d+100|0,15220)|0;f=x[31785];x[31785]=0;if((f|0)==1){break r}e=x[e>>2];x[31785]=0;V(933,b|0,a+52|0,c|0,e|0);e=x[31785];x[31785]=0;if((e|0)==1){break q}Eb(c);x[31785]=0;c=P(465,d+88|0,15149)|0;e=x[31785];x[31785]=0;if((e|0)==1){break p}x[31785]=0;S(922,b|0,a+36|0,c|0);e=x[31785];x[31785]=0;if((e|0)==1){break o}Eb(c);x[31785]=0;c=P(465,d+76|0,15697)|0;e=x[31785];x[31785]=0;if((e|0)==1){break n}x[31785]=0;h=a+4|0;S(934,b|0,h|0,c|0);e=x[31785];x[31785]=0;if((e|0)==1){break m}Eb(c);x[31785]=0;c=P(465,d- -64|0,15527)|0;e=x[31785];x[31785]=0;if((e|0)==1){break l}x[31785]=0;f=a+28|0;S(935,b|0,f|0,c|0);e=x[31785];x[31785]=0;if((e|0)==1){break k}Eb(c);x[31785]=0;c=P(465,d+52|0,15382)|0;e=x[31785];x[31785]=0;if((e|0)==1){break j}x[31785]=0;S(935,b|0,a+30|0,c|0);e=x[31785];x[31785]=0;if((e|0)==1){break i}Eb(c);x[31785]=0;c=P(465,d+40|0,15178)|0;e=x[31785];x[31785]=0;if((e|0)==1){break h}x[31785]=0;S(936,b|0,a+32|0,c|0);e=x[31785];x[31785]=0;if((e|0)==1){break g}Eb(c);w[d+38>>1]=0;x[31785]=0;c=P(465,d+24|0,15128)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}x[31785]=0;U(495,b|0,d+38|0,c|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}Eb(c);i=LQ(B[a+32>>2]);B[a+32>>2]=i;e=-1;if(!Rm(i)){break d}k=d,l=vb(x[a+4>>2]),x[k+20>>2]=l;c=vb(x[a+8>>2]);while(1){g=x[d+20>>2];if(!Ib(g,c)){break e}if(!Rm(B[g>>2])){break d}Pe(d+20|0);continue}}a=N()|0;break a}a=N()|0;Eb(e);break a}a=N()|0;break a}a=N()|0;Eb(e);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;break a}a=N()|0;Eb(c);break a}a=N()|0;Eb(c);break a}if(ml(y[b|0])){break d}c=z[f>>1];if((c-301&65535)>>>0<64935){break d}g=z[a>>1];if(g>>>0>3|(g|0)==2){break d}j=w[a+30>>1];if((j|0)<0){break d}k=d,l=Vi(x[a+36>>2]),x[k+20>>2]=l;x[d+16>>2]=0;k=a,l=x[bk(d+20|0,d+16|0,42528)>>2],x[k+36>>2]=l;if(oc(x[a+4>>2],x[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=w[d+38>>1];if((f|0)<=0){break d}w[d+14>>1]=j;B[d+20>>2]=B[a+32>>2];x[31785]=0;w[d+16>>1]=c;w[d+18>>1]=(c+f|0)-1;a=ba(937,a|0,d+14|0,d+20|0,d+16|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(a){break B}break d}a=N()|0;break a;case 0:g=w[d+38>>1];if((g|0)<=0){break d}B[d+20>>2]=B[a+32>>2];x[31785]=0;w[d+16>>1]=c;w[d+18>>1]=(c+g|0)-1;a=ha(938,a|0,h|0,d+20|0,d+16|0,f|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(a){break B}break d}a=N()|0;break a;default:break C}}x[31785]=0;W(939,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}}e=1}yh(b)}fb=d+304|0;return e|0}a=N()|0;break a}a=N()|0}yh(b);Q(a|0);p()}function Hoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0,C=0;d=fb-736|0;fb=d;xc(b);e=fb-16|0;fb=e;h=d+128|0;MW(e+8|0,h);f=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);j=x[e+4>>2];if((j|0)==(f|0)){Yb(b,x[e+12>>2])}fb=e+16|0;e=(f|0)==(j|0);if(!e){LW(h)}a:{if(!e){break a}if(!OW(d+128|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(NW(y[d+162|0]|y[d+163|0]<<8),hb))){break a}if(!c){n=1;break a}Bd(a,262144);f=d+92|0;_i(f,2,d+128|0);e=d+12|0;Ec(e,f);yb(a+1298308|0,e);tb(e);h=uc(e,8337);yb(a+1298344|0,h);tb(h);e=uc(e,10135);yb(a+1298356|0,e);tb(e);e=fb-16|0;fb=e;g=f;f=uc(e+4|0,4213);Yc(g,f);tb(f);fb=e+16|0;v[d|0]=y[d+158|0];x[31785]=0;v[d+115|0]=y[d+157|0];O(695,d+116|0,d+115|0);e=x[31785];x[31785]=0;b:{c:{d:{if((e|0)!=1){x[31785]=0;V(253,d+12|0,d+92|0,d|0,d+116|0);e=x[31785];x[31785]=0;if((e|0)!=1){e=d+12|0;yb(a+1298368|0,e);tb(e);tb(d+116|0);f=d+92|0;Eb(f);B=a+1298404|0,C=x[Gc(e,4)>>2],x[B>>2]=C;x[a+480208>>2]=12;h=a+480188|0;w[h>>1]=y[d+166|0]|y[d+167|0]<<8;w[d+12>>1]=y[d+162|0]|y[d+163|0]<<8;w[d+92>>1]=3999;B=a,C=z[Mc(e,f)>>1],w[B+480190>>1]=C;j_(Wb(x[a+484360>>2],y[a+484376|0]),d+224|0,y[d+160|0]|y[d+161|0]<<8);e=0;while(1)if(z[h>>1]<=e>>>0){e=d+12|0;ce(e,b,D(y[d+162|0]|y[d+163|0]<<8,80));j=c&2;h=ic(d+92|0,e);ub(e);l=d+60|0;e=0;e:{f:{while(1){if(z[a+480190>>1]<=e>>>0){n=1;if(c&1){break f}break b}x[31785]=0;O(696,h|0,d+12|0);f=x[31785];x[31785]=0;if((f|0)==1){break e}_i(d,2,l);x[31785]=0;O(221,d+116|0,d|0);f=x[31785];x[31785]=0;if((f|0)==1){break e}e=e+1|0;f=d+116|0;zc(((e<<5)+a|0)+946304|0,f);tb(f);x[31785]=0;g=f;f=(D(e,104)+a|0)+484380|0;S(697,g|0,d+12|0,f|0);g=x[31785];x[31785]=0;g:{if((g|0)==1){break g}if(!j|!x[f>>2]){continue}x[31785]=0;g=P(152,b|0,y[d+30|0]|y[d+31|0]<<8|(y[d+32|0]<<16|y[d+33|0]<<24))|0;k=x[31785];x[31785]=0;if((k|0)==1){break g}if(!g){continue}x[31785]=0;U(218,d+116|0,f|0,b|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){continue}}break}break e}x[31785]=0;m=a+484344|0;O(226,m|0,y[d+164|0]|y[d+165|0]<<8);c=x[31785];x[31785]=0;if((c|0)==1){break e}o=d+16|0;t=d+14|0;q=d+15|0;u=d+17|0;A=d+13|0;r=a+480188|0;a=0;while(1){if((y[d+164|0]|y[d+165|0]<<8)>>>0<=a>>>0){break b}x[31785]=0;c=U(199,m|0,a&65535,64)|0;e=x[31785];x[31785]=0;if((e|0)==1){break e}h:{if(!c){break h}c=(a<<1)+d|0;c=y[c+480|0]|y[c+481|0]<<8;if(!c){break h}x[31785]=0;c=P(152,b|0,c<<4)|0;e=x[31785];x[31785]=0;if((e|0)==1){break e}if(!c){break h}j=0;c=Vb(x[m>>2],a);l=gd(x[c>>2],x[x[c+48>>2]+12>>2],0,0);while(1){if(j>>>0>63){break h}c=x[b+8>>2];e=x[b>>2];x[31785]=0;c=U(153,e|0,c|0,1)|0;e=x[31785];x[31785]=0;i:{if((e|0)!=1){if(!c){break h}x[31785]=0;c=R(200,b|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break e}g=c<<24>>24;if(g){break i}j=j+1|0;l=D(z[r>>1],6)+l|0;continue}break e}w[o>>1]=0;x[d+12>>2]=0;e=g&31;c=D(e,6)+l|0;f=Jg(d+12|0);e=e>>>0<z[r>>1];k=e?c:f;i=g&255;j:{if(!(i&32)){break j}x[31785]=0;O(201,d+116|0,b|0);f=x[31785];x[31785]=0;if((f|0)==1){break e}f=y[d+116|0];v[k|0]=f;B=e?c+1|0:A,C=y[Ic(d+116|0)|0],v[B|0]=C;k:{if(f){if((f|0)==254){break k}if(f>>>0<121){break j}}f=0}v[k|0]=f}l:{if(!(i&64)){break l}x[31785]=0;O(201,d+116|0,b|0);f=x[31785];x[31785]=0;if((f|0)==1){break e}f=e?c+5|0:u;s=Ic(d+116|0);v[f|0]=y[s|0];i=y[d+116|0];m:{if(i>>>0<=15){Mf(k,i,y[s|0]);break m}v[(e?c+3|0:q)|0]=i>>>0<=23?y[i+25607|0]:0}k=e?c+3|0:q;i=y[k|0];if((i|0)!=23){if((i|0)!=9){break l}v[k|0]=20;v[d|0]=y[f|0]>>>3;v[d+115|0]=1;B=f,C=y[af(d,d+115|0)|0]-1&15|128,v[B|0]=C;break l}v[d|0]=64;B=f,C=y[Ub(f,d)|0]<<1,v[B|0]=C}if((g|0)>=0){continue}v[(e?c+2|0:t)|0]=1;x[31785]=0;f=R(200,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break e}v[(e?c+4|0:o)|0]=f;continue}}a=a+1|0;continue}}b=N()|0;ub(h);break c}else{f=(e<<5)+a|0;Ye(f+480280|0);w[f+480284>>1]=(y[(d+e|0)+192|0]<<4|4)&244;e=e+1|0;continue}}b=N()|0;tb(d+116|0);break d}b=N()|0}Eb(d+92|0)}Q(b|0);p()}ub(h)}fb=d+736|0;return n|0}function nL(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;i=fb-560|0;fb=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;l=g+D(s,-24)|0;o=x[(e<<2)+90416>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){C[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+x[(c<<2)+90432>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=l-24|0;g=0;h=(o|0)>0?o:0;n=(d|0)<=0;while(1){a:{if(n){f=0;break a}k=g+j|0;c=0;f=0;while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(k-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;c=(g|0)==(h|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;u=(l|0)<25;z=l-25|0;g=o;b:{while(1){f=C[(g<<3)+i>>3];c=0;h=g;k=(g|0)<=0;if(!k){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(F(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(F(f)<2147483648){j=~~f;break d}j=-2147483648}x[n>>2]=j;h=h-1|0;f=C[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=mk(f,q);f=f+J(f*.125)*-8;e:{if(F(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{i:{if(!u){h=(g<<2)+i|0;j=x[h+476>>2];c=j>>t;r=h;h=j-(c<<t)|0;x[r+476>>2]=h;n=c+n|0;j=h>>y;break i}if(q){break h}j=x[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;h=0;if(!k){while(1){r=(i+480|0)+(c<<2)|0;v=x[r>>2];k=16777215;j:{k:{if(h){break k}k=16777216;if(v){break k}h=0;break j}x[r>>2]=k-v;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(u){break l}c=8388607;m:{switch(z|0){case 1:c=4194303;break;case 0:break m;default:break l}}k=(g<<2)+i|0;x[k+476>>2]=x[k+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!h){break f}f=f-mk(1,q)}if(f==0){c=1;k=0;h=g;n:{if((g|0)<=(o|0)){break n}while(1){h=h-1|0;k=x[(i+480|0)+(h<<2)>>2]|k;if((h|0)>(o|0)){continue}break}if(!k){break n}l=q;while(1){l=l-24|0;g=g-1|0;if(!x[(i+480|0)+(g<<2)>>2]){continue}break}break b}while(1){h=c;c=c+1|0;if(!x[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;C[(i+320|0)+(j<<3)>>3]=x[(s+g<<2)+90432>>2];c=0;f=0;if((d|0)>0){while(1){f=C[(c<<3)+a>>3]*C[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}C[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=mk(f,24-l|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(F(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(F(f)<2147483648){a=~~f;break q}a=-2147483648}x[d>>2]=a;g=g+1|0;break o}if(F(f)<2147483648){c=~~f}else{c=-2147483648}l=q}x[(i+480|0)+(g<<2)>>2]=c}f=mk(1,l);if((g|0)>=0){d=g;while(1){a=d;C[(a<<3)+i>>3]=f*+x[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}h=g;while(1){f=0;c=0;a=g-h|0;d=(a|0)>(o|0)?o:a;if((d|0)>=0){while(1){f=C[(c<<3)+93200>>3]*C[(c+h<<3)+i>>3]+f;l=(c|0)!=(d|0);c=c+1|0;if(l){continue}break}}C[(i+160|0)+(a<<3)>>3]=f;a=(h|0)>0;h=h-1|0;if(a){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=C[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;w=C[h>>3];f=w+f;C[e+(c<<3)>>3]=m+(w-f);C[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=C[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=C[e>>3];f=p+f;C[d+(c<<3)>>3]=m+(p-f);C[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+C[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=C[i+160>>3];if(j){break s}C[b>>3]=f;f=C[i+168>>3];C[b+16>>3]=p;C[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+C[(i+160|0)+(a<<3)>>3];if(a){continue}break}}C[b>>3]=j?-f:f;f=C[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+C[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}C[b+8>>3]=j?-f:f;break r}C[b>>3]=-f;f=C[i+168>>3];C[b+16>>3]=-p;C[b+8>>3]=-f}fb=i+560|0;return n&7}function f7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-48|0;fb=h;x[h+44>>2]=b;x[e>>2]=0;$c(h,x[d+28>>2]);x[31785]=0;i=R(1220,x[h>>2])|0;j=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Zb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Zb(h);Q(a|0);p()}MJ(a,f+24|0,h+44|0,c,e,i);break b}LJ(a,f+16|0,h+44|0,c,e,i);break b}g=a;i=b;a=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Jb(a);k=h,l=rk(g,i,c,d,e,f,b,b+(Bb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+44>>2]=l;break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}g=x[28015];x[h+24>>2]=x[28014];x[h+28>>2]=g;g=x[28013];x[h+16>>2]=x[28012];x[h+20>>2]=g;g=x[28011];x[h+8>>2]=x[28010];x[h+12>>2]=g;g=x[28009];x[h>>2]=x[28008];x[h+4>>2]=g;k=h,l=rk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}g=x[28023];x[h+24>>2]=x[28022];x[h+28>>2]=g;g=x[28021];x[h+16>>2]=x[28020];x[h+20>>2]=g;g=x[28019];x[h+8>>2]=x[28018];x[h+12>>2]=g;g=x[28017];x[h>>2]=x[28016];x[h+4>>2]=g;k=h,l=rk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=mj(h+44|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+44|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(ji(a,b+12|0)){break H}if(!uj(i,1,ql(x[a>>2]))){break H}ao(a);continue}break}if(ji(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+44|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(x[a+4>>2],y[a+11|0])|0)==(0-Bb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=Ts(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=yc(h,112096,44);k=g,l=rk(a,b,c,d,e,f,g,g+44|0),x[k+44>>2]=l;break b}x[h+16>>2]=x[28040];g=x[28039];x[h+8>>2]=x[28038];x[h+12>>2]=g;g=x[28037];x[h>>2]=x[28036];x[h+4>>2]=g;k=h,l=rk(a,b,c,d,e,f,h,h+20|0),x[k+44>>2]=l;break b}a=mj(h+44|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}g=x[28051];x[h+24>>2]=x[28050];x[h+28>>2]=g;g=x[28049];x[h+16>>2]=x[28048];x[h+20>>2]=g;g=x[28047];x[h+8>>2]=x[28046];x[h+12>>2]=g;g=x[28045];x[h>>2]=x[28044];x[h+4>>2]=g;k=h,l=rk(a,b,c,d,e,f,h,h+32|0),x[k+44>>2]=l;break b}a=mj(h+44|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Jb(a);k=h,l=rk(g,i,c,d,e,f,b,b+(Bb(x[a+4>>2],y[a+11|0])<<2)|0),x[k+44>>2]=l;break b}KJ(f+20|0,h+44|0,c,e,i);break b}a=mj(h+44|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+44|0;L:{M:{if(ji(c,a+12|0)){break M}b=4;if((qk(i,ql(x[c>>2]))|0)!=37){break M}b=2;if(!ji(ao(c),a+12|0)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+44>>2]}fb=h+48|0;return a|0}function I0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;f=fb-864|0;fb=f;xc(b);e=fb-16|0;fb=e;i=f+92|0;hF(e+8|0,i);d=x[e+12>>2];kc(e,x[b>>2],x[b+8>>2],x[e+8>>2],x[e+12>>2]);g=x[e+4>>2];if((g|0)==(d|0)){Yb(b,x[e+12>>2])}fb=e+16|0;e=(d|0)==(g|0);if(!e){gF(i)}a:{if(!e){break a}if(!jF(f+92|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],iF(y[f+607|0]))){break a}if(!c){j=1;break a}Bd(a,2);x[a+480204>>2]=15e5;x[a+480208>>2]=x[a+480208>>2]|16777216;e=y[f+606|0];x[a+480188>>2]=4194322;x[a+480196>>2]=e;e=a+484360|0;d=a+484376|0;Wk(Wb(x[e>>2],y[d|0]),b,y[f+607|0],65535,65535);e=Wb(x[e>>2],y[d|0]);o=f,q=vb(x[e>>2]),x[o+40>>2]=q;e=vb(x[e+4>>2]);while(1){d=x[f+40>>2];if(Ib(d,e)){if(z[d>>1]>127){break a}Wd(f+40|0);continue}break}ag(a);j=1;while(1){i=j&65535;if(i>>>0>z[a+480190>>1]){b:{j=1;c:{d:{e:{if(!(c&1)){break e}m=x[b+8>>2];i=a+484344|0;$f(i,128);c=0;f:{while(1){if((c|0)==128){break f}d=f+16|0;e=(c<<1)+f|0;fF(d,b,(y[e+608|0]|y[e+609|0]<<8)+m|0,4674);e=ic(f+40|0,d);ub(d);d=x[e>>2];x[31785]=0;d=R(175,d|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break c}g:{if(!d){break g}x[31785]=0;d=U(199,i|0,c&65535,32)|0;g=x[31785];x[31785]=0;if((g|0)==1){break c}if(!d){break g}g=0;d=Vb(x[i>>2],c);Ve(f+16|0,x[d>>2],x[x[d+48>>2]+12>>2],0);while(1){h:{d=x[e>>2];x[31785]=0;d=U(153,d|0,x[f+48>>2],1)|0;h=x[31785];x[31785]=0;i:{j:{k:{l:{m:{if((h|0)!=1){if(!d){break h}x[31785]=0;d=R(200,e|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break b}n:{switch(d-251|0){case 0:break j;case 1:break k;case 2:break l;case 3:break m;case 4:break n;default:break i}}x[31785]=0;d=R(200,e|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break b}if(!d){break h}g=d+g|0;if(g>>>0>=32){break h}d=Vb(x[i>>2],c);Ve(f- -64|0,x[d>>2],x[x[d+48>>2]+12>>2],g);d=x[f+68>>2];x[f+16>>2]=x[f+64>>2];x[f+20>>2]=d;continue}break b}x[31785]=0;O(201,f- -64|0,e|0);d=x[31785];x[31785]=0;if((d|0)==1){break b}h=z[a+480188>>1];d=y[xb(f- -64|0,0)|0];if(h>>>0<=d>>>0){break d}h=y[xb(f- -64|0,1)|0];if(h>>>0>63){break d}o=Vc(x[f+16>>2],d),q=h+1|0,v[o+1|0]=q;continue}x[31785]=0;O(201,f- -64|0,e|0);d=x[31785];x[31785]=0;if((d|0)==1){break b}h=z[a+480188>>1];d=y[xb(f- -64|0,0)|0];if(h>>>0<=d>>>0){break d}h=y[xb(f- -64|0,1)|0];if(h>>>0>63){break d}d=Vc(x[f+16>>2],d);v[d+4|0]=63-h;v[d+2|0]=1;continue}x[31785]=0;d=R(200,e|0)|0;h=x[31785];x[31785]=0;if((h|0)!=1){h=Vc(x[f+16>>2],0);v[h+5|0]=d;v[h+3|0]=12;continue}break b}d=Vc(x[f+16>>2],0);v[d+5|0]=0;v[d+3|0]=14;continue}if(d>>>0>=z[a+480188>>1]){break d}x[31785]=0;h=R(200,e|0)|0;n=x[31785];x[31785]=0;if((n|0)==1){break b}if(h>>>0>=124){break d}o=Vc(x[f+16>>2],d),q=(D(h>>>4|0,12)+(h&15)|0)+13|0,v[o|0]=q;d=d&1;k=d|k;l=!d|l;continue}break}ub(e);c=c+1|0;continue}break}ub(e)}if(!(k&l&1)){break e}c=z[a+480188>>1];b=0;while(1){if((b|0)==(c|0)){break e}w[((b<<5)+a|0)+480284>>1]=b<<8&256;b=b+1|0;continue}}$h(a+1298344|0,14908);$h(a+1298356|0,14917);$h(a+1298368|0,14908);o=a+1298404|0,q=x[Gc(f+40|0,4)>>2],x[o>>2]=q;break a}ub(e);j=0;break a}}}else{e=f+81|0;d=fb-16|0;fb=d;o:{if(!Mb(x[b>>2],x[b+8>>2],11)){v[d|0]=0;Rh(e,11,d);break o}ww(d+8|0,e);md(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;x[f+48>>2]=0;x[f+40>>2]=0;x[f+44>>2]=0;g=xb(e,1);d=f+40|0;o=xb(d,0),q=y[g|0],v[o|0]=q;g=xb(e,6);o=xb(d,1),q=y[g|0],v[o|0]=q;g=xb(e,2);o=xb(d,2),q=y[g|0],v[o|0]=q;g=xb(e,7);o=xb(d,3),q=y[g|0],v[o|0]=q;g=xb(e,3);o=xb(d,4),q=y[g|0],v[o|0]=q;g=xb(e,8);o=xb(d,5),q=y[g|0],v[o|0]=q;g=xb(e,4);o=xb(d,6),q=y[g|0],v[o|0]=q;g=xb(e,9);o=xb(d,7),q=y[g|0],v[o|0]=q;g=xb(e,5);o=xb(d,8),q=y[g|0],v[o|0]=q;g=xb(e,10);o=xb(d,9),q=y[g|0],v[o|0]=q;e=xb(e,0);o=xb(d,10),q=y[e|0],v[o|0]=q;e=(D(i,104)+a|0)+484380|0;jd(e,2);x[f+8>>2]=x[f+48>>2];d=x[f+44>>2];x[f>>2]=x[f+40>>2];x[f+4>>2]=d;Vk(e,1,f);d=f- -64|0;hf(d,((i<<3)+f|0)+86|0,8,3);e=f+16|0;Ec(e,d);zc(((i<<5)+a|0)+946304|0,e);j=j+1|0;tb(e);continue}break}a=N()|0;ub(e);Q(a|0);p()}fb=f+864|0;return j|0}function zz(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;l=fb-48|0;fb=l;x[l+44>>2]=0;a:{if(!(d|g|h)){j=3;if(!i){break a}}k=g?l+44|0:0;b:{if(!k){break b}j=x[k>>2];if(!j){break b}Db(j);x[k>>2]=0}x[31785]=0;X(87);j=x[31785];x[31785]=0;c:{d:{if((j|0)==1){m=Va(125240,47696,47752,48732,125428,125532,125480,125372,125360,125676,125644,125612,125600,125824,0)|0;e:{f:{n=gb;if((n|0)==($(125240)|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=277;if((k|0)==1){break f}break c}if(($(47696)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=358;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(47752)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=359;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(48732)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=357;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(125428)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=300;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(125532)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=299;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(125480)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=298;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(125372)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=297;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(125360)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=296;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(125676)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=289;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(125644)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=288;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(125612)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=287;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}if(($(125600)|0)==(n|0)){j=Y(m|0)|0;x[31785]=0;O(1107,k|0,j|0);k=x[31785];x[31785]=0;j=286;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break e}o=$(125824)|0;j=257;m=Y(m|0)|0;if((n|0)!=(o|0)){break c}x[31785]=0;O(1107,k|0,m|0);k=x[31785];x[31785]=0;j=267;if((k|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break e}break d}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break d}}T(0)|0;Rb()}p()}Q(a|0);p()}Z();k=j;m=!g;if(d){j=ib[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){x[g+16>>2]=k;m=g;g=x[l+44>>2];q=m,r=xg(g?g:22485),x[q+20>>2]=r}if(h){x[h>>2]=k}if(!i){break a}g=x[l+44>>2];q=i,r=xg(g?g:22485),x[q>>2]=r}g=x[l+44>>2];if(g){Db(g);x[l+44>>2]=0}g:{if(!(j&1)){break g}x[31785]=0;O(1105,l+32|0,a|0);g=x[31785];x[31785]=0;h:{i:{if((g|0)!=1){j:{if(f){g=x[f+24>>2];x[31785]=0;O(1106,g|0,l+32|0);g=x[31785];x[31785]=0;if((g|0)!=1){break j}break i}g=Jb(l+32|0);if(b){x[31785]=0;O(b|0,g|0,c|0);g=x[31785];x[31785]=0;if((g|0)==1){break i}break j}Tt(g,l)}tb(l+32|0);break g}g=T(0)|0;break h}g=T(0)|0;tb(l+32|0)}Y(g|0)|0;x[l+28>>2]=f;x[l+24>>2]=e;x[l+20>>2]=d;x[l+16>>2]=c;x[l+12>>2]=b;x[l+8>>2]=a?a:22485;x[l+4>>2]=254;x[l>>2]=9194;kP(18690,l);St(126176);Z()}fb=l+48|0}function Gpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-192|0;fb=d;xc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!_o(b,d+180|0)){break l}if(!yX(d+180|0)){break l}g=_h(d+160|0);h=Fb(d+148|0);Sv(d+84|0);x[31785]=0;f=P(620,b|0,d+76|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=$b($b(x[d+80>>2])-4|0),x[m+80>>2]=n;while(1){f=$b($b(x[d+80>>2])-8|0);x[d+80>>2]=f;n:{if(c){break n}if(($b(x[d+76>>2])|0)!=1347699796){break n}k=1;break m}x[31785]=0;S(188,d+56|0,b|0,$b(f)|0);f=x[31785];x[31785]=0;if((f|0)==1){break d}e=d+56|0;f=ic(d,e);ub(e);e=x[f>>2];x[31785]=0;j=R(175,e|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break b}o:{if(!j){break o}p:{e=$b(x[d+76>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}x[31785]=0;P(186,f|0,4)|0;e=x[31785];x[31785]=0;if((e|0)==1){break b}x[31785]=0;e=R(621,f|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break b}if(!e){break o}e=$b(x[d+80>>2]);if(e>>>0<7){break o}i=x[Gc(d+52|0,28)>>2];x[31785]=0;V(622,f|0,h|0,i|0,e-6|0);e=x[31785];x[31785]=0;if((e|0)==1){break b}break o}x[31785]=0;l=P(623,f|0,d+84|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){break o}break b}Nw(g,f);break o}x[31785]=0;k=U(624,a|0,f|0,c|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break b}}ub(f);if(j){x[31785]=0;f=P(620,b|0,d+76|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break i}if(f){continue}}break}if(yd(x[h+4>>2],y[h+11|0])){x[31785]=0;b=P(1,d+56|0,15045)|0;c=x[31785];x[31785]=0;if((c|0)==1){break g}yb(h,b);tb(b)}q:{if(!(k&l&1)){break q}b=y[d+126|0]|y[d+127|0]<<8;x[31785]=0;b=Cb(b)&256;U(269,a+1074312|0,5,!b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break f}c=Cb(y[d+122|0]|y[d+123|0]<<8);if(c){w[d>>1]=64;w[d+40>>1]=c;m=a,n=z[Mc(d,d+40|0)>>1],x[m+480228>>2]=n}c=!b;b=Cb(y[d+124|0]|y[d+125|0]<<8);if(!(c|!b)){x[a+480204>>2]=D(b,1e4)}if(y[d+84|0]){b=d+40|0;Te(b,2,d+84|0);x[31785]=0;O(221,d|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}yb(a+1298308|0,d);tb(d)}c=y[d+130|0]|y[d+131|0]<<8;if(!Pq(c,1,12)){break q}f=y[d+128|0]|y[d+129|0]<<8;if(!Pq(f,1,31)){break q}e=y[d+134|0]|y[d+135|0]<<8;if(!Pq(e,0,23)){break q}j=y[d+136|0]|y[d+137|0]<<8;if(!Pq(j,0,59)){break q}i=y[d+138|0]|y[d+139|0]<<8;if(!Pq(i,0,59)){break q}x[a+1298408>>2]=0;b=bp(d);m=b,n=Cb(y[d+132|0]|y[d+133|0]<<8)+1900|0,x[m>>2]=n;m=b,n=Cb(c),x[m+4>>2]=n;m=b,n=Cb(f),x[m+8>>2]=n;m=b,n=Cb(e),x[m+12>>2]=n;m=b,n=Cb(j),x[m+16>>2]=n;m=b,n=Cb(i),x[m+24>>2]=n;x[b+28>>2]=0;x[31785]=0;O(449,a+1298412|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break q}a=N()|0;break a}if(k&1){b=x[g>>2];x[31785]=0;b=R(175,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break h}if(b){b=Fb(d);x[31785]=0;S(273,g|0,b|0,32);c=x[31785];x[31785]=0;if((c|0)==1){break c}if(er(b,13836)){x[31785]=0;S(261,d+40|0,28,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}c=d+40|0;yb(a+1298320|0,c);tb(c)}c=x[g+8>>2];f=x[g>>2];x[31785]=0;c=P(625,f|0,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}if(!c){x[31785]=0;c=R(205,g|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}x[31785]=0;aa(319,a+1298332|0,g|0,c|0,40,0);c=x[31785];x[31785]=0;if((c|0)==1){break c}}tb(b)}x[31785]=0;b=P(1,d+40|0,18348)|0;c=x[31785];x[31785]=0;if((c|0)==1){break k}x[31785]=0;S(493,d|0,b|0,h|0);c=x[31785];x[31785]=0;if((c|0)==1){break j}yb(a+1298368|0,d);tb(d);tb(b)}x[a+480208>>2]=x[a+480208>>2]|2097152;x[31785]=0;a=U(269,a+1074312|0,84,1)|0;b=x[31785];x[31785]=0;if((b|0)==1){break h}x[31785]=0;a=U(269,a|0,83,1)|0;b=x[31785];x[31785]=0;if((b|0)==1){break h}x[31785]=0;P(270,a|0,85)|0;a=x[31785];x[31785]=0;if((a|0)==1){break h}}tb(h);ub(g)}fb=d+192|0;return k&1}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0;ub(f)}tb(h);ub(g);Q(a|0);p()}function nta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;e=fb-320|0;fb=e;xc(b);a:{if(!_o(b,e+308|0)){break a}if(!H_(e+308|0)){break a}if(!Ob(e+308|0,14295,4)){Yb(b,4)}if(!yi(b,e+300|0)){break a}if(Ob(e+300|0,14248,4)){break a}if(!c){m=1;break a}S$(b,e+108|0,y[e+304|0]|y[e+305|0]<<8|(y[e+306|0]<<16|y[e+307|0]<<24));if((y[e+144|0]|y[e+145|0]<<8)>>>0>128|(y[e+150|0]|y[e+151|0]<<8)>>>0>16|((y[e+148|0]|y[e+149|0]<<8)>>>0>256|(y[e+142|0]|y[e+143|0]<<8)>>>0>128)){break a}Bd(a,8192);d=e+24|0;f=uc(d,6594);yb(a+1298344|0,f);tb(f);f=uc(d,10151);yb(a+1298356|0,f);tb(f);t=a+1298404|0,u=x[Gc(d,4)>>2],x[t>>2]=u;f=e+88|0;_i(f,2,e+108|0);Ec(d,f);yb(a+1298308|0,d);tb(d);w[e+24>>1]=y[e+150|0]|y[e+151|0]<<8;w[e+88>>1]=1;g=z[se(d,f)>>1];w[a+480188>>1]=g;x[a+480196>>2]=y[e+154|0];x[a+480204>>2]=D(y[e+155|0],1e4);v[e+24|0]=y[e+152|0];v[e+88|0]=64;d=y[Ub(d,f)|0];x[a+480200>>2]=d<<2;if(!d){x[a+480200>>2]=256}d=y[e+153|0];b:{if((d|0)==128){x[e+24>>2]=256/(g>>>0);x[e+88>>2]=128;d=x[Gb(e+24|0,e+88|0)>>2];break b}d=d&127}x[a+480228>>2]=d;d=0;while(1){if((d|0)==16){h=a+484376|0;g=Wb(x[a+484360>>2],y[h|0]);m=e+172|0;f=fb-16|0;fb=f;x[f+12>>2]=y[e+144|0]|y[e+145|0]<<8;d=f+12|0;vc(d,128);vc(d,65535);j=z[f+12>>1];tg(g,j);d=0;while(1){if((d|0)==(j|0)){fb=f+16|0}else{i=y[d+m|0];t=Er(x[g>>2],x[g+4>>2],d),u=(i|0)==255?-1:(i|0)==254?-2:i,w[t>>1]=u;d=d+1|0;continue}break}d=y[e+142|0]|y[e+143|0]<<8;if(d>>>0<(y[e+144|0]|y[e+145|0]<<8)>>>0){_e(Wb(x[a+484360>>2],y[h|0]),d)}o=c&2;j=a+484344|0;m=1;q=c&1;r=e+60|0;i=a+480190|0;s=a+480188|0;while(1){if(!yi(b,e+300|0)){break a}d=e+24|0;ce(d,b,y[e+304|0]|y[e+305|0]<<8|(y[e+306|0]<<16|y[e+307|0]<<24));c=ic(e+88|0,d);ub(d);c:{d:{if(!(Ob(e+300|0,13684,4)|!q)){x[31785]=0;k=n&65535;d=U(199,j|0,k|0,64)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}if(!d){break c}x[31785]=0;P(186,c|0,2)|0;d=x[31785];x[31785]=0;if((d|0)==1){break d}g=0;e:{while(1){d=x[c>>2];x[31785]=0;d=U(153,d|0,x[e+96>>2],1)|0;f=x[31785];x[31785]=0;f:{if((f|0)!=1){if(!(d&g>>>0<64)){break e}x[31785]=0;d=R(200,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}h=d<<24>>24;if(h){break f}g=g+1|0;continue}break d}f=e+24|0;d=h&15;if(d>>>0<z[s>>1]){f=Vb(x[j>>2],k);f=gd(x[f>>2],x[x[f+48>>2]+12>>2],g,d)}g:{if((h|0)>=0){break g}x[31785]=0;d=R(200,c|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break d}if(!d){break g}v[f|0]=d>>>0<109?d+12|0:d}d=h&255;if(d&64){x[31785]=0;h=R(200,c|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break d}v[f+1|0]=h}if(d&32){v[f+2|0]=1;x[31785]=0;h=R(200,c|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break d}v[e+12|0]=h;v[e|0]=64;t=f,u=y[Ub(e+12|0,e)|0],v[t+4|0]=u}if(!(d&16)){continue}x[31785]=0;O(201,e+12|0,c|0);d=x[31785];x[31785]=0;if((d|0)!=1){h=Ic(e+12|0);h:{i:{j:{k:{l:{d=y[e+12|0];switch(d-17|0){case 2:break k;case 0:case 1:break l;default:break j}}d=d&15;break i}v[e+12|0]=33;v[h|0]=145;d=y[e+12|0];break h}if(d>>>0<17){break h}d=(d&240)==32?9:-1}v[e+12|0]=d}Mf(f,d&255,y[h|0]);continue}break}break d}n=n+1|0;break c}if(Ob(e+300|0,13689,4)){break c}d=z[i>>1];if(!si(d)){break c}d=d+1|0;w[i>>1]=d;x[31785]=0;O(327,c|0,e+24|0);f=x[31785];x[31785]=0;m:{if((f|0)==1){break m}x[31785]=0;h=(D(d&65535,104)+a|0)+484380|0;O(328,e+24|0,h|0);d=x[31785];x[31785]=0;if((d|0)==1){break m}_i(e,2,r);x[31785]=0;O(221,e+12|0,e|0);d=x[31785];x[31785]=0;if((d|0)==1){break m}d=e+12|0;zc(((z[i>>1]<<5)+a|0)+946304|0,d);tb(d);if(!o){break c}d=y[e+37|0]|y[e+38|0]<<8;f=2;k=e+12|0;g=ad(k,8,1,0,1);n:{if(!(d&64)){f=0;if(!(d&2)){break n}}ug(g,f)}if(d&4){ed(g,16)}x[31785]=0;U(218,k|0,h|0,c|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break c}}}a=N()|0;ub(c);Q(a|0);p()}ub(c);continue}}f=(d<<5)+a|0;Ye(f+480280|0);g=y[(e+d|0)+156|0];if(g>>>0<=128){w[f+480284>>1]=g<<1}d=d+1|0;continue}}fb=e+320|0;return m|0}function msa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0;g=fb-32|0;fb=g;a:{b:{if(!c){break b}f=Xh(a,b);a=vb(x[d>>2]);x[g+28>>2]=a;d=vb(x[d+4>>2]);while(1){if(!Ib(a,d)){break b}xc(a);c:{if((Qk(a)|0)==(c|0)){Yb(a,20);d=Qk(a);k=lg(g+16|0);c=Yl(g+12|0,0,b?32:64);x[31785]=0;O(406,f|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}o=(b|0)==2?4096:(b|0)==1?2048:16384;c=24;d=d+24|0;q=1;l=1;d:{while(1){h=o;while(1){e=x[a+8>>2];i=x[a>>2];x[31785]=0;e=U(153,i|0,e|0,1)|0;i=x[31785];x[31785]=0;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((i|0)!=1){if(!e){break d}e=x[f+4>>2];i=x[f>>2];m=x[a+8>>2];x[31785]=0;x[g+12>>2]=m;m=P(407,k|0,g+12|0)|0;r=x[31785];x[31785]=0;if((r|0)==1){break a}u=m,A=Od(i,e),x[u>>2]=A;x[31785]=0;e=R(200,a|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break a}q:{switch(e-128|0){case 5:case 6:case 9:case 10:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:case 7:case 8:break e;default:break q}}r:{switch(e|0){case 0:break g;case 5:break l;case 4:break m;case 3:break n;case 2:break o;case 1:break p;default:break r}}s:{switch(e-160|0){case 5:case 6:break h;case 2:break i;case 1:break j;case 0:break k;case 3:case 4:break e;default:break s}}switch(e-192|0){case 2:break i;case 1:break j;case 0:break k;default:break e}}break a}if(y[f+12|0]&4){break e}x[31785]=0;e=R(276,a|0)|0;i=x[31785];x[31785]=0;t:{if((i|0)==1){break t}x[31785]=0;x[g+12>>2]=e;e=P(407,k|0,g+12|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break t}v[f+15|0]=x[e>>2];u=f,A=Od(x[f>>2],x[f+4>>2])-1|0,v[u+16|0]=A;v[f+12|0]=y[f+12|0]|4;break e}break a}x[31785]=0;e=R(276,a|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break a}w[g+12>>1]=e;w[g+10>>1]=1;e=z[se(g+12|0,g+10|0)>>1];h=D(e,D(s<<16>>16,l))+h|0;u:{if(e>>>0<2){break u}u=g,A=cm((e+z[qi(x[f+4>>2])>>1]|0)-1|0),w[u+12>>1]=A;e=Gv(b,h);x[31785]=0;v[g+10|0]=e;S(408,f|0,g+12|0,g+10|0);e=x[31785];x[31785]=0;if((e|0)!=1){break u}break a}u=g,A=cm(z[qi(x[f+4>>2])>>1]+1|0),w[u+12>>1]=A;e=Gv(b,h);x[31785]=0;v[g+10|0]=e;S(408,f|0,g+12|0,g+10|0);e=x[31785];x[31785]=0;if((e|0)!=1){break e}break a}x[31785]=0;j=R(200,a|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}t=x[a+8>>2];break e}x[31785]=0;e=R(276,a|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break a}e=c+e|0;x[g+12>>2]=e;if(!(!(j&255)|e>>>0<t>>>0)){j=j-1|0;if(!(j&255)){break f}x[31785]=0;P(152,a|0,e|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){break e}break a}if(!(j&255)){break f}x[31785]=0;e=P(409,k|0,g+12|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break a}v[f+13|0]=x[e>>2];u=f,A=Od(x[f>>2],x[f+4>>2])-1|0,v[u+14|0]=A;v[f+12|0]=y[f+12|0]|2;break e}q=0;n=1;break e}x[31785]=0;h=R(276,a|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}e=Gv(b,h);u=qi(x[f+4>>2]),A=e,v[u+2|0]=A;break e}x[31785]=0;s=R(410,a|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){break e}break a}x[31785]=0;e=R(200,a|0)|0;l=x[31785];x[31785]=0;if((l|0)!=1){v[g+12|0]=e;v[g+10|0]=1;l=y[af(g+12|0,g+10|0)|0];break e}break a}x[31785]=0;P(186,a|0,1)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}break e}n=1;if(c>>>0<d>>>0){break e}break d}j=0}if(!n|c>>>0>=d>>>0){continue}break}x[31785]=0;c=P(152,a|0,d|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}if(!c){break d}c=x[a+8>>2];h=x[a>>2];x[31785]=0;c=U(153,h|0,c|0,2)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}if(!c){break d}h=y[f+12|0];v:{if(!(!(h&4)&q)){c=x[f+4>>2];break v}c=x[f+4>>2];e=x[f>>2];v[f+12|0]=h|4;h=Od(e,c)-1|0;v[f+15|0]=h;v[f+16|0]=h}u=g,A=cm(z[qi(c)>>1]+1|0),w[u+12>>1]=A;c=Gv(b,o);x[31785]=0;v[g+10|0]=c;S(408,f|0,g+12|0,g+10|0);c=x[31785];x[31785]=0;if((c|0)!=1){n=1;v[f+17|0]=y[f+16|0]+1;c=d;continue}break}break a}v[f+12|0]=y[f+12|0]|1;GZ(k);break b}a=x[Xf(g+28|0)>>2];continue}break}break a}fb=g+32|0;return}a=N()|0;GZ(k);Q(a|0);p()}function Ez(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-256|0;fb=f;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[xl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Jl(f+96|0,h,g,g-1|0);g=x[f+100>>2];x[b>>2]=x[f+96>>2];x[b+4>>2]=g}g=f+96|0;de(g);h=x[f+96>>2];de(f+236|0);i=wl(h,x[f+240>>2],b);de(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{if((i|0)==x[f+100>>2]){a=pc(f+248|0,22485);i=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=i;if(Oc(h,g,f+8|0)){e=ac(8);x[31785]=0;c=di(f+236|0,c,d);a=x[31785];x[31785]=0;f:{g:{h:{if((a|0)!=1){x[31785]=0;S(1020,f+96|0,18453,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break h}nc(e,f+96|0);a=0;x[31785]=0;S(100,e|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(f+96|0);break g}b=N()|0;break f}b=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}if(!e){break e}e=ac(8);a=x[b+4>>2];b=x[b>>2];x[31785]=0;g=di(f+212|0,b,a);a=x[31785];x[31785]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31785]=0;S(1020,f+224|0,18489,g|0);a=x[31785];x[31785]=0;if((a|0)==1){break q}x[31785]=0;O(1022,f+236|0,f+224|0);b=x[31785];x[31785]=0;a=1;if((b|0)==1){break p}x[31785]=0;c=di(f+200|0,c,d);a=x[31785];x[31785]=0;if((a|0)==1){break o}x[31785]=0;S(1024,f+96|0,f+236|0,c|0);b=x[31785];x[31785]=0;a=1;if((b|0)==1){break n}nc(e,f+96|0);x[31785]=0;S(100,e|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(f+96|0);a=0;break m}b=N()|0;break i}b=N()|0;a=1;break j}b=N()|0;break k}b=N()|0;a=1;break l}b=N()|0}tb(c)}tb(f+236|0)}tb(f+224|0)}tb(g);if(!a){break c}}jc(e);break c}b=pc(f+192|0,22485);e=x[b+4>>2];x[f+88>>2]=x[b>>2];x[f+92>>2]=e;if(Oc(h,g,f+88|0)){e=ac(8);x[31785]=0;c=di(f+236|0,c,d);a=x[31785];x[31785]=0;r:{s:{t:{if((a|0)!=1){x[31785]=0;S(1020,f+96|0,18453,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break t}nc(e,f+96|0);a=0;x[31785]=0;S(100,e|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(f+96|0);break s}b=N()|0;break r}b=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}b=pc(f+184|0,12442);e=x[b+4>>2];x[f+80>>2]=x[b>>2];x[f+84>>2]=e;if(Oc(h,g,f+80|0)){b=pc(f+176|0,5621);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;if(Oc(c,d,f+32|0)){x[a+52>>2]=0;break e}b=pc(f+168|0,11306);e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(Oc(c,d,f+24|0)){x[a+52>>2]=1;break e}b=pc(f+160|0,9226);e=x[b+4>>2];x[f+16>>2]=x[b>>2];x[f+20>>2]=e;if(Oc(c,d,f+16|0)){x[a+52>>2]=2;break e}e=ac(8);x[31785]=0;c=di(f+236|0,c,d);a=x[31785];x[31785]=0;u:{v:{w:{if((a|0)!=1){x[31785]=0;S(1020,f+96|0,14765,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break w}nc(e,f+96|0);a=0;x[31785]=0;S(100,e|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(f+96|0);break v}b=N()|0;break u}b=N()|0;a=1}tb(c);if(!a){break c}}jc(e);break c}b=pc(f+152|0,11543);e=x[b+4>>2];x[f+72>>2]=x[b>>2];x[f+76>>2]=e;if(!Oc(h,g,f+72|0)){break e}b=pc(f+144|0,15803);e=x[b+4>>2];x[f+64>>2]=x[b>>2];x[f+68>>2]=e;b=0;x:{if(Oc(c,d,f- -64|0)){break x}b=pc(f+136|0,15808);e=x[b+4>>2];x[f+56>>2]=x[b>>2];x[f+60>>2]=e;b=1;if(Oc(c,d,f+56|0)){break x}b=pc(f+128|0,12716);e=x[b+4>>2];x[f+48>>2]=x[b>>2];x[f+52>>2]=e;b=2;if(Oc(c,d,f+48|0)){break x}b=pc(f+120|0,9290);e=x[b+4>>2];x[f+40>>2]=x[b>>2];x[f+44>>2]=e;b=3;if(Oc(c,d,f+40|0)){break x}a=ac(8);x[31785]=0;c=P(37,f+96|0,11579)|0;b=x[31785];x[31785]=0;if((b|0)==1){break d}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}x[a+56>>2]=b;a=x[a+24>>2];if(!x[a+24668>>2]){break e}c=a+24664|0;d=x[c+4>>2];x[f+112>>2]=x[c>>2];x[f+116>>2]=d;c=a+24656|0;d=x[c+4>>2];x[f+104>>2]=x[c>>2];x[f+108>>2]=d;c=x[a+24652>>2];x[f+96>>2]=x[a+24648>>2];x[f+100>>2]=c;j=f,k=IM(b),x[j+116>>2]=k;if(!rz(f+96|0,a+24648|0)){break e}yA(a,f+96|0)}fb=f+256|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function cua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-3056|0;fb=e;xc(b);f=fb-16|0;fb=f;h=e+1102|0;N$(f+8|0,h);i=x[f+12>>2];j=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(i|0)){Yb(j,x[f+12>>2])}fb=f+16|0;b=(b|0)==(i|0);if(!b){M$(h)}a:{if(!b){break a}if(!O$(e+1102|0)){break a}b:{if(!c){break b}if(!Mb(x[j>>2],x[j+8>>2],Bc(1024,0))){break a}L$(j,e+576|0);L$(j,e- -64|0);while(1){if((g|0)!=128){b=g<<2;f=x[b+(e+576|0)>>2];if(f>>>0>16777215){break a}b=x[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}g=g+1|0;if(sm(x[j>>2],(b+f|0)+2978|0)){continue}break a}break}Bd(a,2);ag(a);b=e+40|0;d=uc(b,13943);yb(a+1298344|0,d);tb(d);d=uc(b,14904);yb(a+1298356|0,d);tb(d);d=uc(b,15713);yb(a+1298368|0,d);tb(d);o=a+1298404|0,q=x[Gc(b,4)>>2],x[o>>2]=q;b=y[e+1102|0];x[a+480204>>2]=143e4;x[a+480196>>2]=b;_e(Wb(x[a+484360>>2],y[a+484376|0]),y[e+1103|0]);x[a+480188>>2]=4194317;Lb(a+1074312|0,95,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=0;g=0;while(1){if((g|0)==4){c:{while(1){d:{if((d|0)==32){g=0;break d}b=d+1|0;g=D(b,104)+a|0;i=g+484380|0;jd(i,2);h=e+20|0;ui(h,1,(D(d,13)+e|0)+1104|0);f=e+40|0;Ec(f,h);zc(((b<<5)+a|0)+946304|0,f);tb(f);d=(e+1102|0)+(d<<4)|0;f=y[d+422|0]|y[d+423|0]<<8|(y[d+424|0]<<16|y[d+425|0]<<24);x[i>>2]=f;h=f;f=y[d+430|0]|y[d+431|0]<<8|(y[d+432|0]<<16|y[d+433|0]<<24);if(h>>>0>=f>>>0){d=y[d+426|0]|y[d+427|0]<<8|(y[d+428|0]<<16|y[d+429|0]<<24);w[g+484414>>1]=2;x[g+484388>>2]=f;x[g+484384>>2]=d}x[g+484404>>2]=8287;d=b;continue}break}while(1){if((g|0)!=32){d=g+33|0;f=(D(d,104)+a|0)+484380|0;jd(f,2);i=e+20|0;ui(i,1,(D(g,13)+e|0)+2032|0);b=e+40|0;Ec(b,i);zc(((d<<5)+a|0)+946304|0,b);tb(b);x[e+48>>2]=0;x[e+40>>2]=0;x[e+44>>2]=0;d=(e+1102|0)+D(g,11)|0;o=xb(b,0),q=y[d+1347|0],v[o|0]=q;o=xb(b,1),q=y[d+1352|0],v[o|0]=q;o=xb(b,2),q=y[d+1348|0],v[o|0]=q;o=xb(b,3),q=y[d+1353|0],v[o|0]=q;o=xb(b,4),q=y[d+1349|0],v[o|0]=q;o=xb(b,5),q=y[d+1354|0],v[o|0]=q;o=xb(b,6),q=y[d+1350|0],v[o|0]=q;o=xb(b,7),q=y[d+1355|0],v[o|0]=q;o=xb(b,8),q=y[d+1351|0],v[o|0]=q;o=xb(b,9),q=y[d+1356|0],v[o|0]=q;o=xb(b,10),q=y[d+1346|0],v[o|0]=q;x[e+16>>2]=x[e+48>>2];b=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=b;Vk(f,1,e+8|0);g=g+1|0;continue}break}Dr(Wb(x[a+484360>>2],y[a+484376|0]),e+2800|0,256,255,65535);l=a+484344|0;$f(l,128);m=c&1;f=0;while(1){e:{f:{if((f|0)!=128){b=f<<2;bd(j,x[b+(e+576|0)>>2]+2978|0);d=e+20|0;ce(d,j,x[b+(e- -64|0)>>2]);b=ic(e+40|0,d);ub(d);if(!m){break e}x[31785]=0;d=U(199,l|0,f&65535,64)|0;g=x[31785];x[31785]=0;if((g|0)==1){break c}if(!d){break e}g=0;i=Vb(x[l>>2],f);while(1){if(g>>>0>63){break e}d=x[b>>2];x[31785]=0;d=U(153,d|0,x[e+48>>2],1)|0;h=x[31785];x[31785]=0;g:{if((h|0)!=1){if(!d){break e}x[31785]=0;d=R(200,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break c}if(d>>>0>12){break g}h=gd(x[i>>2],x[x[i+48>>2]+12>>2],g,d);x[31785]=0;O(201,e+20|0,b|0);k=x[31785];x[31785]=0;if((k|0)==1){break c}k=y[e+20|0];d=d>>>0>3;v[h|0]=((k&15)+(d?13:37)|0)+D(k>>>4&7,12);k=Ic(e+20|0);v[h+1|0]=((y[k|0]>>>4|0)+(d?33:1)|0)+(y[e+20|0]>>>3&16);K$(h,y[k|0],d);continue}break c}h=d-32|0;if((h&255)>>>0<=12){h=gd(x[i>>2],x[x[i+48>>2]+12>>2],g,h&65535);x[31785]=0;k=R(200,b|0)|0;n=x[31785];x[31785]=0;if((n|0)==1){break c}K$(h,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!g){break e}o=gd(x[i>>2],x[x[i+48>>2]+12>>2],g-1|0,0),q=14,v[o+3|0]=q;break e}x[31785]=0;d=R(200,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break c}g=d+g|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}qg(ad(e+40|0,8,1,0,1),(D(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}ub(b);d=0;break a}ub(b);f=f+1|0;continue}}}else{w[((g<<5)+a|0)+480284>>1]=g&1?192:64;g=g+1|0;continue}break}a=N()|0;ub(b);Q(a|0);p()}d=1}fb=e+3056|0;return d|0}function sna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-176|0;fb=e;a:{b:{if(Mb(x[c>>2],x[c+8>>2],8)){Yb(c,4);while(1){if(Cv(x[c>>2],x[c+8>>2])){break b}m=fb-288|0;fb=m;f=jU(m+6|0);h=0;i=fb-368|0;fb=i;k=yc(f,jU(i+80|0),282);f=0;g=fb-32|0;fb=g;x[g+28>>2]=0;j=gc(g+8|0,g+28|0,4);l=x[j>>2];kc(g+20|0,x[c>>2],x[c+8>>2],l,x[j+4>>2]);c:{if(x[g+24>>2]!=4){break c}if(Ob(g+28|0,13742,4)){break c}Yb(c,4);h=1}fb=g+32|0;d:{e:{f:{g:{h:{if(h){kU(c,4);j=A$(i+60|0,c);x[31785]=0;g=P(795,j|0,k|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break h}i:{if(!g){break i}g=x[j+8>>2];h=x[j>>2];l=y[k+26|0];x[31785]=0;g=U(796,h|0,g|0,l|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break h}if(!g){break i}h=0;j:{while(1){if(y[k+26|0]<=f>>>0){g=x[j+8>>2];l=x[j>>2];f=0;x[31785]=0;h=h&65535;g=U(796,l|0,g|0,h|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break f}if(!g){break i}x[31785]=0;O(797,j|0,h|0);f=x[31785];x[31785]=0;if((f|0)==1){break f}kU(j,lU(k));f=rc(i+56|0);g=i+80|0;CB(g);x[31785]=0;O(798,j|0,g|0);g=x[31785];x[31785]=0;if((g|0)!=1){w[i+102>>1]=0;w[i+104>>1]=0;f=iU(f,i+80|0,i+107|0);g=y[k+26|0];x[31785]=0;O(797,j|0,g|0);g=x[31785];x[31785]=0;if((g|0)!=1){break j}}f=N()|0;break e}x[31785]=0;g=R(799,j|0)|0;l=x[31785];x[31785]=0;if((l|0)!=1){v[(f+k|0)+27|0]=g;f=f+1|0;h=g+h|0;continue}break}f=N()|0;break e}g=f;f=k+27|0;g=iU(g,f,f+y[k+26|0]|0);x[31785]=0;S(800,i+36|0,j|0,h|0);f=x[31785];x[31785]=0;if((f|0)==1){break g}f=0;x[31785]=0;O(578,i+16|0,i+36|0);h=x[31785];x[31785]=0;if((h|0)==1){f=N()|0;ub(i+36|0);break e}n=i+16|0;QF(i+8|0,n);h=vb(x[i+8>>2]);o=Tk(x[i+8>>2],x[i+12>>2]);l=fb-16|0;fb=l;x[l+12>>2]=h;while(1){if(Ib(h,o)){fU(g,y[h|0]);h=x[je(l+12|0)>>2];continue}else{fb=l+16|0}break}Jc(n);ub(i+36|0);if(x[g>>2]!=(y[k+22|0]|y[k+23|0]<<8|(y[k+24|0]<<16|y[k+25|0]<<24))){break i}f=lU(k);x[31785]=0;O(797,c|0,f|0);g=x[31785];x[31785]=0;f=1;if((g|0)==1){break f}}ub(j)}fb=i+368|0;break d}f=N()|0;break e}f=N()|0;break e}f=N()|0}ub(j);Q(f|0);p()}fb=m+288|0;if(f){continue}break}}xc(c);qg(b,a,c);a=1;break a}v[d|0]=1;xc(c);f=Mg(c);d=e+136|0;ce(d,c,jf(c));g=ic(e+156|0,d);ub(d);c=z[a+34>>1]&-66|y[b|0]>15;b=y[b+1|0]!=1;c=c|b<<6;w[a+34>>1]=c;x[a>>2]=f>>>(c&1)>>>b;x[e+132>>2]=0;x[e+128>>2]=0;x[31785]=0;O(578,d|0,g|0);b=x[31785];x[31785]=0;k:{l:{m:{n:{if((b|0)!=1){c=Se(e+136|0);d=x[e+136>>2];i=LC(c,Vi(d),e+132|0,e+128|0);x[31785]=0;b=x[e+132>>2];P(186,g|0,b|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){if(!i){break k}Bh(a);k=b+c|0;b=d-b|0;d=x[e+128>>2];c=0;while(1){o:{if(d){if(!b|(d|0)!=1){break l}d=x[a>>2];if(d>>>0>c>>>0){break o}break l}d=x[a>>2];if(d>>>0<=c>>>0){break l}}if(!ge(d,x[a+20>>2])){break l}x[e+124>>2]=0;x[e+120>>2]=0;j=bY(i,k,Vi(b),e+124|0,e+116|0,e+120|0);x[31785]=0;P(186,g|0,j|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break n}xi(e+120|0,Vi(x[a>>2]-c|0));d=x[e+120>>2];p:{if((d|0)<=0){break p}f=x[e+124>>2];m=z[a+34>>1];if((Xd(m)|0)!=(f|0)){break p}h=D(c,f);l=x[a+20>>2];if(m&1){x[e+112>>2]=d;x[e+100>>2]=d;x[e- -64>>2]=d;x[e+48>>2]=d;x[e+96>>2]=f;x[e+92>>2]=x[e+116>>2];x[e+108>>2]=f;x[e+104>>2]=l+(h<<1);x[31785]=0;f=x[e+96>>2];x[e+40>>2]=x[e+92>>2];x[e+44>>2]=f;f=x[e+108>>2];x[e+56>>2]=x[e+104>>2];x[e+60>>2]=f;O(579,e+56|0,e+40|0);f=x[31785];x[31785]=0;if((f|0)!=1){break p}break n}x[e+88>>2]=d;x[e+76>>2]=d;x[e+32>>2]=d;x[e+16>>2]=d;x[e+72>>2]=f;x[e+68>>2]=x[e+116>>2];x[e+84>>2]=f;x[e+80>>2]=h+l;x[31785]=0;f=x[e+72>>2];x[e+8>>2]=x[e+68>>2];x[e+12>>2]=f;f=x[e+84>>2];x[e+24>>2]=x[e+80>>2];x[e+28>>2]=f;O(580,e+24|0,e+8|0);f=x[31785];x[31785]=0;if((f|0)==1){break n}}b=b-j|0;k=j+k|0;c=c+d|0;d=aY(i);continue}}break n}c=N()|0;break m}c=N()|0;Jc(e+136|0)}ub(g);Q(c|0);p()}$X(i)}Jc(e+136|0);ub(g);a=(i|0)!=0}fb=e+176|0;return a|0}function Dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,q=0;d=fb-80|0;fb=d;g=-1;a:{b:{c:{d:{if(x[(x[x[b>>2]-12>>2]+b|0)+16>>2]){break d}Yd(d- -64|0,b);e=x[d+72>>2];k=x[d+76>>2];f=d+56|0;bl(f);b=zj(b,f,8);if(Ob(f,16948,8)){Ei(b,e,k,0);break d}w[d+54>>1]=0;kg(b,d+54|0);k=w[d+54>>1];if((k-4&65535)>>>0<65534){break d}f=d+46|0;bl(f);e=zj(b,f,8);if(Ob(f,14428,8)){break d}w[d+44>>1]=0;kg(e,d+44|0);f=w[d+44>>1];if((f-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{if(f>>>0<=3){b=Fb(d- -64|0);x[31785]=0;h=U(499,e|0,b|0,65535)|0;l=x[31785];x[31785]=0;if((l|0)==1){break b}if(!h){break i}x[31785]=0;S(500,d+32|0,c|0,b|0);h=x[31785];x[31785]=0;if((h|0)!=1){break j}break b}b=Fb(d- -64|0);x[31785]=0;h=P(502,e|0,b|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break c}if(!h){break h}x[31785]=0;S(500,d+32|0,c|0,b|0);h=x[31785];x[31785]=0;if((h|0)==1){break c}}h=d+32|0;yb(a+40|0,h);tb(h);tb(b);w[d+30>>1]=0;kg(e,d+30|0);w[d+28>>1]=0;kg(e,d+28|0);w[a>>1]=z[d+28>>1];w[d+26>>1]=0;k:{if((f|0)<=3){x[d+64>>2]=0;Ik(e,d- -64|0);b=x[d+64>>2];if(b>>>0>65535){break d}b=cm(b);w[d+26>>1]=b;break k}kg(e,d+26|0);b=z[d+26>>1]}h=a+52|0;l=b&65535;n=(f|0)>3;b=0;l:{m:{while(1){if(l>>>0<=(b&65535)>>>0){break l}f=Fb(d- -64|0);x[31785]=0;w[d+8>>1]=0;O(943,e|0,d+8|0);i=x[31785];x[31785]=0;if((i|0)==1){break g}n:{if(!n){x[31785]=0;i=U(499,e|0,f|0,65535)|0;j=x[31785];x[31785]=0;if((j|0)==1){break g}if(i){break n}break e}x[31785]=0;i=P(502,e|0,f|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break g}if(!i){break e}}x[31785]=0;S(500,d+32|0,c|0,f|0);i=x[31785];x[31785]=0;if((i|0)!=1){x[31785]=0;i=P(940,h|0,d+8|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break m}j=i;i=d+32|0;yb(j,i);tb(i);tb(f);b=b+1|0;continue}break}g=N()|0;break f}g=N()|0;tb(d+32|0);break f}c=d+32|0;bl(c);b=zj(e,c,8);if(Ob(c,14372,8)){break d}c=z[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;o:{if((k|0)<=2){if(IQ(b,c)){break o}break d}if(!HQ(b,c)){break d}}o=d,q=vb(x[a+4>>2]),x[o+64>>2]=q;c=vb(x[a+8>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!Rm(B[e>>2])){break d}Pe(d- -64|0);continue}break}c=a+16|0;p:{if((k|0)<=2){if(IQ(b,c)){break p}break d}if(!HQ(b,c)){break d}}o=d,q=vb(x[a+16>>2]),x[o+64>>2]=q;c=vb(x[a+20>>2]);while(1){e=x[d+64>>2];if(Ib(e,c)){if(!Rm(B[e>>2])){break d}Pe(d- -64|0);continue}break}o=a,q=oc(x[a+16>>2],x[a+20>>2]),x[o+36>>2]=q;w[d+24>>1]=0;kg(b,d+24|0);c=z[d+24>>1];w[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}w[d+22>>1]=0;kg(b,d+22|0);c=w[d+22>>1];w[a+30>>1]=c;if((c|0)<0){break d}x[d+16>>2]=0;jq(b,d+16|0);m=LQ(B[d+16>>2]);B[a+32>>2]=m;if(!Rm(m)){break d}x[d+8>>2]=0;x[d+12>>2]=0;c=fb-32|0;fb=c;e=d+8|0;al(c+16|0,e);Im(c+24|0,b,x[c+16>>2],x[c+20>>2]);al(c+8|0,e);fb=c+32|0;if(Ob(e,16939,8)){break d}b=oc(x[a+4>>2],x[a+8>>2]);if(b>>>0>32767){break d}c=w[a+30>>1];e=z[a>>1];if(!(e?!(B[a+32>>2]<=E(0))&(c|0)>0:1)){break d}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break d}break;default:break q}}b=0;c=x[a+36>>2];if(c){b=c-1|0;x[a+36>>2]=b}o=d,q=Vi(b),x[o+64>>2]=q;x[d+4>>2]=0;o=a,q=x[bk(d- -64|0,d+4|0,42528)>>2],x[o+36>>2]=q;kq(a);g=1;if(z[a>>1]!=3){break d}c=w[a+30>>1];if((c-w[a+28>>1]|0)>(TQ(oc(x[a+4>>2],x[a+8>>2]))|0)){break d}g=a+32|0;e=Nb(d- -64|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=z[a+28>>1];w[d+4>>1]=b;o=d,q=(oc(x[a+4>>2],x[a+8>>2])+b|0)-1|0,w[o+6>>1]=q;x[31785]=0;w[d+2>>1]=0;ha(938,a|0,e|0,g|0,d+4|0,d+2|0)|0;a=x[31785];x[31785]=0;g=1;if((a|0)==1){break r}sc(e);break d}c=w[a+28>>1];f=x[a+4>>2];x[31785]=0;O(944,e|0,wb(f,b-c|0)|0);c=x[31785];x[31785]=0;if((c|0)!=1){b=b+1|0;c=z[a+30>>1];continue}}break}g=N()|0;sc(e);break a}tb(b);break d}tb(b);break d}g=N()|0}tb(f);break a}tb(f)}fb=d+80|0;return g|0}g=N()|0;tb(b);break a}g=N()|0;tb(b)}Q(g|0);p()}function l7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;x[h+12>>2]=b;x[e>>2]=0;$c(h,x[d+28>>2]);x[31785]=0;i=R(28,x[h>>2])|0;j=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Zb(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=N()|0;Zb(h);Q(a|0);p()}PJ(a,f+24|0,h+12|0,c,e,i);break b}OJ(a,f+16|0,h+12|0,c,e,i);break b}g=a;i=b;a=ib[x[x[a+8>>2]+12>>2]](a+8|0)|0;b=Jb(a);k=h,l=sk(g,i,c,d,e,f,b,Bb(x[a+4>>2],y[a+11|0])+b|0),x[k+12>>2]=l;break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];B:{if(!(b&4|a-1>>>0>30)){x[f+12>>2]=a;break B}x[e>>2]=b|4}break b}x[h>>2]=623865125;x[h+4>>2]=2032480100;k=h,l=sk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}x[h>>2]=623728933;x[h+4>>2]=1680158061;k=h,l=sk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];C:{if(!(b&4|(a|0)>23)){x[f+8>>2]=a;break C}x[e>>2]=b|4}break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];D:{if(!(b&4|a-1>>>0>11)){x[f+8>>2]=a;break D}x[e>>2]=b|4}break b}a=nj(h+12|0,c,e,i,3);b=x[e>>2];E:{if(!(b&4|(a|0)>365)){x[f+28>>2]=a;break E}x[e>>2]=b|4}break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];a=a-1|0;F:{if(!(b&4|a>>>0>11)){x[f+16>>2]=a;break F}x[e>>2]=b|4}break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];G:{if(!(b&4|(a|0)>59)){x[f+4>>2]=a;break G}x[e>>2]=b|4}break b}a=h+12|0;b=fb-16|0;fb=b;x[b+12>>2]=c;while(1){H:{if(qh(a,b+12|0)){break H}c=rl(x[a>>2]);if(!Ef(x[i+8>>2],1,c)){break H}Bm(a);continue}break}if(qh(a,b+12|0)){x[e>>2]=x[e>>2]|2}fb=b+16|0;break b}b=h+12|0;a=ib[x[x[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Bb(x[a+4>>2],y[a+11|0])|0)==(0-Bb(x[a+16>>2],y[a+23|0])|0)){x[e>>2]=x[e>>2]|4;break I}c=Xs(b,c,a,a+24|0,i,e,0);b=x[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){x[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){x[f+8>>2]=b+12}}break b}g=y[112008]|y[112009]<<8|(y[112010]<<16|y[112011]<<24);v[h+7|0]=g;v[h+8|0]=g>>>8;v[h+9|0]=g>>>16;v[h+10|0]=g>>>24;g=y[112005]|y[112006]<<8|(y[112007]<<16|y[112008]<<24);x[h>>2]=y[112001]|y[112002]<<8|(y[112003]<<16|y[112004]<<24);x[h+4>>2]=g;k=h,l=sk(a,b,c,d,e,f,h,h+11|0),x[k+12>>2]=l;break b}v[h+4|0]=y[112016];x[h>>2]=y[112012]|y[112013]<<8|(y[112014]<<16|y[112015]<<24);k=h,l=sk(a,b,c,d,e,f,h,h+5|0),x[k+12>>2]=l;break b}a=nj(h+12|0,c,e,i,2);b=x[e>>2];J:{if(!(b&4|(a|0)>60)){x[f>>2]=a;break J}x[e>>2]=b|4}break b}x[h>>2]=624576549;x[h+4>>2]=1394948685;k=h,l=sk(a,b,c,d,e,f,h,h+8|0),x[k+12>>2]=l;break b}a=nj(h+12|0,c,e,i,1);b=x[e>>2];K:{if(!(b&4|(a|0)>6)){x[f+24>>2]=a;break K}x[e>>2]=b|4}break b}a=ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;i=b;a=ib[x[x[a+8>>2]+24>>2]](a+8|0)|0;b=Jb(a);k=h,l=sk(g,i,c,d,e,f,b,Bb(x[a+4>>2],y[a+11|0])+b|0),x[k+12>>2]=l;break b}NJ(f+20|0,h+12|0,c,e,i);break b}a=nj(h+12|0,c,e,i,4);if(!(y[e|0]&4)){x[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}x[e>>2]=x[e>>2]|4;break b}a=fb-16|0;fb=a;x[a+12>>2]=c;b=6;c=h+12|0;L:{M:{if(qh(c,a+12|0)){break M}b=4;if((jl(i,rl(x[c>>2]))|0)!=37){break M}b=2;if(!qh(Bm(c),a+12|0)){break L}}x[e>>2]=x[e>>2]|b}fb=a+16|0}a=x[h+12>>2]}fb=h+16|0;return a|0}function nk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;i=1;o(+b);c=j(1)|0;e=j(0)|0;a:{b:{g=c;p=c&2147483647;c:{if(!(p|e)){break c}o(+a);c=j(1)|0;f=j(0)|0;if(!f&(c|0)==1072693248){break c}q=c&2147483647;t=f;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(f|0)!=0|p>>>0>2146435072)&(!e|(p|0)!=2146435072))){return a+b}d:{e:{f:{g:{h:{r=0;i:{if((c|0)>0|(c|0)>=0){break i}r=2;if(p>>>0>1128267775){break i}r=0;if(p>>>0<1072693248){break i}f=p>>>20|0;if(p>>>0<1094713344){break h}m=1075-f|0;f=e>>>m|0;r=0;if((e|0)!=f<<m){break i}r=2-(f&1)|0}m=r;if(e){break f}if((p|0)!=2146435072){break g}if(!(q-1072693248|t)){break c}if(q>>>0<1072693248){break e}return(g|0)>0|(g|0)>=0?b:0}if(e){break f}f=1043-f|0;e=p>>>f|0;if((p|0)!=e<<f){break g}m=2-(e&1)|0}if((p|0)==1072693248){if((g|0)>0|(g|0)>=0){return a}return 1/a}if((g|0)==1073741824){return a*a}if((g|0)!=1071644672|(c|0)<0){break f}return M(a)}d=F(a);if(t){break d}j:{if((c|0)<0){if((c|0)==-2147483648|(c|0)==-1074790400|(c|0)==-1048576){break j}break d}if(!c|(c|0)==2146435072){break j}if((c|0)!=1072693248){break d}}i=(g|0)<0?1/d:d;if((c|0)>0|(c|0)>=0){break c}if(!(q-1072693248|m)){a=i-i;return a/a}return(m|0)==1?-i:i}return(g|0)>0|(g|0)>=0?0:-b}k:{if((c|0)>0|(c|0)>=0){break k}l:{switch(m|0){case 0:a=a-a;return a/a;case 1:break l;default:break k}}i=-1}m:{if(p>>>0>=1105199105){if(p>>>0>=1139802113){if(q>>>0<=1072693247){return(g|0)<0?Infinity:0}return(g|0)>0?Infinity:0}if(q>>>0<=1072693246){return(g|0)<0?i*1e300*1e300:i*1e-300*1e-300}if(q>>>0>=1072693249){return(g|0)>0?i*1e300*1e300:i*1e-300*1e-300}a=d+-1;d=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;h=d;d=a*1.4426950216293335;o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-d);break m}a=d*9007199254740992;e=q>>>0<1048576;d=e?a:d;o(+a);c=j(1)|0;j(0)|0;m=e?c:q;f=m&1048575;c=f|1072693248;m=(m>>20)+(e?-1076:-1023)|0;e=0;n:{if(f>>>0<235663){break n}if(f>>>0<767610){e=1;break n}c=f|1071644672;m=m+1|0}f=((e<<18)+(c>>>1|0)|0)+537395200|0;e=e<<3;w=C[e+3536>>3];o(+d);j(1)|0;t=0;l(0,j(0)|t);l(1,c|0);k=+n();s=C[e+3520>>3];h=k-s;u=1/(s+k);d=h*u;o(+d);c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();x=a;l(0,t|0);l(1,f|0);v=a*a;y=h;h=+n();k=u*(y-a*h-a*(k-(h-s)));h=k*(d+a);a=d*d;s=h+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();h=x*a;d=k*a+d*(s-(a+-3-v));o(+(h+d));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=w+(a*-7.028461650952758e-9+(d-(a-h))*.9617966939259756);h=d;k=C[e+3552>>3];d=a*.9617967009544373;s=+(m|0);o(+(k+(h+d)+s));c=j(1)|0;j(0)|0;l(0,0);l(1,c|0);a=+n();d=h-(a-s-k-d)}l(0,0);l(1,g|0);k=+n();d=(b-k)*a+d*b;b=a*k;a=d+b;o(+a);c=j(1)|0;g=j(0)|0;o:{if((c|0)>=1083179008){if(g|c-1083179008){break b}if(!(d+8008566259537294e-32>a-b)){break o}break b}if((c&2147482624)>>>0<1083231232){break o}if(g|c+1064252416){break a}if(!(d<=a-b)){break o}break a}e=0;f=c&2147483647;if(f>>>0>=1071644673){g=c+(1048576>>>(f>>>20|0)-1022|0)|0;f=g>>>20&2047;e=(g&1048575|1048576)>>>1043-f|0;e=(c|0)<0?0-e|0:e;l(0,0);l(1,g&-1048576>>f-1023);b=b-+n();o(+(d+b));c=j(1)|0;j(0)|0}l(0,0);l(1,c|0);a=+n();k=a*.6931471824645996;d=(d-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=k+d;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);h=a*b/(b+-2);b=a;a=d-(a-k);a=b-(h-(b*a+a))+1;o(+a);c=j(1)|0;g=j(0)|0;c=(e<<20)+c|0;p:{if((c|0)<=1048575){a=mk(a,e);break p}l(0,g|0);l(1,c|0);a=+n()}i=i*a}return i}return i*1e300*1e300}return i*1e-300*1e-300}function _ra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;j=fb-720|0;fb=j;a:{b:{if(d>>>0<=511){a=fb-16|0;fb=a;e=j+46|0;bc(a+8|0,e,554);d=x[a+12>>2];kc(a,x[b>>2],x[b+8>>2],x[a+8>>2],x[a+12>>2]);f=x[a+4>>2];if((f|0)==(d|0)){Yb(b,x[a+12>>2])}fb=a+16|0;a=(d|0)==(f|0);if(!a){Tb(e,0,554)}if(!a){break b}d=fb-32|0;fb=d;c:{a=j+46|0;if(Ob(a,14105,4)){break c}e=d+8|0;Kr(e,a+32|0);b=d+20|0;Ec(b,e);zc(c+492|0,b);tb(b);ui(e,1,a+4|0);Ec(b,e);zc(c+524|0,b);tb(b);b=y[a+24|0]|y[a+25|0]<<8;x[c+4>>2]=64;x[c+8>>2]=128;x[c>>2]=b<<6;v[c+16|0]=y[a+26|0];v[c+17|0]=y[a+27|0];f=c+108|0;k=c+236|0;b=0;while(1)if((b|0)==120){b=y[c+60|0]&-2|v[a+17|0]&1;v[c+60|0]=b;b=b&-3|y[a+17|0]&2;v[c+60|0]=b;v[c+60|0]=b&251|y[a+17|0]&4;k=c+61|0;v[k|0]=y[a+18|0];g=c+62|0;v[g|0]=y[a+19|0];h=c+63|0;v[h|0]=y[a+20|0];i=c- -64|0;v[i|0]=y[a+21|0];f=c+48|0;dh(f,25);e=x[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=wb(e,b);m=b<<1;n=y[(a+m|0)+504|0];w[l>>1]=n;if((n|0)!=255){break d}dh(f,b);e=x[f>>2]}b=af(k,g);a=Od(e,x[c+52>>2]);if(a>>>0<=y[b|0]){v[c+60|0]=y[c+60|0]&253}if(a>>>0>y[af(h,i)|0]){break c}v[c+60|0]=y[c+60|0]&251;break c}v[l+2|0]=y[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{g=a+(b<<1)|0;e=y[g- -64|0];g=y[g+65|0];o=_b(k,b),q=g,w[o>>1]=q;o=xb(f,b),q=(e>>>0<120?e:b)+1|0,v[o|0]=q;b=b+1|0;continue}}fb=d+32|0;break b}k=x[b+8>>2];d=fb-32|0;fb=d;x[d+28>>2]=674;x[d+8>>2]=674;e=x[b>>2];g=x[b+8>>2];f=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,g,f)){f=jf(b)}g=d+8|0;e=j+46|0;sZ(g,e);h=gc(d+16|0,x[d+8>>2],f);i=x[h>>2];kc(d,x[b>>2],x[b+8>>2],i,x[h+4>>2]);sZ(g,e);Tb(x[d+8>>2]+f|0,0,674-f|0);Yb(b,x[d+28>>2]);fb=d+32|0;g=x[a+480180>>2];a=0;d=fb-32|0;fb=d;if(!Ob(e,14105,4)){f=d+8|0;Kr(f,e+32|0);a=d+20|0;Ec(a,f);zc(c+492|0,a);tb(a);ui(f,1,e+4|0);Ec(a,f);zc(c+524|0,a);tb(a);x[c>>2]=(y[e+20|0]|y[e+21|0]<<8)<<5;x[c+4>>2]=y[e+24|0]>>>1;vc(c+4|0,64);h=y[e+25|0]&127;x[c+8>>2]=h>>>0>64?128:h<<2;v[c+15|0]=y[c+15|0]&254|((y[e+25|0]^-1)&128)>>>7;v[d+20|0]=y[e+26|0];v[d+8|0]=100;o=c,q=y[Ub(a,f)|0],v[o+20|0]=q;v[d+20|0]=y[e+27|0];v[d+8|0]=64;o=c,q=y[Ub(a,f)|0],v[o+19|0]=q;v[c+16|0]=y[e+17|0];v[c+17|0]=y[e+18|0];v[c+18|0]=y[e+19|0];v[c+26|0]=y[e+22|0];v[c+27|0]=y[e+23|0];a=y[e+58|0];gk(c,a&127,a>>>7|0);a=y[e+59|0];fk(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=y[e+28|0]|y[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=y[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){v[c+30|0]=a}a=y[e+62|0]|y[e+63|0]<<8;if(a>>>0<129){break f}break e}a=v[e+61|0];if((a|0)<0){break g}v[c+30|0]=a+1}a=y[e+62|0];a=a<<24>>24>=0?a+1|0:0;f=v[e+63|0];if((f|0)<0){break f}a=((f&255)<<7)+a|0}w[c+28>>1]=a}a=v[e+60|0];v[c+31|0]=a;if((a|0)<0){v[c+31|0]=0;v[c+34|0]=a^128}a=0;f=g&16777216?240:25;Iw(e+304|0,c+48|0,0,f);Iw(e+386|0,c+68|0,32,f);Iw(e+468|0,c+88|0,32,f);v[c+100|0]=y[c+100|0]&239|y[e+468|0]>>>3&16;g=c+108|0;h=c+236|0;while(1){if((a|0)!=120){i=e+(a<<1)|0;f=y[i- -64|0];i=y[i+65|0];o=_b(h,a),q=i,w[o>>1]=q;o=xb(g,a),q=(f>>>0<120?f:a)+1|0,v[o|0]=q;a=a+1|0;continue}break}a=554}fb=d+32|0;d=0;k:{if(!a){break k}d=e+550|0;l:{if(Ob(d,13621,4)){if(Ob(d,13928,4)){break l}}a=c+236|0;f=0;while(1){if((f|0)!=120){d=y[(e+f|0)+554|0];g=_b(a,f);w[g>>1]=z[g>>1]|d<<8;f=f+1|0;continue}break}a=674}d=a}bd(b,d+k|0);if(!ek(b,14110)){break b}d=j+4|0;ce(d,b,Mg(b));a=ic(j+24|0,d);ub(d);b=x[a>>2];x[31785]=0;R(157,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}x[31785]=0;b=P(416,a|0,13851)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}if(b){x[31785]=0;b=R(200,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}v[c+34|0]=b>>>0<=250?b:0}ub(a)}fb=j+720|0;return}b=N()|0;ub(a);Q(b|0);p()}function FR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;a:{b:{c:{if(!zd(c)|!d|x[b+480180>>2]!=16777216|z[b+480192>>1]<d>>>0){break c}d=x[((d<<2)+b|0)+900380>>2];if(!d){break c}d=x[d+44>>2];if(!d){break c}w[i+14>>1]=c-61;b=fb+-64|0;fb=b;d:{e:{e=w[d+28>>1];f=i+14|0;c=w[f>>1];if((e|0)<=(c|0)){if((c|0)<=(oc(x[d+4>>2],x[d+8>>2])+e|0)-1<<16>>16){break e}}Fb(a);break d}f:{e=z[d+30>>1];if(!e){c=d+52|0;d=bA(c,f);if(!Vg(d,Jf(c))){break f}nm(a,qd(d)+4|0);break d}c=aA(c,e<<16>>16);w[b+62>>1]=c;e=Fb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=d+52|0;g=bA(a,b+62|0);t:{if(Vg(g,Jf(a))){x[31785]=0;O(132,e|0,qd(g)+4|0);a=x[31785];x[31785]=0;if((a|0)==1){break t}a=w[d+30>>1];c=w[f>>1];x[31785]=0;m=b,n=$z(c,a)+5|0,x[m+36>>2]=n;O(129,b+48|0,b+36|0);a=x[31785];x[31785]=0;u:{if((a|0)!=1){x[31785]=0;P(77,e|0,b+48|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break u}tb(b+48|0);break d}a=N()|0;break g}a=N()|0;tb(b+48|0);break g}if(w[d+30>>1]>26){break q}x[31785]=0;c=U(545,b+36|0,1,c+65<<24>>24)|0;a=x[31785];x[31785]=0;if((a|0)==1){break s}x[31785]=0;S(605,b+48|0,0,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break r}a=b+48|0;g=yb(e,a);tb(a);tb(c);x[31785]=0;P(130,g|0,14788)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break p}}a=N()|0;break g}a=N()|0;break g}a=N()|0;tb(c);break g}x[31785]=0;a=c<<16>>16;x[b+32>>2]=(a|0)%16;O(887,b+36|0,b+32|0);c=x[31785];x[31785]=0;if((c|0)==1){break o}x[31785]=0;x[b+16>>2]=((a|0)/16<<16>>16)%16;O(887,b+20|0,b+16|0);c=x[31785];x[31785]=0;if((c|0)==1){break n}x[31785]=0;S(2,b+48|0,b+36|0,b+20|0);c=x[31785];x[31785]=0;if((c|0)==1){break m}c=b+48|0;h=yb(e,c);tb(c);tb(b+20|0);tb(b+36|0);if((a|0)<256){break p}x[31785]=0;O(888,b+4|0,h|0);a=x[31785];x[31785]=0;if((a|0)==1){break k}j=b+36|0;g=b+4|0;c=wd(g);k=yf(g);l=wd(g);a=fb-16|0;fb=a;x[a+8>>2]=l;x[a+12>>2]=c;while(1){if(Ib(c,k)){m=x[a+8>>2],n=xq(v[c|0]),v[m|0]=n;c=je(a+12|0);je(a+8|0);c=x[c>>2];continue}break}fb=a+16|0;Yc(j,g);x[31785]=0;S(605,b+48|0,0,j|0);a=x[31785];x[31785]=0;if((a|0)==1){break j}a=b+48|0;yb(h,a);tb(a);tb(b+36|0);tb(b+4|0)}a=w[d+30>>1];c=w[f>>1];x[31785]=0;m=b,n=$z(c,a)+5|0,x[m+20>>2]=n;O(129,b+48|0,b+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break i}x[31785]=0;P(77,e|0,b+48|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break h}tb(b+48|0);break d}a=N()|0;break g}a=N()|0;break l}a=N()|0;tb(b+20|0)}tb(b+36|0);break g}a=N()|0;break g}a=N()|0;tb(b+36|0);tb(b+4|0);break g}a=N()|0;break g}a=N()|0;tb(b+48|0)}break a}g=fb-16|0;fb=g;e=g+4|0;d=fb-32|0;fb=d;c=pf(d+20|0,1,0);v:{w:{x:{while(1){h=Jb(c);ds(d+12|0,h,Bb(x[c+4>>2],y[c+11|0])+h|0,w[f>>1]);if(!x[d+16>>2]){break x}h=ni(Bb(x[c+4>>2],y[c+11|0]));x[31785]=0;O(46,c|0,h|0);h=x[31785];x[31785]=0;if((h|0)!=1){continue}break}break w}f=x[d+12>>2];h=Jb(c);x[31785]=0;O(47,c|0,f-h|0);f=x[31785];x[31785]=0;y:{if((f|0)!=1){x[31785]=0;O(48,e|0,c|0);f=x[31785];x[31785]=0;if((f|0)!=1){break y}break w}break w}tb(c);fb=d+32|0;break v}a=N()|0;tb(c);Q(a|0);p()}Oh(a,e);tb(e);fb=g+16|0}fb=b- -64|0;break b}d=x[b>>2];b=fb-32|0;fb=b;z:{if(Cl(c)){x[b+16>>2]=x[7688];d=x[7687];x[b+8>>2]=x[7686];x[b+12>>2]=d;d=x[7685];x[b>>2]=x[7684];x[b+4>>2]=d;uc(a,(b+(c<<2)|0)-1004|0);break z}if(zd(c)){e=Fb(b);x[31785]=0;c=c-1|0;f=(c|0)/12|0;c=P(889,e|0,d+(D(f,-12)+c<<16>>16<<2)|0)|0;d=x[31785];x[31785]=0;A:{if((d|0)==1){break A}x[31785]=0;c=P(890,c|0,f+48&255)|0;d=x[31785];x[31785]=0;if((d|0)==1){break A}x[31785]=0;P(3,a|0,c|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break A}tb(c);break z}a=N()|0;break a}if(!c){uc(a,16972);break z}uc(a,14759)}fb=b+32|0}fb=i+16|0;return}tb(e);Q(a|0);p()}function pS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;i=a+1074376|0;g=D(b,872);d=(i+g|0)+616|0;e=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+g|0)+1075080|0;x[a>>2]=x[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(y[a+480209|0]&16)){break a}if(Oj(x[d+656>>2])){a=D(b,872)+a|0;w[a+1075764>>1]=e-8;a=a+1075843|0;v[a|0]=y[a|0]|64;break a}if(x[a+480180>>2]!=64){g=D(b,872)+a|0;d=e<<28>>24;w[g+1075764>>1]=d;c=z[(e<<1)+31952>>1];x[g+1075696>>2]=c;b=g+1075692|0;if(!x[b>>2]){break a}l=b,m=vh(a,y[g+1075789|0],d,c),x[l>>2]=m;break a}b=D(b,872)+a|0;a=x[b+1075096>>2];if(!a){break a}x[b+1075696>>2]=x[a+24>>2]+D(e,80);break a;case 2:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075814|0]=c&3;break a}Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075814|0]=e>>>0<4?e:0;break a}v[(D(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(x[a+480180>>2]==2){v[(D(b,872)+a|0)+1075817|0]=c&3;break a}Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){v[(D(b,872)+a|0)+1075817|0]=e>>>0<4?e:0;break a}v[(D(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Kb(f+8|0,a+1074312|0,21);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){a=D(b,872)+a|0;v[a+1075813|0]=0;v[a+1075820|0]=e>>>0<4?e:0;break a}v[(D(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(x[a+1074392>>2]|!(y[a+480209|0]&16)){break a}a=a+1074400|0;x[a>>2]=x[a>>2]+e;break a;case 6:if(!(y[a+480209|0]&16)){break a}if(e>>>0<=2){c=z[a+480188>>1];j=c>>>0<=256?256:c;k=a+906300|0;i=b+1|0;g=e-1|0;while(1){if((c|0)==(j|0)){break a}h=D(c,872)+a|0;c:{if(z[h+1075778>>1]!=(i|0)){break c}d:{e:{switch(g|0){case 0:yo(a,h+1074992|0);if(!(y[h+1075081|0]&2)){break d}d=x[a+1298300>>2];if(!xd(d)){break d}yk(d,c&65535);break d;case 1:d=h+1075080|0;e=x[d>>2];x[d>>2]=e|4096;if(!(e&512)){break d}d=x[a+1298300>>2];if(!xd(d)){break d}yk(d,c&65535);break d;default:break e}}x[h+1075688>>2]=0;d=h+1075080|0;e=x[d>>2];x[d>>2]=e|4096;if(!(e&512)){break d}d=x[a+1298300>>2];if(!xd(d)){break d}Jj(d,c&65535,1)}e=x[h+1075648>>2];if(!e){break c}d=y[e+34|0];if(!d){break c}d=x[rd(k,d-1|0)>>2];if(!d){break c}ib[x[x[d>>2]+96>>2]](d,e,y[h+1075789|0]|256,0,b)}c=c+1|0;continue}}QU(d,e,x[a+480180>>2]);break a;case 7:if(!(y[a+480209|0]&16)){break a}Xm(a,d,e,4);break a;case 8:b=x[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e|0){case 0:x[d+88>>2]=x[d+88>>2]&-257;break f;case 1:x[d+692>>2]=128;x[d+88>>2]=x[d+88>>2]|256;break f;case 8:x[d+88>>2]=x[d+88>>2]&-25165825|16777216;break f;case 9:x[d+88>>2]=x[d+88>>2]&-25165825|8388608;break f;case 10:x[a+480208>>2]=b&-16385;break f;case 11:x[a+480208>>2]=b|16384;break f;case 12:x[a+480208>>2]=b&-8193;break f;case 13:x[a+480208>>2]=b|8192;break f;case 14:x[d+88>>2]=x[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(x[d>>2]|x[d+4>>2]){break h}a=x[d+76>>2];if(!a){break h}if(!(l=zd(y[d+788|0]),m=1,n=y[d+88|0]&2,n?l:m)){break h}x[d>>2]=-1;x[d+4>>2]=a-1}x[d+88>>2]=x[d+88>>2]|128}break a;case 9:if(!(y[a+480209|0]&16)){break a}c=D(b,872)+a|0;v[c+1075828|0]=e;Kb(f+8|0,a+1074312|0,35);if(Hb(x[x[f+8>>2]>>2],x[f+12>>2])){break a}if(!zd(y[c+1075780|0])){break a}c=e<<16;if(c>>>0>=A[(D(b,872)+a|0)+1075068>>2]){break a}x[d+4>>2]=c;break a;case 10:if(!(y[a+480209|0]&16)){break a}hB(a,i,b,e);break a;case 11:i:{if(e){break i}e=1;c=x[a+480180>>2];if(c&16777248){break i}e=0;if((c|0)==2){break a}}Kb(f+8|0,a+1074312|0,30);RA(a,b,e,Hb(x[x[f+8>>2]>>2],x[f+12>>2])|x[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(x[a+480180>>2]==2){break a}v[(D(b,872)+a|0)+1075836|0]=e}fb=f+16|0}function Msa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;f=fb-320|0;fb=f;xc(b);d=fb-16|0;fb=d;e_(d+8|0,f+102|0);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(g|0)){Yb(b,x[d+12>>2])}fb=d+16|0;a:{b:{c:{if((g|0)!=(i|0)){break c}if(!g_(f+102|0)){break c}if(!Mb(x[b>>2],x[b+8>>2],Bc(f_(y[f+318|0],y[f+319|0]),hb))){break c}if(!c){e=1;break c}Bd(a,2);ag(a);x[a+480188>>2]=524296;t=a,u=Xe(455e3),x[t+480204>>2]=u;Lb(a+1074312|0,110,1);x[a+480208>>2]=x[a+480208>>2]|16777216;d=f+72|0;Te(d,2,f+133|0);e=f+88|0;Ec(e,d);yb(a+1298308|0,e);tb(e);e=0;d:{e:{while(1){if((e|0)==8){f:{d=Wb(x[a+484360>>2],y[a+484376|0]);o=y[f+318|0];n=o+1|0;Wk(d,b,n,65535,65535);d=Nb(f+88|0);x[31785]=0;S(237,b|0,d|0,n|0);e=x[31785];x[31785]=0;if((e|0)==1){break f}t=f,u=vb(x[d>>2]),x[t+72>>2]=u;e=vb(x[d+4>>2]);while(1){g=x[f+72>>2];q=Ib(g,e);if(q){if((y[g|0]-1&255)>>>0>7){break d}je(f+72|0);continue}break}t=a,u=y[xb(x[d>>2],0)|0],x[t+480196>>2]=u;e=y[f+317|0];i=y[f+319|0];g=Nb(f+72|0);x[31785]=0;m=i+1|0;S(237,b|0,g|0,m|0);i=x[31785];x[31785]=0;g:{if((i|0)==1){break g}x[31785]=0;i=a+484344|0;O(226,i|0,m|0);h=x[31785];x[31785]=0;if((h|0)==1){break g}r=e+1|0;if(!(c&1)){break e}c=0;while(1){if((c|0)==(m|0)){break e}e=y[xb(x[g>>2],c)|0];x[31785]=0;e=U(199,i|0,e|0,r|0)|0;h=x[31785];x[31785]=0;h:{if((h|0)!=1){if(!e){break e}h=0;k=Vb(x[i>>2],y[xb(x[g>>2],c)|0]);i:while(1){s=h&65535;if(s>>>0>7){break h}h=h+1|0;e=0;while(1){if(A[k+12>>2]<=e>>>0){continue i}x[31785]=0;j=R(200,b|0)|0;l=x[31785];x[31785]=0;j:{k:{if((l|0)!=1){j=j<<24>>24;if((j|0)>=0){break k}e=(j&127)+e|0;break j}break b}l=gd(x[k>>2],x[x[k+48>>2]+12>>2],e,s);if((j|0)==1){v[l|0]=254;break j}if((j-1&255)>>>0>96){break j}v[l+1|0]=h;v[l|0]=j+12}e=e+1|0;continue}}}break b}c=c+1|0;continue}}break b}}else{i=f+88|0;d=(f+102|0)+D(e,19)|0;yD(i,d+63|0);g=f+72|0;Ec(g,i);fm(((e<<5)+a|0)+480289|0,g);tb(g);e=e+1|0;h=D(e,104)+a|0;j=h+484380|0;jd(j,2);v[f+83|0]=0;g=y[d+78|0]|y[d+79|0]<<8|(y[d+80|0]<<16|y[d+81|0]<<24);v[f+79|0]=g;v[f+80|0]=g>>>8;v[f+81|0]=g>>>16;v[f+82|0]=g>>>24;g=y[d+75|0]|y[d+76|0]<<8|(y[d+77|0]<<16|y[d+78|0]<<24);d=y[d+71|0]|y[d+72|0]<<8|(y[d+73|0]<<16|y[d+74|0]<<24);x[f+16>>2]=x[f+80>>2];x[f+72>>2]=d;x[f+76>>2]=g;d=x[f+76>>2];x[f+8>>2]=x[f+72>>2];x[f+12>>2]=d;Vk(j,1,f+8|0);x[h+484404>>2]=8215;d=f+60|0;Ec(d,i);zc(((e<<5)+a|0)+946304|0,d);tb(d);continue}break}e=N()|0;break a}j=o+1|0;c=a+484376|0;e=0;while(1){l:{if((e|0)==(j|0)){x[31785]=0;b=P(1,f+60|0,8636)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break l}break b}b=Wb(x[a+484360>>2],y[c|0]);k=e&65535;m:{if(!$i(b,k)){x[31785]=0;h=P(370,i|0,r|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break b}if((h|0)==65535){break m}b=Wb(x[a+484360>>2],y[c|0]);t=_b(x[b>>2],e),u=h,w[t>>1]=u}b=xD(vb(x[Vb(x[i>>2],z[_b(x[b>>2],e)>>1])+4>>2]),1);h=y[b+5|0];l=y[xb(x[d>>2],(e+1>>>0)%(n>>>0)|0)|0];if((h|0)==(l|0)){break m}n:{if(y[b+3|0]!=16){break n}h=y[c|0];m=x[a+484360>>2];x[31785]=0;h=P(371,Wb(m,h)|0,k|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break b}if((h|0)==65535){break n}b=xD(vb(x[Vb(x[i>>2],h)+4>>2]),1)}v[b+5|0]=l;v[b+3|0]=16}e=e+1|0;continue}break}yb(a+1298344|0,b);tb(b);x[31785]=0;b=P(1,f+48|0,6069)|0;c=x[31785];x[31785]=0;if((c|0)==1){break b}yb(a+1298356|0,b);tb(b);b=f+24|0;Zj(b,2,f+113|0);x[31785]=0;S(372,f+36|0,4,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break b}b=f+36|0;yb(a+1298368|0,b);tb(b);t=a+1298404|0,u=x[Gc(b,4)>>2],x[t>>2]=u;dc(g)}dc(d);e=q^1}fb=f+320|0;return e|0}e=N()|0;dc(g)}dc(d);Q(e|0);p()}function Osa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;e=fb-960|0;fb=e;xc(b);d=fb-16|0;fb=d;h=e+862|0;m_(d+8|0,h);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Yb(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(g|0);if(!d){l_(h)}a:{if(!d){break a}if(!o_(e+862|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(n_(y[e+909|0]|y[e+910|0]<<8),hb))){break a}if(!c){l=1;break a}Bd(a,512);x[a+480228>>2]=32;w[a+480188>>1]=16;x[a+480196>>2]=y[e+937|0];x[a+480208>>2]=16;x[a+480200>>2]=256;x[a+480204>>2]=8e5;Lb(a+1074312|0,7,1);d=e+88|0;f=uc(d,8244);yb(a+1298344|0,f);tb(f);f=uc(d,8932);yb(a+1298356|0,f);tb(f);s=a+1298404|0,t=x[Gc(d,4)>>2],x[s>>2]=t;f=e+12|0;k_(f,e+866|0);Ec(d,f);yb(a+1298308|0,d);tb(d);d=0;while(1){if((d|0)==16){b:{d=y[e+958|0]|y[e+959|0]<<8;if(d){TD(a+1298332|0,b,d,132,0)}d=fb-16|0;fb=d;h=e+88|0;bc(d+8|0,h,771);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Yb(b,x[d+12>>2])}fb=d+16|0;l=(f|0)==(g|0);if(!l){Tb(h,0,771)}if(!l){break a}d=a+484360|0;f=a+484376|0;j_(Wb(x[d>>2],y[f|0]),e+88|0,y[e+345|0]);_e(Wb(x[d>>2],y[f|0]),y[e+346|0]);bd(b,y[e+909|0]|y[e+910|0]<<8);m=a+484344|0;o=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}E$(b,e+60|0);d=0;while(1){if((d|0)==64){break a}if(!(y[e+60+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!zD(b,e+12|0)){break a}d=d+1|0;w[a+480190>>1]=d;Te(e,1,e+12|0);h=e+68|0;Ec(h,e);zc(((z[a+480190>>1]<<5)+a|0)+946304|0,h);tb(h);c=(D(d,104)+a|0)+484380|0;jd(c,0);i=y[e+44|0]|y[e+45|0]<<8|(y[e+46|0]<<16|y[e+47|0]<<24);x[c>>2]=i;f=y[e+50|0]|y[e+51|0]<<8|(y[e+52|0]<<16|y[e+53|0]<<24);x[c+4>>2]=f;g=y[e+54|0]|y[e+55|0]<<8|(y[e+56|0]<<16|y[e+57|0]<<24);x[c+24>>2]=16726;x[c+8>>2]=g;w[c+30>>1]=y[e+49|0]<<4;if(v[e+58|0]&1){g=g>>>1|0;x[c+8>>2]=g;f=f>>>1|0;x[c+4>>2]=f;x[c>>2]=i>>>1}if(!(!(y[e+59|0]&8)|f>>>0>=g>>>0)){w[c+34>>1]=z[c+34>>1]|2}ad(h,v[e+58|0]&1?16:8,1,0,0);qg(h,c,b);continue}}d:{d=(h<<1)+e|0;g=y[d+347|0]|y[d+348|0]<<8;if(g){f=e+68|0;ce(f,b,g);i=ic(e+12|0,f);ub(f);n=((y[d+347|0]|y[d+348|0]<<8)-2|0)/64|0;e:{if(!o){break e}x[31785]=0;d=U(199,m|0,h&65535,n|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}if(!d){break e}x[31785]=0;d=R(200,i|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break b}x[31785]=0;P(186,i|0,1)|0;f=x[31785];x[31785]=0;if((f|0)==1){break b}q=d?d>>>0>=n-2>>>0?-1:d+1|0:-1;f=0;f:while(1){if((f|0)!=(n|0)){d=Vb(x[m>>2],h);Ve(e+68|0,x[d>>2],x[x[d+48>>2]+12>>2],f);s=e,t=vb(x[e+68>>2]),x[s>>2]=t;r=pr(x[e+68>>2],x[e+72>>2]);while(1){d=x[e>>2];if(!Ib(d,r)){f=f+1|0;continue f}x[31785]=0;O(360,e+60|0,i|0);g=x[31785];x[31785]=0;if((g|0)==1){break c}j=e+60|0;g=Ze(j);j=cj(j);k=y[e+60|0];if((k-1&255)>>>0<=71){v[d|0]=k+36;s=d,t=y[Ic(e+60|0)|0]+1|0,v[s+1|0]=t}if((y[g|0]-1&255)>>>0<=15){v[d+2|0]=1;v[d+4|0]=((y[g|0]<<6)+-64>>>0)/15}k=y[j|0];g=k&15;v[d+5|0]=g;g:{h:{switch((y[j|0]>>>4|0)-1|0){case 0:case 1:v[d+5|0]=k|240;break g;case 2:v[d+5|0]=g<<2;break g;case 3:v[d+5|0]=(6/(g+1>>>0)|0)+1;break g;case 5:case 6:v[d+5|0]=g<<3;break g;case 9:v[d+2|0]=1;v[d+4|0]=(g<<2)+4;break g;case 10:v[d+5|0]=g|128;break g;case 11:break h;default:break g}}v[d+5|0]=(6/(g+1>>>0)|0)+1|13}v[d+3|0]=y[(y[j|0]>>>4|0)+24976|0];ah(e);continue}}break}we(Vb(x[m>>2],h),Vh(Ue(Le(e+68|0,14,0),q)))}ub(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;Ye(h);g=h;h=(e+862|0)+d|0;x[g>>2]=!y[h+50|0]<<10;w[f+480284>>1]=(y[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=N()|0;ub(i);Q(a|0);p()}fb=e+960|0;return l|0}function F0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=fb-560|0;fb=e;xc(b);d=fb-16|0;fb=d;f=e+63|0;$E(d+8|0,f);g=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);j=x[d+4>>2];if((j|0)==(g|0)){Yb(b,x[d+12>>2])}fb=d+16|0;d=(g|0)==(j|0);if(!d){_E(f)}a:{if(!d){break a}if(!bF(e+63|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],Bc(aF(y[e+173|0],y[e+174|0]),hb))){break a}Bd(a,64);x[a+480204>>2]=78e4;x[a+480260>>2]=112;x[a+480264>>2]=13696;x[a+480196>>2]=4;w[a+480188>>1]=8;Lb(a+1074312|0,7,1);d=e+36|0;g=uc(d,14801);yb(a+1298344|0,g);tb(g);g=uc(d,14834);yb(a+1298356|0,g);tb(g);$h(a+1298368|0,Ob(e+63|0,11167,2)?14829:14801);o=a+1298404|0,p=x[Gc(d,4)>>2],x[o>>2]=p;f=y[e+173|0];w[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=fb-16|0;fb=f;d=e+36|0;bc(f+8|0,d,25);l=x[f+12>>2];kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);i=x[f+4>>2];if((i|0)==(l|0)){Yb(b,x[f+12>>2])}fb=f+16|0;if((i|0)!=(l|0)){v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;v[d+24|0]=0;v[d+16|0]=0;v[d+17|0]=0;v[d+18|0]=0;v[d+19|0]=0;v[d+20|0]=0;v[d+21|0]=0;v[d+22|0]=0;v[d+23|0]=0;v[d+8|0]=0;v[d+9|0]=0;v[d+10|0]=0;v[d+11|0]=0;v[d+12|0]=0;v[d+13|0]=0;v[d+14|0]=0;v[d+15|0]=0}if((y[e+49|0]|y[e+50|0]<<8|(y[e+51|0]<<16|y[e+52|0]<<24))>>>0>67108863){break a}f=(D(j,104)+a|0)+484380|0;jd(f,0);x[f+24>>2]=8363;l=e+36|0;d=l;i=y[d+13|0]|y[d+14|0]<<8|(y[d+15|0]<<16|y[d+16|0]<<24);x[f>>2]=i;k=y[d+17|0]|y[d+18|0]<<8|(y[d+19|0]<<16|y[d+20|0]<<24);x[f+4>>2]=k;d=y[d+21|0]|y[d+22|0]<<8|(y[d+23|0]<<16|y[d+24|0]<<24);x[f+8>>2]=d;c:{if(!(k|d>>>0<=i>>>0)){x[f+8>>2]=0;break c}if(d){w[f+34>>1]=2;Xk(f)}}f=e+12|0;ui(f,2,l);d=e+24|0;Ec(d,f);zc(((j<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);f=z[a+480190>>1];continue}break}g=e+24|0;h=e+65|0;rg(g,3,h,36);d=e+36|0;Ec(d,g);yb(a+1298308|0,d);tb(d);g=0;ZE(a+1298332|0,h,108,36,0);d=a+484360|0;h=a+484376|0;uw(Wb(x[d>>2],y[h|0]),e+176|0,128,255,254);d=Wb(x[d>>2],y[h|0]);h=y[e+175|0];if(z[_b(x[d>>2],h)>>1]<y[e+174|0]){_e(d,h)}while(1)if((g|0)==8){j=a+484344|0;$f(j,y[e+174|0]);n=c&1;f=0;while(1)if(y[e+174|0]<=f>>>0){h=1;if(!(c&2)){break a}c=ad(e+36|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>z[a+480190>>1]){break b}qg(c,(D(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{d:{e:{if(n){if(bh(j,f&65535,64)){break e}}Yb(b,1536);break d}x[e+24>>2]=-1;x[e+28>>2]=-1;l=0;f:while(1){if((l|0)==64){d=(e+63|0)+f|0;g=y[d+369|0];if(g>>>0<63){we(Vb(x[j>>2],f),Vh(Ue(Le(e+36|0,14,0),g)))}we(Vb(x[j>>2],f),Vh(Le(e+36|0,16,y[d+241|0])));break d}g=0;d=Vb(x[j>>2],f);h=gd(x[d>>2],x[x[d+48>>2]+12>>2],l,0);while(1){if((g|0)==8){l=l+1|0;continue f}d=e+36|0;Fr(d,b);i=Ic(d);k=Ze(d);i=y[i|0];d=y[e+36|0];if(d>>>0<=253){v[h|0]=(d>>>2|0)+37;v[h+1|0]=(d<<4&48|i>>>4)+1;v[(e+24|0)+g|0]=255;d=y[e+36|0]}if((d&255)!=255){v[h+2|0]=1;v[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=y[k|0];if((d|0)!=255){v[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;g:{h:{if(!(d&15)&(d|0)!=48){break h}k=y[i|0];if((k|0)==255){break g}m=k<<24>>24;d=m&15;v[h+5|0]=d;i:{if((m|0)<0){break i}k=k>>>4|0;v[h+3|0]=y[k+24760|0];j:{switch(k-3|0){case 0:v[h+5|0]=d|32;break h;case 1:v[h+5|0]=d|m<<4;break g;case 2:break h;case 3:break j;default:break g}}k:{switch(d|0){case 0:v[h+5|0]=79;break g;case 1:break k;default:break i}}v[h+5|0]=244;break g}v[h+3|0]=0;break g}v[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;Ye(d+480280|0);w[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}fb=e+560|0;return h|0}function OA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,E=0,F=0;e=fb-16|0;fb=e;l=D(b,872)+a|0;m=l+1075800|0;j=y[m|0];k=a+1074312|0;Kb(e+8|0,k,23);i=c&15;a:{b:{c:{d:{e:{f:{g:{h:{i:{if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){if(!(x[a+1074392>>2]|!y[(D(b,872)+a|0)+1075780|0])){v[m|0]=i;break i}f=y[m|0];if(f){f=f-1|0;v[m|0]=f;if(f&255){break c}}v[m|0]=i;h=1;break c}Kb(e+8|0,k,52);f=c&256;if(!(!f|!Hb(x[x[e+8>>2]>>2],x[e+12>>2]))){g=x[a+480208>>2]&4096;if(!g){break e}f=D(b,872)+a|0;if(y[f+1075781|0]){j=tZ(y[f+1075780|0])?1:j}if(y[(D(b,872)+a|0)+1075784|0]?y[f+1075782|0]==1:0){break b}if(i>>>0>j>>>0){break c}if(!g){break d}if(zd(y[(D(b,872)+a|0)+1075780|0])){break c}break d}g=x[a+480180>>2];if(g&16777250){h=!(j?(j>>>0)%((i>>>0<=1?1:i)>>>0)|0:1);j=j+1|0;break c}if((g|0)==16){break g}if((g|0)!=1){break f}f=A[a+1074392>>2]%A[a+1074416>>2]|0;if(!f){if(zd(y[(D(b,872)+a|0)+1075780|0])){break a}}if(i){break h}}break c}h=!((f>>>0)%(i>>>0)|0);break c}h=x[a+1074392>>2]==(i|0)&(i|0)!=0;break c}j:{if(!f){break j}h=D(b,872)+a|0;if(y[h+1075782|0]!=1){break j}i=(y[h+1075785|0]>15)+i|0}k:{if(x[a+480208>>2]&4096?f:1){i=i>>>0<=1?1:i;h=0;h=!x[a+1074416>>2]|f?h:!(A[a+1074392>>2]%(i>>>0)|0);j=j+1|0;break k}h=0;j=g&1048580?0:j}if(!(!(y[(D(b,872)+a|0)+1075780|0]|!f?x[a+1074392>>2]:1)|(j&255)>>>0<i>>>0)){h=1}Kb(e+8|0,k,52);if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])|c){break c}h=!x[a+1074392>>2];break c}if(i>>>0>j>>>0){break c}}j=0;h=1}i=l+1074992|0;q=(D(b,872)+a|0)+1075068|0;l:{if(x[q>>2]){break l}Kb(e+8|0,k,38);if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break l}if(!Gj(x[i+656>>2])){break a}}Kb(e+8|0,k,106);if(C=0,E=Hb(x[x[e+8>>2]>>2],x[e+12>>2]),F=x[(D(b,872)+a|0)+1075688>>2],F?C:E){break a}if(h){h=D(b,872)+a|0;r=h+1075680|0;g=x[r>>2];x[e+4>>2]=g;f=c>>>4&15;m:{if(!f){h=x[h+1075080>>2];break m}Kb(e+8|0,k,52);n:{if(C=Hb(x[x[e+8>>2]>>2],x[e+12>>2]),E=0,F=y[(D(b,872)+a|0)+1075782|0]==1,F?C:E){break n}if(!(16191>>>f&1)){x[e+4>>2]=(D(g,v[f+32368|0])|0)/16;break n}x[e+4>>2]=g+(v[f+32384|0]<<2)}Ee(e+4|0,0,256);f=(D(b,872)+a|0)+1075080|0;h=x[f>>2]|2097152;x[f>>2]=h}g=D(b,872)+a|0;s=g+1075692|0;t=x[s>>2];f=y[g+1075794|0];l=0;if(h&512){Kb(e+8|0,k,108);l=Hb(x[x[e+8>>2]>>2],x[e+12>>2])}if(!((l^-1)&x[a+480180>>2]==2|(!x[q>>2]|(f-1&255)>>>0>119))){vS(a,b,0,f,1)}o:{if(!(x[a+480180>>2]&1048580)){h=0;break o}h=(c|0)<256;if((c|0)>255){break o}n=y[(D(b,872)+a|0)+1075781|0];if(!n){break o}h=1;Eo(a,i,n,0,0,1)}n=g+1075080|0;Kb(e+8|0,k,85);p:{if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break p}g=D(b,872)+a|0;o=y[g+1075781|0];if(!o){break p}g=g+1075764|0;p=z[g>>1];Eo(a,i,o,0,0,1);w[g>>1]=p}o=D(b,872)+a|0;p=o+1075652|0;u=x[p>>2];B=x[n>>2];x[p>>2]=0;Kb(e+8|0,k,23);g=1;q:{if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break q}g=0;if(x[a+480180>>2]!=2){break q}g=(l^1)&x[q>>2]!=0}zu(a,i,f,g,h,0,b);if(!y[o+1075781|0]){x[p>>2]=u}if(!(!(B&4096)|x[a+480180>>2]!=4)){x[n>>2]=x[n>>2]|4096}h=o+1075780|0;x[r>>2]=x[e+4>>2];if(z[a+480192>>1]){v[h|0]=f;tS(a,b)}f=x[a+480180>>2];if(!(!(f&16777248)|(y[h|0]|!t))){x[s>>2]=t}if(g){x[i>>2]=0;x[i+4>>2]=0}f=f&16777250;r:{if(d-11>>>0<4294967286){break r}g=x[(D(b,872)+a|0)+1075096>>2];if(!g){break r}s:{if((d|0)==1){b=x[(D(b,872)+a|0)+1075656>>2];break s}h=(D(b,872)+a|0)+1075656|0;b=x[wb(g+68|0,d-2|0)>>2];x[h>>2]=b}Do(a,i,b)}j=f?j:0}a=e+8|0;Kb(a,k,52);b=x[x[e+8>>2]>>2];d=x[e+12>>2];Kb(a,k,23);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}j=(Hb(b,d)&c>>>8)+j|0}v[m|0]=j}fb=e+16|0}function Cs(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-160|0;fb=e;x[e+148>>2]=-1;x[e+140>>2]=6;x[e+144>>2]=364;x[e+132>>2]=11;x[e+136>>2]=161;x[e+124>>2]=23;x[e+128>>2]=31;x[e+116>>2]=59;x[e+120>>2]=55;x[e+152>>2]=0;x[e+156>>2]=0;v[e+14|0]=c;v[e+13|0]=37;v[e+15|0]=0;l=b+484|0;i=b+460|0;j=b+172|0;k=b+4|0;f=e+16|0;h=f+(fa(f|0,100,e+13|0,e+116|0,x[b>>2])|0)|0;x[e+8>>2]=f;g=Fb(a);m=(c|0)!=120;a:while(1){b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=(h|0)){if(Ef(x[d+8>>2],1,v[f|0])){x[31785]=0;O(118,g|0,32);a=x[31785];x[31785]=0;if((a|0)==1){break c}a=x[d+8>>2];while(1){f=f+1|0;if((h|0)==(f|0)){f=h;break b}if(Ef(a,1,v[f|0])){continue}break}break b}x[e+4>>2]=f;x[31785]=0;x[e>>2]=0;a=ea(1365,e+4|0,h|0,k|0,j|0,d|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}p:{a=a-k|0;q:{if((a|0)<=167){x[31785]=0;O(118,g|0,37);c=x[31785];x[31785]=0;if((c|0)==1){break c}x[31785]=0;O(118,g|0,((a|0)<84?65:97)|0);a=x[31785];x[31785]=0;if((a|0)!=1){break q}break c}x[31785]=0;x[e+4>>2]=f;a=ea(1365,e+4|0,h|0,j|0,i|0,d|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}a=a-j|0;c=(a|0)/12|0;if((a|0)<=287){x[31785]=0;O(118,g|0,37);f=x[31785];x[31785]=0;if((f|0)==1){break c}x[31785]=0;O(118,g|0,((a|0)<144?66:98)|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}if(m){break q}if(!Ef(x[d+8>>2],64,v[cc((D(c,12)+b|0)+172|0,0)|0])){break q}n=qz(g),o=109,v[n|0]=o;break q}if((Bb(x[b+464>>2],y[b+471|0])|0)==(0-Bb(x[b+476>>2],y[b+483|0])|0)){break p}x[31785]=0;x[e+4>>2]=f;a=ea(1365,e+4|0,h|0,i|0,l|0,d|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}if((a-i|0)>23){break p}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;O(118,g|0,112);a=x[31785];x[31785]=0;if((a|0)==1){break c}}f=x[e+4>>2];break b}x[e+4>>2]=f;a=v[f|0];if(Ef(x[d+8>>2],64,a)){x[31785]=0;a=ba(1366,e+8|0,h|0,e|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}r:{s:{switch(a-6|0){case 2:case 3:case 4:break r;case 0:break e;case 1:break f;case 5:break g;case 6:break h;default:break s}}t:{switch(a-55|0){case 0:break k;case 4:break l;case 6:break m;case 1:case 2:case 3:case 5:break r;default:break t}}if((a|0)==23){break i}if((a|0)==31){break j}if((a|0)==364){break n}if((a|0)==2061){break o}}a=x[e+8>>2];while(1){if((a|0)==(f|0)){f=a;continue a}c=v[f|0];x[31785]=0;O(118,g|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}f=f+1|0;continue}}u:{if((a|0)==37){x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;O(118,g|0,37);break u}x[31785]=0;O(118,g|0,a|0)}a=x[31785];x[31785]=0;if((a|0)==1){break c}f=f+1|0;break b}fb=e+160|0;return}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=89;break d}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=106;break d}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=121;break d}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=83;break d}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=77;break d}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=100;break d}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=72;break d}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=109;break d}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=73;break d}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=117;break d}x[31785]=0;O(118,g|0,37);a=x[31785];x[31785]=0;c=119}if((a|0)==1){break c}x[31785]=0;O(118,g|0,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}f=x[e+8>>2];continue}a=N()|0;tb(g);Q(a|0);p()}x[e+8>>2]=f;continue}}function Fo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,A=0,B=0;f=fb+-64|0;fb=f;r=AB(x[a+24>>2],y[a+32|0]);t=Lj(r);c=t;e=x[a>>2];d=Qd(e,x[a+4>>2]);a:{if(c>>>0>d>>>0){k=fb-32|0;fb=k;d=c-d|0;c=x[Ab(a)>>2];e=x[a+4>>2];b:{if(d>>>0<=(c-e|0)/12>>>0){e=fb-16|0;fb=e;c=dv(e+4|0,a,d);d=x[c+4>>2];g=x[c+8>>2];while(1){if((d|0)==(g|0)){hc(c);fb=e+16|0}else{ET(d);d=d+12|0;x[c+4>>2]=d;continue}break}break b}c=Ab(a);c=um(k+12|0,Dp(a,Qd(x[a>>2],e)+d|0),Qd(x[a>>2],x[a+4>>2]),c);g=fb-16|0;fb=g;d=cW(g+4|0,c+8|0,d);e=x[d>>2];while(1){if(x[d+4>>2]!=(e|0)){ET(e);e=x[d>>2]+12|0;x[d>>2]=e;continue}break}ee(d);fb=g+16|0;e=fb-16|0;fb=e;d=zb(e+12|0,x[a+4>>2]);j=zb(e+8|0,x[a>>2]);i=zb(e+4|0,x[c+4>>2]);g=x[d>>2];m=x[j>>2];d=fb-16|0;fb=d;x[d+8>>2]=x[i>>2];x[d+12>>2]=g;while(1){j=x[d+8>>2];if(Pg(g,m)){lC(mx(j),On(g));g=tm(d+12|0);tm(d+8|0);g=x[g>>2];continue}break}fb=d+16|0;x[c+4>>2]=j;wc(a,c+4|0);wc(a+4|0,c+8|0);wc(Ab(a),Ac(c));x[c>>2]=x[c+4>>2];fb=e+16|0;d=x[c+4>>2];while(1){e=x[c+8>>2];if((e|0)!=(d|0)){e=e-12|0;x[c+8>>2]=e;$e(e);continue}break}d=x[c>>2];if(d){fs(c);Db(d)}}fb=k+32|0;break a}if(c>>>0<d>>>0){KT(a,e+D(c,12)|0)}}if(b){c=a+12|0;yq(c,$d(c));A=Ab(c),B=0,x[A>>2]=B;h=c;c=ec(c);x[h>>2]=c;x[c>>2]=0;x[a+28>>2]=0}k=Nb(f+52|0);c=x[a+24>>2];c=Gu(x[c+484344>>2],x[c+484348>>2]);x[31785]=0;j=U(629,f+40|0,c|0,28828)|0;c=x[31785];x[31785]=0;c:{if((c|0)!=1){g=a+12|0;while(1){if((l|0)==(t|0)){kd(j);dc(k);fb=f- -64|0;return}c=x[a+24>>2];h=x[c+484344>>2];c=x[c+484348>>2];m=z[_b(x[r>>2],l)>>1];d=PT(h,c,m);x[f+36>>2]=d;c=Dd(x[a>>2],l);d:{e:{f:{if(b){x[31785]=0;v[f+20|0]=0;S(809,c|0,d|0,f+20|0);d=x[31785];x[31785]=0;if((d|0)!=1){break f}d=N()|0;break e}x[31785]=0;O(762,c|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){break f}d=N()|0;break e}if(!$i(r,l&65535)){break d}x[f+20>>2]=b?0:x[c+4>>2];s=x[Gb(f+20|0,f+36|0)>>2];o=Jf(g);c=z[_b(x[j>>2],m)>>1];if((c|0)!=65535){d=NT(g,z[Zm(f+20|0,c,s)>>1],x[f+24>>2]);g:{if(Vg(d,Jf(g))){c=NT(g,z[Zm(f+20|0,z[_b(x[j>>2],m)>>1],x[f+36>>2])>>1],x[f+24>>2]);break g}c=Jf(g)}x[f+32>>2]=d;while(1){h:{if(!Vg(d,c)){break d}e=Nb(f+20|0);d=Ln(qd(d)+8|0);x[31785]=0;O(810,e|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){d=Gc(f+12|0,o);i=Zm(f+4|0,l,x[qd(x[f+32>>2])+4>>2]);d=x[d>>2];x[31785]=0;d=ba(811,g|0,d|0,i|0,e|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break h}x[f+16>>2]=d;o=x[Yg(f+16|0)>>2];ze(e);d=x[Yg(f+32|0)>>2];continue}}break}d=N()|0;ze(e);break e}q=Vb(x[x[a+24>>2]+484344>>2],m);c=Nf(x[x[q+48>>2]+12>>2]);x[31785]=0;v[f+20|0]=0;S(784,k|0,c|0,f+20|0);c=x[31785];x[31785]=0;if((c|0)!=1){n=x[f+36>>2];i:while(1){j:{if((n|0)==(s|0)){if(s){break d}A=_b(x[j>>2],m),B=l,w[A>>1]=B;break d}c=1;i=0;e=x[x[q+48>>2]+12>>2];n=n-1|0;d=gd(x[q>>2],e,n,0);while(1){if(c>>>0<16&Nf(e)>>>0>i>>>0){u=xb(x[k>>2],i);e=y[u|0];k:{l:{m:{switch(y[d+3|0]-19|0){case 1:h=y[d+5|0];if((h&240)==176){break l}break k;case 0:break m;default:break k}}h=y[d+5|0];if((h&240)!=96){break k}}v[u|0]=h&15;h=y[xb(x[k>>2],i)|0];e=h?h:e}h=c;c=e&255;c=D(h,c?c+1|0:1);d=d+6|0;i=i+1|0;e=x[x[q+48>>2]+12>>2];continue}else{n:{if(c>>>0<=1){continue i}e=Nb(f+20|0);x[31785]=0;O(810,e|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break n}c=Gc(f,o);d=Zm(f+4|0,l,n);c=x[c>>2];x[31785]=0;o=ba(811,g|0,c|0,d|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break j}ze(e);continue i}}break}}break}d=N()|0;ze(e);break e}d=N()|0}kd(j);break c}l=l+1|0;continue}}d=N()|0}dc(k);Q(d|0);p()}function ina(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=fb-48|0;fb=i;xc(b);a:{if((be(b)|0)!=3){break a}if(!Mb(x[b>>2],x[b+8>>2],4355)){break a}g=1;while(1){if((g&65535)>>>0<=256){d=i+32|0;SD(b,d);if(!cV(d)){break a}f=0;d=fb-32|0;fb=d;h=y[i+43|0];m=y[i+41|0]|y[i+42|0]<<8;v[d+14|0]=0;v[d+18|0]=h;w[d+16>>1]=m;w[d+12>>1]=0;while(1){if((f|0)!=3){h=y[xb(d+16|0,f)|0];p=xb(d+12|0,f),q=h,v[p|0]=q;f=f+1|0;continue}break}h=_f(d+12|0);m=y[i+40|0];n=y[i+38|0]|y[i+39|0]<<8;f=0;v[d+10|0]=0;v[d+26|0]=m;w[d+24>>1]=n;w[d+8>>1]=0;while(1){if((f|0)!=3){m=y[xb(d+24|0,f)|0];p=xb(d+8|0,f),q=m,v[p|0]=q;f=f+1|0;continue}break}f=_f(d+8|0);fb=d+32|0;e=f>>>0<h>>>0?g:e;g=g+1|0;continue}break}if(!(e&65535)){break a}b:{if(!c){break b}Bd(a,1);x[a+480228>>2]=192;w[a+480190>>1]=e;x[a+480208>>2]=x[a+480208>>2]|16777216;bd(b,1);m=e+1|0;n=m&65535;g=1;while(1)if((g|0)==(n|0)){bd(b,4097);Wk(Wb(x[a+484360>>2],y[a+484376|0]),b,256,255,65535);g=be(b);if(g>>>0>31){break a}w[a+480188>>1]=g+1;g=be(b);e=z[a+480188>>1];d=g+1|0;if(!Mb(x[b>>2],x[b+8>>2],D(D(e,d),384)+e|0)){break a}while(1)if(z[a+480188>>1]<=k>>>0){f=a+484344|0;$f(f,d);n=c&1;k=0;while(1){c:{if((d|0)!=(k|0)){d:{if(n){if(bh(f,k&65535,64)){break d}}Yb(b,D(z[a+480188>>1],384));break c}e=0;j=Jg(i+20|0);while(1){if((e|0)==64){break c}g=Vb(x[f>>2],k);Ve(i+32|0,x[g>>2],x[x[g+48>>2]+12>>2],e);p=i,q=vb(x[i+32>>2]),x[p+16>>2]=q;l=pr(x[i+32>>2],x[i+36>>2]);e:{while(1){g=x[i+16>>2];if(Ib(g,l)){h=i+10|0;s_(h,b);h=y[xb(h,0)|0];if((h-1&255)>>>0<=76){v[g|0]=h+36}h=i+10|0;p=g,q=y[xb(h,1)|0],v[p+1|0]=q;if(!bV(g,y[xb(h,2)|0],y[xb(h,5)|0])){break e}h=i+10|0;if(!bV(j,y[xb(h,3)|0],y[xb(h,4)|0])){break e}sn(i+8|0,g,y[g+3|0],y[g+5|0],y[i+23|0],y[i+25|0]);ah(i+16|0);continue}break}e=e+1|0;continue}break}k=0;break a}f:{if(!(c&2)){break f}c=m&65535;g=1;while(1){if((c|0)==(g|0)){break f}e=D(g,104)+a|0;qg(ad(i+32|0,w[e+484414>>1]&1?16:8,1,0,0),e+484380|0,b);g=g+1|0;continue}}$h(a+1298344|0,14267);$h(a+1298356|0,11151);rf(a+1298368|0);p=a+1298404|0,q=x[Gc(i+32|0,4)>>2],x[p>>2]=q;break b}k=k+1|0;continue}}else{g=(k<<5)+a|0;Ye(g+480280|0);p=g+480284|0,q=D(be(b),17),w[p>>1]=q;k=k+1|0;continue}}else{f=i+32|0;SD(b,f);d=0;e=fb-16|0;fb=e;h=(D(g,104)+a|0)+484380|0;jd(h,1);j=y[f+11|0];l=y[f+9|0]|y[f+10|0]<<8;v[e+6|0]=0;v[e+10|0]=j;w[e+8>>1]=l;w[e+4>>1]=0;while(1){if((d|0)!=3){j=y[xb(e+8|0,d)|0];p=xb(e+4|0,d),q=j,v[p|0]=q;d=d+1|0;continue}break}j=_f(e+4|0);l=y[f+8|0];o=y[f+6|0]|y[f+7|0]<<8;d=0;v[e+2|0]=0;v[e+10|0]=l;w[e+8>>1]=o;w[e>>1]=0;while(1){if((d|0)!=3){l=y[xb(e+8|0,d)|0];p=xb(e,d),q=l,v[p|0]=q;d=d+1|0;continue}break}p=h,q=j-_f(e)|0,x[p>>2]=q;j=y[f+2|0];l=y[f|0]|y[f+1|0]<<8;d=0;v[e+6|0]=0;v[e+10|0]=j;w[e+8>>1]=l;w[e+4>>1]=0;while(1){if((d|0)!=3){j=y[xb(e+8|0,d)|0];p=xb(e+4|0,d),q=j,v[p|0]=q;d=d+1|0;continue}break}p=h,q=_f(e+4|0),x[p+4>>2]=q;j=y[f+5|0];l=y[f+3|0]|y[f+4|0]<<8;d=0;v[e+6|0]=0;v[e+10|0]=j;w[e+8>>1]=l;w[e+4>>1]=0;while(1){if((d|0)!=3){j=y[xb(e+8|0,d)|0];p=xb(e+4|0,d),q=j,v[p|0]=q;d=d+1|0;continue}break}p=h,q=_f(e+4|0),x[p+8>>2]=q;d=y[f+13|0];j=d>>>2|0;j=z[h+34>>1]&-7|j&2|j&4;w[h+34>>1]=j;if(d&4){w[h+34>>1]=j|1;x[h>>2]=x[h>>2]>>>1}w[h+30>>1]=y[f+12|0];x[h+24>>2]=y[f+14|0]|y[f+15|0]<<8;aV(h);fb=e+16|0;e=Cc(i+20|0,22485);zc(((g<<5)+a|0)+946304|0,e);tb(e);g=g+1|0;continue}}k=1}fb=i+48|0;return k|0}function Ika(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-96|0;fb=e;g=a+140|0;Yj(e+76|0,g,1296125513);x[31785]=0;f=R(175,x[e+76>>2])|0;h=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Fb(e+28|0);x[31785]=0;h=R(157,x[e+76>>2])|0;i=x[31785];x[31785]=0;if((i|0)==1){break p}x[31785]=0;S(820,e+76|0,f|0,h|0);h=x[31785];x[31785]=0;if((h|0)==1){break p}h=z[a+174>>1];x[31785]=0;S(821,e- -64|0,h|0,f|0);h=x[31785];x[31785]=0;if((h|0)==1){break o}x[31785]=0;S(822,e+4|0,c|0,e- -64|0);c=x[31785];x[31785]=0;if((c|0)==1){break n}c=e+4|0;zc(d,c);tb(c);tb(e- -64|0);tb(f)}if(y[a+176|0]){x[31785]=0;O(823,e+28|0,d|0);c=x[31785];x[31785]=0;if((c|0)==1){break e}c=e+28|0;ye(b+43|0,c);tb(c)}x[31785]=0;S(815,e+28|0,g|0,1413894985);c=x[31785];x[31785]=0;if((c|0)==1){break l}x[31785]=0;f=R(824,e+28|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break k}g=e+28|0;ub(g);c=a+40|0;xc(c);x[31785]=0;g=P(825,c|0,g|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break j}if(g){q:{if((y[e+56|0]|y[e+57|0]<<8|(y[e+58|0]<<16|y[e+59|0]<<24))>>>0<2){break q}x[31785]=0;g=P(826,c|0,e+4|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break i}if(!g){break q}kR(e+4|0,b+12|0,b+16|0,x[b>>2],b+34|0,8,16,f)}x[31785]=0;c=P(826,c|0,e+4|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break i}if(c){kR(e+4|0,b+4|0,b+8|0,x[b>>2],b+34|0,2,4,f)}c=y[e+40|0]|y[e+41|0]<<8|(y[e+42|0]<<16|y[e+43|0]<<24);v[b+42|0]=c&128?0:c+1|0;Xk(b)}r:{if(y[b+42|0]){break r}c=x[a+60>>2];x[31785]=0;c=P(682,c|0,7)|0;f=x[31785];x[31785]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;xc(c);x[31785]=0;c=P(827,c|0,e+4|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}if(!c){break r}c=v[e+4|0];v[b+42|0]=(c|0)>=0?c+1|0:0}c=x[a+120>>2];x[31785]=0;c=R(175,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break j}if(!c){break f}x[31785]=0;h=a+120|0;c=R(154,h|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}x[e+64>>2]=c;vc(e- -64|0,9);f=b+68|0;g=x[e+64>>2];c=0;while(1){if((c|0)==(g|0)){break g}x[31785]=0;O(828,h|0,e+4|0);i=x[31785];x[31785]=0;if((i|0)==1){break h}i=y[e+8|0]|y[e+9|0]<<8|(y[e+10|0]<<16|y[e+11|0]<<24);j=wb(f,c),k=i,x[j>>2]=k;c=c+1|0;continue}}a=N()|0;break a}a=N()|0;break m}a=N()|0;break m}a=N()|0;tb(e- -64|0)}tb(f);break a}a=N()|0;break a}a=N()|0;ub(e+28|0);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}Oz(f+(g<<2)|0,kZ(f),41380)}c=a+80|0;xc(c);x[31785]=0;f=P(829,c|0,e+4|0)|0;g=x[31785];x[31785]=0;s:{if((g|0)==1){break s}if(!f){break b}if(y[e+4|0]&32){w[b+34>>1]=z[b+34>>1]|32}w[e+64>>1]=z[e+8>>1];w[e+2>>1]=256;j=b,k=z[Mc(e- -64|0,e+2|0)>>1],w[j+28>>1]=k;w[e+64>>1]=z[e+10>>1];w[e+2>>1]=256;j=b,k=z[Mc(e- -64|0,e+2|0)>>1],w[j+30>>1]=k;w[e+64>>1]=z[e+12>>1];w[e+2>>1]=64;j=b,k=z[Mc(e- -64|0,e+2|0)>>1],w[j+32>>1]=k;v[b+38|0]=y[e+16|0];v[b+39|0]=y[e+17|0];v[b+40|0]=y[e+18|0];v[b+41|0]=y[e+19|0];f=x[a+88>>2];a=x[a+80>>2];x[31785]=0;a=U(153,a|0,f|0,32)|0;f=x[31785];x[31785]=0;if((f|0)==1){break s}if(!a){break b}x[31785]=0;O(830,c|0,d|0);a=x[31785];x[31785]=0;if((a|0)==1){break s}x[31785]=0;a=R(205,c|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break s}x[31785]=0;S(831,c|0,b+43|0,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){break b}}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}a=N()|0;break a}ub(e+76|0);fb=e+96|0;return}ub(e+76|0);Q(a|0);p()}function woa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-176|0;fb=e;xc(b);a:{if(!zD(b,e+128|0)){break a}if(!xW(e+128|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(wW(y[e+159|0],y[e+161|0]),hb))){break a}b:{if(!c){break b}Bd(a,256);g=e+16|0;Zj(g,2,e+128|0);d=e+48|0;Ec(d,g);yb(a+1298308|0,d);tb(d);f=uc(d,15488);yb(a+1298344|0,f);tb(f);d=uc(d,10130);yb(a+1298356|0,d);tb(d);cg(g,4291);x[31785]=0;O(252,e+116|0,e+159|0);d=x[31785];x[31785]=0;c:{d:{if((d|0)!=1){x[31785]=0;V(704,e+48|0,e+16|0,e+158|0,e+116|0);d=x[31785];x[31785]=0;if((d|0)!=1){d=e+48|0;yb(a+1298368|0,d);tb(d);tb(e+116|0);Eb(e+16|0);o=a+1298404|0,q=x[Gc(d,4)>>2],x[o>>2]=q;d=Lb(a+1074312|0,107,1);x[a+480260>>2]=64;x[a+480264>>2]=32767;x[a+480188>>2]=2031620;Lb(d,107,1);f=y[e+160|0];d=y[e+159|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|D(g,-10)+f}g=(f&255?f:96)&255;f=jC(g);x[a+480196>>2]=g>>>4;x[a+480204>>2]=f;f=0;if(d>>>0>=11){v[e+48|0]=64;o=a,q=y[Ub(e+162|0,e+48|0)|0]<<2,x[o+480200>>2]=q}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){ov(b,e+16|0);d=y[e+28|0];if(d?(d|0)!=46:0){break c}i=fb-32|0;fb=i;d=(D(f,104)+a|0)+484380|0;jd(d,0);j=i+8|0;k=e+16|0;g=k;Lk(j,2,g);h=i+20|0;Ec(h,j);ye(d+43|0,h);tb(h);x[d+24>>2]=y[g+24|0]|y[g+25|0]<<8;v[i+20|0]=y[g+22|0];v[i+8|0]=64;o=d,q=y[Ub(h,j)|0]<<2,w[o+30>>1]=q;h=y[g+16|0]|y[g+17|0]<<8;x[d>>2]=h;j=y[g+18|0]|y[g+19|0]<<8;x[d+4>>2]=j;g=y[g+20|0]|y[g+21|0]<<8;x[d+8>>2]=g;e:{if(h>>>0<=1){x[d>>2]=0;break e}if((g|0)==65535|h>>>0<=j>>>0|g>>>0<=j>>>0){break e}w[d+34>>1]=2;o=d,q=x[Gb(d+8|0,d)>>2],x[o+8>>2]=q}fb=i+32|0;g=e+4|0;Lk(g,2,k);d=e+116|0;Ec(d,g);zc(((f<<5)+a|0)+946304|0,d);tb(d);w[((f<<1)+e|0)+46>>1]=y[e+30|0]|y[e+31|0]<<8;f=f+1|0;continue}break}d=a+484360|0;g=a+484376|0;Wk(Wb(x[d>>2],y[g|0]),b,y[e+159|0]?128:64,65535,65535);f=0;if(!uW(Wb(x[d>>2],y[g|0]))){break a}m=c&1;if(m){$f(a+484344|0,y[e+161|0])}h=a+484344|0;while(1)if(y[e+161|0]<=l>>>0){f=1;if(!(c&2)){break a}c=ad(e+16|0,8,1,0,0);while(1){if((f|0)==32){break b}d=D(f,104)+a|0;g=d+484380|0;f:{if(!x[g>>2]|!z[d+484410>>1]){break f}d=z[((f<<1)+e|0)+46>>1];if(d>>>0<4){break f}if(!bd(b,d<<4)){break f}qg(c,g,b)}f=f+1|0;continue}}else{f=0;g:{h:{if(m){if(bh(h,l&65535,64)){break h}}while(1){if((f|0)==256){break g}if((be(b)+2&255)>>>0<=252){Yb(b,3)}f=f+1|0;continue}}o=e,q=vb(x[Vb(x[h>>2],l)>>2]),x[o+116>>2]=q;w[e+2>>1]=65535;x[e+4>>2]=63;i=0;i:while(1){f=0;if((i|0)==64){d=z[e+2>>1];if((d|0)==65535){break g}we(Vb(x[h>>2],l),qn(Ue(Le(e+16|0,12,d&255),x[e+4>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=be(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}v[x[e+116>>2]]=254;break j}d=e+16|0;Fr(d,b);j=y[xb(d,0)|0];k=y[xb(d,1)|0];n=y[xb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(D(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=x[e+116>>2];v[d|0]=g;break k}i=i+1|0;continue i}d=x[e+116>>2]}v[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){v[d+4|0]=g;v[d+2|0]=1}v[d+5|0]=n;tW(d,k&15,i,y[e+159|0],e+2|0,e+4|0)}f=f+1|0;vC(e+116|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;Ye(d+480280|0);w[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=N()|0;tb(e+116|0);break d}f=N()|0}Eb(e+16|0);Q(f|0);p()}f=0;break a}f=1}fb=e+176|0;return f|0}function kka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,A=0,B=0,C=0,F=0,G=0,H=0,I=0;l=fb-32|0;fb=l;s=x[a+4>>2];k=Re(x[a+8>>2],b);t=x[k>>2];a:{if(t+1>>>0<2){break a}i=(D(b,872)+s|0)+616|0;if(!(Pi(x[i+8>>2],x[i+12>>2])|y[k+4|0])){break a}h=D(b,872)+s|0;if(!x[h+720>>2]){break a}g=x[h+704>>2]&2;u=x[(g?h+700|0:h+692|0)>>2];n=x[h+700>>2];f=x[h+696>>2];w=Pb(x[a>>2]+1074312|0,31);e=sf(x[h+624>>2],x[h+628>>2],c);o=y[h+704|0]&128;k=o?0-e|0:e;m=hb;m=o?0-(m+((e|0)!=0)|0)|0:m;e=0;o=g?e:0;e=f;r=g?e:0;n=n-e|0;B=n<<1;C=h+1316|0;p=h+1467|0;A=h+1362|0;F=(y[A|0]&17)!=1;b:{c:{while(1){if((q|0)!=(t|0)){d:{if(d>>>0>q>>>0){e=(y[A|0]&17)==1;break d}x[x[a+4>>2]+16>>2]=q-d;v[p|0]=y[p|0]&254|(d|0)==(q|0);e=x[a>>2];j=x[a+4>>2];f=Vb(x[e+484344>>2],z[j+70>>1]);f=gd(x[f>>2],x[x[f+48>>2]+12>>2],x[j+48>>2],b);g=y[f+3|0];e:{f:{switch(y[f+2|0]-11|0){case 0:j=l+8|0;jB(j,e,g,y[f+4|0],0);j=Ze(j);vu(x[a>>2],x[a+4>>2],b,z[l+8>>1]);e=1;if(!y[j|0]){break e}break d;case 1:dB(e,j,b,y[f+4|0]<<2&252,Pb(e+1074312|0,12));break e;case 2:break f;default:break e}}cB(e,j,b,y[f+4|0]<<2&252,Pb(e+1074312|0,12))}e=1;g:{h:{i:{j:{k:{switch(g-2|0){default:if(g-38>>>0<4){break h}if((g|0)==19){break j}if((g|0)!=28){break g}e=y[f+5|0];f=e&240;if((f|0)==32){break i}if((f|0)!=16){break g}bB(x[a>>2],i,e&15);break g;case 2:vu(x[a>>2],x[a+4>>2],b,y[f+5|0]);break g;case 4:vu(x[a>>2],x[a+4>>2],b,0);break g;case 0:f=y[f+5|0];g=x[a>>2];if(!f&(v[g+480180|0]&1)){break d}dB(g,x[a+4>>2],b,f,0);break g;case 1:break k;case 3:break d}}f=y[f+5|0];g=x[a>>2];if(!f&(v[g+480180|0]&1)){break d}cB(g,x[a+4>>2],b,f,0);break g}f=y[f+5|0];e=f&15;if(!(e|x[x[a>>2]+480180>>2]&1048580)){break g}f=f&240;if((f|0)!=32){if((f|0)!=16){break g}aB(x[a>>2],i,e);break g}$A(x[a>>2],i,e);break g}_A(x[a>>2],i,e&15);break g}QS(x[a>>2],i,y[f+5|0],(g|0)==38|(g|0)==40,(g&254)==40)}e=1}x[l+28>>2]=x[C>>2];if(w){uu(x[a>>2],i)}if(!F){PS(x[a>>2],i,l+28|0);e=1}if(!w){uu(x[a>>2],i)}x[l+24>>2]=0;OS(i,l+24|0);l:{if(y[h+705|0]&2){break l}m:{if(!e){if(!y[Re(x[a+8>>2],b)+4|0]){break m}}if(y[p|0]&96){RU(i,E(1),0,x[a>>2]);k=y[p|0];v[p|0]=(k&64?-65:-33)&k}lB(l+8|0,x[a>>2],i,x[l+28>>2],0);k=x[l+12>>2];x[h+624>>2]=x[l+8>>2];x[h+628>>2]=k;H=Re(x[a+8>>2],b),I=0,v[H+4|0]=I;e=sf(x[h+624>>2],x[h+628>>2],c);f=y[h+704|0]&128;k=f?0-e|0:e;g=hb;m=f?0-(g+((e|0)!=0)|0)|0:g}Qb(i,k,m);f=x[i>>2];e=x[i+4>>2];if((f>>>0<G>>>0&(e|0)<=(u|0)|(e|0)<(u|0))&((e|0)>=(r|0)&f>>>0>=o>>>0|(e|0)>(r|0)|((m|0)>0|(m|0)>=0))){break l}j=x[h+704>>2];if(!(j&2)){break c}if(j&4){g=x[h+696>>2];if(f>>>0<o>>>0&(e|0)<=(r|0)|(e|0)<(r|0)){H=i,I=fh(0,g<<1,f,e),x[H>>2]=I;e=hb;x[i+4>>2]=e;x[h+704>>2]=j^128;f=k;k=0-f|0;m=0-(((f|0)!=0)+m|0)|0}e=(e-g>>>0)%(B-Pb(x[a>>2]+1074312|0,33)>>>0)|0;n:{if(e>>>0<n>>>0){f=e+x[h+696>>2]|0;break n}f=x[h+700>>2]+(n-e|0)|0}x[i+4>>2]=f;f=x[h+704>>2];if((f&128)>>>7^e>>>0<n>>>0){break l}x[h+704>>2]=f^128;e=k;k=0-e|0;m=0-(((e|0)!=0)+m|0)|0;break l}j=x[h+700>>2];if(j+n>>>0<=e>>>0){e=j+((e-j>>>0)%(n>>>0)|0)|0}while(1){g=e;e=e-n|0;if(g>>>0>=j>>>0){continue}break}x[i>>2]=f;x[i+4>>2]=g}q=q+1|0;continue}break}x[x[a+4>>2]+16>>2]=0;break b}x[x[a+4>>2]+16>>2]=0;TU(i);x[(D(b,872)+s|0)+1324>>2]=0}H=Re(x[a+8>>2],b),I=0,x[H>>2]=I}fb=l+32|0}function KG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-32|0;fb=f;d=x[b+28>>2];x[f+24>>2]=x[b+24>>2];x[f+28>>2]=d;d=x[b+20>>2];x[f+16>>2]=x[b+16>>2];x[f+20>>2]=d;d=x[b+12>>2];x[f+8>>2]=x[b+8>>2];x[f+12>>2]=d;d=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=d;d=fb-144|0;fb=d;j=Fb(d+132|0);k=Fb(d+120|0);x[31785]=0;b=P(1,d+108|0,c|0)|0;c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=yb(k,b);tb(b);if(!x[f>>2]){break b}x[31785]=0;O(76,d+96|0,f|0);b=x[31785];x[31785]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((b|0)!=1){x[31785]=0;e=P(77,j|0,d+96|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break q}tb(d+96|0);x[31785]=0;b=P(1,d+84|0,17006)|0;g=x[31785];x[31785]=0;if((g|0)==1){break p}x[31785]=0;O(78,d+72|0,f+4|0);g=x[31785];x[31785]=0;if((g|0)==1){break o}x[31785]=0;S(2,d+96|0,b|0,d+72|0);g=x[31785];x[31785]=0;if((g|0)==1){break n}x[31785]=0;e=P(77,e|0,d+96|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break m}tb(d+96|0);g=d+72|0;tb(g);tb(b);x[31785]=0;b=P(1,g|0,17006)|0;g=x[31785];x[31785]=0;if((g|0)==1){break j}x[31785]=0;O(78,d+60|0,f+8|0);g=x[31785];x[31785]=0;if((g|0)==1){break i}x[31785]=0;S(2,d+96|0,b|0,d+60|0);g=x[31785];x[31785]=0;if((g|0)==1){break h}x[31785]=0;i=P(77,e|0,d+96|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break g}tb(d+96|0);tb(d+60|0);tb(b);b=x[f+24>>2];g=x[f+28>>2];if(x[f+12>>2]|(x[f+16>>2]|!(b|g))){break d}break b}a=N()|0;break c}a=N()|0;tb(d+96|0);break c}a=N()|0;break c}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+96|0)}tb(d+72|0)}tb(b);break c}a=N()|0;break c}a=N()|0;break e}a=N()|0;break f}a=N()|0;tb(d+96|0)}tb(d+60|0)}tb(b);break c}x[31785]=0;e=P(1,d+96|0,13740)|0;h=x[31785];x[31785]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{if((h|0)!=1){x[31785]=0;i=P(77,i|0,e|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break J}tb(e);x[31785]=0;O(79,d+36|0,f+12|0);e=x[31785];x[31785]=0;if((e|0)==1){break I}x[31785]=0;e=P(1,d+24|0,14788)|0;h=x[31785];x[31785]=0;if((h|0)==1){break H}x[31785]=0;S(2,d+48|0,d+36|0,e|0);h=x[31785];x[31785]=0;if((h|0)==1){break G}x[31785]=0;O(79,d+12|0,f+16|0);h=x[31785];x[31785]=0;if((h|0)==1){break F}x[31785]=0;S(2,d+60|0,d+48|0,d+12|0);h=x[31785];x[31785]=0;if((h|0)==1){break E}x[31785]=0;i=P(77,i|0,d+60|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break D}tb(d+60|0);tb(d+12|0);tb(d+48|0);tb(e);tb(d+36|0);if(b|g){break y}x[31785]=0;S(80,a|0,i|0,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break x}break a}a=N()|0;break c}a=N()|0;tb(e);break c}a=N()|0;break c}a=N()|0;break z}a=N()|0;break A}a=N()|0;break B}a=N()|0;break C}a=N()|0;tb(d+60|0)}tb(d+12|0)}tb(d+48|0)}tb(e)}tb(d+36|0);break c}x[31785]=0;b=P(1,d+48|0,14788)|0;e=x[31785];x[31785]=0;if((e|0)==1){break w}x[31785]=0;O(81,d+36|0,f+24|0);e=x[31785];x[31785]=0;if((e|0)==1){break v}x[31785]=0;S(2,d+60|0,b|0,d+36|0);e=x[31785];x[31785]=0;if((e|0)==1){break u}x[31785]=0;e=P(77,i|0,d+60|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break t}tb(d+60|0);tb(d+36|0);tb(b);x[31785]=0;P(77,e|0,c|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break b}}a=N()|0;break c}a=N()|0;break c}a=N()|0;break r}a=N()|0;break s}a=N()|0;tb(d+60|0)}tb(d+36|0)}tb(b);break c}a=N()|0}tb(k);tb(j);Q(a|0);p()}Yc(a,j)}tb(c);tb(j);fb=d+144|0;fb=f+32|0}function IP(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=E(0),m=E(0),n=0,o=E(0),p=0,q=E(0),r=E(0),s=E(0),t=0,u=E(0);j=fb-16|0;fb=j;b=a+4208|0;i=Bk(E(B[wb(b,12)>>2]*E(3)));x[a+4264>>2]=i;d=E(x[x[a+16>>2]+24620>>2]>>>((i^-1)>>>1&1)>>>0);B[a+4268>>2]=d;t=a,u=E(E(B[wb(b,9)>>2]*E(100))*E(.0061803399585187435)),B[t+4272>>2]=u;t=j,u=Ce(E(10),E(E(HP(a)+E(E(B[wb(b,5)>>2]*E(11e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[j+8>>2]=1065353216;t=a,u=E(B[Pm(j+12|0,j+8|0)>>2]*E(.7609999775886536)),B[t+4280>>2]=u;c=Ce(E(10),E(E(E(E(B[wb(b,1)>>2]*E(1e4))+E(-1e4))/E(100))/E(10)));if(c!=E(1)){d=iq(E(E(GP(a)*E(6.2831854820251465))/d));f=E(c+c);e=E(c*c);c=oB(E(E(E(E(d*f)+E(-2))+E(M(E(E(E(E(d*E(E(d*e)*E(4)))+E(c*E(8)))-E(e*E(4)))-E(E(d*c)*E(8))))))/E(f+E(-2))),E(0),E(1))}else{c=E(0)}B[a+4276>>2]=c;i=fb-16|0;fb=i;c=B[a+4268>>2];b=a+4208|0;d=E(B[wb(b,6)>>2]*E(.30000001192092896));t=i,u=E(B[wb(b,8)>>2]*E(.10000000149011612)),B[t+12>>2]=u;x[i+8>>2]=1000593162;f=B[Pz(i+12|0,i+8|0)>>2];e=E(c*E(E(d+f)+E(.007000000216066837)));a:{if(E(F(e))<E(2147483648)){b=~~e;break a}b=-2147483648}x[a+4352>>2]=b;b=1;while(1){if((b|0)==12){t=i,u=E(E(E(E(B[wb(a+4208|0,10)>>2]*E(100))/E(100))+E(.10000000149011612))*E(.9090999960899353)),B[t+12>>2]=u;x[i+8>>2]=1065353216;d=B[Pm(i+12|0,i+8|0)>>2];f=E(c*E(E(d*E(75))/E(1e3)));d=E(c*E(E(d*E(67))/E(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=E(c*E(.0035299998708069324));b:{if(E(F(d))<E(2147483648)){b=~~d;break b}b=-2147483648}x[h>>2]=b;h=a+4344|0;d=E(c*E(.0032500000670552254));c:{if(E(F(d))<E(2147483648)){b=~~d;break c}b=-2147483648}x[h>>2]=b;h=a+4340|0;c=E(c*E(.009999999776482582));d:{if(E(F(c))<E(2147483648)){b=~~c;break d}b=-2147483648}x[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=Ce(E(.9300000071525574),E(n|0));g=E(f*e);e:{if(E(F(g))<E(2147483648)){k=~~g;break e}k=-2147483648}x[p>>2]=k;k=h+4292|0;e=E(d*e);f:{if(E(F(e))<E(2147483648)){h=~~e;break f}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){LP((D(b,24)+a|0)+4504|0,x[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}fb=i+16|0}else{k=((D(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=E(c*E(E(f*B[(b<<2)+45648>>2])+d));g:{if(E(F(e))<E(2147483648)){h=~~e;break g}h=-2147483648}x[k>>2]=h;b=b+1|0;continue}break}b=fb-16|0;fb=b;d=Nh(a,5);e=Nh(a,11);c=E(d*Nh(a,4));d=E(E(c*E(.03999999910593033))+E(E(d*E(.02250000089406967))+E(0)));f=E(e*Nh(a,10));e=E(E(f*E(.03999999910593033))+E(E(e*E(.02250000089406967))+E(0)));if(v[a+4264|0]&1){g=Nh(a,3);l=Nh(a,9);g=E(c*g);c=E(g*Nh(a,2));d=E(E(c*E(.1444000005722046))+E(E(g*E(.12250000238418579))+d));g=E(f*l);f=E(g*Nh(a,8));e=E(E(f*E(.1444000005722046))+E(E(g*E(.12250000238418579))+e))}Nh(a,12);g=B[a+4496>>2];l=Nh(a,1);m=Nh(a,7);q=Nh(a,0);r=Nh(a,6);t=b,u=Ce(E(10),E(E(HP(a)+E(E(B[wb(a+4208|0,7)>>2]*E(12e3))+E(-1e4)))/E(2e3))),B[t+12>>2]=u;x[b+8>>2]=1065353216;o=B[Pm(b+12|0,b+8|0)>>2];s=c;c=E(g*g);g=E(l*E(s*c));l=E(q*g);c=E(m*E(f*c));f=E(r*c);m=E(E(E(l+f)*E(-.5))+E(1));B[a+4284>>2]=o*E(M(E(m/E(E(l*E(.1444000005722046))+E(E(c*E(.1444000005722046))+d)))));B[a+4288>>2]=o*E(M(E(m/E(E(f*E(.1444000005722046))+E(E(g*E(.1444000005722046))+e)))));fb=b+16|0;v[a+5046|0]=0;fb=j+16|0}function cS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,z=0;if(b){i=a+327720|0;c=fb-352|0;fb=c;eU(c+340|0,8);x[31785]=0;la(801,c+328|0,9);j=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((j|0)!=1){x[31785]=0;j=P(802,c+312|0,14)|0;e=x[31785];x[31785]=0;if((e|0)==1){break l}x[31785]=0;O(803,c+340|0,j|0);e=x[31785];x[31785]=0;if((e|0)==1){break k}x[31785]=0;O(803,c+328|0,j|0);e=x[31785];x[31785]=0;if((e|0)==1){break k}dU(c+240|0,4900);dU(c+168|0,32e3);XT(c+96|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);x[31785]=0;e=P(804,c+72|0,c+340|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break j}Ku(c+84|0,c+240|0,e);ze(e);x[31785]=0;e=P(804,c+48|0,c+328|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break i}Ku(c+60|0,c+168|0,e);ze(e);x[31785]=0;e=P(804,c+24|0,c+84|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break h}Ku(c+36|0,c+96|0,e);ze(e);x[31785]=0;e=P(804,c|0,c+60|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break g}g=c+12|0;Ku(g,c+96|0,e);ze(e);e=c+84|0;Aq(e);l=c+36|0;Aq(l);m=c+60|0;Aq(m);Aq(g);q=c+328|0;Aq(q);zq(x[c+84>>2],x[c+88>>2],Go(i,0));zq(x[c+36>>2],x[c+40>>2],Go(i,1));zq(x[c+60>>2],x[c+64>>2],Go(i,2));zq(x[c+12>>2],x[c+16>>2],Go(i,3));zq(x[c+328>>2],x[c+332>>2],Go(i,4));ze(g);ze(l);ze(m);ze(e);cn(j);ze(q);ze(c+340|0);fb=c+352|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;ze(c+36|0)}ze(c+60|0)}ze(c+84|0)}cn(j)}ze(c+328|0)}ze(c+340|0);Q(a|0);p()}oA(a+131112|0,9.6377,.97);oA(a+196648|0,8.5,.5);oA(a+262184|0,7,.425)}c=a+368680|0;if(!(u=0,v=nR(c,a),z=b,z?u:v)){e=a+24|0;s=C[a+8>>3];g=y[a+16|0];i=fb+-64|0;fb=i;m:while(1){if((n|0)!=8193){t=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){d=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;h=J(C[i+(b<<3)>>3]*32768*d+.5);h=h<-32768?-32768:h>32768?32768:h;n:{if(F(h)<2147483648){j=~~h;break n}j=-2147483648}w[m>>1]=j;b=b+1|0;continue}}else{h=s;f=1;d=+(b|0)-t;r=d+-3.5;if(!(F(r)<1e-8)){o:{p:{switch(g|0){case 0:f=ff(d*.8975979010256552)*-.5+.5;break o;case 1:f=ff(d*.8975979010256552)*-.46+.54;break o;case 2:f=ff(d*1.7951958020513104)*.08+(ff(d*.8975979010256552)*-.5+.42);break o;case 3:f=ff(d*1.7951958020513104)*.05677+(ff(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=ff(d*1.7951958020513104)*.07922+(ff(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=ff(d*1.7951958020513104);k=ff(d*.8975979010256552);f=ff(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=ff(d*1.7951958020513104);k=ff(d*.8975979010256552);f=ff(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=ff(d*1.7951958020513104);k=ff(d*.8975979010256552);f=ff(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=r*3.141592653589793;h=Ti(d*h)/d}h=f*h;C[i+(b<<3)>>3]=h;o=o+h;b=b+1|0;continue}}break}fb=i- -64|0;b=x[a+20>>2];x[c+16>>2]=x[a+16>>2];x[c+20>>2]=b;b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b}}function Hz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-240|0;fb=e;v[e+239|0]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[xl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Jl(e+80|0,g,f,f-1|0);f=x[e+84>>2];x[b>>2]=x[e+80>>2];x[b+4>>2]=f}f=e+80|0;de(f);g=x[e+80>>2];de(e+216|0);h=wl(g,x[e+220>>2],b);de(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==x[e+84>>2]){a=pc(e+228|0,22485);c=x[a+4>>2];x[e>>2]=x[a>>2];x[e+4>>2]=c;if(Oc(g,f,e)){d=ac(8);x[31785]=0;O(1013,e+216|0,e+239|0);a=x[31785];x[31785]=0;if((a|0)==1){break g}x[31785]=0;S(1020,e+80|0,18453,e+216|0);a=x[31785];x[31785]=0;if((a|0)==1){break f}nc(d,e+80|0);a=0;x[31785]=0;S(100,d|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(e+80|0);break e}if(!d){break h}d=ac(8);a=x[b+4>>2];b=x[b>>2];x[31785]=0;a=di(e+192|0,b,a);b=x[31785];x[31785]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[31785]=0;S(1020,e+204|0,18489,a|0);b=x[31785];x[31785]=0;if((b|0)==1){break p}x[31785]=0;O(1022,e+216|0,e+204|0);b=x[31785];x[31785]=0;c=1;if((b|0)==1){break o}x[31785]=0;O(1013,e+180|0,e+239|0);b=x[31785];x[31785]=0;if((b|0)==1){break n}x[31785]=0;S(1024,e+80|0,e+216|0,e+180|0);b=x[31785];x[31785]=0;if((b|0)==1){break m}nc(d,e+80|0);x[31785]=0;S(100,d|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(e+80|0);c=0;break l}b=N()|0;break d}b=N()|0;c=1;break i}b=N()|0;break j}b=N()|0;break k}b=N()|0}tb(e+180|0)}tb(e+216|0)}tb(e+204|0)}tb(a);if(c){break d}break c}b=pc(e+172|0,22485);d=x[b+4>>2];x[e+72>>2]=x[b>>2];x[e+76>>2]=d;if(Oc(g,f,e+72|0)){d=ac(8);x[31785]=0;O(1013,e+216|0,e+239|0);a=x[31785];x[31785]=0;q:{r:{if((a|0)!=1){x[31785]=0;S(1020,e+80|0,18453,e+216|0);a=x[31785];x[31785]=0;if((a|0)==1){break r}nc(d,e+80|0);a=0;x[31785]=0;S(100,d|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(e+80|0);break q}b=N()|0;break d}b=N()|0;a=1}tb(e+216|0);if(a){break d}break c}b=pc(e+164|0,7482);d=x[b+4>>2];x[e+64>>2]=x[b>>2];x[e+68>>2]=d;s:{if(!Oc(g,f,e- -64|0)){b=pc(e+156|0,7464);d=x[b+4>>2];x[e+56>>2]=x[b>>2];x[e+60>>2]=d;if(!Oc(g,f,e+56|0)){break s}}v[a+60|0]=c;break h}b=pc(e+148|0,7009);d=x[b+4>>2];x[e+48>>2]=x[b>>2];x[e+52>>2]=d;t:{if(!Oc(g,f,e+48|0)){b=pc(e+140|0,6990);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(!Oc(g,f,e+40|0)){break t}}v[a+61|0]=c;break h}b=pc(e+132|0,7093);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Oc(g,f,e+32|0)){v[a+62|0]=c;break h}b=pc(e+124|0,6084);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Oc(g,f,e+24|0)){v[a+63|0]=c;break h}b=pc(e+116|0,7531);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(Oc(g,f,e+16|0)){v[a+64|0]=c;break h}b=pc(e+108|0,13468);d=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=d;if(!Oc(g,f,e+8|0)){break h}b=x[a+24>>2];d=b+24664|0;f=x[d+4>>2];x[e+96>>2]=x[d>>2];x[e+100>>2]=f;d=b+24656|0;f=x[d+4>>2];x[e+88>>2]=x[d>>2];x[e+92>>2]=f;d=x[b+24652>>2];x[e+80>>2]=x[b+24648>>2];x[e+84>>2]=d;if(c){a=IM(x[a+56>>2])}else{a=0}x[e+100>>2]=a;if(!rz(e+80|0,b+24648|0)){break h}yA(b,e+80|0)}fb=e+240|0;return}b=N()|0;break d}b=N()|0;a=1}tb(e+216|0);if(!a){break c}}jc(d)}Q(b|0)}p()}function sH(){var a=0,b=0,c=0,d=0;if(y[500624]){return x[125155]}b=td(502264,1);x[b>>2]=112216;c=gJ(b+8|0);x[31785]=0;d=P(37,b+152|0,14426)|0;a=x[31785];x[31785]=0;a:{b:{c:{if((a|0)!=1){Gf(c);bJ(501936,1);x[31785]=0;W(1261,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}aJ(501944,1);x[31785]=0;W(1262,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}$I(501952,1);x[31785]=0;W(1263,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}_I(501968,1);x[31785]=0;W(1264,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(501976,1);x[125494]=114164;x[31785]=0;W(1265,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;X(1266);a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;W(1267,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502e3,1);x[125500]=114312;x[31785]=0;W(1268,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502008,1);x[125502]=114544;x[31785]=0;W(1269,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502016,1);x[125504]=114428;x[31785]=0;W(1270,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502024,1);x[125506]=114660;x[31785]=0;W(1271,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}ZI(502032,1);x[31785]=0;W(1272,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}YI(502056,1);x[31785]=0;W(1273,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502088,1);x[125522]=115380;x[31785]=0;W(1274,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502096,1);x[125524]=115624;x[31785]=0;W(1275,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502104,1);x[125526]=115836;x[31785]=0;W(1276,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502112,1);x[125528]=116068;x[31785]=0;W(1277,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}XI(502120,1);x[31785]=0;W(1278,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}WI(502128,1);x[31785]=0;W(1279,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}VI(502136,1);x[31785]=0;W(1280,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}UI(502144,1);x[31785]=0;W(1281,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502152,1);x[125538]=118760;x[31785]=0;W(1282,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502160,1);x[125540]=118924;x[31785]=0;W(1283,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502168,1);x[125542]=119088;x[31785]=0;W(1284,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}td(502176,1);x[125544]=119252;x[31785]=0;W(1285,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}TI(502184,1);x[31785]=0;W(1286,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}SI(502200,1);x[31785]=0;W(1287,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;X(1288);a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;W(1289,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;X(1290);a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;W(1291,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}RI(502248,1);x[31785]=0;W(1292,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}QI(502256,1);x[31785]=0;W(1293,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}break a}b=N()|0;break b}b=N()|0;tb(d)}Yx(c);Q(b|0);p()}x[125154]=502264;v[500624]=1;x[125155]=500616;return 500616}function Gz(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-160|0;fb=e;C[e+152>>3]=c;f=x[b+4>>2];a:{if(!f){break a}g=x[b>>2];h=y[xl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Jl(e+128|0,g,f,f-1|0);f=x[e+132>>2];x[b>>2]=x[e+128>>2];x[b+4>>2]=f}f=e+128|0;de(f);g=x[e+128>>2];de(e+116|0);h=wl(g,x[e+120>>2],b);de(f);f=x[b+4>>2];g=x[b>>2];b:{c:{d:{e:{if((h|0)==x[e+132>>2]){a=pc(e+144|0,22485);h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;if(Oc(g,f,e+8|0)){d=ac(8);x[31785]=0;O(1017,e+116|0,e+152|0);a=x[31785];x[31785]=0;f:{g:{h:{if((a|0)!=1){x[31785]=0;S(1020,e+128|0,18453,e+116|0);a=x[31785];x[31785]=0;if((a|0)==1){break h}nc(d,e+128|0);a=0;x[31785]=0;S(100,d|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(e+128|0);break g}b=N()|0;break f}b=N()|0;a=1}tb(e+116|0);if(!a){break c}}jc(d);break c}if(!d){break e}d=ac(8);a=x[b+4>>2];b=x[b>>2];x[31785]=0;f=di(e+92|0,b,a);a=x[31785];x[31785]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){x[31785]=0;S(1020,e+104|0,18489,f|0);a=x[31785];x[31785]=0;if((a|0)==1){break q}x[31785]=0;O(1022,e+116|0,e+104|0);b=x[31785];x[31785]=0;a=1;if((b|0)==1){break p}x[31785]=0;O(1017,e+80|0,e+152|0);a=x[31785];x[31785]=0;if((a|0)==1){break o}x[31785]=0;S(1024,e+128|0,e+116|0,e+80|0);b=x[31785];x[31785]=0;a=1;if((b|0)==1){break n}nc(d,e+128|0);x[31785]=0;S(100,d|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(e+128|0);a=0;break m}b=N()|0;break i}b=N()|0;a=1;break j}b=N()|0;break k}b=N()|0;a=1;break l}b=N()|0}tb(e+80|0)}tb(e+116|0)}tb(e+104|0)}tb(f);if(!a){break c}}jc(d);break c}b=pc(e+72|0,22485);d=x[b+4>>2];x[e+40>>2]=x[b>>2];x[e+44>>2]=d;if(Oc(g,f,e+40|0)){d=ac(8);x[31785]=0;O(1017,e+116|0,e+152|0);a=x[31785];x[31785]=0;r:{s:{t:{if((a|0)!=1){x[31785]=0;S(1020,e+128|0,18453,e+116|0);a=x[31785];x[31785]=0;if((a|0)==1){break t}nc(d,e+128|0);a=0;x[31785]=0;S(100,d|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(e+128|0);break s}b=N()|0;break r}b=N()|0;a=1}tb(e+116|0);if(!a){break c}}jc(d);break c}b=pc(e- -64|0,7779);d=x[b+4>>2];x[e+32>>2]=x[b>>2];x[e+36>>2]=d;if(Oc(g,f,e+32|0)){if(!Ad(y[a+28|0])){break e}if(c<=0|c>4){a=ac(8);x[31785]=0;d=P(37,e+128|0,7874)|0;b=x[31785];x[31785]=0;if((b|0)==1){break d}nc(a,d);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(d);break c}a=x[a+24>>2];i=a,j=Xe(65536/c),x[i+480244>>2]=j;oq(a);break e}b=pc(e+56|0,7831);d=x[b+4>>2];x[e+24>>2]=x[b>>2];x[e+28>>2]=d;if(Oc(g,f,e+24|0)){if(!Ad(y[a+28|0])){break e}if(c<=0|c>4){a=ac(8);x[31785]=0;d=P(37,e+128|0,7895)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,d);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(d);break c}b=N()|0;jc(a);break c}a=x[a+24>>2];i=a,j=Xe(c*65536),x[i+480240>>2]=j;oq(a);break e}b=pc(e+48|0,7849);d=x[b+4>>2];x[e+16>>2]=x[b>>2];x[e+20>>2]=d;if(!Oc(g,f,e+16|0)){break e}i=x[a+24>>2],j=Xi(c*65536),x[i+480236>>2]=j}fb=e+160|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function UL(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-48|0;fb=g;a:{b:{if(zt(c)){h=x[b+484344>>2];if(Ge(h,x[b+484348>>2],c&65535)){break b}}c=a;a=Fb(g+36|0);b=Fb(g+24|0);Gi(c,a,b);tb(b);tb(a);break a}c=Vb(h,c);if(!(x[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Gi(c,a,b);tb(b);tb(a);break a}if(!(z[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Gi(c,a,b);tb(b);tb(a);break a}if(f>>>0>=6){c=a;a=Fb(g+36|0);b=Fb(g+24|0);Gi(c,a,b);tb(b);tb(a);break a}c=gd(x[c>>2],x[x[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=y[c|0];if(!zd(d)){if(!Cl(d)){break k}}e=g+24|0;FR(e,b,d,y[c+1|0]);x[31785]=0;O(1068,g+36|0,e|0);b=x[31785];x[31785]=0;d=1;if((b|0)!=1){break j}c=N()|0;break g}d=0;x[31785]=0;P(37,g+36|0,16972)|0;b=x[31785];x[31785]=0;if((b|0)==1){break i}}b=9978;c=y[c|0];if(!zd(c)){b=Cl(c)?10288:16972}x[31785]=0;b=P(37,g+12|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break h}c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);if(!d){break a}tb(g+24|0);break a}c=N()|0;break d}c=N()|0;tb(g+36|0);if(!d){break d}}tb(g+24|0);break d;case 1:b=c+1|0;l:{if(y[c+1|0]){tv(g+36|0,b);break l}Cc(g+36|0,16977)}b=y[b|0];x[31785]=0;b=P(37,g+24|0,(b?10811:16977)|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);break a;case 2:m:{if(Sg(y[c|0])){Cc(g+36|0,18645);break m}d=y[c+2|0];if(d){pf(g+36|0,1,dR(x[x[b+8>>2]+88>>2],d));break m}Cc(g+36|0,18645)}b=18645;if(!Sg(y[c|0])){b=y[c+2|0]?5525:18645}x[31785]=0;b=P(37,g+24|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 4:n:{if(Sg(y[c|0])){i=g,j=Hj(y[c+2|0],y[c+4|0])&255,x[i+12>>2]=j;MC(g+36|0,g+12|0);break n}if(y[c+2|0]){tv(g+36|0,c+4|0);break n}Cc(g+36|0,16977)}b=5509;if(!Sg(y[c|0])){b=y[c+2|0]?5509:16977}x[31785]=0;b=P(37,g+24|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 3:o:{if(Sg(y[c|0])){i=g,j=(Hj(y[c+3|0],y[c+5|0])&3840)!=0,v[i+12|0]=j;b=fb-32|0;fb=b;x[b+12>>2]=-1;x[b+16>>2]=0;x[b+4>>2]=0;Fb(b+20|0);x[31785]=0;x[b+4>>2]=x[b+4>>2]&-1332|1058;x[b+8>>2]=1;S(1170,g+36|0,g+12|0,b+4|0);d=x[31785];x[31785]=0;p:{if((d|0)!=1){Dh(b+4|0);fb=b+32|0;break p}a=N()|0;Dh(b+4|0);Q(a|0);p()}break o}d=y[c+3|0];if(d){pf(g+36|0,1,cR(x[x[b+8>>2]+84>>2],d));break o}Cc(g+36|0,16978)}b=12396;if(!Sg(y[c|0])){b=y[c+3|0]?12396:16978}x[31785]=0;b=P(37,g+24|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d;case 5:break f;default:break c}}q:{if(Sg(y[c|0])){i=g,j=Hj(y[c+3|0],y[c+5|0])&255,x[i+12>>2]=j;MC(g+36|0,g+12|0);break q}if(y[c+3|0]){tv(g+36|0,c+5|0);break q}Cc(g+36|0,16977)}b=11183;if(!Sg(y[c|0])){b=y[c+3|0]?11183:16977}x[31785]=0;b=P(37,g+24|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){c=a;a=g+36|0;Gi(c,a,b);tb(b);tb(a);break a}c=N()|0;tb(g+36|0);break d}c=N()|0;tb(g+36|0)}Q(c|0);p()}c=a;a=Fb(g+36|0);b=Fb(g+24|0);Gi(c,a,b);tb(b);tb(a)}fb=g+48|0}function wra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-368|0;fb=e;g=fb-32|0;fb=g;d=g+12|0;bD(d,b);Fn(g+4|0,d);x[31785]=0;S(479,e+216|0,x[g+4>>2],x[g+8>>2]);b=x[31785];x[31785]=0;a:{if((b|0)!=1){Jc(g+12|0);fb=g+32|0;break a}a=N()|0;Jc(g+12|0);Q(a|0);p()}x[31785]=0;S(461,e+104|0,x[e+216>>2],x[e+220>>2]);b=x[31785];x[31785]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){x[31785]=0;g=P(106,e+228|0,e+104|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break z}tb(e+104|0);dc(e+216|0);if(c>>>0<2189){break g}b=Gm(e+104|0,g);x[31785]=0;c=P(465,e+216|0,10134)|0;d=x[31785];x[31785]=0;if((d|0)==1){break x}x[31785]=0;x[e+88>>2]=19988519;x[e+92>>2]=0;S(466,b|0,c|0,e+88|0);d=x[31785];x[31785]=0;if((d|0)==1){break w}Eb(c);v[e+103|0]=0;x[31785]=0;c=P(465,e+88|0,11057)|0;d=x[31785];x[31785]=0;if((d|0)==1){break v}x[31785]=0;S(467,b|0,e+103|0,c|0);d=x[31785];x[31785]=0;if((d|0)==1){break u}Eb(c);d=Gc(e+84|0,y[e+103|0]?0:x[a+1298404>>2]);f=x[a+4>>2];x[31785]=0;c=P(465,e+72|0,16013)|0;h=x[31785];x[31785]=0;if((h|0)==1){break i}h=x[d>>2];x[31785]=0;V(468,b|0,f|0,c|0,h|0);f=x[31785];x[31785]=0;if((f|0)==1){break t}Eb(c);x[31785]=0;c=P(465,e+60|0,15690)|0;f=x[31785];x[31785]=0;if((f|0)==1){break s}d=x[d>>2];x[31785]=0;V(469,b|0,a|0,c|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break r}Eb(c);x[31785]=0;c=P(465,e+48|0,15525)|0;d=x[31785];x[31785]=0;if((d|0)==1){break q}x[31785]=0;d=a+484360|0;S(470,b|0,d|0,c|0);f=x[31785];x[31785]=0;if((f|0)==1){break p}Eb(c);x[31785]=0;c=P(465,e+36|0,25254)|0;f=x[31785];x[31785]=0;if((f|0)==1){break o}x[31785]=0;S(471,b|0,a+484344|0,c|0);f=x[31785];x[31785]=0;if((f|0)==1){break n}Eb(c);f=x[a+1298404>>2];x[31785]=0;c=P(465,e+24|0,25260)|0;h=x[31785];x[31785]=0;if((h|0)==1){break m}x[31785]=0;V(472,b|0,d|0,c|0,f|0);d=x[31785];x[31785]=0;if((d|0)==1){break l}Eb(c);if(ml(y[b|0])){x[31785]=0;c=P(1,e+12|0,16492)|0;d=x[31785];x[31785]=0;if((d|0)==1){break k}a=x[a+1298472>>2];x[31785]=0;S(389,a|0,1,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break j}tb(c)}yh(b);break f}a=N()|0;break y}a=N()|0;tb(e+104|0)}dc(e+216|0);break b}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;Eb(c);break h}a=N()|0;break h}a=N()|0;tb(c);break h}a=N()|0}yh(b);break c}b=Fb(e+104|0);d=x[a+1298404>>2];f=x[a+4>>2];x[31785]=0;d=ba(473,f|0,g|0,b|0,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break e}A:{if((d|0)!=1){x[31785]=0;c=P(1,e+216|0,16798)|0;d=x[31785];x[31785]=0;B:{if((d|0)!=1){a=x[a+1298472>>2];x[31785]=0;S(389,a|0,1,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break B}tb(c);break A}a=N()|0;break d}a=N()|0;tb(c);break d}d=x[a+1298404>>2];x[31785]=0;V(474,g|0,a|0,d|0,c>>>0<2188|0);a=x[31785];x[31785]=0;if((a|0)==1){break e}}tb(b)}Af(g);fb=e+368|0;return}a=N()|0}tb(b)}Af(g)}Q(a|0);p()}function ira(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-192|0;fb=f;Yd(f+80|0,b);i=x[f+88>>2];l=x[f+92>>2];e=fb-32|0;fb=e;x[e+28>>2]=0;Ik(b,e+28|0);a:{b:{c:{if(x[e+28>>2]!=(yn(14212)|0)){break c}x[e+24>>2]=0;h=fb-32|0;fb=h;x[h+28>>2]=0;Tx(h+8|0,h+28|0);Im(h+20|0,b,x[h+8>>2],x[h+12>>2]);Hm(e+24|0,x[h+28>>2]);fb=h+32|0;h=-1;g=x[e+24>>2];if(g-3>>>0<4294967294){break c}d:{e:{f:{if(g>>>0<=1){g=Fb(e+12|0);x[31785]=0;j=U(499,b|0,g|0,256)|0;k=x[31785];x[31785]=0;if((k|0)==1){break b}if(!j){break e}x[31785]=0;S(500,e|0,d|0,g|0);j=x[31785];x[31785]=0;if((j|0)!=1){break f}break b}g=Fb(e+12|0);x[31785]=0;j=P(502,b|0,g|0)|0;k=x[31785];x[31785]=0;if((k|0)==1){break b}if(!j){break d}x[31785]=0;S(500,e|0,d|0,g|0);j=x[31785];x[31785]=0;if((j|0)==1){break b}}yb(c,e);tb(e);tb(g);kg(b,e);g=0;x[e+12>>2]=0;Ik(b,e+12|0);j=x[e+12>>2];if(j>>>0>50){break c}g:{while(1){if((g|0)==(j|0)){break g}g=g+1|0;if(FQ(a,b,d)){continue}break}break c}x[e+12>>2]=0;Ik(b,e+12|0);h=x[e+12>>2]==(yn(14258)|0)?1:-1;break c}tb(g);break c}tb(g)}fb=e+32|0;break a}a=N()|0;tb(g);Q(a|0);p()}h:{if(h){break h}eg(x[x[b>>2]-12>>2]+b|0,0);b=Gm(f+80|0,Ei(b,i,l,0));x[31785]=0;h=P(465,f+68|0,14420)|0;i=x[31785];x[31785]=0;i:{if((i|0)!=1){x[31785]=0;x[f+48>>2]=3;x[f+52>>2]=0;S(466,b|0,h|0,f+48|0);i=x[31785];x[31785]=0;if((i|0)!=1){Eb(h);v[f+67|0]=0;x[31785]=0;h=P(465,f+48|0,14887)|0;i=x[31785];x[31785]=0;if((i|0)!=1){x[31785]=0;S(467,b|0,f+67|0,h|0);i=x[31785];x[31785]=0;if((i|0)!=1){Eb(h);h=Gc(f+44|0,y[f+67|0]?0:d);x[31785]=0;d=R(480,b|0)|0;i=x[31785];x[31785]=0;if((i|0)!=1){x[31785]=0;i=R(481,b|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){x[f+40>>2]=d;j:{k:{l:{m:{while(1){if(!Ib(d,i)){a=ml(y[b|0]);yh(b);h=a?-1:1;break h}x[31785]=0;d=P(465,f+24|0,16013)|0;e=x[31785];x[31785]=0;if((e|0)==1){break l}e=x[b+44>>2];g=x[b+40>>2];x[31785]=0;e=ba(482,g|0,e|0,x[f+40>>2],d|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break k}Eb(d);n:{o:{if(e){d=x[h>>2];x[31785]=0;V(483,b|0,f+40|0,c|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){break o}break j}x[31785]=0;d=P(465,f+12|0,15690)|0;e=x[31785];x[31785]=0;p:{q:{if((e|0)!=1){e=x[b+44>>2];g=x[b+40>>2];x[31785]=0;e=ba(482,g|0,e|0,x[f+40>>2],d|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break q}Eb(d);if(!e){break p}x[31785]=0;S(484,b|0,f+40|0,f+38|0);d=x[31785];x[31785]=0;if((d|0)==1){break j}break o}a=N()|0;break i}a=N()|0;Eb(d);break i}x[31785]=0;d=P(465,f|0,15525)|0;e=x[31785];x[31785]=0;if((e|0)==1){break n}e=x[b+44>>2];g=x[b+40>>2];x[31785]=0;e=ba(482,g|0,e|0,x[f+40>>2],d|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break m}Eb(d);if(!e){break o}d=x[h>>2];x[31785]=0;V(485,b|0,f+40|0,a|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break j}}Zz(f+40|0);d=x[f+40>>2];continue}break}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;Eb(d);break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0;break i}a=N()|0;Eb(h);break i}a=N()|0}yh(b);Q(a|0);p()}fb=f+192|0;return h|0}function Qg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-112|0;fb=j;k=i&2147483647;a:{b:{l=e&2147483647;m=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:m)){o=k-2147418112|0;if(!h&(o|0)==-2147418112?f|g:(o|0)==-2147418112&(h|0)!=0|o>>>0>2147549184){break b}}if(!(!d&(l|0)==2147418112?m:l>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(l^2147418112|c))){n=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:n;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|l))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}n=(k|0)==(l|0);r=n&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:n&d>>>0<h>>>0|k>>>0>l>>>0;m=r;l=m?f:b;o=m?g:c;n=m?i:e;s=n;m=m?h:d;q=n&65535;d=r?d:h;e=r?e:i;t=e;n=e>>>16&32767;p=s>>>16&32767;if(!p){e=!(m|q);i=e;k=e?l:m;e=e<<6;i=G(i?o:q);e=e+((i|0)==32?G(k)+32|0:i)|0;Vf(j+96|0,l,o,m,q,e-15|0);m=x[j+104>>2];q=x[j+108>>2];o=x[j+100>>2];p=16-e|0;l=x[j+96>>2]}f=r?b:f;g=r?c:g;h=d;i=t&65535;if(!n){b=!(h|i);e=b;k=b?f:h;b=b<<6;e=G(e?g:i);b=b+((e|0)==32?G(k)+32|0:e)|0;Vf(j+80|0,f,g,h,i,b-15|0);n=16-b|0;h=x[j+88>>2];i=x[j+92>>2];g=x[j+84>>2];f=x[j+80>>2]}c=i<<3|h>>>29;b=h<<3|g>>>29;c=c|524288;h=m<<3|o>>>29;i=q<<3|m>>>29;r=s^t;e=g<<3|f>>>29;d=f<<3;c:{if((n|0)==(p|0)){break c}f=p-n|0;if(f>>>0>127){b=0;c=0;e=0;d=1;break c}Vf(j- -64|0,d,e,b,c,128-f|0);Vm(j+48|0,d,e,b,c,f);b=x[j+56>>2];c=x[j+60>>2];e=x[j+52>>2];d=x[j+48>>2]|(x[j+64>>2]|x[j+72>>2]|(x[j+68>>2]|x[j+76>>2]))!=0}m=d;k=e;n=h;q=i|524288;e=o<<3|l>>>29;o=l<<3;l=e;d:{if((r|0)<0){f=0;g=0;h=0;i=0;if(!(m^o|b^n|(k^l|c^q))){break a}d=o-m|0;e=l-((m>>>0>o>>>0)+k|0)|0;f=n-b|0;g=(k|0)==(l|0)&m>>>0>o>>>0|k>>>0>l>>>0;h=f-g|0;b=(q-((b>>>0>n>>>0)+c|0)|0)-(f>>>0<g>>>0)|0;i=b;if(b>>>0>524287){break d}b=!(h|i);f=b;g=b?d:h;b=b<<6;f=G(f?e:i);b=b+((f|0)==32?G(g)+32|0:f)|0;b=b-12|0;Vf(j+32|0,d,e,h,i,b);p=p-b|0;h=x[j+40>>2];i=x[j+44>>2];d=x[j+32>>2];e=x[j+36>>2];break d}e=k+l|0;d=m+o|0;e=d>>>0<o>>>0?e+1|0:e;f=(k|0)==(e|0)&d>>>0<m>>>0|e>>>0<k>>>0;k=c+q|0;b=b+n|0;k=b>>>0<n>>>0?k+1|0:k;h=b+f|0;i=h>>>0<b>>>0?k+1|0:k;if(!(i&1048576)){break d}d=m&1|((e&1)<<31|d>>>1);e=h<<31|e>>>1;p=p+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}c=0;l=s&-2147483648;if((p|0)>=32767){h=c;i=l|2147418112;f=0;g=0;break a}n=0;e:{if((p|0)>0){n=p;break e}Vf(j+16|0,d,e,h,i,p+127|0);Vm(j,d,e,h,i,1-p|0);d=x[j>>2]|(x[j+16>>2]|x[j+24>>2]|(x[j+20>>2]|x[j+28>>2]))!=0;e=x[j+4>>2];h=x[j+8>>2];i=x[j+12>>2]}o=d&7;d=(e&7)<<29|d>>>3;f=(o>>>0>4)+d|0;b=h<<29|e>>>3;g=d>>>0>f>>>0?b+1|0:b;d=(b|0)==(g|0)&d>>>0>f>>>0|b>>>0>g>>>0;b=c|((i&7)<<29|h>>>3);h=d+b|0;i=l|(i>>>3&65535|n<<16);i=b>>>0>h>>>0?i+1|0:i;f:{if((o|0)==4){b=0;k=g+b|0;d=f;c=f&1;f=f+c|0;g=d>>>0>f>>>0?k+1|0:k;b=(b|0)==(g|0)&c>>>0>f>>>0|b>>>0>g>>>0;h=b+h|0;i=b>>>0>h>>>0?i+1|0:i;break f}if(!o){break a}}}x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;fb=j+112|0}function Cta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-720|0;fb=d;xc(b);f=fb-16|0;fb=f;h=d+110|0;k$(f+8|0,h);g=x[f+12>>2];j=b;kc(f,x[b>>2],x[b+8>>2],x[f+8>>2],x[f+12>>2]);b=x[f+4>>2];if((b|0)==(g|0)){Yb(j,x[f+12>>2])}fb=f+16|0;b=(b|0)==(g|0);if(!b){j$(h)}a:{if(!b){break a}if(!l$(d+110|0)){break a}b:{if(!c){break b}Bd(a,67108864);ag(a);b=y[d+135|0];w[a+480190>>1]=31;w[a+480188>>1]=b;x[a+480228>>2]=256/(b>>>0);b=uc(d,8199);yb(a+1298344|0,b);tb(b);b=uc(d,10814);yb(a+1298356|0,b);tb(b);b=d+84|0;cg(b,4194);f=y[d+134|0];x[d+64>>2]=f>>>4;x[31785]=0;x[d+104>>2]=f&15;V(310,d|0,b|0,d- -64|0,d+104|0);b=x[31785];x[31785]=0;c:{d:{if((b|0)!=1){yb(a+1298368|0,d);tb(d);Eb(d+84|0);o=a+1298404|0,q=x[Gc(d,28)>>2],x[o>>2]=q;_v(Wb(x[a+484360>>2],y[a+484376|0]),d+158|0,y[d+157|0]+1|0);while(1){e:{if((e|0)==31){eE(j,a+1298308|0,32);e=1;break e}b=e+1|0;g=D(b,104)+a|0;h=g+484380|0;jd(h,1);f=(d+110|0)+(e<<2)|0;o=h,q=$b(y[f+176|0]|y[f+177|0]<<8|(y[f+178|0]<<16|y[f+179|0]<<24)),x[o>>2]=q;k=$b(y[f+300|0]|y[f+301|0]<<8|(y[f+302|0]<<16|y[f+303|0]<<24));x[g+484384>>2]=k;f=$b(y[f+424|0]|y[f+425|0]<<8|(y[f+426|0]<<16|y[f+427|0]<<24));x[g+484388>>2]=f+k;if(f){f=g+484414|0;w[f>>1]=z[f>>1]|2}Xk(h);e=(d+110|0)+e|0;v[d|0]=y[e+548|0];v[d+84|0]=64;o=g+484410|0,q=y[Ub(d,d+84|0)|0]<<2,w[o>>1]=q;v[g+484417|0]=y[e+579|0]<<4;e=b;continue}break}while(1){if((e|0)!=32){i$(j,((e<<5)+a|0)+946304|0,30);e=e+1|0;continue}break}n=c&1;if(n){$f(a+484344|0,y[d+156|0]+1|0)}h=a+484344|0;k=a+480188|0;f=0;while(1){if(y[d+156|0]<f>>>0){e=1;if(!(c&2)){break a}b=ad(d,8,1,1,0);while(1){if((e|0)==32){break b}qg(b,(D(e,104)+a|0)+484380|0,j);e=e+1|0;continue}}g=_h(d+84|0);f:{g:{if(y[d+136|0]){x[31785]=0;b=R(276,j|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}x[31785]=0;S(188,d- -64|0,j|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break f}break g}b=z[k>>1];x[31785]=0;S(188,d- -64|0,j|0,b<<8);b=x[31785];x[31785]=0;if((b|0)==1){break d}}b=d- -64|0;e=ic(d,b);hd(g,e);ub(e);ub(b);h:{if(!n){break h}x[31785]=0;b=U(199,h|0,f&65535,64)|0;e=x[31785];x[31785]=0;if((e|0)==1){break d}if(!b){break h}b=0;if(y[d+136|0]){x[31785]=0;O(311,g|0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break d}i:while(1){if((b|0)==64){break h}e=Vb(x[h>>2],f);Ve(d- -64|0,x[e>>2],x[x[e+48>>2]+12>>2],b);o=d,q=vb(x[d+64>>2]),x[o+104>>2]=q;l=b+d|0;e=128;i=pr(x[d+64>>2],x[d+68>>2]);while(1){m=x[d+104>>2];if(!Ib(m,i)){b=b+1|0;continue i}j:{if(!(y[l|0]&e)){break j}x[31785]=0;O(312,g|0,m|0);m=x[31785];x[31785]=0;if((m|0)!=1){break j}break d}e=e>>>1|0;ah(d+104|0);continue}}}k:while(1){e=0;l=b&65535;if(l>>>0>=z[k>>1]){break h}while(1){if((e|0)==64){b=b+1|0;continue k}i=Vb(x[h>>2],f);i=gd(x[i>>2],x[x[i+48>>2]+12>>2],e,l);x[31785]=0;O(312,g|0,i|0);i=x[31785];x[31785]=0;if((i|0)!=1){e=e+1|0;continue}break}break}break d}ub(g);f=f+1|0;continue}break}break d}e=N()|0;Eb(d+84|0);break c}e=N()|0;ub(g)}Q(e|0);p()}e=1}fb=d+720|0;return e|0}function Db(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=x[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=x[d>>2];d=d-b|0;if(d>>>0<A[31665]){break a}a=a+b|0;if(x[31666]!=(d|0)){if(b>>>0<=255){b=b>>>3|0;e=x[d+12>>2];c=x[d+8>>2];if((e|0)==(c|0)){i=126644,j=x[31661]&vua(-2,b),x[i>>2]=j;break b}x[c+12>>2]=e;x[e+8>>2]=c;break b}h=x[d+24>>2];b=x[d+12>>2];c:{if((d|0)!=(b|0)){c=x[d+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break c}d:{e=d+20|0;c=x[e>>2];if(c){break d}e=d+16|0;c=x[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0}if(!h){break b}e=x[d+28>>2];c=(e<<2)+126948|0;e:{if(x[c>>2]==(d|0)){x[c>>2]=b;if(b){break e}i=126648,j=x[31662]&vua(-2,e),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}x[b+24>>2]=h;c=x[d+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[d+20>>2];if(!c){break b}x[b+20>>2]=c;x[c+24>>2]=b;break b}b=x[f+4>>2];if((b&3)!=3){break b}x[31663]=a;x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=x[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(x[31667]==(f|0)){x[31667]=d;a=x[31664]+a|0;x[31664]=a;x[d+4>>2]=a|1;if(x[31666]!=(d|0)){break a}x[31663]=0;x[31666]=0;return}if(x[31666]==(f|0)){x[31666]=d;a=x[31663]+a|0;x[31663]=a;x[d+4>>2]=a|1;x[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){b=b>>>3|0;e=x[f+12>>2];c=x[f+8>>2];if((e|0)==(c|0)){i=126644,j=x[31661]&vua(-2,b),x[i>>2]=j;break g}x[c+12>>2]=e;x[e+8>>2]=c;break g}h=x[f+24>>2];b=x[f+12>>2];h:{if((f|0)!=(b|0)){c=x[f+8>>2];x[c+12>>2]=b;x[b+8>>2]=c;break h}i:{e=f+20|0;c=x[e>>2];if(c){break i}e=f+16|0;c=x[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=x[e>>2];if(c){continue}e=b+16|0;c=x[b+16>>2];if(c){continue}break}x[g>>2]=0}if(!h){break g}e=x[f+28>>2];c=(e<<2)+126948|0;j:{if(x[c>>2]==(f|0)){x[c>>2]=b;if(b){break j}i=126648,j=x[31662]&vua(-2,e),x[i>>2]=j;break g}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}x[b+24>>2]=h;c=x[f+16>>2];if(c){x[b+16>>2]=c;x[c+24>>2]=b}c=x[f+20>>2];if(!c){break g}x[b+20>>2]=c;x[c+24>>2]=b}x[d+4>>2]=a|1;x[a+d>>2]=a;if(x[31666]!=(d|0)){break f}x[31663]=a;return}x[f+4>>2]=b&-2;x[d+4>>2]=a|1;x[a+d>>2]=a}if(a>>>0<=255){b=(a&-8)+126684|0;c=x[31661];a=1<<(a>>>3);k:{if(!(c&a)){x[31661]=a|c;a=b;break k}a=x[b+8>>2]}x[b+8>>2]=d;x[a+12>>2]=d;x[d+12>>2]=b;x[d+8>>2]=a;return}e=31;if(a>>>0<=16777215){b=G(a>>>8|0);e=((a>>>38-b&1)-(b<<1)|0)+62|0}x[d+28>>2]=e;x[d+16>>2]=0;x[d+20>>2]=0;g=(e<<2)+126948|0;l:{m:{c=x[31662];b=1<<e;n:{if(!(c&b)){x[31662]=b|c;x[g>>2]=d;x[d+24>>2]=g;break n}e=a<<((e|0)!=31?25-(e>>>1|0)|0:0);b=x[g>>2];while(1){c=b;if((x[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=x[g+16>>2];if(b){continue}break}x[g+16>>2]=d;x[d+24>>2]=c}x[d+12>>2]=d;x[d+8>>2]=d;break l}a=x[c+8>>2];x[a+12>>2]=d;x[c+8>>2]=d;x[d+24>>2]=0;x[d+12>>2]=c;x[d+8>>2]=a}a=x[31669]-1|0;x[31669]=a?a:-1}}function hy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-32|0;fb=d;i=a+32|0;Pc(d+8|0,i,11);a:{b:{c:{if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])|x[a+8>>2]){b=x[a+76>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+72>>2]|0;Ei(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);c=x[a+36>>2];if(pk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){Mh(a,2,256);break a}b=x[a+104>>2];c=a+52|0;f=x[c>>2];e=lj(f,x[c+4>>2]);d:{if(b>>>0>e>>>0){j=fb-32|0;fb=j;f=b-e|0;h=x[Ab(c)>>2];b=x[c+4>>2];e:{if(f>>>0<=(h-b|0)/24>>>0){e=fb-16|0;fb=e;c=fJ(e+4|0,c,f);b=x[c+4>>2];f=x[c+8>>2];while(1){if((b|0)==(f|0)){hc(c);fb=e+16|0}else{eJ(b);b=b+24|0;x[c+4>>2]=b;continue}break}break e}e=Ab(c);e=wJ(j+12|0,CJ(c,lj(x[c>>2],b)+f|0),lj(x[c>>2],x[c+4>>2]),e);h=fb-16|0;fb=h;b=h+4|0;x[b>>2]=x[e+8>>2];k=x[e+8>>2];x[b+8>>2]=e+8;x[b+4>>2]=k+D(f,24);f=x[b>>2];while(1){if(x[b+4>>2]!=(f|0)){eJ(f);f=x[b>>2]+24|0;x[b>>2]=f;continue}break}ee(b);fb=h+16|0;rJ(c,e);nJ(e)}fb=j+32|0;break d}if(b>>>0<e>>>0){kJ(c,f+D(b,24)|0)}}f=a+40|0;ko(f,x[a+104>>2]<<2);while(1){if(A[a+104>>2]>g>>>0){c=x[a+36>>2];if(pk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){Mh(a,2,1024);break a}b=z[a+24>>1];w[d>>1]=b;if((b|0)==65535){qy(c,d);b=z[d>>1]}c=Sc(x[a+40>>2],x[a+44>>2]);e=b&65535;f:{if(!e){b=0;break f}if(e>>>0>(c^-1)>>>0){break f}Uj(f,c+e|0);zj(x[a+36>>2],xb(x[a+40>>2],c),e)}e=tf(x[a+52>>2],g);x[e>>2]=c;w[e+20>>1]=b;Pc(d+8|0,i,6);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){ll(x[a+36>>2],d+8|0);c=x[d+8>>2];b=x[d+12>>2];if(!ly(c,b)){break c}e=tf(x[a+52>>2],g);x[e+8>>2]=c;x[e+12>>2]=b}c=x[a+8>>2];g:{if(c){b=tf(x[a+52>>2],g);x[b+16>>2]=c;break g}Pc(d+8|0,i,7);if(!Hb(x[x[d+8>>2]>>2],x[d+12>>2])){b=tf(x[a+52>>2],g);break g}ll(x[a+36>>2],d+8|0);c=x[d+8>>2];if(!ly(c,x[d+12>>2])){break b}b=tf(x[a+52>>2],g);x[b+16>>2]=c}h:{if(x[b+16>>2]==-1){break h}Pc(d+8|0,i,6);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){break h}i:{if(!g){b=0;e=tf(x[a+52>>2],0);h=0;break i}e=x[a+52>>2];c=tf(e,g-1|0);j=x[c+16>>2];b=x[c+8>>2]+j|0;c=x[c+12>>2];e=tf(e,g);h=b>>>0<j>>>0?c+1|0:c}c=h;x[e+8>>2]=b;x[e+12>>2]=c}Pc(d+8|0,i,8);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){w[d+30>>1]=0;qy(x[a+36>>2],d+30|0);Pc(d+8|0,i,9);Km(x[a+36>>2],z[d+30>>1]<<Hb(x[x[d+8>>2]>>2],x[d+12>>2]))}g=g+1|0;continue}break}Yd(d+8|0,x[a+36>>2]);c=x[d+20>>2];x[a+80>>2]=x[d+16>>2];x[a+84>>2]=c}g=d+8|0;Pc(g,i,4);Df(g,1);f=x[a+80>>2];j=x[a+84>>2];c=x[a+96>>2];h=x[a+16>>2];e=c+h|0;k=x[a+100>>2];b=k+x[a+20>>2]|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=(c|0)==x[a+72>>2]&(k|0)==x[a+76>>2];c=e?f:h;x[a+88>>2]=c;b=e?j:b;x[a+92>>2]=b;Ei(x[a+36>>2],c,b,0);Pc(g,i,6);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}Pc(d,i,7);if(!(Hb(x[x[d>>2]>>2],x[d+4>>2])|x[a+8>>2])){break a}b=x[a+88>>2];g=x[a+16>>2];c=b-g|0;e=x[a+92>>2]-(x[a+20>>2]+(b>>>0<g>>>0)|0)|0;f=x[a+52>>2];j=x[a+104>>2];a=0;while(1){if((a|0)==(j|0)){break a}b=tf(f,a);g=b;h=x[b+8>>2];i=h+c|0;b=x[b+12>>2]+e|0;x[g+8>>2]=i;x[g+12>>2]=i>>>0<h>>>0?b+1|0:b;a=a+1|0;continue}}Mh(a,2,2048);break a}Mh(a,2,2048)}fb=d+32|0}function yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-112|0;fb=e;g=x[b+4>>2];h=y[b+11|0];a:{if(yd(g,h)){break a}f=y[qz(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+100|0;jx(f,b,0,Wc(g,h)-1|0);yb(b,f);tb(f)}g=e+100|0;de(g);f=x[e+100>>2];de(e+88|0);f=JM(f,x[e+92>>2],b);de(g);b:{c:{d:{e:{if((f|0)==x[e+104>>2]){if(ke(b,22485)){a=ac(8);x[31785]=0;S(1011,e+100|0,18453,c|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}nc(a,e+100|0);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(e+100|0);break c}if(!d){break e}a=ac(8);x[31785]=0;S(1011,e+76|0,18489,b|0);b=x[31785];x[31785]=0;f:{g:{h:{i:{j:{if((b|0)!=1){x[31785]=0;O(1022,e+88|0,e+76|0);b=x[31785];x[31785]=0;if((b|0)==1){break j}x[31785]=0;S(547,e+100|0,e+88|0,c|0);b=x[31785];x[31785]=0;d=1;if((b|0)==1){break i}nc(a,e+100|0);x[31785]=0;S(100,a|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(e+100|0);d=0;break h}b=N()|0;break f}b=N()|0;d=1;break g}b=N()|0}tb(e+88|0)}tb(e+76|0);if(!d){break c}}jc(a);break c}k:{switch(x[f+4>>2]){case 0:ue(e+68|0,b);b=fb-176|0;fb=b;f=b+12|0;Of(f,c);x[31785]=0;O(127,b+24|0,f|0);c=x[31785];x[31785]=0;l:{m:{n:{o:{p:{if((c|0)!=1){x[31785]=0;c=P(106,b+36|0,b+24|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break p}tb(b+24|0);tb(b+12|0);f=x[x[c>>2]-12>>2];x[31785]=0;g=ca(107)|0;h=x[31785];x[31785]=0;if((h|0)==1){break n}x[31785]=0;S(108,b+8|0,c+f|0,g|0);f=x[31785];x[31785]=0;if((f|0)==1){break n}Zb(b+8|0);x[31785]=0;f=P(128,c|0,b+24|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break n}c=pk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];Af(f);fb=b+176|0;b=(c^-1)&(g|0)!=0;break l}a=N()|0;break o}a=N()|0;tb(b+24|0)}tb(b+12|0);break m}a=N()|0;Af(c)}Q(a|0);p()}c=x[e+72>>2];x[e>>2]=x[e+68>>2];x[e+4>>2]=c;Hz(a,e,b,d);break e;case 1:ue(e+60|0,b);b=fb-176|0;fb=b;f=b+12|0;Of(f,c);x[31785]=0;O(127,b+24|0,f|0);c=x[31785];x[31785]=0;q:{r:{s:{t:{u:{if((c|0)!=1){x[31785]=0;c=P(106,b+36|0,b+24|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break u}tb(b+24|0);tb(b+12|0);f=x[x[c>>2]-12>>2];x[31785]=0;g=ca(107)|0;h=x[31785];x[31785]=0;if((h|0)==1){break s}x[31785]=0;S(108,b+8|0,c+f|0,g|0);f=x[31785];x[31785]=0;if((f|0)==1){break s}Zb(b+8|0);x[31785]=0;x[b+24>>2]=0;x[b+28>>2]=0;f=P(1138,c|0,b+24|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break s}c=pk(x[(f+x[x[f>>2]-12>>2]|0)+16>>2]);g=x[b+24>>2];h=x[b+28>>2];Af(f);fb=b+176|0;b=c?0:g;c=c?0:h;break q}a=N()|0;break t}a=N()|0;tb(b+24|0)}tb(b+12|0);break r}a=N()|0;Af(c)}Q(a|0);p()}f=x[e+64>>2];x[e+8>>2]=x[e+60>>2];x[e+12>>2]=f;Fz(a,e+8|0,b,c,d);break e;case 2:ue(e+52|0,b);i=MZ(c);b=x[e+56>>2];x[e+16>>2]=x[e+52>>2];x[e+20>>2]=b;Gz(a,e+16|0,i,d);break e;case 3:break k;default:break e}}ue(e+44|0,b);ue(e+32|0,c);b=x[e+48>>2];x[e+24>>2]=x[e+44>>2];x[e+28>>2]=b;Ez(a,e+24|0,x[e+32>>2],x[e+36>>2],d)}fb=e+112|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function CR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=E(0),m=E(0),n=0,o=0,p=0,q=0,r=0,s=0,t=E(0),u=0;if(b){zA(a);c=a+24596|0;x[c>>2]=0;x[c+4>>2]=0;x[a+24588>>2]=0;x[a+24592>>2]=0;HR(a)}BR(a+24648|0);o=x[a+24620>>2];f=fb-144|0;fb=f;d=!b;e=a+397456|0;c=x[e+4>>2];if(c>>>0>=29){x[e+4>>2]=0;c=0}g=D(c,44)+46224|0;if(!((g|0)==x[e+8>>2]&d)){x[e+8>>2]=g;m=E(o>>>0);c=f+12|0;d=x[g+24>>2];x[c>>2]=d;j=x[g+16>>2];x[c+4>>2]=j;x[c+8>>2]=x[g+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){h=j;j=k+600|0;x[c+4>>2]=h-j;x[c>>2]=d-j}i=E(B[g+36>>2]*E(79.30999755859375));a:{if(E(F(i))<E(2147483648)){d=~~i;break a}d=-2147483648}x[c+16>>2]=d- -8192;i=E(E(E(B[g+32>>2]*E(.0036000001709908247))+E(.15000000596046448))*E(32767));b:{if(E(F(i))<E(2147483648)){d=~~i;break b}d=-2147483648}x[c+20>>2]=(d|0)>=32512?32512:d;j=0;i=B[g+8>>2];l=B[g+20>>2];l=E((l>E(.10000000149011612)?E(.10000000149011612):l)*m);c:{if(E(F(l))<E(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)<=96?96:d;h=k-7500|0;n=k>>>0>=h>>>0?h:0;l=E(B[g+28>>2]*m);d:{if(E(F(l))<E(2147483648)){h=~~l;break d}h=-2147483648}d=n+(h+((d|0)<96?d-96|0:0)|0)|0;h=(d|0)<=128?128:d;p=h>>>0>=3800?3800:h;x[c+24>>2]=p;n=(d|0)<128?d-128|0:0;i=E(i*m);e:{if(E(F(i))<E(2147483648)){q=~~i;break e}q=-2147483648}d=h-3800|0;h=(q+n|0)+(d>>>0<=h>>>0?d:0)|0;x[c+32>>2]=h;n=k>>>0>=7500?7500:k;while(1){if((j|0)==8){i=E(h|0);l=E(Ce(E(.0010000000474974513),(h|0)<4721?E(1):E(E(4720)/i))*E(32768));f:{if(E(F(l))<E(2147483648)){d=~~l;break f}d=-2147483648}x[c+12>>2]=d;i=E(B[g+12>>2]*i);s=c,t=Ce(E(.0010000000474974513),i<=E(4720)?E(1):E(E(4720)/i)),B[s+28>>2]=t}else{d=D(j,12);k=d+c|0;w[k+42>>1]=z[d+47514>>1];w[k+36>>1]=z[d+47508>>1];w[k+40>>1]=z[d+47512>>1];w[k+38>>1]=z[d+47510>>1];x[k+44>>2]=n+((D(x[d+47504>>2],p)+50|0)/100|0);j=j+1|0;continue}break}x[e+20>>2]=x[f+44>>2];r=+m;c=xP(yP(x[f+20>>2]),r);w[e+86>>1]=c;w[e+84>>1]=c;c=z[f+28>>1]<<1;w[e+94>>1]=c;w[e+92>>1]=c;c=0;while(1){if((c|0)==8){x[e+49892>>2]=x[f+36>>2];c=x[f+16>>2];if((c|0)>-9e3){c=wP(c)}else{c=0}x[e+80>>2]=c;d=e+49948|0;c=x[f+12>>2];if((c|0)>=-8999){c=wP(c)}else{c=0}x[d>>2]=c;c=x[f+32>>2];d=e+49932|0;x[d>>2]=268464128;x[d+4>>2]=1879052288;c=c>>>0>=32512?32512:c;w[e+49906>>1]=c;w[e+49904>>1]=c;w[e+49902>>1]=c;w[e+49900>>1]=c;x[f+8>>2]=x[f+24>>2];Ee(f+8|0,0,32752);c=z[f+8>>1];w[e+49914>>1]=c;w[e+49910>>1]=0;w[e+49912>>1]=0;w[e+49908>>1]=c;m=B[f+40>>2];s=f,u=xP(+E(m*m),r),x[s+4>>2]=u;Ee(f+4|0,256,32512);c=z[f+4>>1];w[e+49922>>1]=c;w[e+49918>>1]=0;w[e+49920>>1]=0;w[e+49916>>1]=c}else{d=(c<<4)+e|0;g=(f+12|0)+D(c,12)|0;j=x[g+44>>2];x[d+100>>2]=j;x[d+104>>2]=j;w[d+108>>1]=z[g+36>>1];w[d+110>>1]=z[g+42>>1];w[d+112>>1]=z[g+40>>1];w[d+114>>1]=z[g+38>>1];c=c+1|0;continue}break}}if(b){x[e+16>>2]=0;AP(e,a+397448|0,a+397452|0)}b=D(o,5);if(b>>>0>A[e+20>>2]){x[e+20>>2]=b}fb=f+144|0;b=x[a+1298300>>2];if(xd(b)){qU(b,x[a+24620>>2])}}function coa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,B=0,C=0,D=0;h=fb-4128|0;fb=h;g=Cb(y[a+14|0]|y[a+15|0]<<8);a:{if(!g|g>>>0>20){break a}j=b+480190|0;if(z[j>>1]<=y[a+23|0]){break a}jd(d,32);w[d+34>>1]=1;f=h+12|0;g=a+20|0;x[f>>2]=g;x[f+4>>2]=(g+80|0)-g>>2;UV(h+4120|0,x[h+12>>2],x[h+16>>2],Cb(y[a+14|0]|y[a+15|0]<<8));g=x[h+4120>>2];i=y[wb(g,0)+3|0];x[h+12>>2]=1;i=x[_c(ri(b,i+1|0)+24|0,f)>>2];k=f;f=x[h+4124>>2];UV(k,g,f,c?f:1);C=h,D=vb(x[h+12>>2]),x[C+4108>>2]=D;q=1/+(i>>>0);f=fb-16|0;fb=f;i=x[zb(f+12|0,x[h+12>>2]+(x[h+16>>2]<<2)|0)>>2];fb=f+16|0;f=x[d>>2];k=x[h+4120>>2];j=z[j>>1];while(1){g=x[h+4108>>2];if(Ib(g,i)){l=y[g+3|0];b:{if(l>>>0>=j>>>0){break b}g=v[g+1|0];if((g|0)<0){break b}l=ri(b,l+1|0);n=x[l>>2];f=Xe(q*(zi(+(g-v[wb(k,0)+1|0]|0)/-12)*+(n>>>0)*+A[l+24>>2]))+f|0;x[d>>2]=f}Pe(h+4108|0);continue}else{c:{r=Bh(d);if(!r){break c}j=(e<<12>>>0)/1e4|0;f=x[h+4124>>2];e=fb-16|0;fb=e;i=h+4108|0;x[i>>2]=0;x[i+4>>2]=0;rc(i+8|0);Nd(e+8|0,x[zb(e+4|0,i)>>2]);d:{if(!f){break d}x[31785]=0;O(758,i|0,f|0);g=x[31785];x[31785]=0;if((g|0)!=1){x[31785]=0;GV(i,f);f=x[31785];x[31785]=0;if((f|0)!=1){break d}}a=N()|0;FV(e+8|0);Q(a|0);p()}f=e+8|0;Md(f);FV(f);fb=e+16|0;t=x[i>>2];l=x[h+4120>>2];u=x[h+4124>>2];B=b+480190|0;f=0;while(1){if((f|0)==(u|0)){g=b+24648|0}else{g=wb(l,f);e=TV(t,f);k=y[g+3|0];e:{if(k>>>0>=z[B>>1]){break e}o=v[g+1|0];if((o|0)<0){break e}n=0;g=y[g+2|0];if((g+14&255)>>>0<=5){n=y[g+25406|0]}k=ri(b,k+1|0);g=x[k+24>>2];s=q*(zi(+(n<<24>>24)/96+ +(o-v[wb(l,0)+1|0]|0)/12)*+(g>>>0));if(s<=0){break e}g=SV(s);x[e+8>>2]=g;n=hb;x[e+12>>2]=n;x[e+16>>2]=x[k+20>>2];o=x[k>>2];x[e+76>>2]=o;x[e+88>>2]=z[k+34>>1]&1023;f:{if(c){x[e+664>>2]=m;m=Xe(+(o>>>0)/eC(g,n))+m|0;g=j;break f}g=(j>>>0)/(Cb(y[a+14|0]|y[a+15|0]<<8)>>>0)|0}x[e+20>>2]=g;x[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){g:{a=x[d>>2];if(a>>>0>b>>>0){Tb(h+12|0,0,4096);x[h+8>>2]=512;x[h+4>>2]=a-b;c=x[Gb(h+8|0,h+4|0)>>2];C=h,D=vb(x[i>>2]),x[C+8>>2]=D;j=vb(x[i+4>>2]);while(1){a=x[h+8>>2];if(!Ib(a,j)){break g}h:{i:{if(!x[a+16>>2]){break i}e=x[a+664>>2];if(e>>>0>=c>>>0){x[a+664>>2]=e-c;break i}f=x[a+88>>2];x[h+4>>2]=c-e;C=h,D=Xe((+A[a+76>>2]-eC(x[a>>2],x[a+4>>2]))/eC(x[a+8>>2],x[a+12>>2])),x[C>>2]=D;m=x[Gb(h+4|0,h)>>2];x[31785]=0;V(x[((f&1|(f&64?18:16))<<2)+26e3>>2],a|0,g|0,(h+12|0)+(e<<3)|0,m|0);e=x[31785];x[31785]=0;if((e|0)==1){break h}x[a+664>>2]=0;if(A[a+76>>2]>A[a+4>>2]){break i}x[a+16>>2]=0}x[h+8>>2]=x[h+8>>2]+872;continue}break}a=N()|0;RV(i);Q(a|0);p()}RV(i);break c}e=x[d+20>>2]+(b<<1)|0;f=h+12|0;a=fb-16|0;fb=a;x[a+12>>2]=c;vc(a+12|0,512);m=x[a+12>>2];while(1){if(m){j=od(x[f>>2]+2048|0,12);j=(j|0)>=32767?32767:j;w[e>>1]=(j|0)<=-32768?-32768:j;f=f+8|0;e=e+2|0;m=m-1|0;continue}break}fb=a+16|0;b=b+c|0;continue}}f=(r|0)!=0}break}}fb=h+4128|0;return f|0}function mv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=x[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}e=x[a>>2];b=e+b|0;c:{a=a-e|0;if((a|0)!=x[31666]){if(e>>>0<=255){d=x[a+8>>2];c=x[a+12>>2];if((d|0)!=(c|0)){break c}i=126644,j=x[31661]&vua(-2,e>>>3|0),x[i>>2]=j;break b}h=x[a+24>>2];c=x[a+12>>2];d:{if((c|0)!=(a|0)){d=x[a+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break d}e:{e=a+20|0;d=x[e>>2];if(d){break e}e=a+16|0;d=x[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=x[e>>2];if(d){continue}e=c+16|0;d=x[c+16>>2];if(d){continue}break}x[g>>2]=0}if(!h){break b}e=x[a+28>>2];d=(e<<2)+126948|0;f:{if(x[d>>2]==(a|0)){x[d>>2]=c;if(c){break f}i=126648,j=x[31662]&vua(-2,e),x[i>>2]=j;break b}x[h+(x[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}x[c+24>>2]=h;d=x[a+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[a+20>>2];if(!d){break b}x[c+20>>2]=d;x[d+24>>2]=c;break b}c=x[f+4>>2];if((c&3)!=3){break b}x[31663]=b;x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[f>>2]=b;return}x[d+12>>2]=c;x[c+8>>2]=d}c=x[f+4>>2];g:{if(!(c&2)){if(x[31667]==(f|0)){x[31667]=a;b=x[31664]+b|0;x[31664]=b;x[a+4>>2]=b|1;if(x[31666]!=(a|0)){break a}x[31663]=0;x[31666]=0;return}if(x[31666]==(f|0)){x[31666]=a;b=x[31663]+b|0;x[31663]=b;x[a+4>>2]=b|1;x[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){c=c>>>3|0;e=x[f+12>>2];d=x[f+8>>2];if((e|0)==(d|0)){i=126644,j=x[31661]&vua(-2,c),x[i>>2]=j;break h}x[d+12>>2]=e;x[e+8>>2]=d;break h}h=x[f+24>>2];c=x[f+12>>2];i:{if((f|0)!=(c|0)){d=x[f+8>>2];x[d+12>>2]=c;x[c+8>>2]=d;break i}j:{d=f+20|0;e=x[d>>2];if(e){break j}d=f+16|0;e=x[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=x[d>>2];if(e){continue}d=c+16|0;e=x[c+16>>2];if(e){continue}break}x[g>>2]=0}if(!h){break h}e=x[f+28>>2];d=(e<<2)+126948|0;k:{if(x[d>>2]==(f|0)){x[d>>2]=c;if(c){break k}i=126648,j=x[31662]&vua(-2,e),x[i>>2]=j;break h}x[h+(x[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}x[c+24>>2]=h;d=x[f+16>>2];if(d){x[c+16>>2]=d;x[d+24>>2]=c}d=x[f+20>>2];if(!d){break h}x[c+20>>2]=d;x[d+24>>2]=c}x[a+4>>2]=b|1;x[a+b>>2]=b;if(x[31666]!=(a|0)){break g}x[31663]=b;return}x[f+4>>2]=c&-2;x[a+4>>2]=b|1;x[a+b>>2]=b}if(b>>>0<=255){c=(b&-8)+126684|0;d=x[31661];b=1<<(b>>>3);l:{if(!(d&b)){x[31661]=b|d;b=c;break l}b=x[c+8>>2]}x[c+8>>2]=a;x[b+12>>2]=a;x[a+12>>2]=c;x[a+8>>2]=b;return}e=31;if(b>>>0<=16777215){c=G(b>>>8|0);e=((b>>>38-c&1)-(c<<1)|0)+62|0}x[a+28>>2]=e;x[a+16>>2]=0;x[a+20>>2]=0;g=(e<<2)+126948|0;m:{d=x[31662];c=1<<e;n:{if(!(d&c)){x[31662]=c|d;x[g>>2]=a;x[a+24>>2]=g;break n}e=b<<((e|0)!=31?25-(e>>>1|0)|0:0);c=x[g>>2];while(1){d=c;if((x[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=x[g+16>>2];if(c){continue}break}x[g+16>>2]=a;x[a+24>>2]=d}x[a+12>>2]=a;x[a+8>>2]=a;return}b=x[d+8>>2];x[b+12>>2]=a;x[d+8>>2]=a;x[a+24>>2]=0;x[a+12>>2]=d;x[a+8>>2]=b}}function fZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-128|0;fb=g;i=lg(g+116|0);a:{b:{c:{if(d){x[31785]=0;S(486,a|0,i|0,c|0);c=x[31785];x[31785]=0;if((c|0)!=1){break c}break b}x[31785]=0;S(487,a|0,i|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}}k=Nb(g+104|0);m=b+480192|0;n=b+1298472|0;c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=c&65535;if(h>>>0<=z[m>>1]){x[31785]=0;w[g+102>>1]=0;O(488,a|0,g+102|0);d=x[31785];x[31785]=0;t:{u:{v:{w:{if((d|0)!=1){j=fb-16|0;fb=j;o=z[g+102>>1];d=$d(i);e=ec(i);f=fb-16|0;fb=f;while(1){if(d){l=To(z[d+16>>1],o);e=l?e:d;d=x[(l?d+4|0:d)>>2];continue}break}d=x[zb(f+12|0,e)>>2];fb=f+16|0;x:{if(Ib(d,mg(i))){if(!To(z[g+102>>1],z[qd(d)>>1])){break x}}d=mg(i)}d=zb(j+12|0,d);fb=j+16|0;j=((h<<2)+b|0)+900380|0;if(!x[j>>2]){break d}d=x[d>>2];if(!Vg(d,Jf(i))){break u}x[31785]=0;d=P(3,g+88|0,qd(d)+4|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break t}x[31785]=0;e=P(1,g+76|0,16988)|0;f=x[31785];x[31785]=0;if((f|0)==1){break v}f=Vq(d,e);tb(e);if(f){break p}e=x[b+4>>2];x[31785]=0;e=P(489,e|0,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break r}x[x[j>>2]+44>>2]=e;if(!x[x[j>>2]+44>>2]){break w}break e}c=N()|0;break f}x[31785]=0;e=P(1,g- -64|0,13521)|0;f=x[31785];x[31785]=0;y:{z:{A:{if((f|0)!=1){B:{if(!Vq(d,e)){x[31785]=0;f=P(1,g+52|0,13726)|0;h=x[31785];x[31785]=0;if((h|0)==1){break A}h=Vq(d,f);tb(f);tb(e);if(h){break B}break s}tb(e)}x[31785]=0;e=R(490,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break z}x[g+36>>2]=e;e=x[b+4>>2];f=x[oe(g+48|0,g+36|0)>>2];x[31785]=0;e=P(491,e|0,f|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break y}Ig(g+36|0);if(e){break e}break s}c=N()|0;break g}c=N()|0;tb(e);break g}c=N()|0;break g}c=N()|0;Ig(g+36|0);break g}c=N()|0;break g}d=x[j>>2];if(!d){break d}x[d+44>>2]=0;break d}c=N()|0;break f}Pd(k);dZ(i);fb=g+128|0;return}e=vb(x[k>>2]);h=vb(x[k+4>>2]);f=fb-16|0;fb=f;x[f+12>>2]=e;while(1){C:{if(!Ib(e,h)){break C}if(Vq(e,d)){break C}e=x[Uq(f+12|0)>>2];continue}break}fb=f+16|0;if(Ib(e,vb(x[k+4>>2]))){break p}x[31785]=0;O(492,k|0,d|0);e=x[31785];x[31785]=0;if((e|0)!=1){break q}}c=N()|0;break g}x[31785]=0;e=P(1,g+12|0,17705)|0;f=x[31785];x[31785]=0;if((f|0)==1){break o}x[31785]=0;S(493,g+24|0,e|0,d|0);f=x[31785];x[31785]=0;if((f|0)==1){break n}x[31785]=0;f=P(1,g|0,16541)|0;h=x[31785];x[31785]=0;if((h|0)==1){break m}x[31785]=0;S(2,g+36|0,g+24|0,f|0);h=x[31785];x[31785]=0;if((h|0)==1){break l}h=x[n>>2];x[31785]=0;S(389,h|0,2,g+36|0);h=x[31785];x[31785]=0;if((h|0)==1){break k}tb(g+36|0);tb(f);tb(g+24|0);tb(e)}x[x[j>>2]+44>>2]=0;break e}c=N()|0;break g}c=N()|0;break h}c=N()|0;break i}c=N()|0;break j}c=N()|0;tb(g+36|0)}tb(f)}tb(g+24|0)}tb(e)}tb(d)}Pd(k);break a}tb(d)}c=c+1|0;continue}}c=N()|0}dZ(i);Q(c|0);p()}function U0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,w=0;e=fb-32|0;fb=e;a:{if((d|0)<=0){break a}x[e+8>>2]=d;x[e+20>>2]=b;x[e+16>>2]=214748364;u=e,w=D(x[Gb(e+20|0,e+16|0)>>2],20),x[u+24>>2]=w;ko(c,x[Gb(e+8|0,e+24|0)>>2]);x[e+12>>2]=b;x[e+8>>2]=a;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}g=Fh(a,b,i);h=Fh(a,b,i+4|0);f=Fh(a,b,i+5|0);u=e,w=Fh(a,b,i+6|0)<<8|Fh(a,b,i+7|0),x[u+28>>2]=w;n=f|h<<8;t=i+8|0;f:{g:{switch(g|0){case 0:i=0;if(d>>>0<n>>>0){i=ac(8);x[31785]=0;a=R(191,i|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break f}break d}while(1){if((i|0)!=(n|0)){u=e,w=Fh(a,b,i+t|0),v[u+24|0]=w;jo(c,e+24|0);i=i+1|0;continue}break};s=n;break b;case 1:break g;default:break e}}xi(e+28|0,d);s=x[e+28>>2];o=Fh(a,b,i+10|0);v[e+24|0]=o;jo(c,e+24|0);j=i+11|0;n=n+3&65532;i=s-1|0;h=0;l=0;q=0;m=0;while(1){if((i|0)<=0){break c}f=Lg(j,h,1,e+8|0);h:{i:{j:{k:{l:{if((l|0)<=7){if(f){g=h;break i}g=h+1|0;m=8;break l}g=h+1|0;m:{if(!f){if(!Lg(j,g,1,e+8|0)){break i}k=2;n:{o:{f=h+2|0;if(!Lg(j,f,1,e+8|0)){break o}k=3;f=h+3|0;if(!Lg(j,f,1,e+8|0)){break o}k=Lg(j,f,3,e+8|0);g=h+6|0;break n}g=f+1|0}f=4;p:{q:{r:{h=((m<<3)+k|0)-17|0;s:{if((h|0)<0){a=ac(8);x[31785]=0;b=R(191,a|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break r}break s}if(h>>>0<56){break p}a=ac(8);x[31785]=0;b=R(191,a|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break q}}b=N()|0;jc(a);Q(b|0);p()}da(b|0,24664,165);p()}da(b|0,24664,165);p()}m=y[h+24704|0];if((m|0)!=8){break k}break m}f=4;if((m|0)!=8){break k}}m=8;f=1;if((q|0)>19){break k}}f=0;break j}q=q+8|0}while(1){if(!((f|0)<0|(i|0)<=0)){k=(g|0)/8|0;h=k+j|0;r=Fh(x[e+8>>2],x[e+12>>2],h);o=o-od((Fh(x[e+8>>2],x[e+12>>2],h+1|0)<<8|r<<16|Fh(x[e+8>>2],x[e+12>>2],h+2|0))<<(g-(k<<3)|0)+8,32-m|0)|0;v[e+24|0]=o;jo(c,e+24|0);f=f-1|0;i=i-1|0;g=g+m|0;continue}break}l=(l|0)==31?31:l+1|0;h=g;break h}t:{u:{v:{f=g+1|0;if(!Lg(j,f,1,e+8|0)){h=2;break v}f=g+2|0;if(!Lg(j,f,1,e+8|0)){h=4;break v}f=g+3|0;if(!Lg(j,f,1,e+8|0)){h=6;break v}f=g+5|0;if(!Lg(j,g+4|0,1,e+8|0)){g=g+8|0;f=Lg(j,f,3,e+8|0)+8|0;break t}g=g+10|0;h=16;f=Lg(j,f,5,e+8|0);break u}g=f+2|0;f=Lg(j,f+1|0,1,e+8|0)}f=f+h|0}w:{if(Lg(j,g,1,e+8|0)){k=-256;h=12;break w}g=g+1|0;h=Lg(j,g,1,e+8|0);k=h?-4352:0;h=h?14:8}r=g+1|0;g=Lg(j,r,h,e+8|0);if(f>>>0>=3){l=l-((f|0)!=3)|0;l=((l|0)<=1?1:l)-1|0}k=(g^-1)+k|0;g=Sc(x[c>>2],x[c+4>>2])+k|0;if(g>>>0<k>>>0){h=h+r|0;while(1){if((f|0)<=0|(i|0)<=0){break h}o=y[xb(x[c>>2],g)|0];v[e+24|0]=o;jo(c,e+24|0);i=i-1|0;g=g+1|0;f=f-1|0;continue}}i=ac(8);x[31785]=0;a=R(191,i|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break d}da(a|0,24664,165);p()}q=q-(q>>3)|0;continue}}da(a|0,24664,165);p()}i=mc(x[c>>2],x[c+4>>2])^1;break a}a=N()|0;jc(i);Q(a|0);p()}x[e+28>>2]=i}d=d-s|0;i=n+t|0;continue}}fb=e+32|0;return i|0}function Cna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-32|0;fb=j;a:{b:{if(Pu(a)>>>0<b>>>0){if((b|0)<0){break b}n=Mo(j+20|0);x[31785]=0;O(766,n|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}fn(j+12|0,x[a>>2]);Mq(j+4|0,x[a>>2],x[a+4>>2]);m=fb-48|0;fb=m;d=x[n+4>>2];c=gc(m+40|0,x[j+12>>2],x[j+16>>2]);e=gc(m+32|0,x[j+4>>2],x[j+8>>2]);b=fb-16|0;fb=b;c=gc(b+8|0,x[c>>2],x[c+4>>2]);e=gc(b,x[e>>2],x[e+4>>2]);c=SW(x[c>>2],x[c+4>>2],x[e>>2],x[e+4>>2]);fb=b+16|0;c=c+d|0;x[n+4>>2]=c;c:{d:{if(!d){b=c-1|0;break d}b=c-1|0;if((b^d-1)>>>0<32){break c}}x[x[n>>2]+((c>>>0>=33?b>>>5|0:0)<<2)>>2]=0}e=gc(m+24|0,x[j+12>>2],x[j+16>>2]);c=gc(m+16|0,x[j+4>>2],x[j+8>>2]);b=m+8|0;op(b,x[n>>2],d);d=x[e>>2];o=fb-48|0;fb=o;e=x[e+4>>2];e:{if((e|0)==x[b+4>>2]){e=gc(o+40|0,d,e);c=gc(o+32|0,x[c>>2],x[c+4>>2]);b=gc(o+24|0,x[b>>2],x[b+4>>2]);d=fb-16|0;fb=d;f=x[e>>2];g=x[e+4>>2];c=dn(x[c>>2],x[c+4>>2],f,g);x[d+12>>2]=c;f:{if((c|0)<=0){c=x[b>>2];break f}if(g){i=32-g|0;x[d+8>>2]=i;k=c;c=x[pd(d+8|0,d+12|0)>>2];x[d+12>>2]=k-c;h=x[b>>2];g=-1<<g&-1>>>i-c;x[h>>2]=x[h>>2]&(g^-1)|g&x[f>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;x[b>>2]=h+(c>>>3&536870908);f=x[e>>2]+4|0;x[e>>2]=f;c=x[d+12>>2]}k=f;f=(c|0)/32|0;NC(k,f,x[b>>2]);g=c-(f<<5)|0;x[d+12>>2]=g;f=f<<2;c=f+x[b>>2]|0;x[b>>2]=c;if((g|0)<=0){break f}c=e;e=f+x[e>>2]|0;x[c>>2]=e;c=x[b>>2];f=-1>>>32-g|0;x[c>>2]=x[c>>2]&(f^-1)|f&x[e>>2];x[b+4>>2]=x[d+12>>2]}gc(m,c,x[b+4>>2]);fb=d+16|0;break e}g=gc(o+16|0,d,e);d=gc(o+8|0,x[c>>2],x[c+4>>2]);f=gc(o,x[b>>2],x[b+4>>2]);e=fb-16|0;fb=e;c=x[d>>2];k=x[d+4>>2];b=x[g>>2];d=x[g+4>>2];c=dn(c,k,b,d);x[e+12>>2]=c;g:{if((c|0)<=0){d=x[f+4>>2];break g}h:{if(!d){d=x[f+4>>2];break h}l=32-d|0;x[e+8>>2]=l;i=e+8|0;h=x[pd(i,e+12|0)>>2];x[e+12>>2]=c-h;c=x[f+4>>2];q=x[b>>2];x[e+8>>2]=h;k=32-c|0;x[e+4>>2]=k;b=x[f>>2];r=x[b>>2];i=x[Gb(i,e+4|0)>>2];l=q&(-1<<d&-1>>>l-h);x[b>>2]=(-1<<c&-1>>>k-i^-1)&r|(c>>>0>d>>>0?l<<c-d:l>>>d-c|0);c=c+i|0;d=c&31;x[f+4>>2]=d;c=b+(c>>>3&536870908)|0;x[f>>2]=c;b=h-i|0;if((b|0)>0){x[c>>2]=x[c>>2]&(-1>>>32-b^-1)|l>>>i+x[g+4>>2];x[f+4>>2]=b;d=b}b=x[g>>2]+4|0;x[g>>2]=b;c=x[e+12>>2]}h=32-d|0;i=-1<<d;l=i^-1;while(1){if((c|0)>=32){c=x[f>>2];b=x[b>>2];x[c>>2]=l&x[c>>2]|b<<d;x[f>>2]=c+4;x[c+4>>2]=i&x[c+4>>2]|b>>>h;c=x[e+12>>2]-32|0;x[e+12>>2]=c;b=x[g>>2]+4|0;x[g>>2]=b;continue}break}if((c|0)<=0){break g}l=x[b>>2];x[e+8>>2]=h;g=x[f>>2];b=x[g>>2];k=b;b=x[pd(e+12|0,e+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-c;x[g>>2]=k|h<<d;c=b+d|0;d=c&31;x[f+4>>2]=d;c=g+(c>>>3&536870908)|0;x[f>>2]=c;g=x[e+12>>2]-b|0;x[e+12>>2]=g;if((g|0)<=0){break g}x[c>>2]=x[c>>2]&(-1>>>32-g^-1)|h>>>b;d=x[e+12>>2];x[f+4>>2]=d}gc(m,x[f>>2],d);fb=e+16|0}fb=o+48|0;fb=m+48|0;YB(a,n);$e(n)}fb=j+32|0;return}cd();p()}a=N()|0;$e(n);Q(a|0);p()}function $0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=fb-144|0;fb=d;xc(b);zp(a);a:{if(!Pw(b,d+108|0)){break a}if(!OF(d+108|0)){break a}j=x[b+8>>2];b:{if(!bd(b,y[d+124|0]|y[d+125|0]<<8|(y[d+126|0]<<16|y[d+127|0]<<24))){break b}while(1){c:{if((y[d+120|0]|y[d+121|0]<<8|(y[d+122|0]<<16|y[d+123|0]<<24))>>>0>h>>>0){if(Mb(x[b>>2],x[b+8>>2],5)){break c}}f=i&1;break b}f=0;g=1;d:{if((y[d+112|0]|y[d+113|0]<<8)>>>0>=64){if((Ni(b)|0)<=0){break d}}while(1){l=be(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(xq(l<<24>>24)&255)==y[f+13186|0]}g=e;f=f+1|0;continue}break}Yb(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}bd(b,j);if(!f){break a}if(!Mb(x[b>>2],x[b+8>>2],MF(d+108|0))){break a}if(!c){k=1;break a}g=fb-16|0;fb=g;e=d+108|0;bd(b,y[e+16|0]|y[e+17|0]<<8|(y[e+18|0]<<16|y[e+19|0]<<24));i=d+96|0;f=Nb(i);c=y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24);x[31785]=0;O(179,f|0,c|0);c=x[31785];x[31785]=0;e:{f:{g:{if((c|0)!=1){c=0;h:{i:{while(1){if((y[e+12|0]|y[e+13|0]<<8|(y[e+14|0]<<16|y[e+15|0]<<24))>>>0<=c>>>0){break h}h=x[b+8>>2];j=x[b>>2];x[31785]=0;h=U(153,j|0,h|0,5)|0;j=x[31785];x[31785]=0;if((j|0)==1){break g}if(!h){break h}h=y[e+4|0]|y[e+5|0]<<8;x[31785]=0;S(180,g+4|0,b|0,h|0);h=x[31785];x[31785]=0;if((h|0)!=1){x[31785]=0;O(181,f|0,g+4|0);h=x[31785];x[31785]=0;if((h|0)==1){break i}c=c+1|0;tb(g+4|0);continue}break}c=N()|0;break f}c=N()|0;tb(g+4|0);break f}fb=g+16|0;break e}c=N()|0;break f}c=N()|0}Pd(f);Q(c|0);p()}x[31785]=0;V(173,d+84|0,b|0,e|0,i|0);c=x[31785];x[31785]=0;j:{if((c|0)!=1){x[31785]=0;P(152,b|0,y[d+132|0]|y[d+133|0]<<8|(y[d+134|0]<<16|y[d+135|0]<<24))|0;c=x[31785];x[31785]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if((y[d+128|0]|y[d+129|0]<<8|(y[d+130|0]<<16|y[d+131|0]<<24))>>>0>k>>>0){c=x[b+8>>2];e=x[b>>2];x[31785]=0;c=U(153,e|0,c|0,8)|0;e=x[31785];x[31785]=0;if((e|0)==1){break q}if(c){break p}}k=mc(x[a>>2],x[a+4>>2])^1;sc(d+84|0);Pd(d+96|0);break a}b=N()|0;break k}x[31785]=0;aa(174,d+60|0,b|0,d+108|0,d+84|0,d+96|0);c=x[31785];x[31785]=0;if((c|0)!=1){e=Bp(d+60|0);x[31785]=0;c=R(175,x[d+60>>2])|0;f=x[31785];x[31785]=0;if((f|0)==1){break o}if(c){x[31785]=0;c=R(176,d+24|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break n}e=x[e>>2];r:{if((e|0)<0){break r}f=x[d+96>>2];if(Qd(f,x[d+100>>2])>>>0<=e>>>0){break r}x[31785]=0;O(177,d+12|0,Dd(f,e)|0);e=x[31785];x[31785]=0;if((e|0)==1){break m}e=d+12|0;yb(c,e);tb(e)}Nw(g,d+60|0);x[31785]=0;O(178,a|0,c|0);e=x[31785];x[31785]=0;if((e|0)==1){break m}Rr(c)}k=k+1|0;ub(d+60|0);continue}break}b=N()|0;break k}b=N()|0;break l}b=N()|0;break l}b=N()|0;Rr(c)}ub(d+60|0);break k}b=N()|0}sc(d+84|0);break j}b=N()|0}Pd(d+96|0);Q(b|0);p()}fb=d+144|0;return k|0}function rG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-144|0;fb=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)<=5){_w(d+108|0,b);x[31785]=0;b=P(1,d+96|0,18589)|0;e=x[31785];x[31785]=0;if((e|0)==1){break E}x[31785]=0;S(2,d+120|0,d+108|0,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break D}x[31785]=0;c=P(3,d+72|0,c|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break C}x[31785]=0;e=P(1,d+60|0,20417)|0;f=x[31785];x[31785]=0;if((f|0)==1){break B}x[31785]=0;S(4,d+84|0,c|0,e|0);f=x[31785];x[31785]=0;if((f|0)==1){break A}x[31785]=0;S(2,d+132|0,d+120|0,d+84|0);f=x[31785];x[31785]=0;if((f|0)==1){break z}tb(d+84|0);tb(e);tb(c);c=d+120|0;tb(c);tb(b);tb(d+108|0);b=x[a>>2];x[31785]=0;O(5,c|0,(b?b:22485)|0);b=x[31785];x[31785]=0;if((b|0)==1){break t}b=x[a+4>>2];x[31785]=0;O(5,d+108|0,(b?b:22485)|0);b=x[31785];x[31785]=0;if((b|0)==1){break s}a=x[a+8>>2];x[31785]=0;x[d+48>>2]=a;O(6,d+84|0,d+48|0);a=x[31785];x[31785]=0;if((a|0)==1){break r}x[31785]=0;P(7,499800,18468)|0;a=x[31785];x[31785]=0;if((a|0)==1){break q}x[31785]=0;O(8,d+48|0,d+120|0);a=x[31785];x[31785]=0;if((a|0)==1){break p}x[31785]=0;P(9,499800,d+48|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break o}x[31785]=0;P(7,499800,17665)|0;a=x[31785];x[31785]=0;if((a|0)==1){break o}x[31785]=0;O(8,d+36|0,d+84|0);a=x[31785];x[31785]=0;if((a|0)==1){break n}x[31785]=0;P(9,499800,d+36|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break m}x[31785]=0;P(7,499800,17663)|0;a=x[31785];x[31785]=0;if((a|0)==1){break m}x[31785]=0;P(7,499800,18589)|0;a=x[31785];x[31785]=0;if((a|0)==1){break m}x[31785]=0;O(8,d+24|0,d+132|0);a=x[31785];x[31785]=0;if((a|0)==1){break l}x[31785]=0;P(9,499800,d+24|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break k}x[31785]=0;P(7,499800,13547)|0;a=x[31785];x[31785]=0;if((a|0)==1){break k}x[31785]=0;O(8,d+12|0,d+108|0);a=x[31785];x[31785]=0;if((a|0)==1){break j}x[31785]=0;P(9,499800,d+12|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break i}x[31785]=0;P(7,499800,13545)|0;a=x[31785];x[31785]=0;if((a|0)==1){break i}x[31785]=0;R(10,499800)|0;a=x[31785];x[31785]=0;if((a|0)==1){break i}tb(d+12|0);tb(d+24|0);tb(d+36|0);tb(d+48|0);tb(d+84|0);tb(d+108|0);tb(d+120|0);tb(d+132|0)}fb=d+144|0;return}a=N()|0;break u}a=N()|0;break v}a=N()|0;break w}a=N()|0;break x}a=N()|0;break y}a=N()|0;tb(d+84|0)}tb(e)}tb(c)}tb(d+120|0)}tb(b)}tb(d+108|0);break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break e}a=N()|0;break f}a=N()|0;break f}a=N()|0;break g}a=N()|0;break g}a=N()|0;break h}a=N()|0;break h}a=N()|0;tb(d+12|0)}tb(d+24|0)}tb(d+36|0)}tb(d+48|0)}tb(d+84|0)}tb(d+108|0)}tb(d+120|0)}tb(d+132|0)}Q(a|0);p()}function FP(a){var b=E(0),c=E(0),d=0,e=E(0),f=E(0),g=0,h=0,i=E(0),k=0,m=E(0),p=E(0),s=E(0),t=0,u=0,v=E(0),w=E(0);d=a+4208|0;nB(wb(d,0),B[a+4272>>2]);b=E(E(B[wb(d,0)>>2]*E(15920))+E(80));s=Ce(E(10),E(E(E(B[wb(d,2)>>2]+E(-.5))*E(30))/E(40)));c=E(E(b/E(A[x[a+16>>2]+24620>>2]))*E(6.2831854820251465));b=WP(c);v=iq(c);w=b;f=E(E(c*E(E(E(B[wb(d,1)>>2]*E(35))+E(1))*E(.02888113260269165)))/b);m=(l(2,(q(f),j(2))&-2147483648|1056964608),r());c=E(F(f));k=(q(f),j(2))&2147483647;a:{if(k>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(q(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=E(-1);if((h|0)<0){break b}if(d>>>0<1118925336){break g}b=E(c*E(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=E(905800061445916e-20);b=E(c+E(-.6931381225585938));break f}d=-1;e=E(-905800061445916e-20);b=E(c+E(.6931381225585938));break f}b=E(E(c*E(1.4426950216293335))+(l(2,(q(c),j(2))&-2147483648|1056964608),r()));h:{if(E(F(b))<E(2147483648)){d=~~b;break h}d=-2147483648}b=E(d|0);e=E(b*E(905800061445916e-20));b=E(c+E(b*E(-.6931381225585938)))}c=E(b-e);e=E(E(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=E(c*E(.5));i=E(c*b);p=E(E(i*E(E(i*E(.0015807170420885086))+E(-.03333321213722229)))+E(1));b=E(E(3)-E(p*b));p=E(i*E(E(p-b)/E(E(6)-E(c*b))));b=E(c-E(E(c*p)-i));if(!d){break b}e=E(E(E(c*E(p-e))-e)-i);i:{switch(d+1|0){case 0:b=E(E(E(c-e)*E(.5))+E(-.5));break b;case 2:b=E(E(e-E(c+E(.5)))*E(-2));if(c<E(-.25)){break b}b=E(c-e);b=E(E(b+b)+E(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),r());if(d>>>0>=57){c=E(E(c-e)+E(1));b=E(((d|0)==128?E(E(c+c)*E(17014118346046923e22)):E(c*b))+E(-1));break b}i=(l(2,1065353216-h|0),r());c=E((d>>>0<=22?E(E(E(1)-i)+E(c-e)):E(E(c-E(e+i))+E(1)))*b)}b=c}if(k>>>0<=1065353215){if(k>>>0<964689920){break a}f=E(m*E(E(b+b)-E(E(b*b)/E(b+E(1)))));break a}f=E(m*E(b+E(b/E(b+E(1)))));break a}m=E(E(m+m)*E(1661534994731145e20));b=E(c+E(-162.88958740234375));d=Ty(b)&2047;j:{k:{if(Ty(E(88))>>>0>d>>>0){break k}c=E(0);if(((q(b),j(2))|0)==-8388608){break j}c=E(b+b);if(Ty(E(Infinity))>>>0<=d>>>0){break j}if(b>E(88.72283172607422)){c=HF(0);break j}if(!(b<E(-103.97207641601562))){break k}c=qF(0);break j}g=C[165]*+b;t=C[164];u=g+t;g=g-(u-t);g=(C[166]*g+C[167])*(g*g)+(C[168]*g+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;k=x[d>>2];d=x[d+4>>2]+h|0;l(0,k|0);l(1,(k>>>0<k>>>0?d+1|0:d)|0);c=E(g*+n())}f=E(E(m*c)*E(1661534994731145e20))}c=E(w*f);f=E(c/s);b=E(f+E(1));B[a+4236>>2]=E(E(1)-f)/b;f=E(E(v*E(-2))/b);B[a+4232>>2]=f;c=E(c*s);B[a+4228>>2]=E(E(1)-c)/b;B[a+4224>>2]=f;B[a+4220>>2]=E(c+E(1))/b}function Fz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=fb-144|0;fb=f;x[f+136>>2]=c;x[f+140>>2]=d;g=x[b+4>>2];a:{if(!g){break a}h=x[b>>2];i=y[xl(h,g)|0];if((i|0)==33){e=1}else{if((i|0)!=63){break a}e=0}Jl(f+112|0,h,g,g-1|0);g=x[f+116>>2];x[b>>2]=x[f+112>>2];x[b+4>>2]=g}g=f+112|0;de(g);h=x[f+112>>2];de(f+100|0);i=wl(h,x[f+104>>2],b);de(g);g=x[b+4>>2];h=x[b>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==x[f+116>>2]){a=pc(f+128|0,22485);c=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=c;if(Oc(h,g,f+8|0)){a=ac(8);x[31785]=0;O(1015,f+100|0,f+136|0);b=x[31785];x[31785]=0;if((b|0)==1){break g}x[31785]=0;S(1020,f+112|0,18453,f+100|0);b=x[31785];x[31785]=0;if((b|0)==1){break f}nc(a,f+112|0);e=0;x[31785]=0;S(100,a|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(f+112|0);break e}if(!e){break h}a=ac(8);c=x[b>>2];b=x[b+4>>2];x[31785]=0;c=di(f+76|0,c,b);b=x[31785];x[31785]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){x[31785]=0;S(1020,f+88|0,18489,c|0);b=x[31785];x[31785]=0;if((b|0)==1){break p}x[31785]=0;O(1022,f+100|0,f+88|0);b=x[31785];x[31785]=0;e=1;if((b|0)==1){break o}x[31785]=0;O(1015,f- -64|0,f+136|0);b=x[31785];x[31785]=0;if((b|0)==1){break n}x[31785]=0;S(1024,f+112|0,f+100|0,f- -64|0);b=x[31785];x[31785]=0;if((b|0)==1){break m}nc(a,f+112|0);x[31785]=0;S(100,a|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(f+112|0);e=0;break l}b=N()|0;break d}b=N()|0;e=1;break i}b=N()|0;break j}b=N()|0;break k}b=N()|0}tb(f- -64|0)}tb(f+100|0)}tb(f+88|0)}tb(c);if(e){break d}break c}b=pc(f+56|0,22485);e=x[b+4>>2];x[f+32>>2]=x[b>>2];x[f+36>>2]=e;if(Oc(h,g,f+32|0)){a=ac(8);x[31785]=0;O(1015,f+100|0,f+136|0);b=x[31785];x[31785]=0;q:{r:{if((b|0)!=1){x[31785]=0;S(1020,f+112|0,18453,f+100|0);b=x[31785];x[31785]=0;if((b|0)==1){break r}nc(a,f+112|0);e=0;x[31785]=0;S(100,a|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(f+112|0);break q}b=N()|0;break d}b=N()|0;e=1}tb(f+100|0);if(e){break d}break c}b=pc(f+48|0,10984);e=x[b+4>>2];x[f+24>>2]=x[b>>2];x[f+28>>2]=e;if(Oc(h,g,f+24|0)){Cz(a,Fc(c,d));break h}b=pc(f+40|0,8647);e=x[b+4>>2];x[f+16>>2]=x[b>>2];x[f+20>>2]=e;if(!Oc(h,g,f+16|0)){break h}a=x[a+32>>2];b=Au(c,d);b=b>>>0>=4?1:b;c=fb-16|0;fb=c;s:{if((uk(y[a+140|0])|0)==(b|0)){d=a+120|0;Jt(y[d+20|0]);b=fb-16|0;fb=b;x[b+12>>2]=c+15;a=fb-16|0;fb=a;e=x[19939];x[a+8>>2]=x[19938];x[a+12>>2]=e;e=x[19937];x[a>>2]=x[19936];x[a+4>>2]=e;ib[x[bq(a,uk(y[d+20|0]))>>2]](b+12|0,d);fb=a+16|0;fb=b+16|0;break s}GM(a,b,HM(a))}fb=c+16|0}fb=f+144|0;return}b=N()|0;break d}b=N()|0;e=1}tb(f+100|0);if(!e){break c}}jc(a)}Q(b|0)}p()}function A8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-336|0;fb=d;e=fb-16|0;fb=e;x[a+4>>2]=0;v[a|0]=0;f=a+40|0;ko(f,32);v[e+15|0]=0;jo(f,e+15|0);fb=e+16|0;e=x[a+36>>2];a:{if(x[(x[x[e>>2]-12>>2]+e|0)+16>>2]){Mh(a,2,16777216);break a}Yd(d+72|0,e);e=x[d+84>>2];x[a+16>>2]=x[d+80>>2];x[a+20>>2]=e;x[d+72>>2]=3;f=x[a+36>>2];e=0;while(1){if(A[d+72>>2]>e>>>0){Hi(f,d+e|0);e=e+1|0;continue}break}if(Ob(d,24568,3)){Mh(a,2,512);break a}v[d+335|0]=0;Hi(x[a+36>>2],d+335|0);Tb(d+72|0,0,256);e=y[d+335|0];if(e){zj(x[a+36>>2],d+72|0,e)}f=b;b=ol(d,d+72|0,e);e=zy(f,b);Eb(b);if(!e){Mh(a,2,4096)}if(ml(y[a|0])){break a}Hi(x[a+36>>2],d+71|0);b=y[d+71|0];e=b&3;w[a+24>>1]=(e|0)==3?4:e;if(tj(b,6)){Pc(d,a+32|0,9);Df(d,1)}x[d+64>>2]=0;fK(x[a+36>>2],d- -64|0);e=x[d+64>>2];v[d+63|0]=0;if(e>>>0>=2){Hi(x[a+36>>2],d+71|0);f=-1;if(!y[d+71|0]){Hi(x[a+36>>2],d+63|0);f=-2}Km(x[a+36>>2],e+f|0)}x[d+48>>2]=0;x[d+52>>2]=0;b:{if(!tj(b,4)){break b}ll(x[a+36>>2],d+48|0);e=x[d+52>>2];f=x[d+48>>2];x[a+64>>2]=f;x[a+68>>2]=e;g=x[c+4>>2];if((g|0)==(e|0)&A[c>>2]>=f>>>0|e>>>0<g>>>0){break b}Mh(a,1,4)}if(tj(b,5)){Hi(x[a+36>>2],d+71|0);Km(x[a+36>>2],y[d+71|0])}c=y[d+63|0];c:{if(!tj(c,0)){break c}Hi(x[a+36>>2],d+71|0);e=y[d+71|0];e=e&1?-1:e>>>1|0;w[a+24>>1]=e;if(e){break c}Mh(a,1,2)}x[a+8>>2]=0;f=1;if(tj(c,1)){fK(x[a+36>>2],a+8|0)}g=tj(b,2);e=a+32|0;Pc(d,e,6);Df(d,g);g=tj(b,3);Pc(d,e,7);Df(d,g);g=z[a+24>>1];Pc(d,e,5);Df(d,(g|0)!=0);b=tj(b,7);Pc(d,e,8);Df(d,b);Pc(d,e,5);d:{if(Hb(x[x[d>>2]>>2],x[d+4>>2])){break d}Pc(d+40|0,e,6);if(Hb(x[x[d+40>>2]>>2],x[d+44>>2])){break d}Pc(d+32|0,e,7);if(Hb(x[x[d+32>>2]>>2],x[d+36>>2])){break d}Pc(d+24|0,e,8);f=Hb(x[x[d+24>>2]>>2],x[d+28>>2])}b=d+16|0;Pc(b,e,11);Df(b,f);Pc(d,e,11);if(tj(c,2)){w[d+40>>1]=0;qy(x[a+36>>2],d+40|0);b=x[a+36>>2];f=z[d+40>>1];Pc(d,e,9);Km(b,f<<Hb(x[x[d>>2]>>2],x[d+4>>2]))}if(tj(c,3)){Km(x[a+36>>2],5)}ll(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(!c&b>>>0>=16001|c){Mh(a,2,8192);break a}x[a+104>>2]=b;if(!b){Mh(a,1,1)}Pc(d,e,11);e:{if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break e}ll(x[a+36>>2],d+48|0);c=x[d+52>>2];f=c;b=x[d+48>>2];if(ly(b,c)){break e}Mh(a,2,2048);break a}Yd(d,x[a+36>>2]);g=x[d+8>>2];h=x[a+16>>2];c=g-h|0;g=x[d+12>>2]-(x[a+20>>2]+(g>>>0<h>>>0)|0)|0;if((g|0)<0){Mh(a,2,16384);break a}x[a+96>>2]=c;x[a+100>>2]=g;Pc(d,e,11);c=x[a+100>>2];g=b;h=x[a+96>>2];b=Hb(x[x[d>>2]>>2],x[d+4>>2]);x[a+72>>2]=b?g:h;x[a+76>>2]=b?f:c;Pc(d,e,11);if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){b=x[a+100>>2]+x[a+20>>2]|0;f=x[a+16>>2];c=f+x[a+96>>2]|0;x[a+80>>2]=c;x[a+84>>2]=c>>>0<f>>>0?b+1|0:b}Pc(d,e,10);Df(d,1)}fb=d+336|0}function Wia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb-32|0;fb=c;a:{b:{if(!Ib(x[b>>2],x[b+4>>2])){break b}l=a+16|0;m=x[b+12>>2];k=Nf(x[x[b+48>>2]+12>>2]);d=k;e=fb-16|0;fb=e;g=c+20|0;x[g>>2]=0;x[g+4>>2]=0;rc(g+8|0);Nd(e+8|0,x[zb(e+4|0,g)>>2]);c:{d:{if(d){x[31785]=0;O(464,g|0,d|0);f=x[31785];x[31785]=0;if((f|0)==1){break d}h=fb-16|0;fb=h;f=nr(h+4|0,g,d);d=x[f+4>>2];i=x[f+8>>2];while(1){if((d|0)==(i|0)){hc(f);fb=h+16|0}else{v[d|0]=0;v[d+1|0]=0;v[d+2|0]=0;v[d+3|0]=0;v[d+4|0]=0;v[d+5|0]=0;Jg(d);d=d+6|0;x[f+4>>2]=d;continue}break}}d=e+8|0;Md(d);am(d);fb=e+16|0;break c}a=N()|0;am(e+8|0);Q(a|0);p()}while(1){e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!(x[x[x[a>>2]-12>>2]+l>>2]|j>>>0>=m>>>0)){x[31785]=0;v[c+19|0]=0;P(925,a|0,c+19|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}d=v[c+19|0];if(!d){j=j+1|0;continue}v[c+18|0]=0;t:{if((d|0)>=0){break t}x[31785]=0;P(925,a|0,c+18|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){break t}break a}v[c+17|0]=0;w[c+12>>1]=0;x[c+8>>2]=0;u:{d=d&127;f=(d?d-1|0:0)&65535;i=f>>>0>=k>>>0;v:{w:{if(!i){h=gd(x[b>>2],x[x[b+48>>2]+12>>2],j,f);d=y[c+18|0];if(d&1){break w}e=Vc(x[g>>2],f);break v}h=c+8|0;d=y[c+18|0];if(!(d&1)){break u}}x[31785]=0;P(925,a|0,c+17|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}if(i){break u}e=Vc(x[g>>2],f);v[e|0]=y[c+17|0]}v[h|0]=y[e|0];d=y[c+18|0];if(!(d&2)){break r}break s}if(d&2){break s}break q}Nk(g);break b}x[31785]=0;P(925,a|0,c+17|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}if(i){break q}e=Vc(x[g>>2],f);v[e+1|0]=y[c+17|0]}v[h+1|0]=y[e+1|0];if(d&4){break p}break o}if(!(d&4)){break n}}x[31785]=0;P(925,a|0,c+17|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}if(i){break n}e=Vc(x[g>>2],f);v[e+2|0]=y[c+17|0]}v[h+2|0]=y[e+2|0];if(!(d&8)){break l}break m}if(!(d&8)){break k}}x[31785]=0;P(925,a|0,c+17|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}if(i){break k}e=Vc(x[g>>2],f);v[e+4|0]=y[c+17|0]}v[h+4|0]=y[e+4|0];if(d&16){break j}break i}if(!(d&16)){break h}}x[31785]=0;P(925,a|0,c+17|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}if(i){break h}e=Vc(x[g>>2],f);v[e+3|0]=y[c+17|0]}v[h+3|0]=y[e+3|0];if(!(d&32)){break f}break g}if(!(d&32)){break e}}x[31785]=0;P(925,a|0,c+17|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}if(i){break e}e=Vc(x[g>>2],f);v[e+5|0]=y[c+17|0]}v[h+5|0]=y[e+5|0]}if(!(d&64)){continue}x[31785]=0;P(925,a|0,c+7|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){x[31785]=0;P(926,a|0,y[c+7|0])|0;d=x[31785];x[31785]=0;if((d|0)!=1){continue}}break}break a}fb=c+32|0;return}a=N()|0;Nk(g);Q(a|0);p()}function qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=fb-16|0;fb=f;e=fb-16|0;fb=e;d=qB(f+8|0);a:{b:{c:{d:{switch(b-850|0){default:e:{f:{if((b|0)!=437){if((b|0)==737){break f}if((b|0)==775){break e}if((b|0)==1252){break c}g:{h:{if((b|0)!=20127){if((b|0)==28591){break h}if((b|0)==28605){break g}if((b|0)!=65001){break b}b=lf(e+8|0,0);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=lf(e+8|0,1);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=lf(e+8|0,2);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=lf(e+8|0,3);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=lf(e+8|0,4);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=lf(e+8|0,5);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=lf(e+8|0,6);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 0:b=lf(e+8|0,7);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 2:b=lf(e+8|0,8);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 5:b=lf(e+8|0,9);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 7:b=lf(e+8|0,10);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 10:b=lf(e+8|0,11);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 11:b=lf(e+8|0,12);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 12:b=lf(e+8|0,13);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 13:b=lf(e+8|0,14);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 14:b=lf(e+8|0,15);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 15:b=lf(e+8|0,16);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 16:b=lf(e+8|0,17);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 19:b=lf(e+8|0,18);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a;case 1:case 3:case 4:case 6:case 8:case 9:case 17:case 18:case 20:case 21:case 22:case 23:break b;case 24:break d}}b=lf(e+8|0,19);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}b=lf(e+8|0,20);x[d>>2]=x[b>>2];v[d+4|0]=y[b+4|0];break a}if(y[d+4|0]){v[d+4|0]=0}}fb=e+16|0;i:{if(Ad(y[f+12|0])){if(!Ad(y[f+12|0])){a=ac(4);x[a>>2]=0;a=Ij(a);x[a>>2]=121676;da(a|0,121712,847);p()}b=fb-32|0;fb=b;j:{k:{l:{m:{d=x[f+8>>2];if(!d){Of(b+20|0,c);c=0;a=Fb(a);d=y[b+31|0];e=x[b+24>>2];x[31785]=0;O(96,a|0,uh(e,d)|0);d=x[31785];x[31785]=0;if((d|0)!=1){while(1){if(uh(x[b+24>>2],y[b+31|0])>>>0<=c>>>0){break m}d=y[cc(b+20|0,c)|0];x[31785]=0;O(98,a|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break k}c=c+1|0;continue}}break k}e=b+8|0;Of(e,c);x[31785]=0;S(11,b+20|0,d|0,e|0);c=x[31785];x[31785]=0;n:{o:{if((c|0)!=1){x[31785]=0;O(12,a|0,b+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break o}Sb(b+20|0);tb(b+8|0);break l}c=N()|0;break n}c=N()|0;Sb(b+20|0)}tb(b+8|0);break j}tb(b+20|0)}fb=b+32|0;break i}c=N()|0;tb(a);tb(b+20|0)}Q(c|0);p()}Q$(a,22,c)}fb=f+16|0}function VH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;h=fb-48|0;fb=h;o(+a);d=j(1)|0;i=j(0)|0;a:{b:{e=d;k=e&2147483647;c:{if(k>>>0<=1074752122){if((d&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;C[b>>3]=c;C[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;C[b>>3]=c;C[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;C[b>>3]=c;C[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(F(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;i=k>>>20|0;e:{if((i-(e>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;C[b>>3]=a;o(+a);e=j(1)|0;j(0)|0;if((i-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;C[b>>3]=a}C[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;C[b>>3]=a;C[b+8>>3]=a;d=0;break a}l(0,i|0);l(1,e&1048575|1096810496);a=+n();d=0;i=1;while(1){m=(h+16|0)+(d<<3)|0;if(F(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);C[m>>3]=c;a=(a-c)*16777216;d=1;m=i;i=0;if(m){continue}break}C[h+32>>3]=a;d=2;while(1){i=d;d=d-1|0;if(C[(h+16|0)+(i<<3)>>3]==0){continue}break}d=nL(h+16|0,h,(k>>>20|0)-1046|0,i+1|0,1);a=C[h>>3];if((e|0)<0){C[b>>3]=-a;C[b+8>>3]=-C[h+8>>3];d=0-d|0;break a}C[b>>3]=a;C[b+8>>3]=C[h+8>>3]}fb=h+48|0;return d}function Ipa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=fb-560|0;fb=f;a:{if(!bd(b,1464)){break a}if(!Yq(b,f+556|0)){break a}Bd(a,1);Lb(Lb(Yf(a+1074312|0,83),84,1),85,1);b:{if(me(f+556|0,25497)){d=f+32|0;e=uc(d,8450);yb(a+1298344|0,e);tb(e);e=uc(d,14984);yb(a+1298356|0,e);tb(e);e=uc(d,15049);yb(a+1298368|0,e);break b}if(!me(f+556|0,15746)){break a}d=f+32|0;e=uc(d,8624);yb(a+1298344|0,e);tb(e);e=uc(d,12361);yb(a+1298356|0,e);tb(e);e=uc(d,15653);yb(a+1298368|0,e)}tb(e);s=a+1298404|0,t=x[Gc(d,28)>>2],x[s>>2]=t;bd(b,0);lZ(b,a+1298308|0,20);w[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+554|0;xw(d,b);m=Ic(d);if(y[f+554|0]>128){break a}e=f+32|0;d=fb-16|0;fb=d;c:{if(!Mb(x[b>>2],x[b+8>>2],512)){zX(e);break c}fE(d+8|0,e);md(d,b,x[d+8>>2],x[d+12>>2])}fb=d+16|0;d=0;e=y[m|0];while(1){n=(d|0)==512;if(!n){g=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=y[g|0]){continue}break a}break}if(!c){break a}x[a+480260>>2]=56;x[a+480264>>2]=13696;x[a+480204>>2]=125e4;x[a+480196>>2]=6;w[a+480192>>1]=0;w[a+480188>>1]=4;x[a+480228>>2]=64;x[a+480208>>2]=x[a+480208>>2]|18874368;Ch(a,0);o=a+484376|0;tg(Wb(x[a+484360>>2],y[o|0]),y[f+554|0]);l=a+484344|0;$f(l,y[f+554|0]);while(1)if(y[f+554|0]<=i>>>0){if(!(c&2)){break a}bd(b,(y[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(D(d,104)+a|0)+484380|0;if(x[c>>2]){qg(ad(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}else{s=_b(x[Wb(x[a+484360>>2],y[o|0])>>2],i),t=i,w[s>>1]=t;d:{if(!bh(l,i&65535,64)){break d}r=i<<2;e=0;e:while(1){if((e|0)==4){s=f,t=vb(x[Vb(x[l>>2],i)>>2]),x[s+24>>2]=t;e=0;while(1){if((e|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{v[f+30|0]=p;v[f+31|0]=q;d=h&255;if(d){break g}h=0;break f}}else{g=x[f+24>>2];h:{if((y[g+3|0]&254)!=16){break h}v[g+3|0]=16;h=0;j=y[g+5|0];if(j>>>0<16){break h}h=j>>>4|0;v[g+5|0]=h;k=h;g=j&15;h=(g|0)!=(h|0)&(g|0)!=0;p=h?k:p;q=h?g:q}d=d+1|0;vC(f+24|0);continue}break}we(Vb(x[l>>2],i),Ue(Le(f+8|0,16,y[(d+f|0)+29|0]),e));h=h+1|0;h=(h&255)==3?1:h}e=e+1|0;continue}}bd(b,(y[f+32+(e+r)|0]<<8)+1468|0);g=0;d=Vb(x[l>>2],i);d=gd(x[d>>2],x[x[d+48>>2]+12>>2],0,e&65535);while(1)if((g|0)==64){e=e+1|0;continue e}else{k=f+8|0;g$(k,b,d);j=y[f+8|0];k=y[Ic(k)|0];i:{if(!(!(j|k)|(j-5&255)>>>0<5|(j|0)==14&k>>>0>15)){Mf(d,j,k);break i}v[d+3|0]=0}d=d+24|0;g=g+1|0;continue}}}i=i+1|0;continue}}else{e=f+32|0;yC(b,e);g=GC(e,(D(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}fb=f+560|0;return n|0}function dP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-192|0;fb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[xl(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Jl(d+168|0,f,e,e-1|0);e=x[d+172>>2];x[b>>2]=x[d+168>>2];x[b+4>>2]=e}f=d+168|0;de(f);e=x[d+168>>2];de(d+156|0);e=wl(e,x[d+160>>2],b);de(f);b:{c:{d:{e:{if((e|0)==x[d+172>>2]){a=x[b+4>>2];e=x[b>>2];f=pc(d+184|0,22485);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Oc(e,a,d)){a=ac(8);x[31785]=0;c=P(37,d+168|0,10492)|0;b=x[31785];x[31785]=0;if((b|0)==1){break d}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;if(!c){break e}a=ac(8);c=x[b+4>>2];b=x[b>>2];x[31785]=0;e=di(d+156|0,b,c);b=x[31785];x[31785]=0;f:{g:{h:{if((b|0)!=1){x[31785]=0;S(1020,d+168|0,18489,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break h}nc(a,d+168|0);c=0;x[31785]=0;S(100,a|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(d+168|0);break g}b=N()|0;break f}b=N()|0;c=1}tb(e);if(!c){break c}}jc(a);break c}if(x[e+4>>2]){a=ac(8);x[31785]=0;c=P(37,d+168|0,11605)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=x[b+4>>2];b=x[b>>2];e=pc(d+148|0,22485);f=x[e+4>>2];x[d+72>>2]=x[e>>2];x[d+76>>2]=f;if(Oc(b,c,d+72|0)){a=ac(8);x[31785]=0;c=P(37,d+168|0,10492)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}e=pc(d+140|0,7482);f=x[e+4>>2];x[d+64>>2]=x[e>>2];x[d+68>>2]=f;i:{if(!Oc(b,c,d- -64|0)){e=pc(d+132|0,7464);f=x[e+4>>2];x[d+56>>2]=x[e>>2];x[d+60>>2]=f;if(!Oc(b,c,d+56|0)){break i}}e=y[a+60|0]!=0;break e}e=pc(d+124|0,7009);f=x[e+4>>2];x[d+48>>2]=x[e>>2];x[d+52>>2]=f;j:{if(!Oc(b,c,d+48|0)){e=pc(d+116|0,6990);f=x[e+4>>2];x[d+40>>2]=x[e>>2];x[d+44>>2]=f;if(!Oc(b,c,d+40|0)){break j}}e=y[a+61|0]!=0;break e}e=pc(d+108|0,7093);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Oc(b,c,d+32|0)){e=y[a+62|0]!=0;break e}e=pc(d+100|0,6084);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Oc(b,c,d+24|0)){e=y[a+63|0]!=0;break e}e=pc(d+92|0,7531);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Oc(b,c,d+16|0)){e=y[a+64|0]!=0;break e}e=pc(d+84|0,13468);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;if(!Oc(b,c,d+8|0)){break e}e=x[x[a+24>>2]+24668>>2]!=0}fb=d+192|0;return e|0}b=N()|0;jc(a)}Q(b|0)}p()}function bn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;h=Nb(a);x[31785]=0;a=R(284,b|0)|0;c=x[31785];x[31785]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=x[b+8>>2];d=x[b>>2];x[31785]=0;c=U(153,d|0,c|0,a|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}if(c){break d}x[31785]=0;a=R(205,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}x[31785]=0;P(186,b|0,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break c}}a=N()|0;break a}x[31785]=0;S(188,e+24|0,b|0,a|0);b=x[31785];x[31785]=0;f:{g:{h:{if((b|0)!=1){b=e+24|0;c=ic(e+44|0,b);ub(b);if(a>>>0<10){break g}x[31785]=0;b=R(740,c|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break b}if(!b){break g}x[31785]=0;b=R(284,c|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break b}x[e+20>>2]=b;a=a-10|0;vc(e+20|0,a>>>0>25264513?-1:D(a,170));x[31785]=0;d=x[e+20>>2];O(290,h|0,d|0);a=x[31785];x[31785]=0;if((a|0)!=1){break h}break b}a=N()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=x[c+8>>2];f=x[c>>2];x[31785]=0;a=P(741,f|0,a|0)|0;f=x[31785];x[31785]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}x[31785]=0;a=R(537,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}x[31785]=0;a=R(200,c|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=x[c+8>>2];i=x[c>>2];x[31785]=0;g=U(153,i|0,g|0,a|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break b}if(!g){continue}le(e+24|0,x[h>>2],x[h+4>>2]);jr(e+8|0,x[e+24>>2],x[e+28>>2],b,a);x[31785]=0;Rn(475,e,c,x[e+8>>2],x[e+12>>2]);f=x[31785];x[31785]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}x[31785]=0;a=R(200,c|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}x[31785]=0;i=P(742,c|0,e+16|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+16|0;i=ec(f);$u(f,i,Ne(vb(x[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}x[31785]=0;a=P(742,c|0,e+16|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break b}if(!a){continue}a=e+16|0;f=ec(a);$u(a,f,Ne(vb(x[h>>2]),b));$u(a,f,Ne(Ne(vb(x[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}x[31785]=0;a=R(200,c|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}Nb(dc(h));break f}x[31785]=0;S(336,c|0,h|0,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}}ub(c)}fb=e- -64|0;return}a=N()|0;ub(c)}dc(h);Q(a|0);p()}function pe(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31785]=0;O(117,b|0,Wc(e,d)|0);d=x[31785];x[31785]=0;d:{if((d|0)!=1){e:{while(1){if(Wc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Sd(c,a)>>2];x[31785]=0;O(118,b|0,(d>>>0>=128?63:d)<<24>>24);d=x[31785];x[31785]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31785]=0;O(117,b|0,Wc(e,d)|0);d=x[31785];x[31785]=0;f:{if((d|0)!=1){g:{while(1){if(Wc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=x[Sd(c,a)>>2];x[31785]=0;O(118,b|0,(d>>>0>=256?63:d)<<24>>24);d=x[31785];x[31785]=0;if((d|0)==1){break g}a=a+1|0;continue}break}break f}}break a}return;case 3:bf(a,c,49168);return;case 4:bf(a,c,50192);return;case 5:bf(a,c,51216);return;case 6:bf(a,c,52240);return;case 7:bf(a,c,53264);return;case 8:bf(a,c,54288);return;case 9:bf(a,c,55312);return;case 10:bf(a,c,56336);return;case 11:bf(a,c,57360);return;case 12:bf(a,c,58384);return;case 13:bf(a,c,59408);return;case 14:bf(a,c,60432);return;case 15:bf(a,c,61456);return;case 16:bf(a,c,62480);return;case 17:bf(a,c,63504);return;case 18:bf(a,c,64528);return;case 19:bf(a,c,65552);return;case 20:bf(a,c,66576);return;case 21:bf(a,c,67600);return;case 22:bf(a,c,68624);return;case 23:bf(a,c,69648);return;case 24:qx(a,c,70672);return;case 25:qx(a,c,49168);return;case 26:qx(a,c,67600);return;default:a=ac(8);x[31785]=0;b=P(16,a|0,11116)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}b=N()|0;jc(a);Q(b|0);p();case 0:break c}}e=fb-16|0;fb=e;f=Fb(a);h:{while(1){i:{j:{k:{if(Wc(x[c+4>>2],y[c+11|0])>>>0>g>>>0){b=x[Sd(c,g)>>2];if(b>>>0>=2097152){x[31785]=0;O(118,f|0,63);a=x[31785];x[31785]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;v[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=y[e+10|0]|64}else{a=y[e+10|0]}x[31785]=0;O(118,f|0,a<<24>>24);a=x[31785];x[31785]=0;if((a|0)!=1){break j}break i}fb=e+16|0;break h}i=(2<<a)+255<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=v[j|0];x[31785]=0;O(118,f|0,(a|i)<<24>>24);h=x[31785];x[31785]=0;a=d;break l}x[31785]=0;a=a-1|0;O(118,f|0,v[a+(e+10|0)|0]|-128);h=x[31785];x[31785]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=N()|0;tb(f);Q(a|0);p()}return}da(b|0,125372,17);p()}a=N()|0;tb(b);Q(a|0);p()}function _ja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;x[a+24588>>2]=0;x[a+24592>>2]=0;x[a+8>>2]=42272;x[a+4>>2]=0;x[a>>2]=30816;b=a+24596|0;x[b>>2]=0;x[b+4>>2]=0;Gq(a+24604|0);hS(a+24648|0,0);x[a+397448>>2]=0;x[a+397452>>2]=0;b=a+397456|0;x[b>>2]=8;x[b+4>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;v[b+12|0]=0;x[b+8>>2]=0;w[b+24>>1]=0;Tb(b+28|0,0,40);Tb(b+68|0,0,49824);Tb(b+49892|0,0,32832);v[a+480224|0]=0;w[a+480212>>1]=0;x[a+480204>>2]=0;x[a+480208>>2]=0;x[a+480180>>2]=0;x[a+480184>>2]=0;b=a+480186|0;w[b>>1]=0;w[b+2>>1]=0;w[b+4>>1]=0;w[b+6>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;h=Nb(a+480248|0);x[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;XE(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Nb(c);x[f+12>>2]=a;x[31785]=0;i=P(855,a+484360|0,a|0)|0;b=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){c=a+900380|0;b=a+484380|0;while(1){x[31785]=0;b=R(713,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break i}b=b+104|0;if((c|0)!=(b|0)){continue}break}x[31785]=0;R(856,a+901404|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break h}d=a+906300|0;b=0;while(1){bS(d+D(b,160)|0);b=b+1|0;if((b|0)!=250){continue}break}x[a+946300>>2]=0;e=a+1074304|0;g=a+946304|0;b=g;while(1){b=Mu(b)+32|0;if((e|0)!=(b|0)){continue}break}x[a+1074304>>2]=0;x[a+1074308>>2]=0;Qr(a+1074312|0);x[31785]=0;X(857);b=x[31785];x[31785]=0;if((b|0)==1){break g}s=a,t=aS(),x[s+1074328>>2]=t;b=a+1074332|0;x[b+12>>2]=1065353216;SR(b,4);x[31785]=0;e=R(858,a+1074376|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break g}x[31785]=0;j=U(607,a+1298264|0,a|0,255)|0;b=x[31785];x[31785]=0;if((b|0)==1){break f}k=rc(a+1298300|0);l=rc(a+1298304|0);m=Fb(a+1298308|0);n=Fb(a+1298320|0);o=Fb(a+1298332|0);q=gS(a+1298344|0);r=Nb(a+1298412|0);v[a+1298424|0]=0;b=a+1298432|0;x[b>>2]=0;x[b+4>>2]=0;x[b+32>>2]=0;x[b+36>>2]=1072693248;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[a+1298472>>2]=0;pq(a+12|0);IA(a+8204|0);IA(a+12300|0);b=a+1074408|0;x[b>>2]=4;x[b+4>>2]=16;x[a+480216>>2]=4;x[a+480220>>2]=16;Tb(c,0,1024);$R(g);x[31785]=0;b=R(859,12)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}x[b>>2]=0;x[b+4>>2]=0;x[b+8>>2]=0;s=a,t=Nb(b),x[s+4>>2]=t;return a|0}b=N()|0;break a}b=N()|0;break b}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;fS(r);LA(q);tb(o);tb(n);tb(m);KA(l);JA(k);xu(j)}ZA(e)}eS(d)}OB(i)}YR(f);sc(h);Q(b|0);p()}function una(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb+-64|0;fb=d;w[d+62>>1]=c;Pf(d+62|0,32);j=Nb(a);x[31785]=0;o=z[d+62>>1];O(541,j|0,o|0);a=x[31785];x[31785]=0;a:{b:{if((a|0)!=1){k=b+480190|0;q=b+480192|0;c:{d:{while(1){if((r&65535)>>>0>=o>>>0){break d}e=1;c=z[k>>1];a=c+1|0;w[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){f=e&65535;if(f>>>0>c>>>0){break h}i:{g=ri(b,f);if(!ge(x[g>>2],x[g+20>>2])){if(!Ib(xC(vb(x[j>>2]),vb(x[j+4>>2]),e),vb(x[j+4>>2]))){break i}c=z[k>>1]}e=e+1|0;continue}break}w[d+60>>1]=e;a=1;while(1){c=a&65535;if(c>>>0>z[q>>1]){a=e}else{j:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;g=fr(c);while(1){if((c|0)==(g|0)){break j}if((f|0)==z[c>>1]){w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}}if((a&65535)>>>0<4e3){break g}e=Mo(d+48|0);x[31785]=0;a=P(782,b|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break b}if(!a){break e}x[31785]=0;O(783,b|0,e|0);c=x[31785];x[31785]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=z[q>>1]){k:{c=x[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;f=fr(c);while(1){if((c|0)==(f|0)){break k}g=z[c>>1];l:{if(g>>>0>=A[d+52>>2]){break l}Kb(d+40|0,x[e>>2],g);if(Hb(x[x[d+40>>2]>>2],x[d+44>>2])){break l}w[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}fn(d+24|0,x[e>>2]);fV(d+32|0,x[d+24>>2],x[d+28>>2],1);Mq(d+16|0,x[e>>2],x[d+52>>2]);m=fb-16|0;fb=m;g=d+40|0;c=gc(m,x[d+32>>2],x[d+36>>2]);a=dn(x[d+16>>2],x[d+20>>2],x[d+32>>2],x[d+36>>2]);f=fb-16|0;fb=f;x[f+12>>2]=a;h=x[c+4>>2];m:{if(h){i=32-h|0;x[f+8>>2]=i;n=x[Gb(f+8|0,f+12|0)>>2];l=-1<<h&-1>>>i-n;i=x[c>>2];l=l&(x[i>>2]^-1);if(l){gc(g,i,rua(l));break m}if((a|0)==(n|0)){fV(g,i,h,a);break m}a=a-n|0;x[f+12>>2]=a;x[c>>2]=i+4}while(1){if(a>>>0>=32){h=x[c>>2];i=x[h>>2];if((i|0)!=-1){gc(g,h,rua(i^-1));break m}else{x[c>>2]=h+4;a=a-32|0;x[f+12>>2]=a;continue}}break}if(!a){gc(g,x[c>>2],0);break m}c=x[c>>2];h=(x[c>>2]^-1)&-1>>>32-a;if(!h){gc(g,c,a);break m}gc(g,c,rua(h))}fb=f+16|0;fb=m+16|0;fn(d+8|0,x[e>>2]);a=dn(x[d+40>>2],x[d+44>>2],x[d+8>>2],x[d+12>>2]);w[d+60>>1]=a;$e(e);if((a&65535)>>>0>3999){break f}}x[31785]=0;O(260,j|0,d+60|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}if(z[k>>1]>=(a&65535)>>>0){break f}w[k>>1]=a}r=r+1|0;continue}break}$e(e)}fb=d- -64|0;return}c=N()|0;break a}c=N()|0;break a}c=N()|0;$e(e)}kd(j);Q(c|0);p()}function cpa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=fb-16|0;fb=g;a:{if(!Mb(x[a>>2],x[a+8>>2],2)){bh(c+484344|0,b,64);break a}k=c+484344|0;l=Hd(Qk(a),1,1024);if(!bh(k,b,l)){break a}n=z[c+480188>>1];o=c+480190|0;b:while(1){if((j|0)==(l|0)){break a}e=Vb(x[k>>2],b);Ve(g+8|0,x[e>>2],x[x[e+48>>2]+12>>2],j);i=0;while(1)if((i|0)==(n|0)){j=j+1|0;continue b}else{e=Vc(x[g+8>>2],i);f=g+4|0;wn(f,a);p=Ze(f);f=cj(f);h=y[g+4|0];c:{if((h-1&255)>>>0>35){break c}v[e|0]=h+48;m=y[Ic(g+4|0)|0];h=m+1|0;v[e+1|0]=h;q=h;h=h&255;if((q|0)!=(h|0)|h>>>0>z[o>>1]){break c}h=ri(c,h);if(!(!y[xb(d,i)|0]|z[h+30>>1]>255)){v[e+4|0]=64;v[e+2|0]=1}h=h+68|0;d:{if(x[wb(h,0)>>2]==1){if(y[xb(d,i)|0]){break d}}if(x[wb(h,0)>>2]){break c}if(y[xb(d,i)|0]){break c}}v[e+1|0]=m+101}e:{f:{switch(y[p|0]){case 1:if(!y[f|0]){break e}v[e+3|0]=2;v[e+5|0]=y[f|0];break e;case 2:if(!y[f|0]){break e}v[e+3|0]=3;v[e+5|0]=y[f|0];break e;case 12:if(!y[f|0]){break e}v[e+3|0]=1;v[e+5|0]=y[f|0];break e;case 13:if(!y[f|0]){break e}v[e+3|0]=39;v[g|0]=15;r=e,s=y[Ub(g,f)|0]|16,v[r+5|0]=s;break e;case 30:if(!y[f|0]){break e}v[e+3|0]=38;v[g|0]=15;r=e,s=y[Ub(g,f)|0]|16,v[r+5|0]=s;break e;case 21:if(!y[f|0]){break e}v[e+3|0]=39;v[g|0]=15;r=e,s=y[Ub(g,f)|0]|80,v[r+5|0]=s;break e;case 17:if(!y[f|0]){break e}v[e+3|0]=38;v[g|0]=15;r=e,s=y[Ub(g,f)|0]|80,v[r+5|0]=s;break e;case 15:v[e+3|0]=19;v[e+5|0]=y[f|0]!=0;break e;case 25:v[e+3|0]=12;v[e+5|0]=y[f|0];break e;case 27:No(e);v[e|0]=255;break e;case 28:if(y[f|0]>31){break e}v[e+3|0]=16;v[e+5|0]=y[f|0];break e;case 31:h=y[f|0];if(h&15){r=e,s=y[xb(d,i)|0]?22:11,v[r+3|0]=s;v[e+5|0]=y[f|0]&15;h=y[f|0]}g:{h:{switch(h>>>4|0){case 4:if((h|0)!=64){break g}case 0:case 1:case 2:case 3:if(y[xb(d,i)|0]){v[e+3|0]=21;v[e+5|0]=y[f|0];break g}v[e+2|0]=1;f=y[f|0];v[e+3|0]=0;v[e+4|0]=f;break g;case 5:v[e+5|0]=y[e+5|0]<<4;break g;case 6:v[g|0]=y[e+5|0];v[g+3|0]=14;r=e,s=y[Ub(g,g+3|0)|0]|240,v[r+5|0]=s;break g;case 7:v[g|0]=y[e+5|0];v[g+3|0]=14;r=e,s=y[Ub(g,g+3|0)|0]<<4|15,v[r+5|0]=s;break g;default:break h}}v[e+3|0]=0}if((y[e+3|0]-21&255)>>>0>1){break e}f=xb(d,i);f=Vc(x[g+8>>2],v[f|0]+i|0);wr(g,y[f+3|0],y[f+5|0],1);if(y[g|0]){h=z[g>>1];v[f+2|0]=h;v[f+4|0]=h>>>8}v[f+3|0]=y[e+3|0];v[f+5|0]=y[e+5|0];break e;case 0:break e;default:break f}}v[e+3|0]=0}i=i+1|0;continue}}}fb=g+16|0}function haa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;x[d+156>>2]=c;a:{b:{c:{if(b>=.8){x[31785]=0;e=ca(1155)|0;f=x[31785];x[31785]=0;d:{e:{f:{if((f|0)!=1){x[d+72>>2]=e;x[31785]=0;c=R(1156,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break e}x[d+152>>2]=c;no(e,c);a=Fe(d+132|0,a);x[31785]=0;c=x[a+12>>2];x[d+56>>2]=x[a+8>>2];x[d+60>>2]=c;x[d- -64>>2]=x[a+16>>2];c=x[a+4>>2];x[d+48>>2]=x[a>>2];x[d+52>>2]=c;a=U(1148,e|0,d+48|0,15)|0;c=x[31785];x[31785]=0;if((c|0)==1){break f}if(a){x[31785]=0;W(860,e|0);a=x[31785];x[31785]=0;g=1;if((a|0)==1){break f}}rh(d+152|0);sh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;rh(d+152|0);break d}c=T(0)|0}sh(d+72|0);break c}if(b>=.6){x[31785]=0;e=ca(1155)|0;f=x[31785];x[31785]=0;g:{h:{i:{if((f|0)!=1){x[d+72>>2]=e;x[31785]=0;c=R(1156,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break h}x[d+152>>2]=c;no(e,c);a=Fe(d+112|0,a);x[31785]=0;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;x[d+40>>2]=x[a+16>>2];c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;a=U(1148,e|0,d+24|0,2)|0;c=x[31785];x[31785]=0;if((c|0)==1){break i}if(a){x[31785]=0;W(860,e|0);a=x[31785];x[31785]=0;g=.8;if((a|0)==1){break i}}rh(d+152|0);sh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;rh(d+152|0);break g}c=T(0)|0}sh(d+72|0);break c}g=.2;if(b>=.2){x[31785]=0;e=ca(1155)|0;f=x[31785];x[31785]=0;j:{k:{l:{if((f|0)!=1){x[d+72>>2]=e;x[31785]=0;c=R(1156,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break k}x[d+152>>2]=c;no(e,c);a=Fe(d+92|0,a);x[31785]=0;c=x[a+12>>2];x[d+8>>2]=x[a+8>>2];x[d+12>>2]=c;x[d+16>>2]=x[a+16>>2];c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;a=U(1148,e|0,d|0,0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break l}g=0;if(a){x[31785]=0;W(860,e|0);a=x[31785];x[31785]=0;g=.6;if((a|0)==1){break l}}rh(d+152|0);sh(d+72|0);break b}c=T(0)|0;break c}c=T(0)|0;rh(d+152|0);break j}c=T(0)|0}sh(d+72|0);break c}if(!(b>=.1)){break b}x[31785]=0;S(189,d+72|0,a|0,2048);c=x[31785];x[31785]=0;if((c|0)!=1){c=Se(d+72|0);a=x[a>>2];x[31785]=0;e=x[d+72>>2];a=R(157,a|0)|0;f=x[31785];x[31785]=0;m:{if((f|0)==1){break m}x[31785]=0;a=OH(1157,3,0,c,e,a,0);c=x[31785];x[31785]=0;if((c|0)==1){break m}g=C[(a<<3)+79768>>3];Jc(d+72|0);break b}c=T(0)|0;Jc(d+72|0);break c}c=T(0)|0}Y(c|0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;g=0;if((a|0)==1){break a}}Uc(d+156|0);fb=d+160|0;return+g}a=N()|0;Uc(d+156|0);Q(a|0);p()}function vca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;n=fb-32|0;fb=n;j=pf(n+20|0,1,0);a:{b:{while(1){e=Jb(j);i=e+Bb(x[j+4>>2],y[j+11|0])|0;g=x[b>>2];d=x[b+4>>2];if(!((d|0)>0|(d|0)>=0|(e|0)==(i|0))){v[e|0]=45;e=e+1|0;g=wN(g,d);d=hb}k=n+12|0;c:{d:{switch(c<<31|c-2>>>1){case 4:vN(k,e,i,g,d);break c;case 0:f=64-Mt(g|1,d)|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<17){while(1){e=e-1|0;v[e|0]=y[(g&1)+15639|0];h=!d&g>>>0>1|(d|0)!=0;f=d;d=d>>>1|0;g=(f&1)<<31|g>>>1;if(h){continue}break}}else{f=d;e=e-4|0;d=x[(g<<2&60)+79040>>2];v[e|0]=d;v[e+1|0]=d>>>8;v[e+2|0]=d>>>16;v[e+3|0]=d>>>24;d=f>>>4|0;g=(f&15)<<28|g>>>4;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 3:f=(66-Mt(g|1,d)>>>0)/3|0;if((f|0)<=(i-e|0)){i=e+f|0;e=i;while(1){if(!d&g>>>0<65){while(1){e=e-1|0;v[e|0]=y[(g&7)+14921|0];h=!d&g>>>0>7|(d|0)!=0;f=d;d=d>>>3|0;g=(f&7)<<29|g>>>3;if(h){continue}break}}else{f=d;e=e-2|0;d=z[(g<<1&126)+79104>>1];v[e|0]=d;v[e+1|0]=d>>>8;d=f>>>6|0;g=(f&63)<<26|g>>>6;continue}break}f=0}else{f=61}x[k+4>>2]=f;x[k>>2]=i;break c;case 7:l=61;h=67-Mt(g|1,d)>>>2|0;e:{if((h|0)>(i-e|0)){break e}i=e+h|0;e=i;while(1){if(!d&g>>>0>=257|d){f=d;e=e-2|0;d=z[(g<<1&510)+79232>>1];v[e|0]=d;v[e+1|0]=d>>>8;d=f>>>8|0;g=(f&255)<<24|g>>>8;continue}break}l=0;if(!h){break e}while(1){e=e-1|0;v[e|0]=y[(g&15)+11186|0];h=!d&g>>>0>15|(d|0)!=0;f=d;d=d>>>4|0;g=(f&15)<<28|g>>>4;if(h){continue}break}}x[k+4>>2]=l;x[k>>2]=i;break c;default:break d}}f=g;h=d;o=D(c,c);q=D(o,c);r=D(o,o);l=0;f:{while(1){m=l|1;if(!h&c>>>0>f>>>0){break f}m=l|2;if(!h&f>>>0<o>>>0){break f}m=l|3;if(!h&f>>>0<q>>>0){break f}if(!h&f>>>0<r>>>0){m=l+4|0}else{l=l+4|0;f=uua(f,h,r,0);h=hb;continue}break}}h=m;if((h|0)>(i-e|0)){x[k+4>>2]=61;x[k>>2]=i;break c}q=e+h|0;e=q;while(1){e=e-1|0;h=uua(g,d,c,0);f=hb;s=e,t=y[(g-sua(h,f,c,0)|0)+4915|0],v[s|0]=t;o=!d&c>>>0<=g>>>0|(d|0)!=0;g=h;d=f;if(o){continue}break}x[k+4>>2]=0;x[k>>2]=q}if(!x[n+16>>2]){break b}d=ni(Bb(x[j+4>>2],y[j+11|0]));x[31785]=0;O(46,j|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){continue}break}break a}c=x[n+12>>2];b=Jb(j);x[31785]=0;O(47,j|0,c-b|0);b=x[31785];x[31785]=0;g:{if((b|0)!=1){x[31785]=0;O(48,a|0,j|0);a=x[31785];x[31785]=0;if((a|0)!=1){break g}break a}break a}tb(j);fb=n+32|0;return}a=N()|0;tb(j);Q(a|0);p()}function mS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-48|0;fb=h;e=fb-16|0;fb=e;x[e>>2]=b;x[e+4>>2]=c;g=fb-16|0;fb=g;d=x[e+4>>2];i=d;j=fb-16|0;fb=j;f=x[e>>2];d=x[zb(j+12|0,tua(f,d,500654080,20))>>2];fb=j+16|0;j=fb-16|0;fb=j;k=jS(j+8|0,d);l=x[k>>2];fb=j+16|0;m=f>>>0<l>>>0;f=x[k+4>>2];if(m&(f|0)>=(i|0)|(f|0)>(i|0)){i=x[zb(g+12|0,1)>>2];f=fb-16|0;fb=f;d=x[zb(f+12|0,d-i|0)>>2];fb=f+16|0}fb=g+16|0;d=x[zb(e+12|0,d)>>2];fb=e+16|0;f=fb-16|0;fb=f;e=fb-16|0;fb=e;g=d+719468|0;k=(((d|0)>-719469?g:d+573372|0)|0)/146097|0;g=D(k,-146097)+g|0;i=((g>>>0)/36524|0)+g-(((g>>>0)/146096|0)+((g>>>0)/1460|0))|0;j=(i>>>0)/365|0;i=((g-((i>>>0)/1460|0)|0)+((i>>>0)/36500|0)|0)+D(j,-365)|0;l=D(i,5)+2|0;g=(l>>>0)/153|0;m=j+D(k,400)|0;j=g+(l>>>0<1530?3:-9)|0;k=vw(e+14|0,m+(j>>>0<3)|0);j=_p(e+13|0,j);g=_p(e+12|0,(i-((D(g,153)+2>>>0)/5|0)|0)+1|0);iS(f+12|0,z[k>>1],j,g);fb=e+16|0;e=x[f+12>>2];w[h+44>>1]=e;w[h+46>>1]=e>>>16;fb=f+16|0;e=fb-16|0;fb=e;d=jS(e,d);g=x[d>>2];c=te(e+8|0,b-g|0,c-(x[d+4>>2]+(b>>>0<g>>>0)|0)|0);b=x[c>>2];fb=e+16|0;g=fb-16|0;fb=g;c=x[c+4>>2];d=MA(g+8|0,0);n=h,o=kS(b,c,x[d>>2],x[d+4>>2]),v[n+8|0]=o;d=fb-16|0;fb=d;e=te(d+8|0,0,0);f=x[e>>2];fb=d+16|0;if(!(kS(b,c,f,x[e+4>>2])^1)){d=fb-16|0;fb=d;c=te(d+8|0,0-b|0,0-(((b|0)!=0)+c|0)|0);b=x[c>>2];fb=d+16|0;c=x[c+4>>2]}d=fb-16|0;fb=d;e=x[zb(d+12|0,tua(b,c,-694967296,0))>>2];fb=d+16|0;x[h+12>>2]=e;d=fb-16|0;fb=d;f=fb-16|0;fb=f;e=te(f+8|0,sua(e,e>>31,-694967296,0),hb);i=x[e>>2];e=x[e+4>>2];fb=f+16|0;x[d>>2]=i;x[d+4>>2]=e;e=x[d>>2];b=te(d+8|0,b-e|0,c-(x[d+4>>2]+(b>>>0<e>>>0)|0)|0);c=x[b>>2];e=x[b+4>>2];f=e;fb=d+16|0;b=fb-16|0;fb=b;d=x[zb(b+12|0,tua(c,e,6e7,0))>>2];fb=b+16|0;x[h+16>>2]=d;b=fb-16|0;fb=b;e=fb-16|0;fb=e;d=te(e+8|0,sua(d,d>>31,6e7,0),hb);i=x[d>>2];d=x[d+4>>2];fb=e+16|0;x[b>>2]=i;x[b+4>>2]=d;d=x[b>>2];d=te(b+8|0,c-d|0,f-(x[b+4>>2]+(c>>>0<d>>>0)|0)|0);c=x[d>>2];d=x[d+4>>2];e=d;fb=b+16|0;b=NA(c,d);x[h+24>>2]=b;f=hb;x[h+28>>2]=f;d=fb-16|0;fb=d;b=nu(d,b,f);f=x[b>>2];b=te(d+8|0,c-f|0,e-(x[b+4>>2]+(c>>>0<f>>>0)|0)|0);c=x[b>>2];fb=d+16|0;n=h,o=JQ(c,x[b+4>>2]),x[n+32>>2]=o;x[h+36>>2]=hb;fb=g+16|0;a=lS(a);x[a>>2]=z[h+44>>1]<<16>>16;n=a,o=vf(y[h+46|0]),x[n+4>>2]=o;n=a,o=vf(y[h+47|0]),x[n+8>>2]=o;x[a+12>>2]=x[h+12>>2];x[a+16>>2]=x[h+16>>2];b=x[h+28>>2];x[a+24>>2]=x[h+24>>2];x[a+28>>2]=b;fb=h+48|0}function C0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-368|0;fb=e;xc(b);d=fb-16|0;fb=d;h=e+330|0;UE(d+8|0,h);f=x[d+12>>2];kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2]);i=x[d+4>>2];if((i|0)==(f|0)){Yb(b,x[d+12>>2])}fb=d+16|0;d=(f|0)==(i|0);if(!d){TE(h)}a:{if(!d){break a}if(!WE(e+330|0)){break a}if(!Mb(x[b>>2],x[b+8>>2],Bc(VE(y[e+365|0]),hb))){break a}b:{if(!c){break b}Bd(a,2097152);ag(a);Ch(a,1);w[a+480188>>1]=8;x[a+480196>>2]=y[e+362|0];x[a+480204>>2]=D(y[e+363|0],1e4);j=a+480190|0;w[j>>1]=y[e+364|0];d=y[e+367|0];if(d>>>0<y[e+366|0]){_e(Wb(x[a+484360>>2],y[a+484376|0]),d)}d=e- -64|0;g=uc(d,6574);yb(a+1298344|0,g);tb(g);g=uc(d,11163);yb(a+1298356|0,g);tb(g);n=a+1298404|0,o=x[Gc(d,4)>>2],x[n>>2]=o;sw(b,d);Dr(Wb(x[a+484360>>2],y[a+484376|0]),d,y[e+366|0],65535,65535);g=1;while(1){i=g&65535;if(i>>>0>z[j>>1]){Yb(b,D(64-y[e+364|0]|0,37));h=a+484344|0;$f(h,y[e+365|0]);i=c&1;g=0;while(1)if(y[e+365|0]<=g>>>0){if(!(c&2)){break b}c=ad(e+24|0,8,1,0,0);d=a+480190|0;g=1;while(1){f=g&65535;if(f>>>0>z[d>>1]){break b}qg(c,(D(f,104)+a|0)+484380|0,b);g=g+1|0;continue}}else{c:{d:{if(i){if(bh(h,g&65535,64)){break d}}Yb(b,2048);break c}d=Vb(x[h>>2],g);n=e,o=vb(x[d>>2]),x[n+24>>2]=o;j=vb(x[d+4>>2]);while(1){d=x[e+24>>2];if(!Ib(d,j)){break c}f=e+12|0;wn(f,b);k=Ic(f);m=Ze(f);f=cj(f);l=y[e+12|0];if((l-1&255)>>>0<=106){v[d|0]=l+13}v[d+1|0]=y[k|0];Mf(d,y[m|0],y[f|0]);ah(e+24|0);continue}}g=g+1|0;continue}}else{d=e+24|0;SE(b,d);h=fb-16|0;fb=h;f=(D(i,104)+a|0)+484380|0;jd(f,0);v[f+37|0]=y[d+22|0]<<4;v[h+15|0]=y[d+23|0];v[h+14|0]=64;n=f,o=y[Ub(h+15|0,h+14|0)|0]<<2,w[n+30>>1]=o;v[f+36|0]=y[d+24|0];x[f>>2]=y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24);k=y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24);if(!(k>>>0<3|k+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))>>>0>(y[d+25|0]|y[d+26|0]<<8|(y[d+27|0]<<16|y[d+28|0]<<24))>>>0)){w[f+34>>1]=z[f+34>>1]|2;x[f+4>>2]=y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24);x[f+8>>2]=(y[d+33|0]|y[d+34|0]<<8|(y[d+35|0]<<16|y[d+36|0]<<24))+(y[d+29|0]|y[d+30|0]<<8|(y[d+31|0]<<16|y[d+32|0]<<24))}fb=h+16|0;im(e,2,d);d=e+12|0;Ec(d,e);zc(((i<<5)+a|0)+946304|0,d);g=g+1|0;tb(d);continue}}}g=1}fb=e+368|0;return g|0}function Faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-144|0;fb=d;h=zM(d+128|0);x[h>>2]=48940;Nb(h+4|0);no(x[a+24>>2],h);e=x[a+24>>2];i=y[a+62|0];f=y[a+61|0];g=y[a+60|0];b=Fe(d+108|0,b);x[31785]=0;j=x[b+12>>2];x[d+8>>2]=x[b+8>>2];x[d+12>>2]=j;x[d+16>>2]=x[b+16>>2];j=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=j;b=g?13:15;b=f?b&14:b;b=U(1148,e|0,d|0,(i?b&3:b)|0)|0;e=x[31785];x[31785]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ac(8);x[31785]=0;c=P(37,d+96|0,12031)|0;a=x[31785];x[31785]=0;if((a|0)!=1){nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b);break b}if(!y[a+63|0]){x[31785]=0;O(1149,a|0,a+36|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}}v[a+28|0]=1;no(x[a+24>>2],x[a+4>>2]);x[31785]=0;O(1150,d+96|0,h|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}k=d,l=vb(x[d+96>>2]),x[k+92>>2]=l;e=a+68|0;i=vb(x[d+100>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=x[d+92>>2];if(!Ib(b,i)){k=d,l=Yi(x[c>>2]),x[k+80>>2]=l;c=Jf(c);while(1){b=x[d+80>>2];if(!Vg(b,c)){break d}x[31785]=0;e=qd(b);b=P(73,d+20|0,e|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break h}x[31785]=0;V(1021,a|0,b|0,e+12|0,0);e=x[31785];x[31785]=0;if((e|0)==1){break g}tb(b);Yg(d+80|0);continue}}f=x[a+24>>2];g=x[b>>2];x[31785]=0;j=f;f=b+4|0;S(1151,j|0,g|0,f|0);g=x[31785];x[31785]=0;if((g|0)!=1){b=x[b>>2];x[31785]=0;O(1152,d+44|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break r}x[31785]=0;O(1068,d+56|0,d+44|0);b=x[31785];x[31785]=0;if((b|0)==1){break q}x[31785]=0;b=P(37,d+32|0,18589)|0;g=x[31785];x[31785]=0;if((g|0)==1){break p}x[31785]=0;S(1024,d+68|0,d+56|0,b|0);g=x[31785];x[31785]=0;if((g|0)==1){break o}x[31785]=0;S(547,d+80|0,d+68|0,f|0);f=x[31785];x[31785]=0;if((f|0)==1){break n}x[31785]=0;O(181,e|0,d+80|0);f=x[31785];x[31785]=0;if((f|0)==1){break m}tb(d+80|0);tb(d+68|0);tb(b);tb(d+56|0);tb(d+44|0);Kq(d+92|0);continue}break}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;break j}a=N()|0;break k}a=N()|0;break l}a=N()|0;tb(d+80|0)}tb(d+68|0)}tb(b)}tb(d+56|0)}tb(d+44|0);break f}a=N()|0;break f}a=N()|0;tb(b)}oz(d+96|0);break b}a=N()|0;break b}oz(d+96|0);Ht(h);fb=d+144|0;return}a=N()|0}Ht(h);Q(a|0)}p()}function mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-16|0;fb=h;f=x[a+8>>2];e=x[a>>2];x[31785]=0;f=P(625,e|0,f|0)|0;e=x[31785];x[31785]=0;a:{b:{if((e|0)!=1){if(f){break b}x[31785]=0;f=R(200,a|0)|0;e=x[31785];x[31785]=0;c:{if((e|0)==1){break c}x[31785]=0;j=d+484344|0;k=Hd(f+1|0,1,1024);f=U(199,j|0,b|0,k|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}if(!f){break b}d=z[d+480188>>1];if(!d){break b}l=d-1|0;d=0;while(1){if(d>>>0>=k>>>0){break b}f=x[a+8>>2];e=x[a>>2];x[31785]=0;f=U(153,e|0,f|0,1)|0;e=x[31785];x[31785]=0;d:{if((e|0)!=1){if(!f){break b}x[31785]=0;i=R(200,a|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}if(i){break d}d=d+1|0;continue}break a}e=x[j>>2];w[h+14>>1]=i&31;w[h+12>>1]=l;e=Vb(e,b);e=gd(x[e>>2],x[x[e+48>>2]+12>>2],d,z[Mc(h+14|0,h+12|0)>>1]);if(i>>>0<32){continue}e:{if(i<<24>>24>=0){break e}x[31785]=0;g=R(200,a|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break a}v[e+5|0]=g;x[31785]=0;g=R(200,a|0)|0;f=x[31785];x[31785]=0;f:{g:{if((f|0)!=1){if(g>>>0<26){break g}break f}break a}f=y[g+41392|0];v[e+3|0]=f;h:{switch(f-1|0){case 0:if(!y[e+5|0]){break f}break e;case 12:if(y[e+2|0]){break e}v[e+2|0]=1;f=y[e+5|0];v[e+5|0]=0;v[e+3|0]=0;m=e,n=Hd(f,0,64),v[m+4|0]=n;break e;case 5:case 6:case 10:case 23:case 28:f=y[e+5|0]&240;if(!f){break e}v[e+5|0]=f;break e;case 8:f=y[e+5|0];if(f>>>0<=128){m=e,n=Zg(f<<1),v[m+5|0]=n;break e}if((f|0)!=164){break e}v[e+5|0]=145;v[e+3|0]=20;break e;case 13:f=y[e+5|0];v[e+5|0]=D(f>>>4|0,10)+(f&15);break e;case 18:xr(e);break e;case 16:if(y[e+5|0]>31){break e}v[e+3|0]=16;break e;case 27:break h;default:break e}}g=y[e+5|0];f=g&240;i:{if((f|0)==16){f=2}else{if((f|0)!=32){break i}f=3}v[e+3|0]=f}v[e+5|0]=g&15|224;break e}v[e+3|0]=0}j:{k:{if(!(i&64)){break k}x[31785]=0;O(201,h+10|0,a|0);f=x[31785];x[31785]=0;if((f|0)==1){break j}v[e+1|0]=y[h+10|0];g=y[Ic(h+10|0)|0];v[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break k}}v[e|0]=f}if(!(i&32)){continue}v[e+2|0]=1;x[31785]=0;g=R(200,a|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break a}v[e+4|0]=g;if(!c){continue}v[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}ub(a);fb=h+16|0;return}b=N()|0;ub(a);Q(b|0);p()}function Fu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=fb-16|0;fb=j;g=x[a+24>>2];h=AB(g,y[a+32|0]);i=x[h>>2];a:{if(Xc(i,x[h+4>>2])>>>0<=b>>>0){break a}if(PT(x[g+484344>>2],x[g+484348>>2],z[_b(i,b)>>1])>>>0<=c>>>0){break a}h=x[a>>2];b:{if(Qd(h,x[a+4>>2])>>>0>b>>>0){if(A[Dd(h,b)+4>>2]>c>>>0){break b}}Fo(a,0);if(Qd(x[a>>2],x[a+4>>2])>>>0<=b>>>0){break a}g=x[a+24>>2]}bc(j,x[d>>2],z[g+480188>>1]);h=j+8|0;l=x[j>>2];d=e?-2046629010:-2078137563;i=e?-1352371636:-873292572;e=x[j+4>>2];while(1){if(!f&(e|0)==(k|0)){x[h>>2]=d;x[h+4>>2]=i}else{g=y[TV(l,k)+841|0];m=g^sua(d^k,f^i,435,256);g=!g;d=(q=d,r=sua(m,hb,435,256),s=g,s?q:r);i=g?i:hb;k=k+1|0;f=k?f:f+1|0;continue}break}g=0;d=Zm(j,b,c);i=fb-16|0;fb=i;k=a+12|0;e=k;f=FT(z[d>>1],x[d+4>>2],$d(e),ec(e));c:{if(Ib(f,mg(e))){l=z[d>>1];m=x[d+4>>2];d=qd(f);if(!Ll(l,m,z[d>>1],x[d+4>>2])){break c}}f=mg(e)}d=x[zb(i+12|0,f)>>2];fb=i+16|0;if(Vg(d,Jf(k))){e=qd(d);g=mc(x[e+8>>2],x[e+12>>2])^1}i=x[h>>2]!=-2078137563|x[h+4>>2]!=-873292572;Kb(j,x[Dd(x[a>>2],b)>>2],c);f=1;n=Hb(x[x[j>>2]>>2],x[j+4>>2])^1;e=g|i;if(!(n|e)){break a}d:{e:{f:{g:{if(g){m=qd(d);e=vb(x[m+8>>2]);o=vb(x[m+12>>2]);d=x[h>>2];p=x[h+4>>2];l=fb-16|0;fb=l;x[l+12>>2]=e;while(1){h:{if(!Ib(e,o)){break h}if(Un(x[e>>2],x[e+4>>2],d,p)){break h}e=x[Hu(l+12|0)>>2];continue}break}fb=l+16|0;if(Ib(e,vb(x[m+12>>2]))){break a}if(!i){break e}break g}if(i){break g}if(!e){break d}break f}x[a+28>>2]=x[a+28>>2]+1}if(g|n){break e}d=DT(k,Zm(j,b,c));i:{if(A[d+4>>2]<A[Ab(d)>>2]){e=fb-16|0;fb=e;d=CT(e+4|0,d);AT(x[d+4>>2]);x[d+4>>2]=x[d+4>>2]+8;hc(d);fb=e+16|0;break i}f=fb-32|0;fb=f;e=Ab(d);e=Vr(f+12|0,Wr(d,gh(x[d>>2],x[d+4>>2])+1|0),gh(x[d>>2],x[d+4>>2]),e);AT(x[e+8>>2]);x[e+8>>2]=x[e+8>>2]+8;Id(d,e);Ur(e);fb=f+32|0}}d=DT(k,Zm(j,b,c));j:{if(A[d+4>>2]<A[Ab(d)>>2]){e=fb-16|0;fb=e;d=CT(e+4|0,d);BT(x[d+4>>2],x[h>>2],x[h+4>>2]);x[d+4>>2]=x[d+4>>2]+8;hc(d);fb=e+16|0;break j}f=fb-32|0;fb=f;e=Ab(d);e=Vr(f+12|0,Wr(d,gh(x[d>>2],x[d+4>>2])+1|0),gh(x[d>>2],x[d+4>>2]),e);BT(x[e+8>>2],x[h>>2],x[h+4>>2]);x[e+8>>2]=x[e+8>>2]+8;Id(d,e);Ur(e);fb=f+32|0}}Kb(j,x[Dd(x[a>>2],b)>>2],c);Df(j,1);f=0}fb=j+16|0;return f|0}function IZ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-80|0;fb=g;a:{b:{c:{d:{e:{f:{g:{if(yd(x[b+4>>2],y[b+11|0])){Fb(a);break g}k=Nb(g+68|0);x[g+56>>2]=0;x[g+60>>2]=0;h=x[c>>2];x[31785]=0;n=R(39,h|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break b}h=Jb(b);f=Bb(x[b+4>>2],y[b+11|0]);i=oZ(Kk(n));x[31785]=0;O(40,k|0,D(f,i+1|0)|0);i=x[31785];x[31785]=0;if((i|0)==1){break c}o=(f<<2)+h|0;i=x[k>>2];m=i+Sc(i,x[k+4>>2])|0;q=(d|0)!=2;h:{while(1){i:{j:{k:{l:{if(!q){while(1){x[g+48>>2]=0;x[g+52>>2]=0;x[31785]=0;f=h+4|0;j=za(41,n|0,g+56|0,h|0,f|0,g+52|0,i|0,m|0,g+48|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break f}if((j|0)!=1){break l}if((f|0)!=x[g+52>>2]){l=1;break k}else{i=x[g+48>>2];h=f;continue}}}x[g+48>>2]=0;x[g+52>>2]=0;x[31785]=0;j=za(41,n|0,g+56|0,h|0,o|0,g+52|0,i|0,m|0,g+48|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}l=1;if((j|0)==1){break k}}l=2;f=x[g+48>>2];if((j|0)!=2|(m|0)!=(f|0)){break j}}h=x[k+4>>2];f=x[k>>2];x[31785]=0;O(40,k|0,Sc(f,h)<<1);h=x[31785];x[31785]=0;if((h|0)==1){break d}h=x[k>>2];f=x[g+48>>2];i=h+(f-i|0)|0;m=Sc(h,x[k+4>>2])+h|0;j=l;break i}m:{n:{o:{p:{q:{switch(d|0){case 0:if(x[g+52>>2]!=(h|0)|(f|0)!=(i|0)|(j|0)!=2){break p}x[31785]=0;v[g+47|0]=1;h=P(42,g+8|0,22488)|0;f=x[31785];x[31785]=0;r:{s:{t:{if((f|0)!=1){x[31785]=0;S(43,g+20|0,h|0,b|0);f=x[31785];x[31785]=0;if((f|0)==1){break t}x[31785]=0;aa(44,g+32|0,g+20|0,c|0,1,g+47|0);f=x[31785];x[31785]=0;if((f|0)==1){break s}tb(g+32|0);Sb(g+20|0);Sb(h);if(y[g+47|0]){break o}x[31785]=0;aa(44,a|0,b|0,c|0,2,0);a=x[31785];x[31785]=0;if((a|0)!=1){break h}f=N()|0;break a}f=N()|0;break a}f=N()|0;break r}f=N()|0;Sb(g+20|0)}Sb(h);break a;case 1:break q;default:break p}}v[e|0]=(j|0)!=2|x[g+52>>2]!=(h|0)|(f|0)!=(i|0);Fb(a);break h}if((j|0)==2){break n}break m}f=x[g+48>>2]}x[g+52>>2]=x[g+52>>2]+4;v[f|0]=63;f=x[g+48>>2]+1|0;x[g+48>>2]=f}i=f}l=(j|0)==2;h=x[g+52>>2];j=o>>>0>h>>>0;if(l&j&f>>>0<m>>>0|j&(d|0)==2){continue}break}b=x[k>>2];x[31785]=0;U(45,a|0,b|0,f|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break e}}dc(k)}fb=g+80|0;return}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0;break a}f=N()|0}dc(k);Q(f|0);p()}function qla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;r=x[a+128>>2];if(r){k=x[a+8>>2];g=x[a+12>>2];s=Cg(k,g,r);t=hb;h=x[a+76>>2];bg(x[a>>2],x[a+4>>2],sf(k,g,d),hb);q=hb>>>0>h>>>0?d:0}else{q=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;q=q-1|0;h=q;s=h?s:0;t=h?t:0;k=(((g&2147483647)<<1|b>>>31)&-2)+y|0;g=r;a:{b:while(1){c:{if((g|0)<=0){Qb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){_d(j,i>>>3<<16>>16);Zd(j,4);Qb(f+40|0,s,t);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}_d(j,i>>>3<<16>>16);Zd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Ag(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;w=e<<8;e=w;e=sua(h,G,e,e>>31);m=hb;n=e;e=Xb(l,-16777216,16776704);e=sua(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Xb(H,-16777216,16776704);m=sua(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Rc(m,e,24);x[g+4>>2]=e-(w&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];p=x[a+28>>2]+p|0;x[c>>2]=x[c>>2]+D(x[f>>2],p>>12);o=b+o|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],o>>12);Qb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Fb(a);x[31785]=0;X(87);c=x[31785];x[31785]=0;a:{b:{if((c|0)==1){c=Ua(48732,125240,125824,0)|0;d=gb;c:{d:{e:{if(($(48732)|0)==(d|0)){c=Y(c|0)|0;x[31785]=0;b=P(994,a|0,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}x[31785]=0;b=P(994,b|0,18589)|0;d=x[31785];x[31785]=0;if((d|0)==1){break e}x[31785]=0;d=P(994,b|0,18565)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31785]=0;P(994,d|0,(b?b:22485)|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;break a}f:{if(($(125240)|0)==(d|0)){c=Y(c|0)|0;x[31785]=0;b=P(994,a|0,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break f}x[31785]=0;b=P(994,b|0,18589)|0;d=x[31785];x[31785]=0;if((d|0)==1){break f}x[31785]=0;d=P(994,b|0,18540)|0;b=x[31785];x[31785]=0;if((b|0)==1){break f}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31785]=0;P(994,d|0,(b?b:22485)|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break f}x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;break a}e=$(125824)|0;c=Y(c|0)|0;g:{if((d|0)==(e|0)){x[31785]=0;b=P(994,a|0,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break g}x[31785]=0;b=P(994,b|0,18589)|0;d=x[31785];x[31785]=0;if((d|0)==1){break g}x[31785]=0;d=P(994,b|0,18556)|0;b=x[31785];x[31785]=0;if((b|0)==1){break g}b=ib[x[x[c>>2]+8>>2]](c)|0;x[31785]=0;P(994,d|0,(b?b:22485)|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break g}x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;break a}x[31785]=0;b=P(994,a|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}x[31785]=0;b=P(994,b|0,18589)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}x[31785]=0;P(994,b|0,13813)|0;b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;break a}b=N()|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;if((c|0)!=1){break a}break c}b=N()|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;if((c|0)==1){break c}break a}b=N()|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;if((c|0)!=1){break a}}T(0)|0;Rb()}p()}return}tb(a);Q(b|0);p()}function g0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=fb-48|0;fb=f;l=f+29|0;m=f+27|0;n=Jg(f+42|0);while(1){a:{if(A[a+12>>2]>j>>>0){Ve(f+32|0,x[a>>2],x[x[a+48>>2]+12>>2],j);b:while(1){if(!Mb(x[c>>2],x[c+8>>2],1)){break a}e=be(c);if((e|0)==255){break a}g=n;k=e<<24>>24;e=k&31;if(Nf(x[x[a+48>>2]+12>>2])>>>0>e>>>0){g=Vc(x[f+32>>2],e)}d=1;if(!(k&64)){e=be(c);i=e<<24>>24;d=255;e=e&127;c:{d:{if((e|0)==1){break d}d=e-1|0;if(b?d>>>0<=120:0){break d}if((e-109&255)>>>0<159|b){break c}d=e+13|0}v[g|0]=d}q=g,r=be(c),v[q+1|0]=r;d=(i|0)<0}i=g+3|0;e=g+5|0;while(1){e:{f:{g:{if(d&1){w[f+28>>1]=y[g+4|0]|y[g+5|0]<<8;x[f+24>>2]=y[g|0]|y[g+1|0]<<8|(y[g+2|0]<<16|y[g+3|0]<<24);d=be(c);h=d&63;o=d<<24>>24;if(d&64){v[g+4|0]=h;v[g+2|0]=1;break e}d=be(c);v[e|0]=d;if(h>>>0<=15){Mf(g,h,d);h:{i:{j:{d=y[g+3|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}v[i|0]=9;v[e|0]=D(y[e|0]&15,17);break f}v[g+2|0]=1;v[g+3|0]=0;x[f+20>>2]=y[g+5|0]+1>>>1;x[f+16>>2]=64;q=g,r=x[pd(f+20|0,f+16|0)>>2],v[q+4|0]=r;break f}if((d|0)!=19){break f}if(y[e|0]==128){break g}xr(g);break f}if(h>>>0>44){break f}v[i|0]=y[h+24816|0];k:{switch(h-16|0){case 0:if(d>>>0>1){break g}v[e|0]=d|158;break f;case 1:case 2:v[f+20|0]=15;q=e,r=y[Ub(f+20|0,e)|0]|224,v[q|0]=r;break f;case 5:case 6:x[f+20>>2]=16;x[f+16>>2]=d+1;q=e,r=x[pd(f+20|0,f+16|0)>>2]/2|240,v[q|0]=r;break f;case 14:l:{m:{n:{o:{p:{h=d>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}v[i|0]=2;v[e|0]=d|240;break f}v[i|0]=3;v[e|0]=d|240;break f}v[i|0]=11;v[e|0]=(d<<3&120)+8|15;break f}v[i|0]=11;v[e|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}x[f+20>>2]=d+1>>>1;x[f+16>>2]=64;q=e,r=x[pd(f+20|0,f+16|0)>>2],v[q|0]=r;break f}if((k|0)>=0){continue b}break a}v[i|0]=0}gw(i,e,m,l);d=y[f+27|0];p=Uh(d);h=y[i|0];if(p>>>0<=Uh(h)>>>0){break e}if(!y[g+2|0]){wr(f+14|0,h,y[g+5|0],1);h=y[f+14|0];v[g+4|0]=y[f+15|0];v[g+2|0]=h}v[i|0]=d;v[e|0]=y[f+29|0]}d=(o|0)<0;continue}}}fb=f+48|0;return}j=j+1|0;continue}}function cV(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=fb-32|0;fb=b;d=y[a+13|0];a:{if(d&227|(d&24)==16){break a}d=y[a+8|0];e=y[a+6|0]|y[a+7|0]<<8;v[b+22|0]=0;v[b+26|0]=d;w[b+24>>1]=e;w[b+20>>1]=0;while(1){if((c|0)!=3){d=y[xb(b+24|0,c)|0];h=xb(b+20|0,c),i=d,v[h|0]=i;c=c+1|0;continue}break}d=_f(b+20|0);e=y[a+11|0];f=y[a+9|0]|y[a+10|0]<<8;c=0;v[b+18|0]=0;v[b+26|0]=e;w[b+24>>1]=f;w[b+16>>1]=0;while(1){if((c|0)!=3){e=y[xb(b+24|0,c)|0];h=xb(b+16|0,c),i=e,v[h|0]=i;c=c+1|0;continue}break}c=0;if(_f(b+16|0)>>>0<d>>>0){break a}d=a+6|0;c=a+9|0;e=y[c+2|0];f=y[c|0]|y[c+1|0]<<8;c=0;v[b+22|0]=0;v[b+26|0]=e;w[b+24>>1]=f;w[b+20>>1]=0;while(1){if((c|0)!=3){e=y[xb(b+24|0,c)|0];h=xb(b+20|0,c),i=e,v[h|0]=i;c=c+1|0;continue}break}e=_f(b+20|0);f=y[d+2|0];d=y[d|0]|y[d+1|0]<<8;c=0;v[b+18|0]=0;v[b+26|0]=f;w[b+24>>1]=d;w[b+16>>1]=0;while(1){if((c|0)!=3){d=y[xb(b+24|0,c)|0];h=xb(b+16|0,c),i=d,v[h|0]=i;c=c+1|0;continue}break}c=0;d=_f(b+16|0);if((d|0)!=(e|0)&(y[a+14|0]|y[a+15|0]<<8)>>>0<100){break a}e=e-d|0;d=y[a+13|0];if(d&4?e&1:0){break a}b:{if(d&8){d=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;v[b+22|0]=0;w[b+24>>1]=f;v[b+26|0]=d;w[b+20>>1]=0;while(1){if((c|0)!=3){d=y[xb(b+24|0,c)|0];h=xb(b+20|0,c),i=d,v[h|0]=i;c=c+1|0;continue}break}if(!_f(b+20|0)){break b}}d=y[a+5|0];f=y[a+3|0]|y[a+4|0]<<8;c=0;v[b+22|0]=0;v[b+26|0]=d;w[b+24>>1]=f;w[b+20>>1]=0;while(1){if((c|0)!=3){d=y[xb(b+24|0,c)|0];h=xb(b+20|0,c),i=d,v[h|0]=i;c=c+1|0;continue}break}if(_f(b+20|0)){d=a+3|0;f=y[d+2|0];g=y[d|0]|y[d+1|0]<<8;c=0;v[b+18|0]=0;w[b+24>>1]=g;v[b+26|0]=f;w[b+16>>1]=0;while(1){if((c|0)!=3){f=y[xb(b+24|0,c)|0];h=xb(b+16|0,c),i=f,v[h|0]=i;c=c+1|0;continue}break}if(_f(b+16|0)>>>0>e>>>0){break b}e=y[a+2|0];a=y[a|0]|y[a+1|0]<<8;c=0;v[b+14|0]=0;w[b+24>>1]=a;v[b+26|0]=e;w[b+12>>1]=0;while(1){if((c|0)!=3){a=y[xb(b+24|0,c)|0];h=xb(b+12|0,c),i=a,v[h|0]=i;c=c+1|0;continue}break}a=_f(b+12|0);e=y[d+2|0];d=y[d|0]|y[d+1|0]<<8;c=0;v[b+10|0]=0;v[b+26|0]=e;w[b+24>>1]=d;w[b+8>>1]=0;while(1){if((c|0)!=3){d=y[xb(b+24|0,c)|0];h=xb(b+8|0,c),i=d,v[h|0]=i;c=c+1|0;continue}break}c=0;if(_f(b+8|0)>>>0<=a>>>0){break a}}c=1;break a}c=0}fb=b+32|0;return c}function Wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=0,o=0,p=0,q=0,r=E(0),s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,C=0,D=0,F=E(0),G=E(0),H=E(0),I=0,J=0,K=0,L=0,M=E(0),N=E(0),O=E(0),P=E(0),Q=E(0),R=E(0),S=0,T=0,U=E(0);if(wi(a+44|0)){f=x[a+44>>2];y=Hc(f,0);z=Hc(f,1);f=x[a+56>>2];A=Hc(f,0);C=Hc(f,1);n=x[a+4300>>2];s=x[a+4296>>2];m=s+1|0;k=a+4304|0;f=a+4272|0;t=m+x[wb(f,0)>>2]&4095;o=k+(t<<4)|0;u=m+x[wb(f,1)>>2]&4095;j=((u<<4)+k|0)+4|0;v=m+x[wb(f,2)>>2]&4095;p=((v<<4)+k|0)+8|0;i=x[wb(f,3)>>2];g=x[wb(f,4)>>2]+n|0;w=i+m&4095;D=((w<<4)+k|0)+12|0;q=x[wb(f,5)>>2]+n|0;i=a+4232|0;I=a+69840|0;J=a+78032|0;m=d;while(1){if(m){u=u-1&4095;f=((u<<4)+k|0)+4|0;e=B[f>>2];K=g&1023;g=(K<<3)+I|0;r=B[g>>2];M=B[D>>2];N=B[p>>2];O=B[j>>2];P=B[o>>2];Q=B[z>>2];R=B[y>>2];F=B[wb(i,0)>>2];G=B[g+4>>2];j=wb(i,0);t=t-1&4095;o=(t<<4)+k|0;h=B[o>>2];H=B[j>>2];g=n<<3;j=g+I|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[j+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[j>>2]=l+E(h*E(.6180340051651001));B[o>>2]=e;B[f>>2]=h;w=w-1&4095;j=(w<<4)+k|0;D=j+12|0;e=B[D>>2];L=q&1023;p=(L<<3)+J|0;r=B[p>>2];F=B[wb(i,1)>>2];G=B[p+4>>2];S=wb(i,1);v=v-1&4095;q=(v<<4)+k|0;p=q+8|0;h=B[p>>2];H=B[S>>2];g=g+J|0;l=e;e=E(E(e*E(.6180340051651001))+E(r*F));B[g+4>>2]=l+E(e*E(-.6180340051651001));l=h;h=E(E(G*H)+E(h*E(-.6180340051651001)));B[g>>2]=l+E(h*E(.6180340051651001));B[q+8>>2]=e;B[j+12>>2]=h;h=e;e=E(R+E(1.0000000031710769e-30));B[A>>2]=h+E(E(e*B[a+4224>>2])+B[o>>2]);h=E(Q+E(1.0000000031710769e-30));B[C>>2]=E(E(h*B[a+4224>>2])+B[f>>2])+B[j+12>>2];g=(s<<4)+k|0;l=e;e=B[a+4228>>2];r=E(l*e);T=g,U=E(r+E(E(B[o>>2]*B[wb(i,2)>>2])+E(P*B[wb(i,3)>>2]))),B[T>>2]=U;e=E(h*e);T=g,U=E(e+E(E(B[f>>2]*B[wb(i,4)>>2])+E(O*B[wb(i,5)>>2]))),B[T+4>>2]=U;T=g,U=E(E(E(B[q+8>>2]*B[wb(i,6)>>2])+E(N*B[wb(i,7)>>2]))-e),B[T+8>>2]=U;T=g,U=E(r+E(E(B[j+12>>2]*B[wb(i,8)>>2])+E(M*B[wb(i,9)>>2]))),B[T+12>>2]=U;m=m-1|0;C=C+4|0;A=A+4|0;z=z+4|0;y=y+4|0;q=L-1|0;g=K-1|0;n=n-1&1023;s=s-1&4095;j=f;continue}else{x[a+4300>>2]=n;x[a+4296>>2]=s;f=a;a=x[a+56>>2];Li(f,b,c,Hc(a,0),Hc(a,1),d)}break}}}function Lz(a){a=a|0;var b=0,c=0,d=E(0),e=0;Tb(a+4960|0,0,76);v[a+5044|0]=0;x[a+5036>>2]=0;x[a+5040>>2]=0;b=x[a+4292>>2];d=B[a+4268>>2];x[31785]=0;e=a+4504|0;if(d<E(4294967296)&d>=E(0)){c=~~d>>>0}else{c=0}aa(982,e|0,67,5,c|0,b|0);b=x[31785];x[31785]=0;a:{if((b|0)==1){break a}b=x[a+4296>>2];x[31785]=0;aa(982,a+4528|0,62,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4300>>2];x[31785]=0;aa(982,a+4552|0,53,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4304>>2];x[31785]=0;aa(982,a+4576|0,43,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4308>>2];x[31785]=0;aa(982,a+4600|0,32,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4312>>2];x[31785]=0;aa(982,a+4624|0,22,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4316>>2];x[31785]=0;aa(982,a+4648|0,75,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4320>>2];x[31785]=0;aa(982,a+4672|0,69,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4324>>2];x[31785]=0;aa(982,a+4696|0,60,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4328>>2];x[31785]=0;aa(982,a+4720|0,48,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4332>>2];x[31785]=0;aa(982,a+4744|0,36,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4336>>2];x[31785]=0;aa(982,a+4768|0,25,5,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}x[31785]=0;aa(982,a+4792|0,0,0,0,0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4344>>2];x[31785]=0;aa(982,a+4816|0,3,0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+4348>>2];x[31785]=0;aa(982,a+4840|0,3,0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}x[31785]=0;aa(982,a+4864|0,407,1,c|0,0);b=x[31785];x[31785]=0;if((b|0)==1){break a}x[31785]=0;aa(982,a+4888|0,400,1,c|0,0);b=x[31785];x[31785]=0;if((b|0)==1){break a}x[31785]=0;aa(982,a+4912|0,10,0,c|0,-1);b=x[31785];x[31785]=0;if((b|0)==1){break a}x[31785]=0;aa(982,a+4936|0,10,0,c|0,-1);c=x[31785];x[31785]=0;if((c|0)==1){break a}v[a+5045|0]=1;return}c=T(125240)|0;if((gb|0)==($(125240)|0)){Y(c|0)|0;v[a+5045|0]=0;Z();return}Q(c|0);p()}function jha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=E(0),z=0,A=0,C=0,D=0,G=0,H=0,I=E(0),J=0,K=0,L=0,M=0,N=0,O=E(0),P=0,Q=E(0);a:{if(!x[a+4316>>2]){break a}if(!wi(a+44|0)){break a}G=a+4300|0;H=a+4288|0;J=a+4264|0;K=a+4276|0;e=x[a+44>>2];s=Hc(e,0);t=Hc(e,1);e=x[a+56>>2];u=Hc(e,0);v=Hc(e,1);L=ib[x[x[a>>2]+196>>2]](a)|0;w=E(E(ib[x[x[a>>2]+204>>2]](a))/E(100));I=E(ib[x[x[a>>2]+192>>2]](a));z=ib[x[x[a>>2]+216>>2]](a)|0;M=z&1;o=x[a+4324>>2];i=x[a+4320>>2];m=x[a+4328>>2];k=x[a+4312>>2];N=x[a+4276>>2];p=x[a+4264>>2];A=x[a+4256>>2];C=y[a+4260|0];r=a+4316|0;D=d;while(1){if(D){h=B[t>>2];l=B[s>>2];j=x[r>>2];e=qo(j,k+A|0);j=qo(j,k);b:{if(C){P=wb(H,m),Q=l,B[P>>2]=Q;P=wb(G,m),Q=h,B[P>>2]=Q;q=wb(p,e);P=wb(p,j),Q=E(E(B[q>>2]*w)+l),B[P>>2]=Q;g=E(E(B[wb(N,e)>>2]*w)+h);e=K;break b}g=E(E(B[wb(p,e)>>2]*w)+E(E(l+h)*E(.5)));e=J}P=wb(x[e>>2],j),Q=g,B[P>>2]=Q;c:{if(L){f=B[a+4244>>2];g=E(f+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f+B[a+4240>>2]);B[a+4240>>2]=f;if(g>E(1)){g=E(g+E(-2));B[a+4236>>2]=g}if(f>E(1)){f=E(f+E(-2));B[a+4240>>2]=f}g=E(F(g));g=E(E(g+g)+E(-1));f=E(F(f));f=E(E(f+f)+E(-1));break c}f=B[a+4240>>2];n=B[a+4244>>2];g=E(E(f*n)+B[a+4236>>2]);B[a+4236>>2]=g;f=E(f-E(g*n));B[a+4240>>2]=f}if(C){e=(m+2|0)%3|0;l=B[wb(H,e)>>2];h=B[wb(G,e)>>2]}e=x[r>>2];j=wb(p,qo(e,i+k|0));q=e;e=k+4096|0;O=B[wb(p,qo(q,e+i|0))>>2];n=B[j>>2];B[u>>2]=E(E(E(E(E(O-n)*E(E(i&4095)*E(.000244140625)))+n)-l)*I)+l;i=x[(C?4276:4264)+a>>2];j=x[r>>2];q=wb(i,qo(j,k+o|0));n=B[wb(i,qo(j,e+o|0))>>2];l=B[q>>2];B[v>>2]=E(E(E(E(E(n-l)*E(E(o&4095)*E(.000244140625)))+l)-h)*I)+h;m=((m|0)<=0?m+3|0:m)-1|0;x[a+4328>>2]=m;k=(((k|0)<=0?x[r>>2]<<12:0)+k|0)-4096|0;x[a+4312>>2]=k;h=M?f:g;f=B[a+4248>>2];h=E(h*f);d:{if(E(F(h))<E(2147483648)){e=~~h;break d}e=-2147483648}o=(z>>>0>1?e:0-e|0)+A|0;x[a+4324>>2]=o;i=z>>>0<4;t=t+4|0;s=s+4|0;g=E(g*f);e:{if(E(F(g))<E(2147483648)){e=~~g;break e}e=-2147483648}i=(i?e:0-e|0)+A|0;x[a+4320>>2]=i;D=D-1|0;v=v+4|0;u=u+4|0;continue}else{e=a;a=x[a+56>>2];Li(e,b,c,Hc(a,0),Hc(a,1),d)}break}}}function tqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;a:{b:{if(!c){break b}n=e,o=be(a),v[n+8|0]=o;jo(b,e+8|0);k=c-1|0;c=0;while(1){f=1;if(!k){break a}c:{d:{d=c<<1&254;e:{if(!d){if(!xf(a,e+8|0)){break b}g=1;d=y[e+8|0]<<1|1;c=d&255;if(d>>>0<=255){break e}break c}if((c&65535)>>>0>127){break d}c=d}if(!xf(a,e+8|0)){break b}w_(b,e+8|0);k=k-1|0;continue}g=1;c=d}while(1){f:{g:{h:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!xf(a,e+8|0)){break h}c=y[e+8|0]<<1|1;d=c&255;c=c>>>0>255}g=Rq(g,1)+c|0;c=d<<1&254;if(c){break g}if(!xf(a,e+8|0)){break h}d=y[e+8|0]<<1|1;c=d&255;if(d>>>0>255){continue}break f}c=0;break f}if(d>>>0>127){continue}}break}i:{if((g|0)<=2){j=0;h=g-2|0;break i}if(!xf(a,e+8|0)){break b}d=Rq(g-3|0,8)|y[e+8|0];j=((d|0)>1279?2:1)+((d|0)>31999)|0;m=d^-1;h=0}d=c<<1&254;if(d){f=c>>>0>127}else{if(!xf(a,e+8|0)){break b}c=y[e+8|0]<<1|1;d=c&255;f=c>>>0>255}l=Rq(h,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!xf(a,e+8|0)){break b}d=y[e+8|0]<<1|1;c=d&255;d=d>>>0>255}g=1;h=k;d=Rq(f+l|0,1)+d|0;if(!d){while(1){j:{k:{l:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!xf(a,e+8|0)){break l}c=y[e+8|0]<<1|1;d=c&255;c=c>>>0>255}g=Rq(g,1)+c|0;c=d<<1&254;if(c){break k}if(!xf(a,e+8|0)){break l}d=y[e+8|0]<<1|1;c=d&255;if(d>>>0>255){continue}break j}c=0;break j}if(d>>>0>127){continue}}break}d=g+2|0}g=h;h=d+j|0;f=0;if(g>>>0<h>>>0|(h|0)<=0|(m|0)>=0){break a}d=x[b+4>>2];f=0;if((0-Sc(x[b>>2],d)|0)>(m|0)){break a}d=zb(e+12|0,vb(d));v[e+8|0]=0;g=e+8|0;j=fb-32|0;fb=j;f=x[d>>2];d=x[b>>2];i=zk(f,vb(d))+d|0;d=x[Ab(b)>>2];l=x[b+4>>2];m:{if(h>>>0<=d-l>>>0){d=h;f=l-i|0;if(d>>>0>f>>>0){qp(b,h-f|0,g);d=f;if(!d){break m}}x_(b,i,l,h+i|0);Rh(i,d,(g>>>0>=i>>>0?A[b+4>>2]>g>>>0?h:0:0)+g|0);break m}d=Ab(b);d=gn(j+8|0,Ul(b,Sc(x[b>>2],l)+h|0),i-x[b>>2]|0,d);PY(d,h,g);i=ir(b,d,i);en(d)}zb(j+28|0,i);fb=j+32|0;n=e,o=Ne(KC(vb(x[b+4>>2]),h),m),x[n+8>>2]=o;n=e,o=KC(vb(x[b+4>>2]),h),x[n+4>>2]=o;d=h;while(1){f=y[ZX(e+8|0)|0];n=ZX(e+4|0),o=f,v[n|0]=o;f=d>>>0>1;d=d-1|0;if(f){continue}break}k=k-h|0;continue}}f=0}fb=e+16|0;return f|0}
function pla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;y=x[a+16>>2];z=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;q=x[a+128>>2];if(q){i=x[a+8>>2];g=x[a+12>>2];r=Cg(i,g,q);s=hb;h=x[a+76>>2];bg(x[a>>2],x[a+4>>2],sf(i,g,d),hb);p=hb>>>0>h>>>0?d:0}else{p=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;p=p-1|0;h=p;r=h?r:0;s=h?s:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=q;while(1)if((b|0)<=0){Qb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;_d(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Zd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Ag(j,z);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];t=x[a+68>>2];E=t>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){u=(b<<2)+f|0;e=x[u>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;v=e<<8;e=v;e=sua(h,G,e,e>>31);l=hb;m=e;e=Xb(k,-16777216,16776704);e=sua(i,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Xb(H,-16777216,16776704);l=sua(t,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Rc(l,e,24);x[g+4>>2]=e-(v&C);x[u>>2]=(e|0)/256;b=b+1|0;continue}break}b=x[a+32>>2];o=x[a+28>>2]+o|0;x[c>>2]=x[c>>2]+D(x[f>>2],o>>12);n=b+n|0;x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],n>>12);Qb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;_d(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Zd(j,4);Qb(f+40|0,r,s);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function cP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-112|0;fb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];h=y[xl(f,e)|0];if((h|0)==33){c=1}else{if((h|0)!=63){break a}c=0}Jl(d+88|0,f,e,e-1|0);e=x[d+92>>2];x[b>>2]=x[d+88>>2];x[b+4>>2]=e}f=d+88|0;de(f);e=x[d+88>>2];de(d+76|0);e=wl(e,x[d+80>>2],b);de(f);b:{c:{d:{e:{if((e|0)==x[d+92>>2]){a=x[b+4>>2];e=x[b>>2];f=pc(d+104|0,22485);h=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=h;if(Oc(e,a,d)){a=ac(8);x[31785]=0;c=P(37,d+88|0,10492)|0;b=x[31785];x[31785]=0;if((b|0)==1){break d}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}g=0;if(!c){break e}a=ac(8);c=x[b+4>>2];b=x[b>>2];x[31785]=0;e=di(d+76|0,b,c);b=x[31785];x[31785]=0;f:{g:{h:{if((b|0)!=1){x[31785]=0;S(1020,d+88|0,18489,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break h}nc(a,d+88|0);c=0;x[31785]=0;S(100,a|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(d+88|0);break g}b=N()|0;break f}b=N()|0;c=1}tb(e);if(!c){break c}}jc(a);break c}if(x[e+4>>2]!=2){a=ac(8);x[31785]=0;c=P(37,d+88|0,11605)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=x[b+4>>2];b=x[b>>2];e=pc(d+68|0,22485);f=x[e+4>>2];x[d+32>>2]=x[e>>2];x[d+36>>2]=f;if(Oc(b,c,d+32|0)){a=ac(8);x[31785]=0;c=P(37,d+88|0,10492)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}e=pc(d+60|0,7779);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Oc(b,c,d+24|0)){g=1;if(!Ad(y[a+28|0])){break e}g=65536/+A[x[a+24>>2]+480244>>2];break e}e=pc(d+52|0,7831);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Oc(b,c,d+16|0)){g=1;if(!Ad(y[a+28|0])){break e}g=+A[x[a+24>>2]+480240>>2]*152587890625e-16;break e}e=pc(d+44|0,7849);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;g=0;if(!Oc(b,c,d+8|0)){break e}g=+A[x[a+24>>2]+480236>>2]*152587890625e-16}fb=d+112|0;return+g}b=N()|0;jc(a)}Q(b|0)}p()}function ula(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;u=x[a+16>>2];w=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;p=x[a+128>>2];if(p){k=x[a+8>>2];g=x[a+12>>2];q=Cg(k,g,p);r=hb;h=x[a+76>>2];bg(x[a>>2],x[a+4>>2],sf(k,g,d),hb);o=hb>>>0>h>>>0?d:0}else{o=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;o=o-1|0;h=o;q=h?q:0;r=h?r:0;k=(((g&2147483647)<<1|b>>>31)&-2)+u|0;g=p;a:{b:while(1){c:{if((g|0)<=0){Qb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(!h){break a}b=x[f+40>>2];g=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;i=0;b=0;break c}b=x[f+40>>2];h=((x[f+44>>2]&2147483647)<<1|b>>>31)&-2;b=0;i=0;while(1)if((b|0)==2){_d(j,i>>>3<<16>>16);Zd(j,4);Qb(f+40|0,q,r);g=g-1|0;continue b}else{i=(v[k+(b+h|0)|0]<<8)+i|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){i=(v[k+(b+g|0)|0]<<8)+i|0;b=b+1|0;continue}break}_d(j,i>>>3<<16>>16);Zd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Ag(j,w);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];i=x[a+68>>2];E=i>>31;k=x[a+64>>2];F=k>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];l=x[g+4>>2];x[g+8>>2]=l;t=e<<8;e=t;e=sua(h,G,e,e>>31);m=hb;n=e;e=Xb(l,-16777216,16776704);e=sua(k,F,e,e>>31);l=n+e|0;n=hb+m|0;n=e>>>0>l>>>0?n+1|0:n;e=Xb(H,-16777216,16776704);m=sua(i,E,e,e>>31);l=m+l|0;e=hb+n|0;e=l>>>0<m>>>0?e+1|0:e;m=l+8388608|0;e=m>>>0<8388608?e+1|0:e;e=Rc(m,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(x[f+4>>2],y);Qb(f+8|0,A,B);c=c+8|0;continue}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function gQ(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=fb-128|0;fb=j;a:{b:{c:{if(!_m(f,g,h,i,0,0,0,0)){break c}l=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){k=4;if(n){break e}k=f|h|(g|l)?3:2;break d}k=!(f|h|(g|l))}}s=e>>>16|0;o=s&32767;if((o|0)==32767){break c}if(k){break b}}Rd(j+16|0,b,c,d,e,f,g,h,i);b=x[j+16>>2];d=x[j+20>>2];e=x[j+24>>2];c=x[j+28>>2];GQ(j,b,d,e,c,b,d,e,c);d=x[j+8>>2];e=x[j+12>>2];h=x[j>>2];i=x[j+4>>2];break a}k=d;p=e&2147483647;n=h;m=i&2147483647;if((_m(b,c,k,p,f,g,h,m)|0)<=0){if(_m(b,c,k,p,f,g,n,m)){h=b;i=c;break a}Rd(j+112|0,b,c,d,e,0,0,0,0);d=x[j+120>>2];e=x[j+124>>2];h=x[j+112>>2];i=x[j+116>>2];break a}q=i>>>16&32767;if(o){i=c;h=b}else{Rd(j+96|0,b,c,k,p,0,0,0,1081540608);k=x[j+104>>2];h=x[j+108>>2];p=h;o=(h>>>16|0)-120|0;i=x[j+100>>2];h=x[j+96>>2]}if(!q){Rd(j+80|0,f,g,n,m,0,0,0,1081540608);n=x[j+88>>2];f=x[j+92>>2];m=f;q=(f>>>16|0)-120|0;g=x[j+84>>2];f=x[j+80>>2]}r=n;t=m&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;f:{if((l|0)>0|(l|0)>=0){k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(!(h|n|(i|l))){Rd(j+32|0,b,c,d,e,0,0,0,0);d=x[j+40>>2];e=x[j+44>>2];h=x[j+32>>2];i=x[j+36>>2];break a}l=l<<1|n>>>31;k=n<<1|i>>>31;break f}l=p<<1|k>>>31;k=k<<1|i>>>31}p=l;l=i<<1|h>>>31;h=h<<1;i=l;o=o-1|0;if((o|0)>(q|0)){continue}break}o=q}m=k-r|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=m-l|0;l=(p-((k>>>0<r>>>0)+t|0)|0)-(l>>>0>m>>>0)|0;m=l;g:{if((l|0)<0){n=k;m=p;break g}k=h;h=h-f|0;i=i-((f>>>0>k>>>0)+g|0)|0;if(h|n|(i|m)){break g}Rd(j+48|0,b,c,d,e,0,0,0,0);d=x[j+56>>2];e=x[j+60>>2];h=x[j+48>>2];i=x[j+52>>2];break a}if((m|0)==65535|m>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m<<1|n>>>31;n=c|n<<1;m=b;if(b>>>0<65536){continue}break}}b=s&32768;if((o|0)<=0){Rd(j- -64|0,h,i,n,m&65535|(b|o+120)<<16,0,0,0,1065811968);d=x[j+72>>2];e=x[j+76>>2];h=x[j+64>>2];i=x[j+68>>2];break a}d=n;e=m&65535|(b|o)<<16}x[a>>2]=h;x[a+4>>2]=i;x[a+8>>2]=d;x[a+12>>2]=e;fb=j+128|0}function Yna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-112|0;fb=d;a:{b:{c:{d:{switch(y[a|0]-23|0){case 0:e=v[a+1|0];f=d,g=rD(c,+y[a+2|0]*1e4/240),v[f+12|0]=g;x[d+88>>2]=127;x[d+76>>2]=(D(y[a+3|0],127)>>>0)/185;f=d,g=x[pd(d+88|0,d+76|0)>>2],v[f+111|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:bw(d+76|0,15814);x[31785]=0;O(562,d- -64|0,d+12|0);a=x[31785];x[31785]=0;f:{g:{h:{i:{if((a|0)!=1){x[31785]=0;O(562,d+52|0,d+111|0);a=x[31785];x[31785]=0;if((a|0)==1){break i}x[31785]=0;V(563,d+88|0,d+76|0,d- -64|0,d+52|0);a=x[31785];x[31785]=0;if((a|0)==1){break h}a=d+88|0;ue(d+100|0,a);qf(b,x[d+100>>2],x[d+104>>2]);tb(a);tb(d+52|0);tb(d- -64|0);Eb(d+76|0);break b}a=N()|0;break f}a=N()|0;break g}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;case 1:bw(d+76|0,15761);x[31785]=0;O(562,d- -64|0,d+12|0);a=x[31785];x[31785]=0;j:{k:{l:{m:{if((a|0)!=1){x[31785]=0;O(562,d+52|0,d+111|0);a=x[31785];x[31785]=0;if((a|0)==1){break m}x[31785]=0;V(563,d+88|0,d+76|0,d- -64|0,d+52|0);a=x[31785];x[31785]=0;if((a|0)==1){break l}a=d+88|0;ue(d+44|0,a);qf(b,x[d+44>>2],x[d+48>>2]);tb(a);tb(d+52|0);tb(d- -64|0);Eb(d+76|0);break b}a=N()|0;break j}a=N()|0;break k}a=N()|0;tb(d+52|0)}tb(d- -64|0)}break c;default:break e}}a=pc(d+36|0,15841);qf(b,x[a>>2],x[a+4>>2]);break b;case 1:break d;default:break a}}c=v[a+1|0];v[d+111|0]=(c|0)<5?c:0;c=v[a+2|0];v[d+35|0]=(c|0)<0?127:c;a=v[a+3|0];v[d+34|0]=(a|0)<0?127:a;a=fb-16|0;fb=a;c=Cc(a+4|0,4068);Yc(d+76|0,c);tb(c);fb=a+16|0;x[31785]=0;O(562,d- -64|0,d+111|0);a=x[31785];x[31785]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){x[31785]=0;O(562,d+52|0,d+35|0);a=x[31785];x[31785]=0;if((a|0)==1){break s}x[31785]=0;O(562,d+12|0,d+34|0);a=x[31785];x[31785]=0;if((a|0)==1){break r}x[31785]=0;aa(744,d+88|0,d+76|0,d- -64|0,d+52|0,d+12|0);a=x[31785];x[31785]=0;if((a|0)==1){break q}a=d+88|0;ue(d+24|0,a);qf(b,x[d+24>>2],x[d+28>>2]);tb(a);tb(d+12|0);tb(d+52|0);tb(d- -64|0);Eb(d+76|0);break b}a=N()|0;break n}a=N()|0;break o}a=N()|0;break p}a=N()|0;tb(d+12|0)}tb(d+52|0)}tb(d- -64|0)}}Eb(d+76|0);Q(a|0);p()}e=1}fb=d+112|0;return e|0}function Wla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}A=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+32>>2];C=x[a+28>>2];E=x[a+72>>2];z=x[a+68>>2];F=z>>31;l=x[a+64>>2];G=l>>31;j=x[a+60>>2];H=j>>31;while(1){if(d){b=x[f+16>>2];v=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+A|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];y=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=v+(r<<1)|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],y)|0)+D(w[k+8>>1],t)|0)+D(s,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+28|0)+(q<<3)|0;y=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=sua(j,H,e,e>>31);i=hb;v=e;e=Xb(g,-16777216,16776704);e=sua(l,G,e,e>>31);g=v+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Xb(y,-16777216,16776704);i=sua(z,F,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(s&E);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+C|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+B|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Qb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Xla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}u=b+196648|0;break a}u=b+131112|0;break a}u=b+262184|0}B=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}o=x[a+40>>2];p=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+32>>2];E=x[a+28>>2];F=x[a+72>>2];A=x[a+68>>2];G=A>>31;l=x[a+64>>2];H=l>>31;j=x[a+60>>2];I=j>>31;while(1){if(d){b=x[f+16>>2];y=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+B|0;b=(b>>>16&65520)+u|0;m=w[b+14>>1];s=w[b+12>>1];t=w[b+10>>1];z=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];q=0;r=0;while(1){if((r|0)!=2){k=r+y|0;x[(f+8|0)+(r<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],z)|0)+D(v[k+4|0],t)|0)+D(s,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;r=r+1|0;continue}break}while(1){if((q|0)!=2){t=(f+8|0)+(q<<2)|0;e=x[t>>2];b=(f+28|0)+(q<<3)|0;z=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;s=e<<8;e=s;e=sua(j,I,e,e>>31);i=hb;y=e;e=Xb(g,-16777216,16776704);e=sua(l,H,e,e>>31);g=y+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Xb(z,-16777216,16776704);i=sua(A,G,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(s&F);x[t>>2]=(e|0)/256;q=q+1|0;continue}break}p=p+E|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],p>>12);o=o+C|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],o>>12);Qb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=o;x[a+20>>2]=p>>12;x[a+36>>2]=p;x[a+24>>2]=o>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function we(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;e=x[a>>2];a:{if(mc(e,x[a+4>>2])){break a}g=x[b+4>>2];if(g>>>0>=A[a+12>>2]){break a}c=z[b+8>>1];i=x[x[a+48>>2]+12>>2];f=Nf(i);if(c>>>0>=f>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?f-1|0:c;f=g;g=d?0:c;c=gd(e,i,f,g);f=y[b+12|0];j=f&4;b:{c:{if(f&2){break c}k=y[b+10|0];e=c;d=g;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((k|0)!=y[e+3|0]){break d}break b}if((k|0)==y[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}k=l&65535;d=c;e=g;while(1){if(k>>>0>=(e&65535)>>>0){e:{if(!j){if(y[d+3|0]){break e}v[d+3|0]=y[b+10|0];v[d+5|0]=y[b+11|0];break b}if(y[d+2|0]){break e}v[d+2|0]=y[b+10|0];v[d+4|0]=y[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(f&1)){break f}d=x[i+480180>>2]&2;g:{h:{i:{if(!j){while(1){if((g&65535)>>>0<=(l&65535)>>>0){j:{k:{switch(y[c+3|0]-9|0){case 4:if(!Lv(x[x[i+8>>2]+88>>2],1)){break j}d=1;v[c+2|0]=1;v[c+4|0]=y[c+5|0];v[c+3|0]=y[b+10|0];v[c+5|0]=y[b+11|0];break a;case 0:break k;default:break j}}l:{if(d){e=y[c+5|0];if(e>>>0>128){break j}v[c+2|0]=2;v[c+3|0]=y[b+10|0];a=1;break l}v[c+2|0]=2;v[c+3|0]=y[b+10|0];e=y[c+5|0];a=2}v[c+4|0]=a+e>>>a;v[c+5|0]=y[b+11|0];break b}c=c+6|0;g=g+1|0;continue}break}if(!j){break i}}e=y[b+11|0];g=13;m:{switch(y[b+10|0]-1|0){case 1:g=9;e=ej(e<<(d?1:2));break;case 0:break m;default:break g}}v[b+11|0]=e;v[b+10|0]=g;f=f&254;break h}v[h+15|0]=0;v[h+14|0]=0;g=b;c=!d;d=y[b+10|0];n:{if(!(c|(d|0)!=9)){e=y[b+11|0];if(e>>>0>128){break g}d=2;c=e>>>1|0;break n}e=h+12|0;wr(e,d,y[b+11|0],1);d=h+4|0;GD(d,h+15|0,h+14|0);FD(d,e);d=y[h+15|0];if(!d){f=y[b+12|0];break g}f=y[b+12|0];c=y[h+14|0]}v[g+11|0]=c;v[b+10|0]=d;f=f&254}v[b+12|0]=f}d=1;if(f&1){break f}v[b+12|0]=f^4;if(we(a,b)){break a}}d=0;o:{p:{switch(x[b>>2]-1|0){case 0:c=x[b+4>>2]+1|0;if(c>>>0>=A[a+12>>2]){break a}x[b+4>>2]=c;break o;case 1:break p;default:break a}}c=x[b+4>>2];if(!c){break a}x[b+4>>2]=c-1}v[b+12|0]=y[b+12|0]|1;d=we(a,b);break a}d=1}fb=h+16|0;return d}function _T(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0;c=fb-176|0;fb=c;i=1;p=2;d=x[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;v=D(i,3);w=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=x[a+12>>2];continue a}d=x[a>>2];e=Ud(d,h<<1);mR(c+160|0,C[e>>3],C[e+8>>3]);d=Ud(d,h);mR(c+144|0,C[d>>3],C[d+8>>3]);Oi(c+128|0,C[c+144>>3],C[c+152>>3],C[c+160>>3],C[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=x[b>>2];e=Ud(f,d);g=e+8|0;j=x[g+4>>2];x[c+120>>2]=x[g>>2];x[c+124>>2]=j;g=x[e+4>>2];x[c+112>>2]=x[e>>2];x[c+116>>2]=g;k=d+i|0;g=Ud(f,k);n=C[g+8>>3];o=C[g>>3];r=d+w|0;g=Ud(f,r);j=x[g+12>>2];x[c+104>>2]=x[g+8>>2];x[c+108>>2]=j;j=x[g+4>>2];x[c+96>>2]=x[g>>2];x[c+100>>2]=j;s=d+v|0;f=Ud(f,s);t=C[f+8>>3];u=C[f>>3];g=c+80|0;f=c+112|0;Al(g,f,o,n);j=c- -64|0;Bj(j,f,o,n);l=c+96|0;Al(c+48|0,l,u,t);f=c+16|0;Bj(f,l,u,t);Oi(c+32|0,0,1,C[c+16>>3],C[c+24>>3]);Al(f,g,C[c+48>>3],C[c+56>>3]);l=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=l;l=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=l;Al(c,j,C[c+32>>3],C[c+40>>3]);Oi(f,C[c+160>>3],C[c+168>>3],C[c>>3],C[c+8>>3]);e=Ud(x[b>>2],k);k=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=k;k=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=k;Bj(c,g,C[c+48>>3],C[c+56>>3]);Oi(f,C[c+144>>3],C[c+152>>3],C[c>>3],C[c+8>>3]);e=Ud(x[b>>2],r);g=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=g;Bj(c,j,C[c+32>>3],C[c+40>>3]);Oi(f,C[c+128>>3],C[c+136>>3],C[c>>3],C[c+8>>3]);e=Ud(x[b>>2],s);f=x[c+28>>2];x[e+8>>2]=x[c+24>>2];x[e+12>>2]=f;f=x[c+20>>2];x[e>>2]=x[c+16>>2];x[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=x[b>>2];a=Ud(h,d+i|0);m=Ud(h,d);n=C[a>>3];o=C[a+8>>3];Bj(c+160|0,m,n,o);h=x[c+172>>2];x[a+8>>2]=x[c+168>>2];x[a+12>>2]=h;h=x[c+164>>2];x[a>>2]=x[c+160>>2];x[a+4>>2]=h;mA(Ud(x[b>>2],d),n,o);d=d+1|0;continue}}fb=c+176|0}function tla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;u=x[a+16>>2];v=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);b=0;o=x[a+128>>2];if(o){i=x[a+8>>2];g=x[a+12>>2];p=Cg(i,g,o);q=hb;h=x[a+76>>2];bg(x[a>>2],x[a+4>>2],sf(i,g,d),hb);n=hb>>>0>h>>>0?d:0}else{n=0}j=a+112|0;while(1){if((b|0)!=2){g=b<<3;h=g+(f+20|0)|0;g=a+g|0;x[h+4>>2]=x[g+44>>2];x[h+8>>2]=x[g+48>>2];b=b+1|0;continue}break}y=x[a+24>>2];z=x[a+20>>2];b=x[a+4>>2];x[f+8>>2]=x[a>>2];x[f+12>>2]=b;A=x[a+8>>2];B=x[a+12>>2];a:while(1){if(d){d=d-1|0;g=x[f+12>>2];b=x[f+8>>2];x[f+40>>2]=b;x[f+44>>2]=0;n=n-1|0;h=n;p=h?p:0;q=h?q:0;i=((((g&2147483647)<<1|b>>>31)&2147483646)<<1)+u|0;b=o;while(1)if((b|0)<=0){Qb(j,x[a+120>>2],x[a+124>>2]);h=x[a+116>>2];if(h){b=x[f+40>>2];b=(x[f+44>>2]&2147483647)<<1|b>>>31;_d(j,(w[(b<<1|2)+i>>1]+w[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Zd(j,h);x[j>>2]=x[j>>2];x[j+4>>2]=0}b=Ag(j,v);x[f+4>>2]=b;x[f>>2]=b;C=x[a+72>>2];r=x[a+68>>2];E=r>>31;i=x[a+64>>2];F=i>>31;h=x[a+60>>2];G=h>>31;b=0;while(1){if((b|0)!=2){s=(b<<2)+f|0;e=x[s>>2];g=(f+20|0)+(b<<3)|0;H=x[g+8>>2];k=x[g+4>>2];x[g+8>>2]=k;t=e<<8;e=t;e=sua(h,G,e,e>>31);l=hb;m=e;e=Xb(k,-16777216,16776704);e=sua(i,F,e,e>>31);k=m+e|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;e=Xb(H,-16777216,16776704);l=sua(r,E,e,e>>31);k=l+k|0;e=hb+m|0;e=k>>>0<l>>>0?e+1|0:e;l=k+8388608|0;e=l>>>0<8388608?e+1|0:e;e=Rc(l,e,24);x[g+4>>2]=e-(t&C);x[s>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f>>2],z);x[c+4>>2]=x[c+4>>2]+D(y,x[f+4>>2]);Qb(f+8|0,A,B);c=c+8|0;continue a}else{g=x[f+40>>2];g=(x[f+44>>2]&2147483647)<<1|g>>>31;_d(j,(w[(g<<1|2)+i>>1]+w[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);Zd(j,4);Qb(f+40|0,p,q);b=b-1|0;continue}}break}b=x[f+12>>2];x[a>>2]=x[f+8>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+20|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function t7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=Gy(x[g>>2]);o=my(x[g>>2]);ph(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31785]=0;g=P(1237,k|0,g<<24>>24)|0;i=x[31785];x[31785]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31785]=0;g=P(1237,k|0,48)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;g=v[i+1|0];x[31785]=0;g=P(1237,k|0,g|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Kd();if(!yK(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Kd();if(!Kh(h)){break d}g=g+1|0;continue}}e:{if(yd(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[31785]=0;V(1231,k|0,i|0,g|0,h|0);h=x[31785];x[31785]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i<<2);break e}ym(i,g);x[31785]=0;r=R(1229,o|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Us((i-a<<2)+d|0,x[f>>2]);break e}f:{if(v[cc(j+4|0,l)|0]<=0){break f}if(v[cc(j+4|0,l)|0]!=(m|0)){break f}m=x[f>>2];x[f>>2]=m+4;x[m>>2]=r;l=(Bb(x[j+8>>2],y[j+15|0])-1>>>0>l>>>0)+l|0;m=0}q=v[h|0];x[31785]=0;q=P(1237,k|0,q|0)|0;n=x[31785];x[31785]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+4;x[n>>2]=q;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=y[g|0];if((i|0)==46){x[31785]=0;i=R(1232,o|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}l=x[f>>2];h=l+4|0;x[f>>2]=h;x[l>>2]=i;g=g+1|0;break g}x[31785]=0;i=P(1237,k|0,i<<24>>24)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=i;g=g+1|0;continue}break}h=x[f>>2]}x[31785]=0;V(1231,k|0,g|0,c|0,h|0);i=x[31785];x[31785]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g<<2)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;tb(j+4|0);fb=j+16|0;return}a=N()|0;tb(j+4|0);Q(a|0);p()}function hK(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=x[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=x[d>>2];if(!h){break k}if(!a){g=c;break j}x[d>>2]=0;g=c;break i}l:{if(!x[x[124291]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=v[e|0];if(g){x[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}x[a>>2]=0;x[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return gf(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=y[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=x[e>>2];if((d|d-16843009)&-2139062144){break p}x[a>>2]=d&255;x[a+4>>2]=y[e+1|0];x[a+8>>2]=y[e+2|0];x[a+12>>2]=y[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=y[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}x[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=x[(f<<2)+111760>>2];d=1;continue}d=y[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=y[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=y[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;x[a>>2]=d;g=g-1|0;a=a+4|0;break q}x[31660]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=y[e|0];if(!(e&3|d-1>>>0>126)){d=x[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=x[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=x[(h<<2)+111760>>2];d=1;continue}d=y[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((y[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((y[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=y[e|0]}if(d&255){break d}if(a){x[a>>2]=0;x[b>>2]=0}return c-g|0}x[31660]=25;if(!a){break b}}x[b>>2]=e}return-1}x[b>>2]=e;return c}function Li(a,b,c,d,e,f){var g=0,h=0,i=0,j=E(0),k=E(0),l=0,m=0,n=E(0),o=E(0),p=E(0),q=0,r=E(0);m=ib[x[x[a>>2]+140>>2]](a)|0;g=x[a+20>>2];h=m?h:y[g+25|0];j=B[g+144>>2];k=E(1);if(!(ib[x[x[a>>2]+140>>2]](a)|0)){k=B[x[a+20>>2]+144>>2]}j=E(E(1)-j);a:{if((ib[x[x[a>>2]+156>>2]](a)|0)<=0){break a}if(!iQ(y[x[a+20>>2]+24|0])){break a}j=E(E(j+j)+E(-1));k=E(-j)}n=B[a+4196>>2];k=E(k*n);j=E(j*n);g=0;l=x[a+44>>2];m=Hc(l,0);l=Hc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;B[i>>2]=B[i>>2]+E(E(B[d+g>>2]*j)+E(k*B[g+m>>2]));i=c+g|0;B[i>>2]=B[i>>2]+E(E(B[e+g>>2]*j)+E(k*B[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[h+m>>2]-E(B[d+h>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]+E(B[h+l>>2]-E(B[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]+E(B[d+h>>2]-E(B[h+m>>2]*k));i=c+h|0;B[i>>2]=B[i>>2]+E(B[e+h>>2]-E(B[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;B[i>>2]=B[i>>2]-E(B[d+h>>2]-E(B[h+m>>2]*j));i=c+h|0;B[i>>2]=B[i>>2]-E(B[e+h>>2]-E(B[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=B[i>>2];q=i;r=k;n=B[h+m>>2];i=c+h|0;o=B[i>>2];p=B[h+l>>2];k=E(E(E(E(k+n)+o)+p)*E(.5));B[q>>2]=r-E(E(k+E(k-E(B[d+h>>2]*j)))-n);B[i>>2]=o-E(E(k+E(k-E(B[e+h>>2]*j)))-p);g=g+1|0;continue}}g=iQ(y[x[a+20>>2]+24|0]);j=g?E(j*E(.5)):j;k=g?E(k*E(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=E(B[d+g>>2]-B[g+m>>2]);o=E(B[g+l>>2]-B[e+g>>2]);B[i>>2]=B[i>>2]+E(E(j*n)+E(k*o));g=c+g|0;B[g>>2]=B[g>>2]+E(E(k*n)+E(j*o));h=h+1|0;continue}}i:{if(!((y[x[a+20>>2]+24|0]&4)>>>2|0)){break i}if(ib[x[x[a>>2]+140>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;B[d>>2]=B[a+m>>2]+B[d>>2];d=a+c|0;B[d>>2]=B[a+l>>2]+B[d>>2];g=g+1|0;continue}}}function D7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;j=fb-16|0;fb=j;k=lw(x[g>>2]);o=ty(x[g>>2]);ph(j+4|0,o);x[f>>2]=d;a:{b:{c:{i=a;g=y[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}x[31785]=0;g=P(29,k|0,g<<24>>24)|0;i=x[31785];x[31785]=0;if((i|0)==1){break a}i=x[f>>2];x[f>>2]=i+1;v[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|y[g|0]!=48|(y[g+1|0]|32)!=120)){x[31785]=0;g=P(29,k|0,48)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;g=v[i+1|0];x[31785]=0;g=P(29,k|0,g|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Kd();if(!yK(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=v[g|0];Kd();if(!Kh(h)){break d}g=g+1|0;continue}}e:{if(yd(x[j+8>>2],y[j+15|0])){h=x[f>>2];x[31785]=0;V(1218,k|0,i|0,g|0,h|0);h=x[31785];x[31785]=0;if((h|0)==1){break a}x[f>>2]=x[f>>2]+(g-i|0);break e}ym(i,g);x[31785]=0;r=R(1216,o|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){ym((i-a|0)+d|0,x[f>>2]);break e}f:{if(v[cc(j+4|0,m)|0]<=0){break f}if(v[cc(j+4|0,m)|0]!=(l|0)){break f}l=x[f>>2];x[f>>2]=l+1;v[l|0]=r;m=(Bb(x[j+8>>2],y[j+15|0])-1>>>0>m>>>0)+m|0;l=0}q=v[h|0];x[31785]=0;q=P(29,k|0,q|0)|0;n=x[31785];x[31785]=0;if((n|0)!=1){n=x[f>>2];x[f>>2]=n+1;v[n|0]=q;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=y[g|0];if((i|0)!=46){break g}x[31785]=0;i=R(1219,o|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0}i=x[f>>2];x[31785]=0;V(1218,k|0,g|0,c|0,i|0);i=x[31785];x[31785]=0;if((i|0)==1){break a}i=f;f=x[f>>2]+(c-g|0)|0;x[i>>2]=f;x[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;tb(j+4|0);fb=j+16|0;return}x[31785]=0;i=P(29,k|0,i<<24>>24)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}h=x[f>>2];x[f>>2]=h+1;v[h|0]=i;g=g+1|0;continue}}a=N()|0;tb(j+4|0);Q(a|0);p()}function pfa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{k=Lq(1,32);d:{e:{if(!k){a=Om(ac(4));x[31785]=0;S(100,a|0,125240,34);a=x[31785];x[31785]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:986;x[k>>2]=f;c=lg(j+68|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31785]=0;e=P(37,j+56|0,e|0)|0;m=x[31785];x[31785]=0;j:{if((m|0)!=1){x[31785]=0;m=P(997,c|0,e|0)|0;n=x[31785];x[31785]=0;if((n|0)==1){break j}x[31785]=0;O(275,m|0,l|0);l=x[31785];x[31785]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31785]=0;e=P(37,j+44|0,e|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break g}Rt(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31785]=0;a=R(859,104)|0;m=x[31785];x[31785]=0;k:{l:{m:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31785]=0;b=P(998,f|0,d|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break m}x[j+20>>2]=b;b=x[oe(j+24|0,j+20|0)>>2];d=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=d;x[31785]=0;d=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=d;b=ba(1028,a|0,j|0,b|0,c|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break k}i=T(0)|0;Uc(j+20|0);break l}i=T(0)|0;break f}i=T(0)|0}Db(a);break f}x[k+28>>2]=b;Uc(j+20|0);x[k+24>>2]=b+8;Kl(c);break d}i=T(0)|0}Kl(c);Y(i|0)|0;x[31785]=0;V(992,11361,k|0,g|0,h|0);a=x[31785];x[31785]=0;if((a|0)!=1){x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)!=1){a=x[k+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[k+24>>2]=0;x[k+28>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);k=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break b}}Y(i|0)|0;k=0;x[31785]=0;V(992,11361,0,g|0,h|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return k|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Rb()}p()}function _la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}y=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}z=x[a+24>>2];A=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;B=x[a+72>>2];v=x[a+68>>2];C=v>>31;l=x[a+64>>2];E=l>>31;j=x[a+60>>2];F=j>>31;while(1){if(d){b=x[f+16>>2];t=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+y|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=t+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(w[k-8>>1],e)+D(w[k-12>>1],b)|0)+D(w[k-4>>1],i)|0)+D(w[k>>1],g)|0)+D(w[k+4>>1],u)|0)+D(w[k+8>>1],r)|0)+D(q,w[k+12>>1])|0)+D(m,w[k+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+28|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=sua(j,F,e,e>>31);i=hb;t=e;e=Xb(g,-16777216,16776704);e=sua(l,E,e,e>>31);g=t+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Xb(u,-16777216,16776704);i=sua(v,C,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],A);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],z);Qb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function sv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Ed(b)}if(b>>>0>=4294967232){x[31660]=48;return 0}f=b>>>0<11?16:b+11&-8;e=a-8|0;j=x[e+4>>2];d=j&-8;a:{if(!(j&3)){if(f>>>0<256){break a}if(d>>>0>=f+4>>>0){c=e;if(d-f>>>0<=x[31781]<<1>>>0){break a}}c=0;break a}g=d+e|0;b:{if(d>>>0>=f>>>0){d=d-f|0;if(d>>>0<16){break b}x[e+4>>2]=j&1|f|2;c=e+f|0;x[c+4>>2]=d|3;x[g+4>>2]=x[g+4>>2]|1;mv(c,d);break b}if(x[31667]==(g|0)){h=d+x[31664]|0;if(h>>>0<=f>>>0){break a}x[e+4>>2]=j&1|f|2;d=e+f|0;c=h-f|0;x[d+4>>2]=c|1;x[31664]=c;x[31667]=d;break b}if(x[31666]==(g|0)){d=d+x[31663]|0;if(d>>>0<f>>>0){break a}c=d-f|0;c:{if(c>>>0>=16){x[e+4>>2]=j&1|f|2;h=e+f|0;x[h+4>>2]=c|1;d=d+e|0;x[d>>2]=c;x[d+4>>2]=x[d+4>>2]&-2;break c}x[e+4>>2]=d|j&1|2;c=d+e|0;x[c+4>>2]=x[c+4>>2]|1;c=0}x[31666]=h;x[31663]=c;break b}h=x[g+4>>2];if(h&2){break a}k=d+(h&-8)|0;if(k>>>0<f>>>0){break a}m=k-f|0;d:{if(h>>>0<=255){d=x[g+12>>2];c=x[g+8>>2];if((d|0)==(c|0)){n=126644,o=x[31661]&vua(-2,h>>>3|0),x[n>>2]=o;break d}x[c+12>>2]=d;x[d+8>>2]=c;break d}l=x[g+24>>2];i=x[g+12>>2];e:{if((i|0)!=(g|0)){c=x[g+8>>2];x[c+12>>2]=i;x[i+8>>2]=c;break e}f:{h=g+20|0;c=x[h>>2];if(c){break f}h=g+16|0;c=x[h>>2];if(c){break f}i=0;break e}while(1){d=h;i=c;h=c+20|0;c=x[h>>2];if(c){continue}h=i+16|0;c=x[i+16>>2];if(c){continue}break}x[d>>2]=0}if(!l){break d}d=x[g+28>>2];c=(d<<2)+126948|0;g:{if(x[c>>2]==(g|0)){x[c>>2]=i;if(i){break g}n=126648,o=x[31662]&vua(-2,d),x[n>>2]=o;break d}x[(x[l+16>>2]==(g|0)?16:20)+l>>2]=i;if(!i){break d}}x[i+24>>2]=l;c=x[g+16>>2];if(c){x[i+16>>2]=c;x[c+24>>2]=i}c=x[g+20>>2];if(!c){break d}x[i+20>>2]=c;x[c+24>>2]=i}if(m>>>0<=15){x[e+4>>2]=j&1|k|2;c=e+k|0;x[c+4>>2]=x[c+4>>2]|1;break b}x[e+4>>2]=j&1|f|2;d=e+f|0;x[d+4>>2]=m|3;c=e+k|0;x[c+4>>2]=x[c+4>>2]|1;mv(d,m)}c=e}if(c){return c+8|0}e=Ed(b);if(!e){return 0}c=x[a-4>>2];c=(c&3?-4:-8)+(c&-8)|0;yc(e,a,b>>>0>c>>>0?c:b);Db(a);return e}function c1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-112|0;fb=d;xc(b);zp(a);a:{if(!yi(b,d+104|0)){break a}if(!SF(d+104|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],4)){break a}fx(a);n=d,o=ex(),x[n+84>>2]=o;c=d+84|0;dx(hj(x[a+4>>2])+32|0,c);_r(c);k=x[hj(x[a+4>>2])+32>>2];c=hh(x[b>>2]);if(c&1){break a}e=c-4|0;bd(b,e);g=fb-16|0;fb=g;c=g+13|0;Rw(c,b);h=y[xb(c,0)|0];i=y[xb(c,1)|0];c=y[xb(c,2)|0];fb=g+16|0;h=c|(i<<8|h<<16);if(!h){break a}x[31785]=0;O(40,k|0,h|0);c=x[31785];x[31785]=0;c:{if((c|0)==1){b=T(125240)|0;if((gb|0)!=($(125240)|0)){break c}Y(b|0)|0;Z();break a}bd(b,4);c=d+84|0;RF(c,b,e);Fn(d- -64|0,c);kf(d+76|0,x[d+64>>2],x[d+68>>2]);c=x[d+80>>2];i=x[k>>2];e=fb-32|0;fb=e;b=x[d+76>>2];n=e,o=y[xb(b,0)|0],v[n+28|0]=o;n=e,o=y[xb(b,1)|0],v[n+29|0]=o;n=e,o=y[xb(b,2)|0],v[n+30|0]=o;n=e,o=y[xb(b,3)|0],v[n+31|0]=o;g=Qr(e+12|0);c=b+c|0;x[g+12>>2]=c-4;x[g+8>>2]=b;lk(g,y[c-1|0]);c=h;d:while(1){e:{f:{g:{if(!c){break g}if(lk(g,1)){break f}b=1;while(1){f=lk(g,2);b=f+b|0;if((f|0)==3){continue}break}x[e+8>>2]=b;vc(e+8|0,c);b=0;f=x[e+8>>2];while(1)if((b|0)==(f|0)){if(!c){break g}break f}else{c=c-1|0;n=i+c|0,o=lk(g,8),v[n|0]=o;b=b+1|0;continue}}fb=e+32|0;break e}f=lk(g,2);b=f+2|0;x[e+8>>2]=b;h:{if((f|0)==3){i:{if(!lk(g,1)){b=5;f=7;break i}f=y[xb(e+28|0,3)|0]}f=lk(g,f);while(1){j=lk(g,3);b=j+b|0;if((j|0)==7){continue}break}x[e+8>>2]=b;break h}f=lk(g,y[xb(e+28|0,f)|0])}vc(e+8|0,c);b=0;m=x[e+8>>2];while(1){if((b|0)==(m|0)){continue d}j=0;l=c+f|0;if(h>>>0>l>>>0){j=y[i+l|0]}c=c-1|0;v[i+c|0]=j;b=b+1|0;continue}}break}le(d+24|0,x[k>>2],x[k+4>>2]);kf(d+32|0,x[d+24>>2],x[d+28>>2]);b=Jd(d+16|0);x[31785]=0;c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;b=dg(163,d+44|0,x[d+32>>2],x[d+36>>2],d+8|0);c=x[31785];x[31785]=0;if((c|0)!=1){hd(hj(x[a+4>>2])+12|0,b);ub(b);Jc(d+84|0);break b}b=N()|0;Jc(d+84|0)}Q(b|0);p()}f=1}fb=d+112|0;return f|0}function vu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=D(c,872)+b|0;x[f+704>>2]=x[f+704>>2]|524288;a:{b:{if(!(y[a+480208|0]&8)){if(Pb(a+1074312|0,15)|x[a+480180>>2]==268435456){break b}break a}if(x[a+480180>>2]!=268435456){break a}}e=D(c,872)+b|0;d=d?d:y[(D(c,872)+b|0)+1427|0];v[e+1427|0]=d;v[e+1428|0]=d}if(d){w[(D(c,872)+b|0)+1384>>1]=d}c:{g=f+616|0;h=x[g+656>>2];if(Oj(h)){a=z[(D(c,872)+b|0)+1384>>1];if(!a){break c}e=0;d=x[b+16>>2];e=d?x[(D(c,872)+b|0)+1472>>2]:e;k=0-a|0;j=a;g=D(c,872)+b|0;i=g+1324|0;a=x[i>>2];l=(+(d>>>0)+1)*+(((a|0)<0?k:j)|0)/+A[b+40>>2];d:{if(F(l)<2147483648){d=~~l;break d}d=-2147483648}g=g+1472|0;x[g>>2]=d;if(y[f+706|0]&16){d=D(x[x[h+44>>2]+36>>2]+1|0,d);x[g>>2]=d}d=d-e|0;f=d>>31;e=a>>31;if((e^a)-e>>>0<=(d^f)-f>>>0){if(!a){break c}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=a+x[c>>2];x[i>>2]=0;a=b+1467|0;v[a|0]=y[a|0]|64;return 0}b=D(c,872)+b|0;c=b+1468|0;x[c>>2]=d+x[c>>2];x[i>>2]=a-d;a=b+1467|0;v[a|0]=y[a|0]|64;break c}i=a+1074312|0;e:{if(!(!Pb(i,118)|!(y[f+705|0]&2))){d=0;if(zd(y[(D(c,872)+b|0)+1404|0])){break e}}f=1;h=D(c,872)+b|0;e=h+1467|0;f:{if(!(v[e|0]&1)){break f}d=x[a+480180>>2];if(d&524352){break f}if(x[b+40>>2]==1){if(Pb(i,6)){break f}d=x[a+480180>>2]}f=0;if((d|0)!=8){break f}f=(y[a+480208|0]&2)>>>1|0}j=x[a+480180>>2];d=z[h+1384>>1];if(!((j|0)!=268435456|d>>>0<240)){f=v[e|0]&1;d=d-240|0}d=d<<((j|0)==64?1:2);h=D(c,872)+b|0;b=h+1316|0;g:{if(!x[b>>2]){break g}c=h+1324|0;if(!(x[c>>2]!=0&f)){break g}j=Ej(a)?d:0-d|0;k=x[b>>2];m=x[c>>2];if(!(!(y[e|0]&16)&(k|0)>=(m|0))){xk(a,g,b,j,1);c=x[c>>2];if((c|0)>=x[b>>2]){break g}x[b>>2]=c;break g}if((k|0)<=(m|0)){break g}xk(a,g,b,0-j|0,1);g=x[b>>2];c=x[c>>2];h:{if((g|0)<(c|0)){x[b>>2]=c;break h}if((c|0)!=(g|0)){break g}}if(!Pb(i,112)){break g}v[e|0]=y[e|0]|16}c=x[b>>2];b=h+1324|0;i:{if((c|0)!=x[b>>2]){break i}if(!Pb(i,25)&x[a+480180>>2]!=1){break i}x[b>>2]=0}d=f?d:0}return d}return 0}function iP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;j=fb-80|0;fb=j;a:{b:{c:{d:{e:{f:{k=Lq(1,28);if(!k){a=Om(ac(4));x[31785]=0;S(100,a|0,125240,34);a=x[31785];x[31785]=0;if((a|0)!=1){break a}break f}x[k+12>>2]=f;x[k+8>>2]=e;x[k+4>>2]=d;f=c?c:986;x[k>>2]=f;c=lg(j+68|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31785]=0;e=P(37,j+56|0,e|0)|0;m=x[31785];x[31785]=0;k:{if((m|0)!=1){x[31785]=0;m=P(997,c|0,e|0)|0;n=x[31785];x[31785]=0;if((n|0)==1){break k}x[31785]=0;O(275,m|0,l|0);l=x[31785];x[31785]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31785]=0;e=P(37,j+44|0,e|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break h}Rt(c,e)}tb(e);i=i+8|0;continue}}e=x[a+8>>2];i=x[a+4>>2];l=x[a>>2];x[31785]=0;a=R(859,80)|0;m=x[31785];x[31785]=0;l:{m:{n:{if((m|0)!=1){x[j+40>>2]=e;x[j+36>>2]=i;x[j+32>>2]=l;x[j+28>>2]=b;x[31785]=0;b=P(998,f|0,d|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break n}x[j+20>>2]=b;b=x[oe(j+24|0,j+20|0)>>2];d=x[j+40>>2];x[j+8>>2]=x[j+36>>2];x[j+12>>2]=d;x[31785]=0;d=x[j+32>>2];x[j>>2]=x[j+28>>2];x[j+4>>2]=d;b=ba(999,a|0,j|0,b|0,c|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break l}i=T(0)|0;Uc(j+20|0);break m}i=T(0)|0;break g}i=T(0)|0}Db(a);break g}x[k+24>>2]=b;Uc(j+20|0);Kl(c);i=k;break d}i=T(0)|0}Kl(c);Y(i|0)|0;x[31785]=0;V(992,15355,k|0,g|0,h|0);a=x[31785];x[31785]=0;if((a|0)!=1){x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break f}a=x[k+24>>2];if(a){Db(hq(a))}i=0;x[k+24>>2]=0;a=x[k+20>>2];if(a){Db(a);x[k+20>>2]=0}Db(k);break d}i=T(0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31785]=0;V(992,15355,0,g|0,h|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Z()}fb=j+80|0;return i|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Rb()}p()}function ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;l=x[a+12>>2];h=l;a:{b:{c:{n=x[a+8>>2];d:{if((h|0)<=1&n>>>0<=805306368|(h|0)<=0){if((h|0)>=-2&n>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&n>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&n>>>0>2147483648|h>>>0>1){break b}}s=b+196648|0;break a}s=b+131112|0;break a}s=b+262184|0}z=x[a+16>>2];b=0;while(1){if((b|0)!=2){j=b<<3;l=j+(f+28|0)|0;j=a+j|0;x[l+4>>2]=x[j+44>>2];x[l+8>>2]=x[j+48>>2];b=b+1|0;continue}break}A=x[a+24>>2];B=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;C=x[a+72>>2];y=x[a+68>>2];E=y>>31;l=x[a+64>>2];F=l>>31;j=x[a+60>>2];G=j>>31;while(1){if(d){b=x[f+16>>2];t=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+z|0;b=(b>>>16&65520)+s|0;m=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];u=w[b+8>>1];g=w[b+6>>1];i=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];o=0;p=0;while(1){if((p|0)!=2){k=p+t|0;x[(f+8|0)+(p<<2)>>2]=(((((((D(v[k-4|0],e)+D(v[k-6|0],b)|0)+D(v[k-2|0],i)|0)+D(v[k|0],g)|0)+D(v[k+2|0],u)|0)+D(v[k+4|0],r)|0)+D(q,v[k+6|0])|0)+D(m,v[k+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){r=(f+8|0)+(o<<2)|0;e=x[r>>2];b=(f+28|0)+(o<<3)|0;u=x[b+8>>2];g=x[b+4>>2];x[b+8>>2]=g;q=e<<8;e=q;e=sua(j,G,e,e>>31);i=hb;t=e;e=Xb(g,-16777216,16776704);e=sua(l,F,e,e>>31);g=t+e|0;m=hb+i|0;m=e>>>0>g>>>0?m+1|0:m;e=Xb(u,-16777216,16776704);i=sua(y,E,e,e>>31);g=i+g|0;e=hb+m|0;e=g>>>0<i>>>0?e+1|0:e;i=g+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;o=o+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],B);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],A);Qb(f+16|0,n,h);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function ala(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;c=Bf(a,c);Yd(i,x[a+36>>2]);a:{if(!c){Pc(i,a+32|0,5);e=0;if(Hb(x[x[i>>2]>>2],x[i+4>>2])){break a}}e=fb-240|0;fb=e;h=Gm(e+128|0,x[a+36>>2]);x[31785]=0;g=P(465,e+116|0,26408)|0;f=x[31785];x[31785]=0;b:{c:{d:{e:{if((f|0)!=1){x[31785]=0;x[e+96>>2]=19988519;x[e+100>>2]=0;S(466,h|0,g|0,e+96|0);f=x[31785];x[31785]=0;if((f|0)==1){break e}Eb(g);if(!ml(y[h|0])){break d}break b}a=N()|0;break c}a=N()|0;Eb(g);break c}v[e+115|0]=0;x[31785]=0;g=P(465,e+96|0,5525)|0;f=x[31785];x[31785]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){x[31785]=0;S(467,h|0,e+115|0,g|0);f=x[31785];x[31785]=0;if((f|0)==1){break p}Eb(g);g=Fb(e+84|0);x[31785]=0;f=P(465,e+72|0,10104)|0;j=x[31785];x[31785]=0;if((j|0)==1){break o}x[31785]=0;S(792,h|0,g|0,f|0);j=x[31785];x[31785]=0;if((j|0)==1){break n}Eb(f);x[31785]=0;S(261,e+60|0,(y[e+115|0]?0:d)|0,g|0);d=x[31785];x[31785]=0;if((d|0)==1){break m}d=e+60|0;gp(b,d);tb(d);w[e+58>>1]=0;x[31785]=0;d=P(465,e+44|0,10793)|0;f=x[31785];x[31785]=0;if((f|0)==1){break g}x[31785]=0;U(495,h|0,e+58|0,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break l}Eb(d);Pf(e+58|0,4e3);x[31785]=0;d=P(465,e+32|0,13519)|0;f=x[31785];x[31785]=0;if((f|0)==1){break k}j=z[e+58>>1];f=x[zb(e+28|0,j)>>2];x[31785]=0;V(793,h|0,b|0,d|0,f|0);f=x[31785];x[31785]=0;if((f|0)==1){break j}Eb(d);w[e+26>>1]=65535;x[31785]=0;d=P(465,e+12|0,8984)|0;f=x[31785];x[31785]=0;if((f|0)==1){break i}x[31785]=0;k=U(495,h|0,e+26|0,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break h}f=z[e+26>>1];Eb(d);if(f>>>0<j>>>0&k){_e(b,f)}tb(g);break b}a=N()|0;break c}a=N()|0;Eb(g);break c}a=N()|0;break f}a=N()|0;Eb(f);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0;break f}a=N()|0;Eb(d);break f}a=N()|0}tb(g)}yh(h);Q(a|0);p()}yh(h);fb=e+240|0;e=c}cf(a,e);fb=i+16|0}function gta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=fb-1104|0;fb=d;x[d+1100>>2]=c;i=OD(d+40|0,b);r=lr(i);e=Nb(a);x[31785]=0;a=R(205,b|0)|0;c=x[31785];x[31785]=0;a:{if((c|0)!=1){x[d+12>>2]=a;x[d+36>>2]=85899345;t=d,u=D(x[Gb(d+12|0,d+36|0)>>2],50),x[t+24>>2]=u;a=x[Gb(d+1100|0,d+24|0)>>2];x[31785]=0;O(331,e|0,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){x[31785]=0;h=R(343,d+24|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){x[31785]=0;f=P(344,d+12|0,8192)|0;a=x[31785];x[31785]=0;b:{if((a|0)!=1){a=x[h>>2];c=0;while(1){if((c|0)!=256){g=wb(a,c);v[g+2|0]=c;w[g>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){s=m&255;e:{while(1){j=n&65535;while(1){x[31785]=0;o=P(161,i|0,s|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(Sc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:g;a=x[h>>2];l=8192;while(1){c=c&65535;a=wb(a,c);l=l-1|0;q=l&65535;t=xb(x[f>>2],q),u=y[a+2|0],v[t|0]=u;a=x[h>>2];c=z[wb(a,c)>>1];if(c>>>0<8192){continue}break}a=zb(d+8|0,vb(x[e+4>>2]));c=Ne(vb(x[f>>2]),q);l=vb(x[f+4>>2]);a=x[a>>2];x[31785]=0;V(332,e|0,a|0,c|0,l|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=x[f>>2];x[31785]=0;O(345,e|0,xb(a,q)|0);a=x[31785];x[31785]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(Sc(x[e>>2],x[e+4>>2])>>>0>=A[d+1100>>2]){continue}break}a=y[xb(x[f>>2],q)|0];c=wb(x[h>>2],j);w[c>>1]=g;v[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<s)+m|0;n=a;continue}break}break}a=lr(i);x[31785]=0;P(152,b|0,((a-r|0)+3&-4)+r|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}dc(f);sc(h);ub(i);fb=d+1104|0;return}c=N()|0;dc(f);break b}c=N()|0}sc(h);break a}c=N()|0;break a}c=N()|0;break a}c=N()|0}dc(e);ub(i);Q(c|0);p()}function $T(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;c=fb-176|0;fb=c;e=x[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=x[a+12>>2]}else{i=x[b>>2];h=Ud(i,e+l|0);d=Ud(i,e);o=C[h>>3];p=C[h+8>>3];Bj(c+160|0,d,o,p);i=x[c+172>>2];x[h+8>>2]=x[c+168>>2];x[h+12>>2]=i;i=x[c+164>>2];x[h>>2]=x[c+160>>2];x[h+4>>2]=i;mA(Ud(x[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){w=D(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=x[a>>2];e=Ud(d,j<<1);d=Ud(d,j);o=C[d>>3];p=C[d+8>>3];r=C[e>>3];s=C[e+8>>3];Oi(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=x[b>>2];d=Ud(f,e);g=x[d+12>>2];x[c+152>>2]=x[d+8>>2];x[c+156>>2]=g;g=x[d+4>>2];x[c+144>>2]=x[d>>2];x[c+148>>2]=g;g=c+128|0;t=e+h|0;k=Ud(f,t);Oi(g,r,s,C[k>>3],C[k+8>>3]);u=e+y|0;k=Ud(f,u);Oi(c+112|0,o,p,C[k>>3],C[k+8>>3]);m=C[c+160>>3];n=C[c+168>>3];v=e+w|0;f=Ud(f,v);Oi(c+96|0,m,n,C[f>>3],C[f+8>>3]);k=c+80|0;f=c+144|0;m=C[c+112>>3];n=C[c+120>>3];Al(k,f,m,n);q=c- -64|0;Bj(q,f,m,n);m=C[c+96>>3];n=C[c+104>>3];Al(c+48|0,g,m,n);f=c+16|0;Ml(f,-0,-1);Bj(c,g,m,n);Oi(c+32|0,C[c+16>>3],C[c+24>>3],C[c>>3],C[c+8>>3]);Al(f,k,C[c+48>>3],C[c+56>>3]);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Bj(f,k,C[c+48>>3],C[c+56>>3]);d=Ud(x[b>>2],t);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Al(f,q,C[c+32>>3],C[c+40>>3]);d=Ud(x[b>>2],u);g=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=g;g=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=g;Bj(f,q,C[c+32>>3],C[c+40>>3]);d=Ud(x[b>>2],v);f=x[c+28>>2];x[d+8>>2]=x[c+24>>2];x[d+12>>2]=f;f=x[c+20>>2];x[d>>2]=x[c+16>>2];x[d+4>>2]=f;e=e+1|0;continue}}}break}fb=c+176|0}function bP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-96|0;fb=d;e=x[b+4>>2];a:{if(!e){break a}f=x[b>>2];g=y[xl(f,e)|0];if((g|0)==33){c=1}else{if((g|0)!=63){break a}c=0}Jl(d+72|0,f,e,e-1|0);e=x[d+76>>2];x[b>>2]=x[d+72>>2];x[b+4>>2]=e}f=d+72|0;de(f);e=x[d+72>>2];de(d+60|0);e=wl(e,x[d+64>>2],b);de(f);b:{c:{d:{e:{if((e|0)==x[d+76>>2]){a=x[b+4>>2];e=x[b>>2];f=pc(d+88|0,22485);g=x[f+4>>2];x[d>>2]=x[f>>2];x[d+4>>2]=g;if(Oc(e,a,d)){a=ac(8);x[31785]=0;c=P(37,d+72|0,10492)|0;b=x[31785];x[31785]=0;if((b|0)==1){break d}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}e=0;f=0;if(!c){break e}c=ac(8);a=x[b+4>>2];b=x[b>>2];x[31785]=0;e=di(d+60|0,b,a);a=x[31785];x[31785]=0;f:{g:{h:{if((a|0)!=1){x[31785]=0;S(1020,d+72|0,18489,e|0);a=x[31785];x[31785]=0;if((a|0)==1){break h}nc(c,d+72|0);a=0;x[31785]=0;S(100,c|0,48732,1009);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=N()|0;tb(d+72|0);break g}b=N()|0;break f}b=N()|0;a=1}tb(e);if(!a){break c}}jc(c);break c}if(x[e+4>>2]!=1){a=ac(8);x[31785]=0;c=P(37,d+72|0,11605)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}c=x[b+4>>2];b=x[b>>2];e=pc(d+52|0,22485);f=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=f;if(Oc(b,c,d+24|0)){a=ac(8);x[31785]=0;c=P(37,d+72|0,10492)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}e=pc(d+44|0,10984);f=x[e+4>>2];x[d+16>>2]=x[e>>2];x[d+20>>2]=f;if(Oc(b,c,d+16|0)){e=x[a+8>>2];f=e>>31;break e}e=pc(d+36|0,8647);f=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=f;e=0;f=0;if(!Oc(b,c,d+8|0)){break e}e=uk(y[x[a+32>>2]+140|0]);f=0}fb=d+96|0;hb=f;return e|0}b=N()|0;jc(a)}Q(b|0)}p()}function wO(a,b,c){a=a|0;b=E(b);c=c|0;var d=0,e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),k=E(0),m=0,n=0,o=0;d=fb-16|0;fb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(q(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=E(E(-1)/E(b*b));if(!(a&2147483647)){break e}e=E(E(b-b)/E(0));if((a|0)<0){break e}a=(q(E(b*E(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=E(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=E((a>>>23|0)+c|0);b=E((l(2,(a&8388607)+1060439283|0),r())+E(-1));f=E(b*E(b*E(.5)));g=E(b/E(b+E(2)));h=E(g*g);i=E(h*h);e=b;b=(l(2,(q(E(b-f)),j(2))&-4096),r());f=E(E(g*E(f+E(E(h*E(E(i*E(.2849878668785095))+E(.6666666269302368)))+E(i*E(E(i*E(.24279078841209412))+E(.40000972151756287))))))+E(E(e-b)-f));b=E(E(k*E(.3010292053222656))+E(E(b*E(.434326171875))+E(E(f*E(.434326171875))+E(E(k*E(7.903415166765626e-7))+E(E(f+b)*E(-3168997136526741e-20))))))}e=b}b=E(e*E(2e3));if(!(E(F(b))<E(2147483648))){break c}a=~~b;break b;case 1:a=(D(x[a+24604>>2],100)|0)/128|0;break b;case 2:c=fb-16|0;fb=c;h:{i:{j:{k:{a=y[a+24648|0];if(a>>>0>=6){a=ac(8);x[31785]=0;c=P(37,c+4|0,5143)|0;d=x[31785];x[31785]=0;if((d|0)==1){break k}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break i}d=N()|0;tb(c);break j}fb=c+16|0;a=x[(a<<2)+79784>>2];break h}d=N()|0;jc(a)}Q(d|0)}p()}break b;case 3:x[d+4>>2]=0;m=x[a+24640>>2];c=fb-80|0;fb=c;a=x[a+24636>>2];x[c+40>>2]=a;x[c>>2]=m;n=c+40|0;o=x[We(n,c)>>2];l:{if((a|0)==x[Gq(n)+32>>2]){a=-1;if(x[Gq(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}x[d+4>>2]=a;fb=c+80|0;a=x[d+4>>2];break b;default:break d}}c=ac(8);x[31785]=0;d=P(37,d+4|0,10395)|0;a=x[31785];x[31785]=0;m:{if((a|0)!=1){nc(c,d);x[31785]=0;S(100,c|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break m}a=N()|0;jc(c)}Q(a|0);p()}a=-2147483648}fb=d+16|0;return a|0}p()}function vra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,j=E(0);d=fb-96|0;fb=d;c=fb-16|0;fb=c;e=b+16|0;KY(c+8|0,e);f=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){Yb(a,x[c+12>>2])}fb=c+16|0;if((f|0)!=(g|0)){Tb(e,0,128)}v[b+79|0]=0;v[b+143|0]=0;x[b+152>>2]=-2147483648;x[b+156>>2]=-2147483648;c=d+56|0;ce(c,a,Mg(a));f=ic(d+76|0,c);ub(c);x[31785]=0;c=R(205,f|0)|0;e=x[31785];x[31785]=0;a:{b:{if((e|0)==1){break b}x[31785]=0;O(290,b+4|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}le(d+48|0,x[b+4>>2],x[b+8>>2]);x[31785]=0;Rn(475,d+56|0,f,x[d+48>>2],x[d+52>>2]);c=x[31785];x[31785]=0;if((c|0)!=1){x[31785]=0;c=R(154,a|0)|0;e=x[31785];x[31785]=0;c:{if((e|0)==1){break c}x[31785]=0;S(188,d+28|0,a|0,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}a=d+28|0;c=ic(d+56|0,a);ub(a);a=x[c>>2];x[31785]=0;a=R(175,a|0)|0;e=x[31785];x[31785]=0;d:{if((e|0)!=1){e:{f:{g:{if(!a){break g}while(1){a=x[c+8>>2];e=x[c>>2];x[31785]=0;a=U(153,e|0,a|0,5)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}if(!a){break g}x[31785]=0;P(476,c|0,d+24|0)|0;a=x[31785];x[31785]=0;h:{if((a|0)!=1){a=4;if(!Ob(d+24|0,13704,4)){break h}if(!Ob(d+24|0,14225,4)){break h}x[31785]=0;a=R(154,c|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){break h}a=N()|0;break d}a=N()|0;break d}x[31785]=0;S(188,d+4|0,c|0,a|0);a=x[31785];x[31785]=0;i:{j:{if((a|0)!=1){a=d+4|0;e=ic(d+28|0,a);ub(a);if(Ob(d+24|0,13704,4)){break j}x[31785]=0;h=E(xa(477,e|0));a=x[31785];x[31785]=0;if((a|0)==1){break e}i=b,j=Ld(h,E(0)),B[i+144>>2]=j;break i}a=N()|0;break d}if(Ob(d+24|0,14225,4)){break i}x[31785]=0;a=R(154,e|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break e}x[b+148>>2]=a}ub(e);continue}}ub(c);ub(f);fb=d+96|0;return}a=N()|0;break d}a=N()|0;ub(e);break d}a=N()|0}ub(c);break a}a=N()|0;break a}a=N()|0;break a}a=N()|0}ub(f);Q(a|0);p()}function $O(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-96|0;fb=e;f=x[c+4>>2];a:{if(!f){break a}g=x[c>>2];h=y[xl(g,f)|0];if((h|0)==33){d=1}else{if((h|0)!=63){break a}d=0}Jl(e+72|0,g,f,f-1|0);f=x[e+76>>2];x[c>>2]=x[e+72>>2];x[c+4>>2]=f}f=e+72|0;de(f);g=x[e+72>>2];de(e+60|0);h=wl(g,x[e+64>>2],c);de(f);f=x[c+4>>2];g=x[c>>2];b:{c:{d:{e:{if((h|0)==x[e+76>>2]){b=pc(e+88|0,22485);h=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=h;if(Oc(g,f,e)){a=ac(8);x[31785]=0;b=P(37,e+72|0,10492)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}if(d){a=ac(8);b=x[c+4>>2];c=x[c>>2];x[31785]=0;b=di(e+60|0,c,b);c=x[31785];x[31785]=0;f:{g:{h:{if((c|0)!=1){x[31785]=0;S(1020,e+72|0,18489,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break h}nc(a,e+72|0);d=0;x[31785]=0;S(100,a|0,48732,1009);c=x[31785];x[31785]=0;if((c|0)!=1){break b}c=N()|0;tb(e+72|0);break g}c=N()|0;break f}c=N()|0;d=1}tb(b);if(!d){break c}}jc(a);break c}Fb(a);break e}c=pc(e+52|0,22485);d=x[c+4>>2];x[e+24>>2]=x[c>>2];x[e+28>>2]=d;if(Oc(g,f,e+24|0)){a=ac(8);x[31785]=0;b=P(37,e+72|0,10492)|0;c=x[31785];x[31785]=0;if((c|0)!=1){nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}c=N()|0;jc(a);break c}c=pc(e+44|0,12442);d=x[c+4>>2];x[e+16>>2]=x[c>>2];x[e+20>>2]=d;if(Oc(g,f,e+16|0)){i:{switch(x[b+52>>2]){case 0:Cc(a,5621);break e;case 1:Cc(a,11306);break e;case 2:Cc(a,9226);break e;default:break i}}Fb(a);break e}c=pc(e+36|0,11543);d=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=d;if(Oc(g,f,e+8|0)){j:{switch(x[b+56>>2]){case 0:Cc(a,15803);break e;case 1:Cc(a,15808);break e;case 2:Cc(a,12716);break e;case 3:Cc(a,9290);break e;default:break j}}Fb(a);break e}Fb(a)}fb=e+96|0;return}c=N()|0;jc(a)}Q(c|0)}p()}function Dfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-96|0;fb=d;f=1;g=x[c+4>>2];h=y[c+11|0];a:{if(yd(g,h)){break a}e=y[qz(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+84|0;jx(e,c,0,Wc(g,h)-1|0);yb(c,e);tb(e)}e=d+84|0;de(e);g=x[d+84>>2];de(d+72|0);g=JM(g,x[d+76>>2],c);de(e);b:{c:{d:{e:{f:{if((g|0)==x[d+88>>2]){if(ke(c,22485)){a=ac(8);x[31785]=0;b=P(37,d+84|0,10492)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}if(!f){break f}a=ac(8);x[31785]=0;S(1011,d+84|0,18489,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,d+84|0);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}c=N()|0;tb(d+84|0);break c}c=N()|0;jc(a);break c}e=Fb(d+84|0);g:{h:{i:{j:{switch(x[g+4>>2]){case 0:ue(d- -64|0,c);x[31785]=0;c=x[d+68>>2];x[d+8>>2]=x[d+64>>2];x[d+12>>2]=c;b=U(1012,b|0,d+8|0,f|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){x[31785]=0;v[d+72|0]=b;O(1013,a|0,d+72|0);a=x[31785];x[31785]=0;if((a|0)!=1){break g}}break i;case 1:ue(d+56|0,c);x[31785]=0;c=x[d+60>>2];x[d+16>>2]=x[d+56>>2];x[d+20>>2]=c;b=PH(b,d+16|0,f);c=hb;f=x[31785];x[31785]=0;if((f|0)!=1){x[31785]=0;x[d+72>>2]=b;x[d+76>>2]=c;O(1015,a|0,d+72|0);a=x[31785];x[31785]=0;if((a|0)!=1){break g}}break i;case 2:ue(d+48|0,c);x[31785]=0;c=x[d+52>>2];x[d+24>>2]=x[d+48>>2];x[d+28>>2]=c;i=+oa(1016,b|0,d+24|0,f|0);b=x[31785];x[31785]=0;if((b|0)!=1){x[31785]=0;C[d+72>>3]=i;O(1017,a|0,d+72|0);a=x[31785];x[31785]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ue(d+40|0,c);x[31785]=0;c=x[d+44>>2];x[d+32>>2]=x[d+40>>2];x[d+36>>2]=c;V(1018,a|0,b|0,d+32|0,f|0);a=x[31785];x[31785]=0;if((a|0)!=1){break g}}c=N()|0;tb(e);break c}Yc(a,e)}tb(e);break e}Fb(a)}fb=d+96|0;return}c=N()|0;jc(a)}Q(c|0)}p()}function N6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-1056|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+944|0;x[a+940>>2]=j;j=yy(j,100,11203,a+16|0);x[a+48>>2]=1208;k=a+48|0;o=Ae(a+520|0,0,k);x[a+48>>2]=1208;k=Ae(a+512|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+528|0;f=a+944|0;break d}j=Kd();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=oj(a+940|0,j,11203,a);if((j|0)!=-1){f=x[a+940>>2];Oe(o,f);Oe(k,Ed(j<<2));h=x[k>>2];if(!Ak(h)){break d}}x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)!=1){break a}j=N()|0;break c}$c(a+508|0,x[d+28>>2]);x[31785]=0;r=R(1220,x[a+508>>2])|0;g=x[31785];x[31785]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[31785]=0;V(1231,r|0,f|0,f+j|0,h|0);g=x[31785];x[31785]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Fb(a+484|0);f=Fb(a+472|0);g=Fb(a+460|0);x[31785]=0;ka(1259,c|0,q|0,x[a+508>>2],a+504|0,a+500|0,a+496|0,i|0,f|0,g|0,a+456|0);c=x[31785];x[31785]=0;if((c|0)==1){break i}x[a+36>>2]=1208;c=Ae(a+40|0,0,a+36|0);m=a+48|0;n=x[a+456>>2];k:{if((n|0)<(j|0)){l=((Bb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Bb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}l=(Bb(x[g+4>>2],y[g+11|0])+Bb(x[f+4>>2],y[f+11|0])|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Oe(c,Ed(l<<2));m=x[c>>2];if(m){break h}x[31785]=0;X(1209);b=x[31785];x[31785]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}l=x[d+4>>2];x[31785]=0;ma(1260,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,r|0,q|0,a+504|0,x[a+500>>2],x[a+496>>2],i|0,f|0,g|0,n|0);h=x[31785];x[31785]=0;if((h|0)!=1){x[31785]=0;b=ea(1240,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break b}}}j=N()|0;Kc(c)}Sb(g);Sb(f);tb(i)}Zb(a+508|0)}Kc(k);Kc(o);Q(j|0);p()}Kc(c);Sb(g);Sb(f);tb(i);Zb(a+508|0);Kc(k);Kc(o);fb=a+1056|0;return b|0}p()}function Mqa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=x[a>>2];c=zv(e,x[a+4>>2]);if(c>>>0<=63){l=fb-32|0;fb=l;g=64-c|0;e=x[Ab(a)>>2];b=x[a+4>>2];a:{if(g>>>0<=(e-b|0)/33>>>0){e=fb-16|0;fb=e;c=e+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(g,33);a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)==(b|0)){hc(c);fb=e+16|0}else{wY(a);a=a+33|0;x[c+4>>2]=a;continue}break}break a}h=Ab(a);c=l+12|0;e=a;f=zv(x[a>>2],b)+g|0;b=fb-16|0;fb=b;x[b+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=130150524;x[d+8>>2]=2147483647;a=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=f>>>0){d=yY(e);if(d>>>0<a>>>1>>>0){x[b+8>>2]=d<<1;a=x[_c(b+8|0,b+12|0)>>2]}fb=b+16|0;break b}cd();p()}f=zv(x[e>>2],x[e+4>>2]);d=fb-16|0;fb=d;Gg(c+12|0,h);c:{if(!a){b=0;a=0;break c}if(a>>>0>=130150525){Xj();p()}b=Dc(D(a,33));x[d+12>>2]=a;x[d+8>>2]=b;b=x[d+8>>2];a=x[d+12>>2]}x[c>>2]=b;f=b+D(f,33)|0;x[c+8>>2]=f;x[c+4>>2]=f;n=Ac(c),o=b+D(a,33)|0,x[n>>2]=o;fb=d+16|0;d=fb-16|0;fb=d;b=d+4|0;x[b>>2]=x[c+8>>2];a=x[c+8>>2];x[b+8>>2]=c+8;x[b+4>>2]=a+D(g,33);a=x[b>>2];while(1){if(x[b+4>>2]!=(a|0)){wY(a);a=x[b>>2]+33|0;x[b>>2]=a;continue}break}ee(b);fb=d+16|0;b=fb-16|0;fb=b;h=zb(b+12|0,x[e+4>>2]);i=zb(b+8|0,x[e>>2]);j=zb(b+4|0,x[c+4>>2]);d=fb-16|0;fb=d;a=fb-16|0;fb=a;g=fb-16|0;fb=g;f=fb-16|0;fb=f;j=x[j>>2];k=x[h>>2];h=x[i>>2];i=k-h|0;k=j+D((i|0)/-33|0,33)|0;m=ai(k,h,i);i=D((i|0)/33|0,33);x[f+12>>2]=m+i;Td(g+8|0,h+i|0,f+12|0);fb=f+16|0;Td(a+8|0,h,zb(g+4|0,j+D((k-j|0)/33|0,33)|0));fb=g+16|0;g=x[a+8>>2];x[a+4>>2]=x[a+12>>2];Td(d+8|0,g,a+4|0);fb=a+16|0;fb=d+16|0;x[c+4>>2]=x[d+12>>2];wc(e,c+4|0);wc(e+4|0,c+8|0);wc(Ab(e),Ac(c));x[c>>2]=x[c+4>>2];fb=b+16|0;e=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)!=(e|0)){a=a-33|0;x[c+8>>2]=a;continue}break}a=x[c>>2];if(a){Ac(c);Db(a)}}fb=l+32|0;return}if((c|0)!=64){xY(a,e+2112|0)}}function Gla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0;f=fb-48|0;fb=f;v=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+32>>2];A=x[a+28>>2];B=x[a+72>>2];t=x[a+68>>2];C=t>>31;u=x[a+64>>2];E=u>>31;m=x[a+60>>2];F=m>>31;j=x[a+8>>2];G=x[a+12>>2];while(1){if(d){b=x[f+16>>2];H=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+v|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=H+(p<<1)|0;x[(f+8|0)+(p<<2)>>2]=(((((D(w[i+8>>1],r)+D(w[i+4>>1],s)|0)+D(q,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)/2|0)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){r=(f+8|0)+(g<<2)|0;e=x[r>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;q=e<<8;e=q;e=sua(m,F,e,e>>31);k=hb;i=e;e=Xb(h,-16777216,16776704);e=sua(u,E,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(s,-16777216,16776704);k=sua(t,C,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(q&B);x[r>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+A|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+z|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Qb(f+16|0,j,G);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function R6(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;a=fb-448|0;fb=a;x[a+16>>2]=f;x[a+20>>2]=g;x[a+24>>2]=h;x[a+28>>2]=i;j=a+336|0;x[a+332>>2]=j;j=yy(j,100,11203,a+16|0);x[a+48>>2]=1208;k=a+48|0;o=Ae(a+216|0,0,k);x[a+48>>2]=1208;k=Ae(a+208|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+224|0;f=a+336|0;break d}j=Kd();x[a>>2]=f;x[a+4>>2]=g;x[a+8>>2]=h;x[a+12>>2]=i;j=oj(a+332|0,j,11203,a);if((j|0)!=-1){f=x[a+332>>2];Oe(o,f);Oe(k,Ed(j));h=x[k>>2];if(!Ak(h)){break d}}x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)!=1){break a}j=N()|0;break c}$c(a+204|0,x[d+28>>2]);x[31785]=0;r=R(28,x[a+204>>2])|0;g=x[31785];x[31785]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}x[31785]=0;V(1218,r|0,f|0,f+j|0,h|0);g=x[31785];x[31785]=0;if((g|0)==1){break j}q=(j|0)>0?y[f|0]==45:q;i=Fb(a+184|0);f=Fb(a+172|0);g=Fb(a+160|0);x[31785]=0;ka(1257,c|0,q|0,x[a+204>>2],a+200|0,a+199|0,a+198|0,i|0,f|0,g|0,a+156|0);c=x[31785];x[31785]=0;if((c|0)==1){break i}x[a+36>>2]=1208;c=Ae(a+40|0,0,a+36|0);m=a+48|0;n=x[a+156>>2];k:{if((n|0)<(j|0)){l=((Bb(x[g+4>>2],y[g+11|0])+(j-n<<1)|0)+Bb(x[f+4>>2],y[f+11|0])|0)+1|0;break k}l=(Bb(x[g+4>>2],y[g+11|0])+Bb(x[f+4>>2],y[f+11|0])|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Oe(c,Ed(l));m=x[c>>2];if(m){break h}x[31785]=0;X(1209);b=x[31785];x[31785]=0;if((b|0)!=1){break a}break g}j=N()|0;break e}j=N()|0;break f}l=x[d+4>>2];x[31785]=0;ma(1258,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,r|0,q|0,a+200|0,v[a+199|0],v[a+198|0],i|0,f|0,g|0,n|0);h=x[31785];x[31785]=0;if((h|0)!=1){x[31785]=0;b=ea(23,b|0,m|0,x[a+36>>2],x[a+32>>2],d|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break b}}}j=N()|0;Kc(c)}tb(g);tb(f);tb(i)}Zb(a+204|0)}Kc(k);Kc(o);Q(j|0);p()}Kc(c);tb(g);tb(f);tb(i);Zb(a+204|0);Kc(k);Kc(o);fb=a+448|0;return b|0}p()}function Hla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0,H=0,I=0;f=fb-48|0;fb=f;y=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}n=x[a+40>>2];o=x[a+36>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+32>>2];B=x[a+28>>2];C=x[a+72>>2];t=x[a+68>>2];E=t>>31;u=x[a+64>>2];F=u>>31;m=x[a+60>>2];G=m>>31;j=x[a+8>>2];H=x[a+12>>2];while(1){if(d){b=x[f+16>>2];I=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+y|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;p=0;while(1){if((p|0)!=2){i=p+I|0;x[(f+8|0)+(p<<2)>>2]=((((D(v[i+4|0],r)+D(v[i+2|0],s)|0)+D(q,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)<<8>>1)|0)/16384;p=p+1|0;continue}break}while(1){if((g|0)!=2){r=(f+8|0)+(g<<2)|0;e=x[r>>2];b=(f+28|0)+(g<<3)|0;s=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;q=e<<8;e=q;e=sua(m,G,e,e>>31);k=hb;i=e;e=Xb(h,-16777216,16776704);e=sua(u,F,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(s,-16777216,16776704);k=sua(t,E,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(q&C);x[r>>2]=(e|0)/256;g=g+1|0;continue}break}o=o+B|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],o>>12);n=n+A|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],n>>12);Qb(f+16|0,j,H);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=n;x[a+20>>2]=o>>12;x[a+36>>2]=o;x[a+24>>2]=n>>12;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function nfa(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{j=Lq(1,32);d:{e:{if(!j){a=Om(ac(4));x[31785]=0;S(100,a|0,125240,34);a=x[31785];x[31785]=0;if((a|0)!=1){break a}i=T(0)|0;break e}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:986;x[j>>2]=f;c=lg(k+36|0);f:{g:{h:{if(!i){break h}while(1){e=x[i>>2];if(!e){break h}l=x[i+4>>2];i:{if(l){x[31785]=0;e=P(37,k+24|0,e|0)|0;m=x[31785];x[31785]=0;j:{if((m|0)!=1){x[31785]=0;m=P(997,c|0,e|0)|0;n=x[31785];x[31785]=0;if((n|0)==1){break j}x[31785]=0;O(275,m|0,l|0);l=x[31785];x[31785]=0;if((l|0)==1){break j}break i}i=T(0)|0;break f}i=T(0)|0;tb(e);break f}x[31785]=0;e=P(37,k+12|0,e|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break g}Rt(c,e)}tb(e);i=i+8|0;continue}}x[31785]=0;e=R(859,104)|0;i=x[31785];x[31785]=0;k:{l:{m:{if((i|0)!=1){x[31785]=0;d=P(998,f|0,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break m}x[k+4>>2]=d;d=x[oe(k+8|0,k+4|0)>>2];x[31785]=0;a=ha(1029,e|0,a|0,b|0,d|0,c|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break k}i=T(0)|0;Uc(k+4|0);break l}i=T(0)|0;break f}i=T(0)|0}Db(e);break f}x[j+28>>2]=a;Uc(k+4|0);x[j+24>>2]=a+8;Kl(c);break d}i=T(0)|0}Kl(c);Y(i|0)|0;x[31785]=0;V(992,4993,j|0,g|0,h|0);a=x[31785];x[31785]=0;if((a|0)!=1){x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)!=1){a=x[j+28>>2];if(a){ib[x[x[a>>2]+4>>2]](a)}x[j+24>>2]=0;x[j+28>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);j=0;break d}i=T(0)|0;break e}i=T(0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break b}}Y(i|0)|0;j=0;x[31785]=0;V(992,4993,0,g|0,h|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return j|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Rb()}p()}function zg(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=x[a+8>>2]+(D(z[a+14>>1],(y[a+80|0]?c:0)+b|0)>>>1|0)|0;x[a+8>>2]=j;i=y[a+79|0]?z[x[a>>2]+3836>>1]:i;c=z[a+20>>1];l=z[a+22>>1];m=z[a+70>>1];a:{b:{c:{d:{switch(x[a+16>>2]){case 1:b=z[x[a>>2]+3832>>1];f=z[a+26>>1]?z[a+48>>1]>>>z[x[a+52>>2]+((b>>>z[a+44>>1]&7)<<1)>>1]|0:0;g=b;b=z[a+46>>1];f=c+(b?g&b?0:f:f)|0;w[a+20>>1]=f;b=2;h=z[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(y[a+78|0]){break b}case 3:b=0;f=z[x[a>>2]+3832>>1];h=z[a+30>>1]?z[a+60>>1]>>>z[x[a+64>>2]+((f>>>z[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=z[a+58>>1];f=c+(f?g&f?0:h:h)|0;w[a+20>>1]=f;if(f<<16>>16<511){break b}x[a+16>>2]=-1;w[a+20>>1]=511;x[a+72>>2]=0;break a;default:b=0;x[a+72>>2]=0;break a;case 0:break d}}b=1;f=z[x[a>>2]+3832>>1];k=z[a+24>>1]?D((c^-1)<<16>>16,z[a+36>>1]>>>z[x[a+40>>2]+((f>>>z[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=z[a+34>>1];f=c+(f?g&f?0:k:k)|0;w[a+20>>1]=f;if(f<<16>>16>0){break b}}x[a+16>>2]=b;w[a+20>>1]=h}i=((c+l|0)+m|0)+i<<3;if(e){d=(w[a+74>>1]+w[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(z[a+12>>1]){case 0:d=(b&512)>>>9|0;b=z[((b&256?c^255:c)<<1)+27008>>1];break e;case 1:d=0;b=z[((b&512?0:b&256?c^255:c)<<1)+27008>>1];break e;case 2:d=0;b=z[((b&256?c^255:c)<<1)+27008>>1];break e;case 3:d=0;b=z[((b&256?0:c)<<1)+27008>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=z[(e<<1)+27008>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=z[(b<<1)+27008>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}w[a+74>>1]=z[a+72>>1];c=a;a=b+i&65535;a=a>>>0>=8191?8191:a;b=0-d^z[((a&255)<<1)+26496>>1]+1024>>>(a>>>8)<<1;w[c+72>>1]=b}return b<<16>>16}function uX(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;v[a|0]=0;c=y[b|0];if(c){v[a|0]=c>>>0>96?-1:c+12|0}v[a+1|0]=y[b+1|0];c=y[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){v[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch(((c&240)+96&240)>>>4|0){case 0:v[a+2|0]=4;c=c&15;break b;case 1:v[a+2|0]=3;c=c&15;break b;case 2:v[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}v[a+2|0]=5;c=c&15}v[a+4|0]=c}c=y[b+6|0];e=y[b+4|0];d=y[b+5|0];d:{if(!(c|(e|d))){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}v[a+2|0]=15;v[a+3|0]=20;v[a+4|0]=c>>>3;v[f+15|0]=15;h=a,i=y[Ub(b+5|0,f+15|0)|0]|208,v[h+5|0]=i;break d;case 0:Mf(a,c,d);g=y[b+6|0]==15;break d;case 1:v[a+3|0]=2;h=a,i=Zg(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 2:v[a+3|0]=3;h=a,i=Zg(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 3:v[a+3|0]=4;h=a,i=Zg(c<<4|(d&240)>>>4),v[h+5|0]=i;break d;case 4:v[a+3|0]=5;v[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){v[a+5|0]=d;v[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}v[a+5|0]=145;v[a+3|0]=20;break d;case 12:v[a+3|0]=13;v[a+5|0]=c>>>1;break d;case 15:if(c){v[a+5|0]=c;v[a+3|0]=17;break d}v[a+3|0]=16;v[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}hD(a,c,d,1);g=(y[a+3|0]&254)==16;break d}v[a+5|0]=d;v[a+3|0]=18;break d}v[a+3|0]=31;v[a+5|0]=c>>>1;break d}v[a+3|0]=31;v[a+5|0]=c>>>1&120;break d}v[a+5|0]=159;v[a+3|0]=20;break d}v[a+3|0]=21;v[a+5|0]=c>>>2}b=y[b+3|0];l:{if(!b){break l}if(!y[a+3|0]){v[a+5|0]=b;v[a+3|0]=9;break l}if(y[a+2|0]){break l}v[a+2|0]=2;v[a+4|0]=b>>>2}fb=f+16|0;return g}function zR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;e=D(b,872)+a|0;j=e+1074992|0;a:{b:{i=x[e+1075080>>2];if(i&131072){h=a+480180|0;e=x[h>>2];i=1;c:{d:{e:{f=x[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}i=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}if(!i){break c}Kb(g+8|0,a+1074312|0,21);if(!Hb(x[x[g+8>>2]>>2],x[g+12>>2])){break c}e=D(b,872)+a|0;f=e+1075811|0;v[f|0]=y[f|0]+(y[e+1075815|0]<<2)}f=D(b,872)+a|0;k=f+1075814|0;l=f+1075811|0;e=xA(a,y[k|0],y[l|0]);f:{if(Oj(x[j+656>>2])){B[d>>2]=B[d>>2]+E(E(E(D(y[f+1075816|0],e)|0)*E(.05000000074505806))/E(7680));c=f+1075843|0;d=y[c|0];v[c|0]=d&159|64;if(x[a+1074416>>2]!=(x[a+1074392>>2]+1|0)){break f}v[c|0]=d|96;break f}d=x[a+480208>>2];if((d&2101248)==2101248){break a}f=x[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(y[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Kb(g+8|0,k,21);f=x[a+480208>>2];g:{if(Hb(x[x[g+8>>2]>>2],x[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=x[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}Kb(g+8|0,k,80);if(!Hb(x[x[g+8>>2]>>2],x[g+12>>2])){break g}d=y[(D(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=0-((D(y[(D(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0)|0;xk(a,j,c,d,0);e=x[j+656>>2];c=qq(a,x[j+88>>2],e);if(!c){break f}ib[x[x[c>>2]+92>>2]](c,d,(e?y[e+33|0]:2)<<24>>24,b)}if(!i){break a}Kb(g+8|0,a+1074312|0,21);if(Hb(x[x[g+8>>2]>>2],x[g+12>>2])){break a}v[l|0]=y[l|0]+y[(D(b,872)+a|0)+1075815|0];break a}if(!(y[e+1075662|0]&2)){break a}a=qq(a,i,x[j+656>>2]);if(!a){break a}ib[x[x[a>>2]+92>>2]](a,0,0,b);break a}a=D(b,872)+a|0;b=a+1075811|0;d=y[b|0];if(d&1){x[c>>2]=x[c>>2]+D(y[a+1075816|0],167)}v[b|0]=d+1}fb=g+16|0}function TW(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=fb-16|0;fb=l;g=x[b>>2];i=x[b+4>>2];a:{if((i|0)==(f|0)){b=gc(l+8|0,e,f);j=fb-16|0;fb=j;e=dn(c,d,g,f);x[j+12>>2]=e;b:{if((e|0)<=0){e=x[b>>2];break b}c:{if(!f){f=x[b>>2];break c}h=32-f|0;x[j+8>>2]=h;c=x[pd(j+8|0,j+12|0)>>2];x[j+12>>2]=e-c;d=x[b>>2];e=-1<<f&-1>>>h-c;x[d>>2]=x[d>>2]&(e^-1)|e&x[g>>2];c=c+x[b+4>>2]|0;x[b+4>>2]=c&31;f=d+(c>>>3&536870908)|0;x[b>>2]=f;g=g+4|0;e=x[j+12>>2]}c=(e|0)/32|0;NC(g,c,f);d=e-(c<<5)|0;x[j+12>>2]=d;c=c<<2;e=c+x[b>>2]|0;x[b>>2]=e;if((d|0)<=0){break b}d=-1>>>32-d|0;x[e>>2]=x[e>>2]&(d^-1)|d&x[c+g>>2];x[b+4>>2]=x[j+12>>2]}gc(a,e,x[b+4>>2]);fb=j+16|0;break a}j=a;h=gc(l,e,f);f=fb-16|0;fb=f;e=dn(c,d,g,i);x[f+12>>2]=e;d:{if((e|0)<=0){a=x[h+4>>2];break d}e:{if(!i){a=x[h+4>>2];break e}k=32-i|0;x[f+8>>2]=k;c=f+8|0;b=x[pd(c,f+12|0)>>2];x[f+12>>2]=e-b;a=x[h+4>>2];e=x[g>>2];x[f+8>>2]=b;m=32-a|0;x[f+4>>2]=m;d=x[h>>2];n=x[d>>2];c=x[Gb(c,f+4|0)>>2];e=e&(-1<<i&-1>>>k-b);x[d>>2]=(-1<<a&-1>>>m-c^-1)&n|(a>>>0>i>>>0?e<<a-i:e>>>i-a|0);k=a+c|0;a=k&31;x[h+4>>2]=a;d=d+(k>>>3&536870908)|0;x[h>>2]=d;b=b-c|0;if((b|0)>0){x[d>>2]=x[d>>2]&(-1>>>32-b^-1)|e>>>c+i;x[h+4>>2]=b;a=b}g=g+4|0;e=x[f+12>>2]}c=32-a|0;d=-1<<a;i=d^-1;while(1){if((e|0)>=32){b=x[h>>2];e=x[g>>2];x[b>>2]=i&x[b>>2]|e<<a;x[h>>2]=b+4;x[b+4>>2]=d&x[b+4>>2]|e>>>c;e=x[f+12>>2]-32|0;x[f+12>>2]=e;g=g+4|0;continue}break}if((e|0)<=0){break d}i=x[g>>2];x[f+8>>2]=c;g=x[h>>2];b=x[g>>2];k=b;b=x[pd(f+12|0,f+8|0)>>2];e=i&-1>>>32-e;x[g>>2]=k&(d&-1>>>c-b^-1)|e<<a;c=a+b|0;a=c&31;x[h+4>>2]=a;c=g+(c>>>3&536870908)|0;x[h>>2]=c;d=x[f+12>>2]-b|0;x[f+12>>2]=d;if((d|0)<=0){break d}x[c>>2]=x[c>>2]&(-1>>>32-d^-1)|e>>>b;a=x[f+12>>2];x[h+4>>2]=a}gc(j,x[h>>2],a);fb=f+16|0}fb=l+16|0}function hP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0;k=fb-48|0;fb=k;a:{b:{c:{d:{e:{f:{j=Lq(1,28);if(!j){a=Om(ac(4));x[31785]=0;S(100,a|0,125240,34);a=x[31785];x[31785]=0;if((a|0)!=1){break a}break f}x[j+12>>2]=f;x[j+8>>2]=e;x[j+4>>2]=d;f=c?c:986;x[j>>2]=f;c=lg(k+36|0);g:{h:{i:{if(!i){break i}while(1){e=x[i>>2];if(!e){break i}l=x[i+4>>2];j:{if(l){x[31785]=0;e=P(37,k+24|0,e|0)|0;m=x[31785];x[31785]=0;k:{if((m|0)!=1){x[31785]=0;m=P(997,c|0,e|0)|0;n=x[31785];x[31785]=0;if((n|0)==1){break k}x[31785]=0;O(275,m|0,l|0);l=x[31785];x[31785]=0;if((l|0)==1){break k}break j}i=T(0)|0;break g}i=T(0)|0;tb(e);break g}x[31785]=0;e=P(37,k+12|0,e|0)|0;l=x[31785];x[31785]=0;if((l|0)==1){break h}Rt(c,e)}tb(e);i=i+8|0;continue}}x[31785]=0;e=R(859,80)|0;i=x[31785];x[31785]=0;l:{m:{n:{if((i|0)!=1){x[31785]=0;d=P(998,f|0,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break n}x[k+4>>2]=d;d=x[oe(k+8|0,k+4|0)>>2];x[31785]=0;a=ha(1003,e|0,a|0,b|0,d|0,c|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break l}i=T(0)|0;Uc(k+4|0);break m}i=T(0)|0;break g}i=T(0)|0}Db(e);break g}x[j+24>>2]=a;Uc(k+4|0);Kl(c);i=j;break d}i=T(0)|0}Kl(c);Y(i|0)|0;x[31785]=0;V(992,15254,j|0,g|0,h|0);a=x[31785];x[31785]=0;if((a|0)!=1){x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break f}a=x[j+24>>2];if(a){Db(hq(a))}i=0;x[j+24>>2]=0;a=x[j+20>>2];if(a){Db(a);x[j+20>>2]=0}Db(j);break d}i=T(0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)!=1){break e}break b}i=T(0)|0}Y(i|0)|0;i=0;x[31785]=0;V(992,15254,0,g|0,h|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Z()}fb=k+48|0;return i|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}Q(a|0);p()}T(0)|0;Rb()}p()}function Oi(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!Si(p)){break a}if(!Si(m)){break a}h=wf(b);f=wf(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=Si(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=Si(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=wf(d);f=wf(e);b:{if(h|f){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Si(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Si(c),w?u:v);break b}if(k){break b}c:{if(wf(s)){break c}if(wf(t)){break c}if(wf(r)){break c}if(!wf(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=Si(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=Si(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=Si(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=Si(e),w?u:v)}m=(b*e+d*c)*Infinity;p=(b*d-e*c)*Infinity}Ml(a,p,m)}function F6(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=fb-16|0;fb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!y[j|0]){break a}j=j+1|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=x[b+4>>2];x[r+8>>2]=x[b>>2];x[r+12>>2]=i;s=fb-16|0;fb=s;u=Jh(s+12|0,x[a+8>>2]);m=j-c|0;k=0;o=0;n=fb-1040|0;fb=n;i=x[e>>2];x[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=hK(p,n+12|0,l>>>0>q>>>0?q:l,b);if((q|0)==-1){k=-1;l=0;i=x[n+12>>2];break g}t=(n+16|0)!=(p|0)?q:0;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=x[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=gt(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}x[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){x[e>>2]=o}fb=n+1040|0;Ih(u);fb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{x[h>>2]=f;if(x[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=Zx(f,c,j-c|0,r+8|0,x[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}x[e>>2]=c;break n}g=b}c=c+g|0;f=x[h>>2]+4|0;continue}break}x[e>>2]=c;break d}f=x[h>>2]+(k<<2)|0;x[h>>2]=f;if((f|0)==(g|0)){break k}c=x[e>>2];if((d|0)==(j|0)){j=d;continue}if(!Zx(f,c,1,b,x[a+8>>2])){break m}}a=2;break c}x[h>>2]=x[h>>2]+4;c=x[e>>2]+1|0;x[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!y[j|0]){break b}j=j+1|0;continue}}x[e>>2]=c;a=1;break c}c=x[e>>2]}a=(c|0)!=(d|0)}fb=r+16|0;return a|0}f=x[h>>2];continue}}function tS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=fb-16|0;fb=c;e=a+1074376|0;d=D(b,872);a:{if(x[(e+d|0)+704>>2]&134218752){break a}g=x[(a+d|0)+1075648>>2];if(!Gj(g)|y[g+15|0]&2){break a}e=lm(a,e,b,2,1)-1|0;if((e&255)>>>0>249){break a}h=x[rd(a+906300|0,e)>>2];if(!h){break a}d=D(b,872)+a|0;j=d+1075780|0;e=y[j|0];b:{if(y[d+1075782|0]==1){v[c+8|0]=64;d=y[Ub(d+1075784|0,c+8|0)|0];break b}f=y[d+1075783|0];if((f|0)!=46){d=255;if((f|0)!=13){break b}v[c+8|0]=64;d=y[Ub((D(b,872)+a|0)+1075785|0,c+8|0)|0];break b}d=y[(D(b,872)+a|0)+1075785|0]+3>>>2|0}i=a+1074312|0;Kb(c+8|0,i,2);if(Hb(x[x[c+8>>2]>>2],x[c+12>>2])){if(e){if(zd(e)){e=y[xb(g+108|0,e-1|0)|0]}Um(a,b,e&255,z[(D(b,872)+a|0)+1075680>>1]);break a}if((d|0)==255){break a}ib[x[x[h>>2]+76>>2]](h,39,d,b);break a}k=x[g+4>>2];c:{if(!e){break c}f=y[g+35|0]?k<<2:x[(D(b,872)+a|0)+1075680>>2];l=w[(D(b,872)+a|0)+1075768>>1];Kb(c+8|0,i,28);m=c,n=(Hb(x[x[c+8>>2]>>2],x[c+12>>2])?l<<2:l)+f|0,x[m+4>>2]=n;Ee(c+4|0,0,256);f=e;if(zd(e)){f=y[xb(g+108|0,e-1|0)|0]}Kb(c+8|0,i,117);if(!Hb(x[x[c+8>>2]>>2],x[c+12>>2])){if(Hl(y[j+2|0],y[j+3|0])){break c}}Um(a,b,f&255,z[c+4>>1])}a=y[g+35|0];Kb(c+8|0,i,101);a=(a|0)==1;f=(d|0)!=255;if(!Hb(x[x[c+8>>2]>>2],x[c+12>>2])){e=zd(e)}if(((e?a:f)|0)!=1){break a}d:{switch(y[g+36|0]){case 1:a=x[h+20>>2];if((d|0)!=255){pu(a,E(E(E(d<<1)/E(-127))+E(1)));break a}pu(a,E(E(E(k<<1>>>0)/E(-127))+E(1)));break a;case 0:break d;default:break a}}if((d|0)!=255){v[c+8|0]=127;v[c+4|0]=d<<1;n=h,o=7,p=y[Ub(c+8|0,c+4|0)|0],q=b,m=x[x[h>>2]+76>>2],ib[m](n|0,o|0,p|0,q|0);break a}x[c+8>>2]=127;x[c+4>>2]=k<<1;q=h,p=7,o=y[Gb(c+8|0,c+4|0)|0],n=b,m=x[x[h>>2]+76>>2],ib[m](q|0,p|0,o|0,n|0)}fb=c+16|0}function Kla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];v=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;y=b+24|0;z=x[a+72>>2];r=x[a+68>>2];A=r>>31;s=x[a+64>>2];B=s>>31;m=x[a+60>>2];C=m>>31;j=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];F=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(((b>>>16|0)+4&131064)<<1)+y|0;l=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=F+(n<<1)|0;x[(f+8|0)+(n<<2)>>2]=(((((D(w[i+8>>1],p)+D(w[i+4>>1],q)|0)+D(o,w[i+12>>1])|0)+D(l,w[i+16>>1])|0)/2|0)+((((D(w[i-8>>1],e)+D(w[i-12>>1],b)|0)+D(w[i-4>>1],k)|0)+D(w[i>>1],h)|0)/2|0)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){p=(f+8|0)+(g<<2)|0;e=x[p>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;o=e<<8;e=o;e=sua(m,C,e,e>>31);k=hb;i=e;e=Xb(h,-16777216,16776704);e=sua(s,B,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(q,-16777216,16776704);k=sua(r,A,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(o&z);x[p>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],v);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Qb(f+16|0,j,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function Xs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=Ws(c,d);x[i+4>>2]=1208;n=Vs(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ed(k);if(!j){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)!=1){break a}break b}Oe(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31785]=0;h=P(1210,a|0,i+124|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break f}if((h|!k)==1){x[31785]=0;b=P(1210,a|0,i+124|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31785]=0;o=R(1211,b|0)|0;b=x[31785];x[31785]=0;g:{if((b|0)!=1){if(g){break g}x[31785]=0;o=P(1212,e|0,o|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31785]=0;R(1213,a|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Bb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=y[cc(b,q)|0];j:{if(g){break j}x[31785]=0;r=P(1212,e|0,r<<24>>24)|0;t=x[31785];x[31785]=0;if((t|0)!=1){break j}break b}k:{if((o&255)==(r&255)){s=1;if((Bb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=yd(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Kc(n);fb=i+128|0;return d|0}}a=N()|0;Kc(n);Q(a|0)}p()}function Ts(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;i=fb-128|0;fb=i;x[i+124>>2]=b;k=Ws(c,d);x[i+4>>2]=1208;n=Vs(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Ed(k);if(!j){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)!=1){break a}break b}Oe(n,j)}h=j;b=c;c:{d:{while(1){if((b|0)==(d|0)){e:while(1){f:{x[31785]=0;h=P(1225,a|0,i+124|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break f}if((h|!k)==1){x[31785]=0;b=P(1225,a|0,i+124|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}if(!b){break d}x[f>>2]=x[f>>2]|2;break d}b=x[a>>2];x[31785]=0;o=R(1226,b|0)|0;b=x[31785];x[31785]=0;g:{if((b|0)!=1){if(g){break g}x[31785]=0;o=P(1227,e|0,o|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break g}}break b}l=q+1|0;s=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=l;if(!s){continue e}x[31785]=0;R(1228,a|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){h=j;b=c;if(k+m>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(y[h|0]!=2){break h}if((Bb(x[b+4>>2],y[b+11|0])|0)==(q|0)){break h}v[h|0]=0;m=m-1|0}h=h+1|0;b=b+12|0;continue}}break b}i:{if(y[h|0]!=1){break i}r=x[Sd(b,q)>>2];j:{if(g){break j}x[31785]=0;r=P(1227,e|0,r|0)|0;t=x[31785];x[31785]=0;if((t|0)!=1){break j}break b}k:{if((o|0)==(r|0)){s=1;if((Bb(x[b+4>>2],y[b+11|0])|0)!=(l|0)){break i}v[h|0]=2;m=m+1|0;break k}v[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}}else{l=yd(x[b+4>>2],y[b+11|0]);v[h|0]=l?2:1;m=m+l|0;k=k-l|0;h=h+1|0;b=b+12|0;continue}break}break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(y[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}x[f>>2]=x[f>>2]|4}Kc(n);fb=i+128|0;return d|0}}a=N()|0;Kc(n);Q(a|0)}p()}function Tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0;g=fb-32|0;fb=g;f=bU(g+20|0,1<<x[b+12>>2]);e=x[f>>2];while(1){c=x[a>>2];if(gh(c,x[a+4>>2])>>>0>d>>>0){c=Re(c,d);aU(Ud(e,d),C[c>>3]);d=d+1|0;continue}break}$T(b,f);w=g,y=vb(x[f>>2]),x[w>>2]=y;u=vb(x[f+4>>2]);while(1){d=x[g>>2];if(Ib(d,u)){m=C[d+8>>3];k=fb-32|0;fb=k;o(+C[d>>3]);e=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;e=e&2147483647;q=c&2147483647;c=(e|0)==(q|0)&r>>>0<s>>>0|e>>>0<q>>>0;h=c?r:s;c=c?e:q;v=c;l(0,h|0);l(1,c|0);p=+n();t=c>>>20|0;i=p;a:{if((t|0)==2047){break a}c=(e|0)==(q|0)&r>>>0>s>>>0|e>>>0>q>>>0;l(0,(c?r:s)|0);c=c?e:q;l(1,c|0);m=+n();b:{if(!(h|v)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-t|0)>=65){break a}c:{if(c>>>0>=1534){p=p*190109156629516e-225;m=m*190109156629516e-225;i=5.260135901548374e210;break c}i=1;if(t>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=190109156629516e-225}sL(k+24|0,k+16|0,m);sL(k+8|0,k,p);i=i*M(C[k>>3]+C[k+16>>3]+C[k+8>>3]+C[k+24>>3]);break a}i=m}p=i;fb=k+32|0;aU(d,Xp(p));Kq(g);continue}break}_T(b,f);ZT(f);h=x[f>>2];e=Dk(h,x[f+4>>2])>>>1|0;c=e>>>0<=1?1:e;d=1;while(1){if((c|0)!=(d|0)){BB(Ud(h,d),2);BB(Ud(h,d+e|0),0);d=d+1|0;continue}break}$T(b,f);w=g,y=vb(x[f>>2]),x[w+16>>2]=y;e=vb(x[f+4>>2]);while(1){h=x[g+16>>2];if(Ib(h,e)){YT(g,C[h>>3],C[h+8>>3]);c=x[g+12>>2];x[h+8>>2]=x[g+8>>2];x[h+12>>2]=c;c=x[g+4>>2];x[h>>2]=x[g>>2];x[h+4>>2]=c;Kq(g+16|0);continue}break}_T(b,f);ZT(f);e=x[a>>2];c=gh(e,x[a+4>>2]);b=x[f>>2];d=0;while(1){if((c|0)==(d|0)){cn(f);fb=g+32|0}else{a=Ud(b,d);w=Re(e,d),z=C[a>>3],C[w>>3]=z;d=d+1|0;continue}break}}function xna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=fb-48|0;fb=h;k=c+484344|0;$f(k,y[b+70|0]|y[b+71|0]<<8);a:{b:{while(1){if((y[b+70|0]|y[b+71|0]<<8)>>>0<=j>>>0){break b}f=x[a+8>>2];e=Mg(a);Yb(a,1);c:{if((y[b+58|0]|y[b+59|0]<<8)==258){c=be(a)+1|0;break c}c=eh(a)}d=eh(a);bd(a,e+f|0);e=h+8|0;ce(e,a,d);f=ic(h+28|0,e);ub(e);x[31785]=0;c=U(199,k|0,j&65535,(c?c>>>0>=1024?1024:c:64)|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=Vb(x[k>>2],j);m=h,n=vb(x[c>>2]),x[m+8>>2]=n;l=vb(x[c+4>>2]);while(1){c=x[h+8>>2];if(!Ib(c,l)){break d}x[31785]=0;d=R(200,f|0)|0;e=x[31785];x[31785]=0;e:{f:{g:{if((e|0)!=1){e=d<<24>>24;if((e|0)>=0){break g}if(e&1){x[31785]=0;d=R(200,f|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break a}v[c|0]=d}d=e&255;if(e&2){break f}break e}break a}v[c|0]=e;d=255}x[31785]=0;e=R(200,f|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break a}v[c+1|0]=e}i=0;e=0;if(d&4){x[31785]=0;e=R(200,f|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break a}}if(d&8){x[31785]=0;i=R(200,f|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break a}}if(d&16){x[31785]=0;d=R(200,f|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break a}v[c+5|0]=d}h:{i:{d=y[c|0];if(!d){break i}g=255;if((d|0)==97){break h}if(d>>>0>96){break i}g=d+12|0;break h}g=0}v[c|0]=g;d=y[c+5|0];j:{if((d|i)&255){Mf(c,i,d);break j}v[c+3|0]=0}if(y[c+1|0]==255){v[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){v[c+4|0]=d;v[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;v[c+4|0]=d;e=e-96>>>4|0;v[c+2|0]=y[e+25742|0];if((e|0)!=6){break k}v[c+4|0]=d<<2}ah(h+8|0);continue}}ub(f);j=j+1|0;continue}break}break a}fb=h+48|0;return}a=N()|0;ub(f);Q(a|0);p()}function Lla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0,G=0;f=fb-48|0;fb=f;t=x[a+16>>2];while(1){if((g|0)!=2){j=g<<3;m=j+(f+28|0)|0;j=a+j|0;x[m+4>>2]=x[j+44>>2];x[m+8>>2]=x[j+48>>2];g=g+1|0;continue}break}u=x[a+24>>2];y=x[a+20>>2];j=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=j;z=b+24|0;A=x[a+72>>2];r=x[a+68>>2];B=r>>31;s=x[a+64>>2];C=s>>31;m=x[a+60>>2];E=m>>31;j=x[a+8>>2];F=x[a+12>>2];while(1){if(d){b=x[f+16>>2];G=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=(((b>>>16|0)+4&131064)<<1)+z|0;l=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];h=w[b+6>>1];k=w[b+4>>1];e=w[b+2>>1];b=w[b>>1];g=0;n=0;while(1){if((n|0)!=2){i=n+G|0;x[(f+8|0)+(n<<2)>>2]=((((D(v[i+4|0],p)+D(v[i+2|0],q)|0)+D(o,v[i+6|0])|0)+D(l,v[i+8|0])<<8>>1)+(((D(v[i-4|0],e)+D(v[i-6|0],b)|0)+D(v[i-2|0],k)|0)+D(v[i|0],h)<<8>>1)|0)/16384;n=n+1|0;continue}break}while(1){if((g|0)!=2){p=(f+8|0)+(g<<2)|0;e=x[p>>2];b=(f+28|0)+(g<<3)|0;q=x[b+8>>2];h=x[b+4>>2];x[b+8>>2]=h;o=e<<8;e=o;e=sua(m,E,e,e>>31);k=hb;i=e;e=Xb(h,-16777216,16776704);e=sua(s,C,e,e>>31);h=i+e|0;l=hb+k|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(q,-16777216,16776704);k=sua(r,B,e,e>>31);h=k+h|0;e=hb+l|0;e=h>>>0<k>>>0?e+1|0:e;k=h+8388608|0;e=k>>>0<8388608?e+1|0:e;e=Rc(k,e,24);x[b+4>>2]=e-(o&A);x[p>>2]=(e|0)/256;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],y);x[c+4>>2]=x[c+4>>2]+D(u,x[f+12>>2]);Qb(f+16|0,j,F);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;g=0;while(1){if((g|0)!=2){b=g<<3;c=b+a|0;b=b+(f+28|0)|0;x[c+44>>2]=x[b+4>>2];x[c+48>>2]=x[b+8>>2];g=g+1|0;continue}break}fb=f+48|0}function Y3(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Bb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(x[Sd(d,b)>>2]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=x[Sd(d,b+1|0)>>2];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(x[Sd(d,b)>>2]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=x[Sd(d,a+1|0)>>2];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(x[Sd(d,b)>>2]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(x[Sd(d,a+1|0)>>2]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(x[Sd(d,b)>>2]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(x[Sd(d,a+1|0)>>2]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(x[Sd(d,b)>>2]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(x[Sd(d,a)>>2]==121){break b}if(x[Sd(d,a)>>2]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(x[Sd(d,b)>>2]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(x[Sd(d,a+1|0)>>2]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(x[Sd(d,b)>>2]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(x[Sd(d,a)>>2]==121){break b}if(x[Sd(d,a)>>2]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(x[Sd(d,b)>>2]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(x[Sd(d,a+1|0)>>2]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;o=x[a+8>>2];C=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=b>>>21&2040;h=w[b+38390>>1];i=w[b+38388>>1];e=w[b+38386>>1];g=w[b+38384>>1];b=0;j=0;while(1){if((j|0)!=2){k=p+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=sua(s,B,e,e>>31);i=hb;l=e;e=Xb(h,-16777216,16776704);e=sua(r,A,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(p,-16777216,16776704);i=sua(q,z,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&y);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Qb(f+16|0,o,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Yia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=fb-192|0;fb=c;e=Gm(c+80|0,a);x[31785]=0;d=P(465,c+68|0,42511)|0;a=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){x[31785]=0;x[c+56>>2]=19988519;x[c+60>>2]=0;S(466,e|0,d|0,c+56|0);a=x[31785];x[31785]=0;if((a|0)==1){break n}Eb(d);if(ml(y[e|0])){break e}x[31785]=0;d=P(465,c+56|0,13422)|0;a=x[31785];x[31785]=0;if((a|0)==1){break m}x[31785]=0;V(497,e|0,b|0,d|0,921);a=x[31785];x[31785]=0;if((a|0)==1){break l}Eb(d);x[c+52>>2]=0;x[c+48>>2]=0;x[31785]=0;d=P(465,c+36|0,16957)|0;a=x[31785];x[31785]=0;if((a|0)==1){break k}x[31785]=0;S(922,e|0,c+52|0,d|0);a=x[31785];x[31785]=0;if((a|0)==1){break j}Eb(d);x[31785]=0;d=P(465,c+24|0,16929)|0;a=x[31785];x[31785]=0;if((a|0)==1){break i}x[31785]=0;S(922,e|0,c+48|0,d|0);a=x[31785];x[31785]=0;if((a|0)==1){break h}Eb(d);a=x[c+52>>2];d=x[c+48>>2];o:{if(!a|d>>>0<a>>>0){break o}f=x[x[x[x[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}x[b+20>>2]=d;x[b+16>>2]=a}d=Nb(c+12|0);x[31785]=0;f=P(465,c|0,14230)|0;a=x[31785];x[31785]=0;if((a|0)==1){break d}x[31785]=0;S(923,e|0,d|0,f|0);a=x[31785];x[31785]=0;if((a|0)==1){break g}Eb(f);if(mc(x[d>>2],x[d+4>>2])){break f}a=x[b+16>>2];x[31785]=0;O(873,d|0,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){break f}break c}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;break a}a=N()|0;Eb(d);break a}a=N()|0;Eb(f);break b}x[31785]=0;O(924,b|0,d|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}sc(d)}yh(e);fb=c+192|0;return}a=N()|0;break b}a=N()|0}sc(d)}yh(e);Q(a|0);p()}function D3(a){a=a|0;var b=0,c=0,d=0;a=a+12|0;d=a+508|0;c=Bb(x[a+512>>2],y[a+519|0]);while(1){a:{if((b|0)==(c|0)){b=c;break a}if(y[cc(d,b)|0]==37){break a}b=b+1|0;continue}break}b:{c:{d:{e:{f:{a=v[cc(d,b+1|0)|0];if((a|0)!=121){if((a|0)==100){break f}if((a|0)==109){break e}if((a|0)!=89){break c}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){g:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break g}a=b}if((a|0)==(c|0)){break c}b=v[cc(d,a+1|0)|0];if((b|0)==100){break d}if((b|0)!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){h:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break h}a=b}if((a|0)==(c|0)){break c}b=3;if(y[cc(d,a+1|0)|0]!=100){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){i:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break i}a=b}if((a|0)==(c|0)){break c}if(y[cc(d,a+1|0)|0]!=109){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){j:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break j}a=b}if((a|0)==(c|0)){break c}b=1;a=a+1|0;if(y[cc(d,a)|0]==121){break b}if(y[cc(d,a)|0]==89){break b}break c}b=b+1|0;continue}}b=b+1|0;continue}}b=b+2|0;a=b>>>0<c>>>0?c:b;while(1){k:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break k}a=b}if((a|0)==(c|0)){break c}if(y[cc(d,a+1|0)|0]!=100){break c}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){l:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break l}a=b}if((a|0)==(c|0)){break c}b=2;a=a+1|0;if(y[cc(d,a)|0]==121){break b}if(y[cc(d,a)|0]!=89){break c}break b}b=b+1|0;continue}}b=b+1|0;continue}}b=a+2|0;a=b>>>0<c>>>0?c:b;while(1){m:{if(b>>>0<c>>>0){if(y[cc(d,b)|0]!=37){break m}a=b}if((a|0)==(c|0)){break c}b=4;if(y[cc(d,a+1|0)|0]!=109){break c}break b}b=b+1|0;continue}}b=0}return b|0}function kra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=fb-16|0;fb=g;i=Bf(a,c);Yd(g,x[a+36>>2]);j=a;a:{if(!i){Pc(g,a+32|0,5);c=0;if(Hb(x[x[g>>2]>>2],x[g+4>>2])){break a}}e=fb-192|0;fb=e;f=Gm(e+80|0,x[a+36>>2]);x[31785]=0;a=P(465,e+68|0,26415)|0;c=x[31785];x[31785]=0;b:{c:{d:{e:{if((c|0)!=1){x[31785]=0;x[e+8>>2]=19988519;x[e+12>>2]=0;S(466,f|0,a|0,e+8|0);c=x[31785];x[31785]=0;if((c|0)==1){break e}Eb(a);if(!ml(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}v[e+67|0]=0;v[e+66|0]=0;x[31785]=0;a=P(465,e+52|0,10104)|0;c=x[31785];x[31785]=0;f:{g:{h:{i:{if((c|0)!=1){x[31785]=0;S(507,f|0,e+67|0,a|0);c=x[31785];x[31785]=0;if((c|0)==1){break i}Eb(a);if(!y[e+67|0]){break b}If(e+67|0,50);x[31785]=0;a=P(465,e+40|0,13309)|0;c=x[31785];x[31785]=0;if((c|0)==1){break f}x[31785]=0;S(507,f|0,e+66|0,a|0);c=x[31785];x[31785]=0;if((c|0)==1){break g}Eb(a);a=x[b>>2];c=Kj(a,x[b+4>>2]);h=y[e+67|0];if(c>>>0<h>>>0){a=PB(e+8|0,x[b+12>>2]);x[31785]=0;S(508,b|0,h|0,a|0);c=x[31785];x[31785]=0;if((c|0)==1){break h}Ol(a);a=x[b>>2]}k=z[Sj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=y[e+66|0];n=b,o=Kj(x[b>>2],x[b+4>>2])>>>0>a>>>0?a:0,v[n+16|0]=o;break b}_e(Sj(x[b>>2],a),k);l=x[b>>2];x[31785]=0;O(509,e+8|0,c|0);m=x[31785];x[31785]=0;if((m|0)!=1){x[31785]=0;V(510,f|0,Sj(l,a)|0,e+8|0,d|0);a=x[31785];x[31785]=0;if((a|0)==1){break j}c=c+1|0;Eb(e+8|0);continue}break}c=N()|0;break c}c=N()|0;Eb(e+8|0);break c}c=N()|0;break c}c=N()|0;Eb(a);break c}c=N()|0;Ol(a);break c}c=N()|0;Eb(a);break c}c=N()|0}yh(f);Q(c|0);p()}yh(f);fb=e+192|0;c=i}cf(j,c);fb=g+16|0}function Soa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(x[a+4>>2]!=x[Ab(a)>>2]){f=fb-16|0;fb=f;c=f+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+56;a=x[c+4>>2];x[31785]=0;O(686,a|0,b|0);a=x[31785];x[31785]=0;a:{if((a|0)!=1){x[c+4>>2]=x[c+4>>2]+56;hc(c);fb=f+16|0;break a}a=N()|0;hc(c);Q(a|0);p()}return}h=fb-32|0;fb=h;i=Ab(a);f=h+12|0;g=hv(x[a>>2],x[a+4>>2])+1|0;d=fb-16|0;fb=d;x[d+12>>2]=g;e=fb-16|0;fb=e;x[e+12>>2]=76695844;x[e+8>>2]=2147483647;c=x[Gb(e+12|0,e+8|0)>>2];fb=e+16|0;b:{if(c>>>0>=g>>>0){e=XW(a);if(e>>>0<c>>>1>>>0){x[d+8>>2]=e<<1;c=x[_c(d+8|0,d+12|0)>>2]}fb=d+16|0;break b}cd();p()}g=hv(x[a>>2],x[a+4>>2]);e=fb-16|0;fb=e;Gg(f+12|0,i);c:{if(!c){d=0;c=0;break c}if(c>>>0>=76695845){Xj();p()}d=Dc(D(c,56));x[e+12>>2]=c;x[e+8>>2]=d;d=x[e+12>>2];c=x[e+8>>2]}x[f>>2]=c;g=c+D(g,56)|0;x[f+8>>2]=g;x[f+4>>2]=g;j=Ac(f),k=c+D(d,56)|0,x[j>>2]=k;fb=e+16|0;c=x[f+8>>2];x[31785]=0;O(686,c|0,b|0);b=x[31785];x[31785]=0;d:{if((b|0)!=1){x[f+8>>2]=x[f+8>>2]+56;e=fb-16|0;fb=e;b=zb(e+12|0,x[a+4>>2]);c=zb(e+8|0,x[a>>2]);g=zb(e+4|0,x[f+4>>2]);d=x[b>>2];i=x[c>>2];c=fb-16|0;fb=c;x[c+8>>2]=x[g>>2];x[c+12>>2]=d;while(1){g=x[c+8>>2];if(Pg(d,i)){b=fb-16|0;fb=b;x[b+12>>2]=g;x[b+12>>2]=x[b+12>>2]-56;fb=b+16|0;g=x[b+12>>2];b=YW(d);d=Tl(g,b);Tl(d+12|0,b+12|0);lC(d+24|0,b+24|0);w[d+52>>1]=z[b+52>>1];g=x[b+48>>2];x[d+44>>2]=x[b+44>>2];x[d+48>>2]=g;g=x[b+40>>2];x[d+36>>2]=x[b+36>>2];x[d+40>>2]=g;b=VW(c+12|0);VW(c+8|0);d=x[b>>2];continue}break}fb=c+16|0;x[f+4>>2]=g;wc(a,f+4|0);wc(a+4|0,f+8|0);wc(Ab(a),Ac(f));x[f>>2]=x[f+4>>2];fb=e+16|0;WW(f);fb=h+32|0;break d}a=N()|0;WW(f);Q(a|0);p()}}function mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0,C=0,E=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;o=g+(f+28|0)|0;g=a+g|0;x[o+4>>2]=x[g+44>>2];x[o+8>>2]=x[g+48>>2];b=b+1|0;continue}break}m=x[a+40>>2];n=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];q=x[a+68>>2];A=q>>31;r=x[a+64>>2];B=r>>31;s=x[a+60>>2];C=s>>31;o=x[a+8>>2];E=x[a+12>>2];while(1){if(d){b=x[f+16>>2];p=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=b>>>21&2040;h=w[b+38390>>1];i=w[b+38388>>1];e=w[b+38386>>1];g=w[b+38384>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+p|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;p=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=sua(s,C,e,e>>31);i=hb;l=e;e=Xb(h,-16777216,16776704);e=sua(r,B,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(p,-16777216,16776704);i=sua(q,A,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&z);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}n=n+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],n>>12);m=m+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],m>>12);Qb(f+16|0,o,E);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=m;x[a+20>>2]=n>>12;x[a+36>>2]=n;x[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function wr(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{b:{c:{d:{e:{switch(b-2|0){case 11:v[e+14|0]=64;ae(a,1,Ub(e+15|0,e+14|0));break a;case 0:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;ae(a,12,e+14|0);break a;case 1:if(!(c&3|c>>>0>223?d:1)){break b}v[e+14|0]=c>>>2;ae(a,13,e+14|0);break a;case 2:if(c>>>0>=240){v[e+14|0]=9;ae(a,11,e+14|0);break a}b=0;while(1){if((b|0)==10){break b}f=y[b+42448|0];f:{if(d){if(c>>>0>f>>>0){break f}break d}if((c|0)==(f|0)){break d}}b=b+1|0;continue};case 3:g:{if(d){v[e+14|0]=c&15;v[e+13|0]=9;c=y[Ub(e+14|0,e+13|0)|0];break g}if(c>>>0>15|(c&14)>>>0>9){break b}}v[e+14|0]=c&15;ae(a,8,e+14|0);break a;case 24:h:{if(d){v[e+15|0]=0;break h}if(c){break b}}ae(a,8,e+15|0);break a;case 7:v[e+15|0]=(c|0)==255?64:c>>>2|0;ae(a,2,e+15|0);break a;case 9:if(!c){break b}b=c&15;if(!b){v[e+14|0]=c>>>4;ae(a,3,e+14|0);break a}d=c&240;if(!d){ae(a,4,e+15|0);break a}if((b|0)==15){v[e+14|0]=c>>>4;ae(a,5,e+14|0);break a}if((d|0)!=240){break b}v[e+14|0]=c&15;ae(a,6,e+14|0);break a;case 18:if((c&240)!=128){break b}v[e+14|0]=c<<2&60|2;ae(a,2,e+14|0);break a;case 17:i:{switch((c>>>4|0)-8|0){case 0:v[e+14|0]=c<<2&60|2;ae(a,2,e+14|0);break a;case 2:v[e+14|0]=c&15;ae(a,5,e+14|0);break a;case 3:break i;default:break b}}v[e+14|0]=c&15;ae(a,6,e+14|0);break a;case 4:case 5:case 6:case 8:case 10:case 12:case 13:case 14:case 15:case 16:case 19:case 20:case 21:case 22:case 23:break b;default:break e}}if((b|0)==46){break c}break b}v[e+14|0]=b;ae(a,11,e+14|0);break a}if(d?0:c&3){break b}v[e+14|0]=c+3>>>2;ae(a,1,e+14|0);break a}v[e+14|0]=0;ae(a,0,e+14|0)}fb=e+16|0}function NU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=x[b>>2];if(e){if(!x[b+4>>2]){break b}g=x[b+4>>2];c:{if(!g){while(1){g=Qh(d);d=x[d+8>>2];if(!g){continue}break}break c}d=CZ(g)}e=x[d>>2];if(e){break b}}e=x[d+4>>2];if(e){break b}e=0;g=1;break a}x[e+8>>2]=x[d+8>>2];g=0}d:{e:{if(Qh(d)){c=x[d+8>>2];x[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=x[d+8>>2];x[c+4>>2]=e}c=x[c>>2]}h=!y[d+12|0];if((b|0)!=(d|0)){f=x[b+8>>2];x[d+8>>2]=f;i=f+(Qh(b)?0:4)|0,j=d,x[i>>2]=j;f=x[b>>2];x[d>>2]=f;nn(f,d);f=x[b+4>>2];x[d+4>>2]=f;if(f){nn(f,d)}v[d+12|0]=y[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=y[c+12|0];f:{g:{if(!Qh(c)){if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;$q(b);b=x[c>>2];a=(b|0)==(a|0)?c:a;c=x[b+4>>2]}b=x[c>>2];h:{if(!(y[b+12|0]?0:b)){b=x[c+4>>2];if(y[b+12|0]?0:b){break h}v[c+12|0]=0;i:{b=x[c+8>>2];if((b|0)!=(a|0)){if(y[b+12|0]){break i}a=b}v[a+12|0]=1;return}if(!Qh(b)){break g}b=x[b+8>>2]+4|0;break f}a=x[c+4>>2];if(y[a+12|0]?0:a){break h}v[b+12|0]=1;v[c+12|0]=0;_q(c);c=x[c+8>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[x[c+4>>2]+12|0]=1;$q(a);return}if(!b){v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;_q(b);b=x[c+4>>2];a=(b|0)==(a|0)?c:a;c=x[b>>2]}d=x[c>>2];j:{if(y[d+12|0]?0:d){break j}b=x[c+4>>2];if(!(y[b+12|0]?0:b)){v[c+12|0]=0;b=x[c+8>>2];if(!((a|0)!=(b|0)?y[b+12|0]:0)){v[b+12|0]=1;return}if(Qh(b)){b=x[b+8>>2]+4|0;break f}b=x[b+8>>2];break f}if(y[d+12|0]?0:d){break j}v[b+12|0]=1;v[c+12|0]=0;$q(c);c=x[c+8>>2];d=x[c>>2]}a=x[c+8>>2];v[c+12|0]=y[a+12|0];v[a+12|0]=1;v[d+12|0]=1;_q(a);return}b=x[b+8>>2]}c=x[b>>2];continue}}v[e+12|0]=1}}function X6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-624|0;fb=a;x[a+616>>2]=c;x[a+620>>2]=b;x[a+16>>2]=1241;h=Ae(a+200|0,a+208|0,a+16|0);$c(a+192|0,x[e+28>>2]);x[31785]=0;i=R(1220,x[a+192>>2])|0;b=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+191|0]=0;b=x[e+4>>2];x[31785]=0;b=na(1250,a+620|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}if(!b){break e}b=y[14797]|y[14798]<<8|(y[14799]<<16|y[14800]<<24);v[a+183|0]=b;v[a+184|0]=b>>>8;v[a+185|0]=b>>>16;v[a+186|0]=b>>>24;b=y[14794]|y[14795]<<8|(y[14796]<<16|y[14797]<<24);x[a+176>>2]=y[14790]|y[14791]<<8|(y[14792]<<16|y[14793]<<24);x[a+180>>2]=b;x[31785]=0;V(1231,i|0,a+176|0,a+186|0,a+128|0);b=x[31785];x[31785]=0;if((b|0)==1){break g}x[a+4>>2]=1208;d=Ae(a+8|0,0,a+4|0);e=a+16|0;b=x[a+196>>2];c=b-x[h>>2]|0;if((c|0)<393){break f}Oe(d,Ed((c>>2)+2|0));e=x[d>>2];if(e){break f}x[31785]=0;X(1209);b=x[31785];x[31785]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+191|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((rK(a+16|0,a)|0)!=1){x[31785]=0;W(1243,8020);b=x[31785];x[31785]=0;if((b|0)!=1){break a}break c}Kc(d)}else{b=a+128|0;j=e,k=y[(a+176|0)+(ky(b,b+40|0,x[c>>2])-b>>2)|0],v[j|0]=k;e=e+1|0;c=c+4|0;b=x[a+196>>2];continue}break}}x[31785]=0;b=P(1225,a+620|0,a+616|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+620>>2];Zb(a+192|0);Kc(h);fb=a+624|0;return b|0}c=N()|0;break b}c=N()|0;Kc(d)}Zb(a+192|0);Kc(h);Q(c|0);p()}p()}function jQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;m=fb-16|0;fb=m;a:{if((b|0)==(c|0)){break a}x[m+12>>2]=-1953789045;Oz(b,c,m+12|0);k=c-b|0;c=k>>2;x[m+8>>2]=c;e=oc(x[a>>2],x[a+4>>2]);d=11;b:{if(k>>>0>2488){break b}d=7;if(k>>>0>268){break b}d=5;if(k>>>0>152){break b}d=3;if(k>>>0>24){break b}d=c-1>>>1|0}i=e+1|0;x[m+4>>2]=i;k=x[_c(m+4|0,m+8|0)>>2];h=c-d>>>1|0;f=(h<<2)+b|0;l=x[f>>2];g=c-1|0;j=D(Vt(l^(x[b>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=j+l;f=d+h|0;d=(f<<2)+b|0;l=d;n=x[d>>2];d=e+j|0;x[l>>2]=n+d;x[b>>2]=d;l=i>>>0<=1?1:i;d=(h>>>0)%(c>>>0)|0;e=(f>>>0)%(c>>>0)|0;f=x[a>>2];h=1;a=0;while(1)if((h|0)==(l|0)){while(1)if(k>>>0<=i>>>0){i=c+k|0;h=k>>>0>i>>>0?k:i;while(1){if((h|0)==(k|0)){break a}g=g+1|0;g=(c|0)!=(g|0)?g:0;d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;i=D(Vt(x[(g<<2)+b>>2]+(l+x[j>>2]|0)|0),1566083941);x[f>>2]=i^l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;i=i-a|0;x[f>>2]=i^x[f>>2];x[j>>2]=i;k=k+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;f=(d<<2)+b|0;l=x[f>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;j=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;h=D(Vt(l^(x[j>>2]^x[(g<<2)+b>>2])),1664525);x[f>>2]=h+l;e=e+1|0;e=(c|0)!=(e|0)?e:0;f=(e<<2)+b|0;h=a+h|0;x[f>>2]=h+x[f>>2];x[j>>2]=h;i=i+1|0;continue}}else{d=d+1|0;d=(c|0)!=(d|0)?d:0;n=(d<<2)+b|0;o=x[n>>2];a=a+1|0;a=(a|0)!=(c|0)?a:0;p=(a<<2)+b|0;g=g+1|0;g=(c|0)!=(g|0)?g:0;j=D(Vt(o^(x[p>>2]^x[(g<<2)+b>>2])),1664525);x[n>>2]=j+o;j=x[wb(f,h-1|0)>>2]+(a+j|0)|0;e=e+1|0;e=(c|0)!=(e|0)?e:0;n=(e<<2)+b|0;x[n>>2]=j+x[n>>2];x[p>>2]=j;h=h+1|0;continue}}fb=m+16|0}function c7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;x[a+16>>2]=1241;h=Ae(a+152|0,a+160|0,a+16|0);$c(a+144|0,x[e+28>>2]);x[31785]=0;i=R(28,x[a+144>>2])|0;b=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){v[a+143|0]=0;b=x[e+4>>2];x[31785]=0;b=na(1242,a+268|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}if(!b){break e}b=y[14797]|y[14798]<<8|(y[14799]<<16|y[14800]<<24);v[a+135|0]=b;v[a+136|0]=b>>>8;v[a+137|0]=b>>>16;v[a+138|0]=b>>>24;b=y[14794]|y[14795]<<8|(y[14796]<<16|y[14797]<<24);x[a+128>>2]=y[14790]|y[14791]<<8|(y[14792]<<16|y[14793]<<24);x[a+132>>2]=b;x[31785]=0;V(1218,i|0,a+128|0,a+138|0,a+118|0);b=x[31785];x[31785]=0;if((b|0)==1){break g}x[a+4>>2]=1208;d=Ae(a+8|0,0,a+4|0);e=a+16|0;b=x[a+148>>2];c=b-x[h>>2]|0;if((c|0)<99){break f}Oe(d,Ed(c+2|0));e=x[d>>2];if(e){break f}x[31785]=0;X(1209);b=x[31785];x[31785]=0;if((b|0)==1){break c}break a}c=N()|0;break b}c=N()|0;break b}if(y[a+143|0]){v[e|0]=45;e=e+1|0}c=x[h>>2];while(1){if(b>>>0<=c>>>0){v[e|0]=0;x[a>>2]=g;if((rK(a+16|0,a)|0)!=1){x[31785]=0;W(1243,8020);b=x[31785];x[31785]=0;if((b|0)!=1){break a}break c}Kc(d)}else{b=a+118|0;i=PZ(b);j=e,k=y[((Ii(b,i,y[c|0])-a|0)+a|0)+10|0],v[j|0]=k;e=e+1|0;c=c+1|0;b=x[a+148>>2];continue}break}}x[31785]=0;b=P(1210,a+268|0,a+264|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}if(b){x[f>>2]=x[f>>2]|2}b=x[a+268>>2];Zb(a+144|0);Kc(h);fb=a+272|0;return b|0}c=N()|0;break b}c=N()|0;Kc(d)}Zb(a+144|0);Kc(h);Q(c|0);p()}p()}function L6(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;w=d&512;z=h<<2;while(1){if((u|0)==4){if(Bb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=lJ(Ek(wd(n),1),kl(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];h=it(g,32);p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 3:if(yd(x[n+4>>2],y[n+11|0])){break a}h=x[Sd(n,0)>>2];p=x[c>>2];x[c>>2]=p+4;x[p>>2]=h;break a;case 2:if(yd(x[m+4>>2],y[m+11|0])|!w){break a}B=c,C=lJ(wd(m),kl(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}A=x[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!uj(g,64,x[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=x[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){q=q-1|0;h=h-4|0;s=x[h>>2];r=p+4|0;x[c>>2]=r;x[p>>2]=s;p=r;continue}break}d:{if(!q){s=0;break d}s=it(g,48);p=x[c>>2]}while(1){r=p+4|0;if((q|0)>0){x[p>>2]=s;q=q-1|0;p=r;continue}break}x[c>>2]=r;x[p>>2]=j}e:{if((e|0)==(h|0)){p=it(g,48);q=x[c>>2];h=q+4|0;x[c>>2]=h;x[q>>2]=p;break e}if(yd(x[l+4>>2],y[l+11|0])){s=-1}else{s=v[cc(l,0)|0]}q=0;t=0;while(1){if((e|0)!=(h|0)){r=x[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;x[c>>2]=p;x[r>>2]=k;r=0;t=t+1|0;if(Bb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){s=q;break f}s=-1;if(y[cc(l,t)|0]==127){break f}s=v[cc(l,t)|0]}h=h-4|0;q=x[h>>2];x[c>>2]=p+4;x[p>>2]=q;q=r+1|0;continue}break}h=x[c>>2]}Us(A,h)}u=u+1|0;continue}break}}function ne(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{b:{c:{switch(b|0){case 1:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31785]=0;O(54,b|0,Wc(e,d)|0);d=x[31785];x[31785]=0;d:{if((d|0)!=1){e:{while(1){if(Wc(x[c+4>>2],y[c+11|0])>>>0>a>>>0){d=v[cc(c,a)|0];x[31785]=0;O(36,b|0,((d|0)<0?65533:d&255)|0);d=x[31785];x[31785]=0;if((d|0)==1){break e}a=a+1|0;continue}break}break d}}break a}return;case 2:b=Fb(a);d=y[c+11|0];e=x[c+4>>2];a=0;x[31785]=0;O(54,b|0,Wc(e,d)|0);d=x[31785];x[31785]=0;f:{if((d|0)!=1){while(1){if(Wc(x[c+4>>2],y[c+11|0])>>>0<=a>>>0){break f}d=y[cc(c,a)|0];x[31785]=0;O(36,b|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){a=a+1|0;continue}break}}break a}return;case 3:ef(a,c,49168);return;case 4:ef(a,c,50192);return;case 5:ef(a,c,51216);return;case 6:ef(a,c,52240);return;case 7:ef(a,c,53264);return;case 8:ef(a,c,54288);return;case 9:ef(a,c,55312);return;case 10:ef(a,c,56336);return;case 11:ef(a,c,57360);return;case 12:ef(a,c,58384);return;case 13:ef(a,c,59408);return;case 14:ef(a,c,60432);return;case 15:ef(a,c,61456);return;case 16:ef(a,c,62480);return;case 17:ef(a,c,63504);return;case 18:ef(a,c,64528);return;case 19:ef(a,c,65552);return;case 20:ef(a,c,66576);return;case 21:ef(a,c,67600);return;case 22:ef(a,c,68624);return;case 23:ef(a,c,69648);return;case 24:TA(a,c,70672);return;case 25:TA(a,c,49168);return;case 26:TA(a,c,67600);return;default:a=ac(8);x[31785]=0;b=P(16,a|0,11116)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}b=N()|0;jc(a);Q(b|0);p();case 0:break c}}NZ(a,c);return}da(b|0,125372,17);p()}a=N()|0;Sb(b);Q(a|0);p()}function wq(a,b,c,d){var e=E(0),f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),p=0;h=fb-16|0;fb=h;x[h+12>>2]=w[b+780>>1]+y[b+837|0];x[h+8>>2]=w[b+782>>1]+(y[b+838|0]&127);Ee(h+12|0,0,127);Ee(h+8|0,0,127);j=a+1074312|0;i=Pb(j,1);k=x[h+12>>2];a:{if(i){i=x[h+8>>2];break a}w[b+780>>1]=0;v[b+837|0]=k;i=x[h+8>>2];w[b+782>>1]=0;v[b+838|0]=i}l=D(d+256|0,k);m=(l|0)/256|0;b:{if(!(!Pb(j,36)|i|(l|0)<65024)){m=-1;if(!(y[b+851|0]&2)){break b}x[b+88>>2]=x[b+88>>2]&-32769;break b}x[b+88>>2]=x[b+88>>2]|32768;e=Ce(E(10),E(E(0-i|0)*E(.00937500037252903)));i=fb-16|0;fb=i;g=E(D(d+256|0,k)>>>0);c:{if(x[a+480180>>2]!=33554432){f=E(110);g=E(E(g/(y[a+480209|0]&128?E(10240):E(12288)))+E(.25));break c}f=E(125);g=E(E(g*E(6))/E(65024))}n=i,o=E(Ce(E(2),g)*f),B[n+12>>2]=o;d=i+12|0;pT(d,E(120),E(2e4));nB(d,E(E(A[a+24620>>2])*E(.5)));fb=i+16|0;g=E(B[i+12>>2]*E(6.2831854820251465));d:{if(!(!Pb(j,36)|y[a+480209|0]&128)){f=E(E(A[a+24620>>2])/g);g=E(E(E(e*f)+e)+E(-1));e=E(f*f);break d}f=E(e+e);e=E(g/E(A[a+24620>>2]));B[h+4>>2]=E(E(1)-f)*e;nB(h+4|0,E(2));g=E(E(f-B[h+4>>2])/e);e=E(E(1)/E(e*e))}f=E(e+E(g+E(1)));g=E(E(e+E(e+g))/f);e=E(E(-e)/f);f=E(E(1)/f);e:{if(y[b+845|0]==1){n=b,p=Il(E(E(E(1)-f)*E(16777216))),x[n+60>>2]=p;n=b,p=Il(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Il(E(e*E(16777216))),x[n+68>>2]=p;a=-1;break e}d=Il(E(f*E(16777216)));x[b+60>>2]=d;n=b,p=Il(E(g*E(16777216))),x[n+64>>2]=p;n=b,p=Il(E(e*E(16777216))),x[n+68>>2]=p;a=0;if(d){break e}x[b+60>>2]=1}x[b+72>>2]=a;if(!c){break b}x[b+44>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;x[b+56>>2]=0}fb=h+16|0;return m}function Ija(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-32|0;fb=c;a:{b:{c:{d:{e:{f:{if(xd(x[a+24>>2])){break f}i=Wc(x[a+8>>2],y[a+15|0]);f=fb-16|0;fb=f;g=f+8|0;x[g>>2]=-1;x[g+4>>2]=-1;x[31785]=0;h=NH(67);d=x[31785];x[31785]=0;b=hb;if((d|0)==1){T(0)|0;Rb();p()}e=fb-16|0;fb=e;d=te(e+8|0,sua(h,b,1e3,0),hb);b=x[d>>2];fb=e+16|0;j=f,k=dA(b,x[d+4>>2]),x[j>>2]=k;x[f+4>>2]=hb;e=NQ(g,f,Ab(f));x[31785]=0;h=NH(68);d=x[31785];x[31785]=0;b=hb;if((d|0)==1){T(0)|0;Rb();p()}g=a+24|0;j=f,k=dA(JQ(h,b),hb),x[j>>2]=k;x[f+4>>2]=hb;b=NQ(e,f,Ab(f));d=x[b>>2];b=x[b+4>>2];fb=f+16|0;if(i){e=Nb(c+20|0);x[31785]=0;x[c+8>>2]=b;O(61,e|0,c+8|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}x[31785]=0;x[c+8>>2]=d;O(61,e|0,c+8|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}h=a+4|0;b=a;a=0;g:{while(1){if(Wc(x[b+8>>2],y[b+15|0])>>>0<=a>>>0){b=vb(x[e>>2]);a=vb(x[e+4>>2]);x[31785]=0;d=U(62,c+8|0,b|0,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break g}a=N()|0;break b}d=y[cc(h,a)|0];x[31785]=0;x[c+8>>2]=d;O(61,e|0,c+8|0);d=x[31785];x[31785]=0;if((d|0)!=1){a=a+1|0;continue}break}a=N()|0;break b}x[31785]=0;b=R(63,d|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){x[c+4>>2]=b;a=c+4|0;iA(g,a);Cj(a);Tm(d);sc(e);break f}a=N()|0;Tm(d);break b}hb=d;x[c+8>>2]=b;x[c+12>>2]=hb;b=Nb(c+20|0);x[31785]=0;S(66,b|0,c+8|0,c+16|0);a=x[31785];x[31785]=0;if((a|0)==1){a=N()|0;sc(b);Q(a|0);p()}x[31785]=0;d=R(63,b|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break e}x[c+4>>2]=d;a=c+4|0;iA(g,a);Cj(a);Tm(b)}fb=c+32|0;return}a=N()|0;Tm(b);break a}a=N()|0;break b}a=N()|0}sc(e)}Q(a|0);p()}function hu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-128|0;fb=f;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}d=x[c+4>>2];if(!d&A[c>>2]>=A[b+4>>2]|d){break h}a=ac(8);x[31785]=0;b=P(52,a|0,22485)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break g}b=N()|0;jc(a);break a}if(!x[b>>2]){a=ac(8);x[31785]=0;b=R(862,a|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break f}b=N()|0;jc(a);break a}d=x[b>>2];j=x[b+4>>2];b=fb-16|0;fb=b;kf(b+8|0,d,j);h=x[b+8>>2];g=f+108|0;jG(g,h,x[b+12>>2]);x[g+12>>2]=0;fb=b+16|0;i:{j:{if(a&2){b=En(f+88|0,g);x[31785]=0;b=R(863,b|0)|0;e=x[31785];x[31785]=0;d=1;if((e|0)==1){break i}if((b|0)==1){break j}d=En(f+68|0,g);x[31785]=0;e=R(864,d|0)|0;h=x[31785];x[31785]=0;d=1;if((h|0)==1){break e}k=(e|0)==1;if(k){break j}d=En(f+48|0,g);x[31785]=0;h=P(865,d|0,c|0)|0;i=x[31785];x[31785]=0;d=1;if((i|0)==1){break d}l=(h|0)==1;if(l){break j}d=En(f+28|0,g);x[31785]=0;i=P(866,d|0,c|0)|0;m=x[31785];x[31785]=0;d=1;if((m|0)==1){break c}if((i|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(e|0)==-1?-1:b;e=(i|0)==-1?-1:l?b:(h|0)==-1?-1:b}k:{if(!(a&1)){break k}b=30160;while(1){if((b|0)==30724){break k}a=x[b>>2];if(a){d=En(f+8|0,g);x[31785]=0;a=P(a|0,d|0,c|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break b}d=1;if((a|0)==1){break j}e=(a|0)==-1?-1:e}b=b+12|0;continue}}a=j;if(c){d=0;if((e|0)!=-1){break j}d=Bc(x[c>>2],x[c+4>>2])>>>0>a>>>0?-1:0;break j}d=0;if((e|0)!=-1){break j}d=a>>>0>2047?1:-1}fb=f+128|0;return d}b=N()|0;break a}da(b|0,125532,17);p()}da(b|0,125428,17);p()}b=N()|0;break a}b=N()|0;break a}b=N()|0;break a}b=N()|0}Q(b|0);p()}function _3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-576|0;fb=c;Tb(c+532|0,0,44);x[c+24>>2]=0;x[c+28>>2]=0;while(1){a:{if((d|0)==7){d=0;while(1){b:{if((d|0)==12){x[c+540>>2]=1;d=c+432|0;fa(d|0,100,9282,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=d;e=Di(c+32|0,c+20|0,100,c+24|0,x[a>>2]);if((e|0)!=-1){break b}break a}x[c+548>>2]=d;e=c+432|0;fa(e|0,100,14437,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=Di(c+32|0,c+8|0,100,c+24|0,x[a>>2]);if(f+1>>>0<=1){break a}g=D(d,12)+a|0;e=c+32|0;xm(g+172|0,e,e+(f<<2)|0);f=c+432|0;fa(f|0,100,13354,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=f;e=Di(e,c+8|0,100,c+24|0,x[a>>2]);if(e+1>>>0<=1){break a}f=c+32|0;xm(g+316|0,f,f+(e<<2)|0);d=d+1|0;continue}break}d=c+32|0;xm(a+460|0,d,d+(e<<2)|0);x[c+540>>2]=13;e=c+432|0;fa(e|0,100,9282,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+20>>2]=e;d=Di(d,c+20|0,100,c+24|0,x[a>>2]);if((d|0)!=-1){e=c+32|0;xm(a+472|0,e,e+(d<<2)|0);d=c+8|0;Es(d,a,99,b);mh(a+484|0,d);Sb(d);Es(d,a,114,b);mh(a+496|0,d);Sb(d);Es(d,a,120,b);mh(a+508|0,d);Sb(c+8|0);Es(d,a,88,b);mh(a+520|0,d);Sb(c+8|0);fb=c+576|0;return}break a}x[c+556>>2]=d;e=c+432|0;fa(e|0,100,14450,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=e;f=Di(c+32|0,c+8|0,100,c+24|0,x[a>>2]);if(f+1>>>0>1){g=D(d,12)+a|0;e=c+32|0;xm(g+4|0,e,e+(f<<2)|0);f=c+432|0;fa(f|0,100,13518,c+532|0,x[a>>2])|0;x[c+24>>2]=0;x[c+28>>2]=0;x[c+8>>2]=f;e=Di(e,c+8|0,100,c+24|0,x[a>>2]);if(e+1>>>0<=1){break a}f=c+32|0;xm(g+88|0,f,f+(e<<2)|0);d=d+1|0;continue}}break}Yn(12682);p()}function iH(a,b,c){var d=0,e=0,f=0,g=0;d=fb-432|0;fb=d;a:{f=Bs(d+428|0,b);e=x[f>>2];b:{if(!xd(e)){x[31785]=0;b=P(37,d+416|0,b|0)|0;a=x[31785];x[31785]=0;c:{d:{e:{if((a|0)!=1){x[31785]=0;S(1020,d+16|0,17888,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break e}x[31785]=0;W(1348,d+16|0);a=x[31785];x[31785]=0;if((a|0)==1){break d}break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d+16|0)}tb(b);break b}Qp(e);if(!Np(a+8|0,22485,x[f>>2])){x[a+8>>2]=2147483647}if(!Np(a+12|0,22485,x[f>>2])){x[a+12>>2]=2147483647}x[31785]=0;O(275,a+16|0,22485);b=x[31785];x[31785]=0;f:{g:{if((b|0)!=1){x[d+8>>2]=0;x[d+12>>2]=0;x[d+4>>2]=22485;b=Di(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((b|0)==-1){x[31785]=0;W(1243,12682);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;break b}x[31785]=0;e=d+16|0;b=U(1355,a+28|0,e|0,e+(b<<2)|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}x[a+64>>2]=0;x[d+4>>2]=22485;x[d+8>>2]=0;x[d+12>>2]=0;h:{e=Di(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((e|0)!=-1){x[31785]=0;g=d+16|0;U(1355,a+40|0,g|0,g+(e<<2)|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}x[d+4>>2]=22485;x[d+8>>2]=0;x[d+12>>2]=0;e=Di(d+16|0,d+4|0,100,d+8|0,x[f>>2]);if((e|0)!=-1){break h}}x[31785]=0;W(1243,12682);a=x[31785];x[31785]=0;if((a|0)!=1){break a}break f}x[31785]=0;g=d+16|0;U(1355,a+52|0,g|0,g+(e<<2)|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}x[31785]=0;b=P(1356,d+416|0,b|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){break g}a=N()|0;break b}a=N()|0;break b}fi(a+68|0,c);fi(a+72|0,c);Sb(b);gl(f);fb=d+432|0;return}a=N()|0}gl(f);Q(a|0);p()}p()}function QP(a){var b=E(0),c=0,d=0,e=0,f=0,g=E(0),h=0,i=0,k=0,l=E(0),m=0,n=E(0);c=fb-16|0;fb=c;e=a+4208|0;b=Mz(B[wb(e,2)>>2]);f=x[a+16>>2]+24620|0;B[c+12>>2]=b/E(A[f>>2]);x[c+8>>2]=1056964608;b=iq(E(B[Pm(c+12|0,c+8|0)>>2]*E(6.2831854820251465)));b=E(M(E(E(E(b+b)+E(3))/E(5))));B[a+4236>>2]=b;B[a+4240>>2]=M(E(E(1)-E(b*b)));b=E(E(B[wb(e,1)>>2]*E(29))+E(2));a:{if(b<E(4294967296)&b>=E(0)){i=~~b>>>0;break a}i=0}v[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}v[a+4273|0]=k;l=Ce(E(10),E(E(E(B[a+4208>>2]*E(60))+E(-60))/E(20)));m=c,n=E(Mz(B[wb(e,3)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;g=B[Pm(c+12|0,c+8|0)>>2];m=c,n=E(Mz(B[wb(e,4)>>2])/E(A[f>>2])),B[m+12>>2]=n;x[c+8>>2]=1056964608;b=E(E(B[Pm(c+12|0,c+8|0)>>2]*E(6.2831854820251465))*E(.5));f=fb-16|0;fb=f;e=(q(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=eo(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=eo(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=eo(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=eo(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=eo(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=E(b-b);break b}d=Qy(b,f+8|0);b=eo(C[f+8>>3],d&1)}fb=f+16|0;b=E(E(E(1)-b)/E(b+E(1)));B[a+4268>>2]=b;g=iq(E(g*E(6.2831854820251465)));B[a+4264>>2]=-g;B[a+4260>>2]=E(E(l*E(M(E(E(1)-E(g*g)))))*E(M(E(E(1)-E(b*b)))))*B[(i<<2)+44304>>2];fb=c+16|0}function Bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=sua(q,B,e,e>>31);i=hb;k=e;e=Xb(h,-16777216,16776704);e=sua(p,A,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Xb(j,-16777216,16776704);i=sua(o,z,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+v|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Qb(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];n=ig(1,2);b=hb;u=b;Qb(a,n,b);b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;v=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;F=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=sua(q,C,e,e>>31);i=hb;j=e;e=Xb(h,-16777216,16776704);e=sua(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Xb(F,-16777216,16776704);i=sua(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&z);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+v|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Qb(f+16|0,m,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Dg(a,n,u);fb=f+48|0}function P6(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,t=0,u=0,w=0,z=0,A=0,B=0,C=0;x[c>>2]=a;z=d&512;while(1){if((u|0)==4){if(Bb(x[n+4>>2],y[n+11|0])>>>0>1){B=c,C=mJ(Ne(wd(n),1),yf(n),x[c>>2]),x[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=x[c>>2]}x[b>>2]=a}}else{a:{b:{switch(v[i+u|0]){case 0:x[b>>2]=x[c>>2];break a;case 1:x[b>>2]=x[c>>2];p=gm(g,32);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 3:if(yd(x[n+4>>2],y[n+11|0])){break a}p=y[cc(n,0)|0];q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break a;case 2:if(yd(x[m+4>>2],y[m+11|0])|!z){break a}B=c,C=mJ(wd(m),yf(m),x[c>>2]),x[B>>2]=C;break a;case 4:break b;default:break a}}p=x[g+8>>2];A=x[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Ef(p,64,v[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){p=p-1|0;r=r-1|0;q=y[r|0];s=x[c>>2];x[c>>2]=s+1;v[s|0]=q;continue}break}if(p){q=gm(g,48)}else{q=0}while(1){s=x[c>>2];x[c>>2]=s+1;if((p|0)>0){v[s|0]=q;p=p-1|0;continue}break}v[s|0]=j}d:{if((e|0)==(r|0)){p=gm(g,48);q=x[c>>2];x[c>>2]=q+1;v[q|0]=p;break d}if(yd(x[l+4>>2],y[l+11|0])){q=-1}else{q=v[cc(l,0)|0]}p=0;t=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=x[c>>2];x[c>>2]=q+1;v[q|0]=k;s=0;t=t+1|0;if(Bb(x[l+4>>2],y[l+11|0])>>>0<=t>>>0){q=p;break e}q=-1;if(y[cc(l,t)|0]==127){break e}q=v[cc(l,t)|0]}r=r-1|0;p=y[r|0];w=x[c>>2];x[c>>2]=w+1;v[w|0]=p;p=s+1|0;continue}}ym(A,x[c>>2])}u=u+1|0;continue}break}}function Cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;t=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;n=g+(f+28|0)|0;g=a+g|0;x[n+4>>2]=x[g+44>>2];x[n+8>>2]=x[g+48>>2];b=b+1|0;continue}break}l=x[a+40>>2];m=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+32>>2];w=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;n=x[a+8>>2];C=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+t|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=sua(q,B,e,e>>31);i=hb;k=e;e=Xb(h,-16777216,16776704);e=sua(p,A,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Xb(j,-16777216,16776704);i=sua(o,z,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&y);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}m=m+w|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],m>>12);l=l+u|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],l>>12);Qb(f+16|0,n,C);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=l;x[a+20>>2]=m>>12;x[a+36>>2]=m;x[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function _na(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;k=f,l=Vj(b),x[k+4>>2]=l;e=fb-16|0;fb=e;h=a;c=$d(a);a:{if(c){g=ec(h);while(1){a=c;c=a+14|0;if(Uu(b,c)){g=a;c=x[a>>2];if(c){continue}break a}if(!Uu(c,b)){break a}g=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(h);g=a}x[e+12>>2]=a;b=x[g>>2];if(!b){i=fb-16|0;fb=i;a=ec(h);j=zh(e,Dc(48),Kg(i+8|0,a));a=x[j>>2];b=x[f+4>>2];c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);d=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a+14|0]=d;v[a+15|0]=d>>>8;v[a+16|0]=d>>>16;v[a+17|0]=d>>>24;v[a+18|0]=c;v[a+19|0]=c>>>8;v[a+20|0]=c>>>16;v[a+21|0]=c>>>24;c=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);d=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[a+38|0]=d;v[a+39|0]=d>>>8;v[a+40|0]=d>>>16;v[a+41|0]=d>>>24;v[a+42|0]=c;v[a+43|0]=c>>>8;v[a+44|0]=c>>>16;v[a+45|0]=c>>>24;c=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);d=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[a+30|0]=d;v[a+31|0]=d>>>8;v[a+32|0]=d>>>16;v[a+33|0]=d>>>24;v[a+34|0]=c;v[a+35|0]=c>>>8;v[a+36|0]=c>>>16;v[a+37|0]=c>>>24;c=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a+22|0]=b;v[a+23|0]=b>>>8;v[a+24|0]=b>>>16;v[a+25|0]=b>>>24;v[a+26|0]=c;v[a+27|0]=c>>>8;v[a+28|0]=c>>>16;v[a+29|0]=c>>>24;w[a+46>>1]=0;k=ec(j),l=1,v[k+4|0]=l;fb=i+16|0;Xg(h,x[e+12>>2],g,x[e>>2]);b=ie(e);Xl(e);d=1}Wg(f+8|0,x[zb(e,b)>>2],d);fb=e+16|0;a=Xo(x[f+8>>2]);fb=f+16|0;return a+32|0}function Z0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;g=Ni(b)^-1;a:{if(oc(x[d>>2],x[d+4>>2])>>>0<=g>>>0){fu(a);break a}Ni(b);if((y[c+4|0]|y[c+5|0]<<8)>>>0>=60){Yb(b,4)}j=f,k=Ni(b),x[j+44>>2]=k;Yb(b,4);h=Ni(b);i=Ni(b);if(!((h|0)>0&(i|0)>36)){fu(a);break a}if(er(Dd(x[e>>2],x[wb(x[d>>2],g)>>2]),13186)){fu(a);break a}e=f+4|0;fF(e,b,i,h);d=ic(f+24|0,e);ub(e);b=x[d>>2];x[31785]=0;b=R(175,b|0)|0;e=x[31785];x[31785]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){x[31785]=0;R(185,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break d}break b}b=y[c+4|0]|y[c+5|0]<<8;if(b>>>0<=39){x[31785]=0;P(186,d|0,8)|0;b=x[31785];x[31785]=0;if((b|0)==1){break b}b=y[c+4|0]|y[c+5|0]<<8}if((b&65535)>>>0<=59){x[31785]=0;P(186,d|0,16)|0;b=x[31785];x[31785]=0;if((b|0)==1){break b}}x[31785]=0;R(187,d|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break b}e:{f:{b=y[c+4|0]|y[c+5|0]<<8;g:{if(b>>>0>=120){x[31785]=0;R(187,d|0)|0;c=x[31785];x[31785]=0;b=8;break g}h:{if(b>>>0>=100){x[31785]=0;P(186,d|0,4)|0;b=x[31785];x[31785]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}x[31785]=0;R(187,d|0)|0;c=x[31785];x[31785]=0;b=4}if((c|0)==1){break b}x[31785]=0;P(186,d|0,b|0)|0;break e}x[31785]=0;R(187,d|0)|0}b=x[31785];x[31785]=0;if((b|0)==1){break b}x[31785]=0;b=R(187,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}x[31785]=0;S(188,f+4|0,d|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}b=a;a=f+4|0;j=ic(b,a),k=x[f+44>>2],x[j+20>>2]=k;ub(a)}ub(d);break a}}a=N()|0;ub(d);Q(a|0);p()}fb=f+48|0}function pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;m=x[a+8>>2];A=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=b>>>21&2040;h=w[b+38390>>1];i=w[b+38388>>1];e=w[b+38386>>1];g=w[b+38384>>1];b=0;j=0;while(1){if((j|0)!=2){k=n+(j<<1)|0;x[(f+8|0)+(j<<2)>>2]=(((D(w[k>>1],e)+D(w[k-4>>1],g)|0)+D(i,w[k+4>>1])|0)+D(h,w[k+8>>1])|0)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=sua(q,z,e,e>>31);i=hb;l=e;e=Xb(h,-16777216,16776704);e=sua(p,y,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(n,-16777216,16776704);i=sua(o,v,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Qb(f+16|0,m,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function rla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);o=x[a+128>>2];a:{if(!o){m=x[a+8>>2];p=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];n=0;break a}b=x[a+12>>2];p=b;m=x[a+8>>2];q=Cg(m,b,o);r=hb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];bg(h,e,sf(m,p,d),hb);n=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{s=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;n=n-1|0;b=n;q=b?q:0;r=b?r:0;h=(e<<1)+t|0;b=o;while(1)if((b|0)<=0){Qb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){_d(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Zd(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Ag(i,u);v=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=sua(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Xb(s,-16777216,16776704);j=sua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=sua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Qb(g,m,p);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue b}else{_d(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Zd(i,4);Qb(g+8|0,q,r);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function Sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0,E=0,F=0;f=fb-48|0;fb=f;t=x[a+16>>2];n=ig(1,2);b=hb;u=b;Qb(a,n,b);b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}k=x[a+40>>2];l=x[a+36>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;w=x[a+32>>2];y=x[a+28>>2];z=x[a+72>>2];o=x[a+68>>2];A=o>>31;p=x[a+64>>2];B=p>>31;q=x[a+60>>2];C=q>>31;m=x[a+8>>2];E=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+t|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){r=(f+8|0)+(b<<2)|0;e=x[r>>2];g=(f+28|0)+(b<<3)|0;F=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;s=e<<8;e=s;e=sua(q,C,e,e>>31);i=hb;j=e;e=Xb(h,-16777216,16776704);e=sua(p,B,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Xb(F,-16777216,16776704);i=sua(o,A,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(s&z);x[r>>2]=(e|0)/256;b=b+1|0;continue}break}l=l+y|0;x[c>>2]=x[c>>2]+D(x[f+8>>2],l>>12);k=k+w|0;x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],k>>12);Qb(f+16|0,m,E);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+24>>2]=k>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Dg(a,n,u);fb=f+48|0}function wh(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=fb-16|0;fb=c;a:{if((d|0)==189){v[a+3843|0]=e>>>7;v[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=D(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){Ho(f,g);break b}Ho(f,0)}v[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=D(d&256?b+9|0:b,44)+a|0;x[c+8>>2]=a+16;b=x[a+52>>2];x[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];rU(x[a>>2],d);rU(x[a+4>>2],d);w[a+22>>1]=h;HB(a);tU(a);v[a+21|0]=f;HB(a);tU(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=x[(c+8|0)+(b<<2)>>2];w[a+20>>1]=z[a+20>>1]&768|e&255;HB(a);b=b+1|0;continue}}v[a+58|0]=(e&32)>>>5;v[a+57|0]=(e&16)>>>4;b=e>>>1&7;w[a+46>>1]=b?9-b|0:0;w[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=v[(d&31)+27600|0];a=(f+D(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:v[a+79|0]=e>>>7;v[a+80|0]=(e&64)>>>6;v[a+78|0]=(e&32)>>>5;v[a+77|0]=(e&16)>>>4;Io(a);w[a+14>>1]=z[((e&15)<<1)+27632>>1];break a;case 1:w[a+68>>1]=y[(e>>>6|0)+22470|0];sU(a);w[a+22>>1]=(e&63)<<2;break a;case 2:w[a+24>>1]=e>>>4;Io(a);w[a+26>>1]=e&15;Io(a);break a;case 3:b=e>>>4|0;w[a+28>>1]=b>>>0>=15?496:b<<4;w[a+30>>1]=e&15;Io(a);break a;case 6:break d;default:break a}}w[a+12>>1]=e&7}fb=c+16|0;return}ib[x[x[b>>2]>>2]](b,c,d,e)}function Yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}t=x[a+16>>2];e=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+44>>2];l=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=l;u=x[a+32>>2];v=x[a+28>>2];y=x[a+72>>2];q=x[a+68>>2];z=q>>31;r=x[a+64>>2];A=r>>31;s=x[a+60>>2];B=s>>31;while(1){l=b;if(d){b=Xb(l,-16777216,16776704);m=sua(r,A,b,b>>31);n=hb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+t|0;b=(b>>>16&65520)+p|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=sua(b,b>>31,s,B);m=b+m|0;o=hb+n|0;o=b>>>0>m>>>0?o+1|0:o;b=Xb(e,-16777216,16776704);e=sua(q,z,b,b>>31);n=e+m|0;b=hb+o|0;b=e>>>0>n>>>0?b+1|0:b;e=n+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;k=k+v|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+u|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Qb(g+8|0,i,h);b=e-(f&y)|0;c=c+8|0;d=d-1|0;e=l;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=e;x[a+44>>2]=l;x[a+24>>2]=j>>12;fb=g+16|0}function qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;m=g+(f+28|0)|0;g=a+g|0;x[m+4>>2]=x[g+44>>2];x[m+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];o=x[a+68>>2];y=o>>31;p=x[a+64>>2];z=p>>31;q=x[a+60>>2];A=q>>31;m=x[a+8>>2];B=x[a+12>>2];while(1){if(d){b=x[f+16>>2];n=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=b>>>21&2040;h=w[b+38390>>1];i=w[b+38388>>1];e=w[b+38386>>1];g=w[b+38384>>1];b=0;j=0;while(1){if((j|0)!=2){k=j+n|0;x[(f+8|0)+(j<<2)>>2]=(((D(v[k|0],e)+D(v[k-2|0],g)|0)+D(i,v[k+2|0])|0)+D(h,v[k+4|0])<<8)/16384;j=j+1|0;continue}break}while(1){if((b|0)!=2){k=(f+8|0)+(b<<2)|0;e=x[k>>2];g=(f+28|0)+(b<<3)|0;n=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;j=e<<8;e=j;e=sua(q,A,e,e>>31);i=hb;l=e;e=Xb(h,-16777216,16776704);e=sua(p,z,e,e>>31);h=l+e|0;l=hb+i|0;l=e>>>0>h>>>0?l+1|0:l;e=Xb(n,-16777216,16776704);i=sua(o,y,e,e>>31);h=i+h|0;e=hb+l|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(j&u);x[k>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(x[f+12>>2],s);Qb(f+16|0,m,B);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function xk(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;a:{if(!d){break a}g=x[c>>2];if(!g){break a}b:{c:{d:{e:{f=x[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=D(d,20)+g|0;break d}f=((D(d,36318)|0)/1024|0)+g|0;break d}f:{g:{h:{if(y[a+480208|0]&16){if((f|0)==4){break h}f=d>>31;x[i+12>>2]=(f^d)-f;vc(i+12|0,1020);h=x[i+12>>2];f=c;i:{if((d|0)>0){if(h>>>0<=15){h=x[(h<<2)+(Pb(a+1074312|0,7)?35680:35744)>>2];break i}h=x[(h&-4)+(Pb(a+1074312|0,7)?35808:36832)>>2];break i}if(h>>>0<=15){h=x[(h<<2)+(Pb(a+1074312|0,7)?35744:35680)>>2];break i}h=x[(h&-4)+(Pb(a+1074312|0,7)?36832:35808)>>2]}j=sua(h,h>>31,g,g>>31);h=hb;j=j+32768|0;h=j>>>0<32768?h+1|0:h;k=f;f=Fc(tua(j,h,65536,0),hb);x[k>>2]=f;if((f|0)!=(g|0)){break c}f=Pb(a+1074312|0,7);g=x[c>>2];if(!(f^(d|0)>0)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}if(Pb(a+1074312|0,7)){break g}g=x[c>>2]}f=g-d|0;break d}f=x[c>>2];if((d|0)<0){g=sua(f,0,14317456,0);h=hb;f=sua(f,0,0-d|0,0);d=hb;f=f+14317456|0;d=f>>>0<14317456?d+1|0:d;f=ES(uua(g,h,f,d),hb);break d}d=sua(f,f>>31,d,0);g=hb;if((g|0)>=0&d>>>0>=14317456|(g|0)>0){if(e){x[c>>2]=2147483647;break a}x[c>>2]=0;x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248;break a}d=ES(uua(sua(f,0,14317456,0),hb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),hb);x[c>>2]=d;if((d|0)>0){break a}break b}f=d+g|0}x[c>>2]=f}if((f|0)>0){break a}}x[c>>2]=1;if(x[a+480180>>2]!=2|e){break a}x[b+696>>2]=0;x[b+88>>2]=x[b+88>>2]|2101248}fb=i+16|0}function Zla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}s=x[a+16>>2];b=x[a+48>>2];j=x[a+40>>2];k=x[a+36>>2];e=x[a+44>>2];l=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=l;t=x[a+32>>2];u=x[a+28>>2];y=x[a+72>>2];o=x[a+68>>2];z=o>>31;p=x[a+64>>2];A=p>>31;q=x[a+60>>2];B=q>>31;while(1){l=e;if(d){e=Xb(l,-16777216,16776704);f=sua(p,A,e,e>>31);e=hb;b=Xb(b,-16777216,16776704);b=sua(o,z,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];m=f;f=x[g+12>>2]+s|0;b=(b>>>16&65520)+n|0;r=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=r;f=sua(b,b>>31,q,B);m=m+f|0;b=hb+e|0;b=f>>>0>m>>>0?b+1|0:b;e=m+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;k=k+u|0;x[c>>2]=D(b,k>>12)+x[c>>2];j=j+t|0;x[c+4>>2]=x[c+4>>2]+D(j>>12,b);Qb(g+8|0,i,h);e=e-(y&r)|0;c=c+8|0;d=d-1|0;b=l;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+48>>2]=b;x[a+44>>2]=l;x[a+24>>2]=j>>12;fb=g+16|0}function Bz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);e=fb-48|0;fb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=x[a+24>>2];if((b|0)==x[d+24604>>2]){break d}a=e+8|0;yc(a,d+24604|0,40);x[e+8>>2]=b;AA(d,a);break d;case 2:f=x[a+24>>2];d=f+24664|0;b=x[d+4>>2];x[e+24>>2]=x[d>>2];x[e+28>>2]=b;d=f+24656|0;b=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=b;b=x[f+24652>>2];x[e+8>>2]=x[f+24648>>2];x[e+12>>2]=b;d=fb-16|0;fb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ac(8);x[31785]=0;b=P(37,d+4|0,10840)|0;a=x[31785];x[31785]=0;i:{if((a|0)!=1){nc(c,b);x[31785]=0;S(100,c|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break g}a=N()|0;tb(b);break i}a=N()|0;jc(c)}Q(a|0);p()}fb=d+16|0;break f}p()}v[e+8|0]=b;a=x[a+24>>2];if(!rz(e+8|0,a+24648|0)){break d}yA(a,e+8|0);break d;case 3:f=e+8|0;d=x[a+24>>2];yc(f,d+24604|0,40);b=fb-48|0;fb=b;j:{if((c|0)==-1){Kt(f,x[Gq(b+8|0)+32>>2]);Ho(f,x[Gq(b+8|0)+36>>2]);break j}if((c|0)<=0){Kt(f,0);Ho(f,0);break j}a=D(c,1e3);Kt(f,a);Ho(f,a)}fb=b+48|0;if(x[d+24636>>2]==x[e+40>>2]&x[d+24640>>2]==x[e+44>>2]){break d}AA(d,e+8|0);break d;default:d=ac(8);x[31785]=0;c=P(37,e+8|0,10395)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(d,c);x[31785]=0;S(100,d|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b;case 0:break e}}g=a,h=Ce(E(10),E(E(E(c|0)*E(.0010000000474974513))*E(.5))),B[g+48>>2]=h}fb=e+48|0;return}b=N()|0;jc(d)}Q(b|0)}p()}function nna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-32|0;fb=e;w[e+30>>1]=254;d=Lj(a);c=fb-16|0;fb=c;f=e+16|0;x[f>>2]=0;x[f+4>>2]=0;rc(f+8|0);Nd(c+8|0,x[zb(c+4|0,f)>>2]);a:{b:{if(d){x[31785]=0;O(644,f|0,d|0);h=x[31785];x[31785]=0;if((h|0)==1){break b}AE(f,d)}h=c+8|0;Md(h);Wj(h);fb=c+16|0;break a}a=N()|0;Wj(c+8|0);Q(a|0);p()}c=x[a>>2];h=x[f>>2];while(1){if((b|0)==(d|0)){c:{if(!(g&65535)){break c}b=vb(c);d=vb(x[a+4>>2]);c=fb-16|0;fb=c;b=xC(b,d,z[e+30>>1]);x[c+12>>2]=b;if(Ib(b,d)){x[c+8>>2]=b;while(1){b=x[Wd(c+8|0)>>2];if(Ib(b,d)){b=z[b>>1];if((b|0)==z[e+30>>1]){continue}w[x[c+12>>2]>>1]=b;Wd(c+12|0);continue}break}b=x[c+12>>2]}fb=c+16|0;b=zb(e+12|0,b);c=x[zb(e+8|0,vb(x[a+4>>2]))>>2];d=fb-16|0;fb=d;g=x[b>>2];b=x[a>>2];b=(dp(g,vb(b))<<1)+b|0;if(Ib(g,c)){xn(a,Ov(b+(dp(c,g)<<1)|0,x[a+4>>2],b))}zb(d+12|0,b);fb=d+16|0;k=e,l=vb(x[a>>2]),x[k+4>>2]=l;d=vb(x[a+4>>2]);while(1){b=x[e+4>>2];if(Ib(b,d)){d:{c=x[a+24>>2];g=x[c+484344>>2];b=z[b>>1];if(!Ge(g,x[c+484348>>2],b)){break d}b=Vb(g,b);k=e,l=vb(x[b>>2]),x[k>>2]=l;g=vb(x[b+4>>2]);h=x[f+4>>2];c=x[f>>2];while(1){b=x[e>>2];if(!Ib(b,g)){break d}e:{if(y[b+3|0]!=12){break e}j=Xc(c,h);i=y[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=y[_b(c,i)|0],v[k+5|0]=l}ah(e);continue}}Wd(e+4|0);continue}else{b=x[f>>2];d=Xc(b,x[f+4>>2]);c=z[a+28>>1];if(d>>>0<=c>>>0){break c}k=a,l=z[_b(b,c)>>1],w[k+28>>1]=l}break}}}else{k=_b(h,b),l=b-g|0,w[k>>1]=l;g=(z[_b(c,b)>>1]==254)+g|0;b=b+1|0;continue}break}kd(f);fb=e+32|0}function sla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;t=x[a+16>>2];u=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);o=x[a+128>>2];a:{if(!o){m=x[a+8>>2];p=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];n=0;break a}b=x[a+12>>2];p=b;m=x[a+8>>2];q=Cg(m,b,o);r=hb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];bg(h,e,sf(m,p,d),hb);n=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];k=x[a+40>>2];l=x[a+36>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{s=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;n=n-1|0;b=n;q=b?q:0;r=b?r:0;h=e+t|0;b=o;while(1)if((b|0)<=0){Qb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){_d(i,v[h+x[g+12>>2]|0]<<6);Zd(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Ag(i,u);w=x[a+72>>2];y=x[a+32>>2];l=x[a+28>>2]+l|0;h=b<<8;b=h;e=x[a+60>>2];b=sua(e,e>>31,b,b>>31);z=hb;e=b;b=x[a+64>>2];j=b;A=b>>31;b=Xb(s,-16777216,16776704);j=sua(j,A,b,b>>31);e=e+j|0;b=hb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=sua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(l>>12,f)+x[c>>2];k=k+y|0;x[c+4>>2]=x[c+4>>2]+D(k>>12,f);Qb(g,m,p);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=s;continue b}else{_d(i,v[h+x[g+12>>2]|0]<<6);Zd(i,4);Qb(g+8|0,q,r);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+40>>2]=k;x[a+20>>2]=l>>12;x[a+36>>2]=l;x[a+48>>2]=f;x[a+44>>2]=s;x[a+24>>2]=k>>12;fb=g+16|0}function c0(){var a=0,b=0,c=0;if(!y[500320]){a=fb-16|0;fb=a;rt(499968);x[125004]=-1;x[125002]=500024;x[125e3]=126328;x[124992]=94876;v[500020]=0;b=a+12|0;$c(b,x[124993]);c=x[x[124992]+8>>2];x[31785]=0;O(c|0,499968,b|0);b=x[31785];x[31785]=0;a:{if((b|0)!=1){Zb(a+12|0);fb=a+16|0;break a}b=N()|0;Zb(a+12|0);$n(499968);Q(b|0);p()}vt(499296);x[124824]=95008;x[124822]=94988;x[124823]=0;go(499296,499968);HK(500032,126472,500080);By(499464,500032);HK(500088,126176,500136);By(499632,500088);By(499800,x[x[x[124908]-12>>2]+499656>>2]);GK(x[x[124822]-12>>2]+499288|0);DK(x[x[124908]-12>>2]+499632|0);GK(x[x[124908]-12>>2]+499632|0);a=fb-16|0;fb=a;TK(500144);x[125048]=-1;x[125046]=500200;x[125044]=126328;x[125036]=95268;v[500196]=0;b=a+12|0;$c(b,x[125037]);c=x[x[125036]+8>>2];x[31785]=0;O(c|0,500144,b|0);b=x[31785];x[31785]=0;b:{if((b|0)!=1){Zb(a+12|0);fb=a+16|0;break b}b=N()|0;Zb(a+12|0);lt(500144);Q(b|0);p()}CK(499384);x[124846]=95400;x[124844]=95380;x[124845]=0;go(499384,500144);FK(500208,126472,500256);Ay(499548,500208);FK(500264,126176,500312);Ay(499716,500264);Ay(499884,x[x[x[124929]-12>>2]+499740>>2]);EK(x[x[124844]-12>>2]+499376|0);DK(x[x[124929]-12>>2]+499716|0);EK(x[x[124929]-12>>2]+499716|0);v[500320]=1}a=fb-16|0;fb=a;c:{if(bb(a+12|0,a+8|0)|0){break c}b=Ed((x[a+12>>2]<<2)+4|0);x[125082]=b;if(!b){break c}b=Ed(x[a+8>>2]);if(b){c=x[125082];x[c+(x[a+12>>2]<<2)>>2]=0;if(!(ab(c|0,b|0)|0)){break c}}x[125082]=0}fb=a+16|0;x[124273]=42;x[124291]=500420}function V7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-272|0;fb=a;x[a+264>>2]=c;x[a+268>>2]=b;oy(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Fb(a+196|0);b=Lc(d);x[31785]=0;O(47,d|0,b|0);b=x[31785];x[31785]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+192>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=y[a+222|0]<<24>>24;i=y[a+223|0]<<24>>24;while(1){d:{x[31785]=0;b=P(1210,a+268|0,a+264|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(b){break c}g=x[a+192>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31785]=0;O(47,d|0,b<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+192>>2]=b+c}x[31785]=0;b=R(1211,x[a+268>>2])|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(ny(b,a+23|0,a+22|0,c,a+192|0,i,h,a+208|0,a+32|0,a+28|0,a+24|0,a+224|0)){break c}x[31785]=0;R(1213,a+268|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+212>>2],y[a+219|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}TJ(a,c,x[a+192>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Qf(a+208|0,a+32|0,x[a+28>>2],e);x[31785]=0;b=P(1210,a+268|0,a+264|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+268>>2];tb(d);tb(a+208|0);fb=a+272|0;break a}}b=N()|0;tb(d);tb(a+208|0);Q(b|0);p()}return b|0}function Hka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,z=0,A=0,B=0;f=fb-48|0;fb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}t=l-4|0;o=D(b,e);u=o-8|0;h:while(1){b=x[c+8>>2];h=x[c>>2];x[31785]=0;b=U(153,h|0,b|0,l|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}x[31785]=0;S(188,f+8|0,c|0,d|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}b=f+8|0;h=ic(f+28|0,b);ub(b);x[31785]=0;O(578,b|0,h|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}z=Se(f+8|0);q=x[f+8>>2];A=q-4|0;k=0;while(1){if((e|0)==(k|0)){Jc(f+8|0);ub(h);n=(q-l<<1)+n|0;continue h}x[31785]=0;g=R(571,h|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){x[31785]=0;b=R(200,h|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break f}x[f>>2]=b;Ee(f,0,89);x[31785]=0;P(186,h|0,1)|0;b=x[31785];x[31785]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>u>>>0){break j}m=0;if(b>>>0>A>>>0){break j}while(1)if((m|0)==8){b=b+t|0;continue i}else{r=x[f>>2];i=y[b+z|0];s=m&1;i=s?i>>>4|0:i&15;x[f>>2]=r+v[(i&7)+28872|0];B=g;g=w[(r<<1)+28880>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;x[f+4>>2]=B+(i>>>0<8?g:0-g|0);Ee(f,0,88);Ee(f+4|0,-32768,32767);g=x[f+4>>2];w[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+s|0;continue}}break}k=k+1|0;continue}break}break}break f}ub(c);fb=f+48|0;return}b=N()|0;Jc(f+8|0);break d}b=N()|0}ub(h);break a}b=N()|0;break a}b=N()|0}ub(c);Q(b|0);p()}function zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-96|0;fb=c;Yj(c+76|0,b,1413829443);x[31785]=0;b=R(175,x[c+76>>2])|0;d=x[31785];x[31785]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){x[31785]=0;S(815,c+56|0,a+140|0,1413894985);a=x[31785];x[31785]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){x[31785]=0;a=P(898,c+56|0,13709)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}b=28591;if(a){b=Fb(c+44|0);x[31785]=0;a=R(205,c+56|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break m}x[31785]=0;S(273,c+56|0,b|0,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break m}x[31785]=0;d=P(73,c+20|0,b|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break l}x[31785]=0;W(899,c+8|0);a=x[31785];x[31785]=0;if((a|0)==1){break k}x[31785]=0;S(900,c+32|0,d|0,c+8|0);a=x[31785];x[31785]=0;if((a|0)==1){break j}a=c+32|0;e=yb(b,a);tb(a);tb(c+8|0);tb(d);x[31785]=0;S(261,a|0,2,e|0);a=x[31785];x[31785]=0;if((a|0)==1){break h}x[31785]=0;a=R(778,c+32|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break g}tb(c+32|0);tb(e);b=a-1>>>0<19398657?1252:28591}ub(c+56|0);break a}a=N()|0;break b}a=N()|0;break f}a=N()|0;break f}a=N()|0;break i}a=N()|0;tb(c+8|0)}tb(d);break f}a=N()|0;break f}a=N()|0;tb(c+32|0)}tb(b);break d}a=N()|0}ub(c+56|0);break b}x[31785]=0;a=U(153,x[c+76>>2],x[c+84>>2],2)|0;b=x[31785];x[31785]=0;if((b|0)==1){break c}b=28591;if(!a){break a}x[31785]=0;b=R(192,c+76|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0}ub(c+76|0);Q(a|0);p()}ub(c+76|0);fb=c+96|0;return b|0}function tO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;g=Nb(a);a:{b:{c:{d=b+36|0;a=x[d>>2];f=x[b+40>>2];d:{if(Ib(a,f)){rc(c+28|0);break d}x[31785]=0;O(1081,c+16|0,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}x[31785]=0;a=R(1065,c+16|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}x[c+28>>2]=a;mf(c+16|0);f=x[b+40>>2];a=x[b+36>>2]}if(!Ib(a,f)){d=x[c+28>>2];a=x[d>>2]}f=x[d+4>>2];x[31785]=0;O(179,g|0,lj(a,f)|0);a=x[31785];x[31785]=0;e:{if((a|0)!=1){i=c,j=vb(x[d>>2]),x[i+12>>2]=j;f=vb(x[d+4>>2]);f:{g:{h:{i:{j:{while(1){a=x[c+12>>2];if(!Ib(a,f)){vl(c+28|0);fb=c+32|0;return}d=y[a+16|0];e=x[x[b+24>>2]+484360>>2];x[31785]=0;d=Sj(e,d);O(1082,c|0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break f}x[31785]=0;O(1068,c+16|0,c|0);e=x[31785];x[31785]=0;if((e|0)!=1){x[31785]=0;O(181,g|0,c+16|0);e=x[31785];x[31785]=0;if((e|0)==1){break j}tb(c+16|0);tb(c);e=On(x[g+4>>2]);k:{if(!yd(x[e+4>>2],y[e+11|0])){break k}a=x[a+12>>2];if(!$i(d,a&255)){break k}e=x[b+24>>2];h=x[e+1298404>>2];a=z[_b(x[d>>2],a)>>1];d=x[e+484344>>2];x[31785]=0;O(1075,c|0,Vb(d,a)|0);a=x[31785];x[31785]=0;if((a|0)==1){break h}x[31785]=0;S(1083,c+16|0,h|0,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break g}a=c+16|0;yb(On(x[g+4>>2]),a);tb(a);tb(c)}Zz(c+12|0);continue}break}a=N()|0;break i}a=N()|0;tb(c+16|0)}tb(c);break e}a=N()|0;break e}a=N()|0;tb(c);break e}a=N()|0;break e}a=N()|0}vl(c+28|0);break a}a=N()|0;mf(c+16|0);break a}a=N()|0}Pd(g);Q(a|0);p()}function M7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;d=x[d+28>>2];a=fb-384|0;fb=a;x[a+376>>2]=c;x[a+380>>2]=b;jy(a+220|0,d,a+240|0,a+236|0,a+232|0);d=Fb(a+208|0);b=Lc(d);x[31785]=0;O(47,d|0,b|0);b=x[31785];x[31785]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+204>>2]=c;x[a+28>>2]=a+32;x[a+24>>2]=0;v[a+23|0]=1;v[a+22|0]=69;h=x[a+232>>2];i=x[a+236>>2];while(1){d:{x[31785]=0;b=P(1225,a+380|0,a+376|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(b){break c}g=x[a+204>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31785]=0;O(47,d|0,b<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+204>>2]=b+c}x[31785]=0;b=R(1226,x[a+380>>2])|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(iy(b,a+23|0,a+22|0,c,a+204|0,i,h,a+220|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}x[31785]=0;R(1228,a+380|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+224>>2],y[a+231|0])|!y[a+23|0]){break e}b=x[a+28>>2];if((b-(a+32|0)|0)>159){break e}x[a+28>>2]=b+4;x[b>>2]=x[a+24>>2]}TJ(a,c,x[a+204>>2],e);b=x[a>>2];c=x[a+4>>2];h=x[a+12>>2];x[f+8>>2]=x[a+8>>2];x[f+12>>2]=h;x[f>>2]=b;x[f+4>>2]=c;Qf(a+220|0,a+32|0,x[a+28>>2],e);x[31785]=0;b=P(1225,a+380|0,a+376|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+380>>2];tb(d);tb(a+220|0);fb=a+384|0;break a}}b=N()|0;tb(d);tb(a+220|0);Q(b|0);p()}return b|0}function L7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-320|0;fb=a;x[a+312>>2]=c;x[a+316>>2]=b;h=Fb(a+196|0);$c(a+16|0,x[d+28>>2]);x[31785]=0;b=R(1220,x[a+16>>2])|0;c=x[31785];x[31785]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[31785]=0;V(1231,b|0,111968,111994,a+208|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}Zb(a+16|0);c=Fb(a+184|0);b=Lc(c);x[31785]=0;O(47,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break b}b=cc(c,0);x[a+180>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[31785]=0;d=P(1225,a+316|0,a+312|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break e}if(d){break c}g=x[a+180>>2];d=Bb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31785]=0;O(47,c|0,d<<1);b=x[31785];x[31785]=0;if((b|0)==1){break b}b=Lc(c);x[31785]=0;O(47,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break b}b=cc(c,0);x[a+180>>2]=d+b}x[31785]=0;d=R(1226,x[a+316>>2])|0;g=x[31785];x[31785]=0;if((g|0)==1){break e}if(Vn(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break c}x[31785]=0;R(1228,a+316|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){continue}}break}break b}b=N()|0;Zb(a+16|0);break a}x[31785]=0;O(47,c|0,x[a+180>>2]-b|0);b=x[31785];x[31785]=0;f:{if((b|0)==1){break f}b=Jb(c);d=Kd();x[a>>2]=f;if((SJ(b,d,a)|0)!=1){x[e>>2]=4}x[31785]=0;b=P(1225,a+316|0,a+312|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+316>>2];tb(c);tb(h);fb=a+320|0;return b|0}}b=N()|0;tb(c)}tb(h);Q(b|0);p()}function U7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;h=Fb(a+196|0);$c(a+16|0,x[d+28>>2]);x[31785]=0;b=R(28,x[a+16>>2])|0;c=x[31785];x[31785]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[31785]=0;V(1218,b|0,111968,111994,a+208|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}Zb(a+16|0);c=Fb(a+184|0);b=Lc(c);x[31785]=0;O(47,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break b}b=cc(c,0);x[a+180>>2]=b;x[a+12>>2]=a+16;x[a+8>>2]=0;while(1){e:{x[31785]=0;d=P(1210,a+252|0,a+248|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break e}if(d){break c}g=x[a+180>>2];d=Bb(x[c+4>>2],y[c+11|0]);if((g|0)==(d+b|0)){x[31785]=0;O(47,c|0,d<<1);b=x[31785];x[31785]=0;if((b|0)==1){break b}b=Lc(c);x[31785]=0;O(47,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break b}b=cc(c,0);x[a+180>>2]=d+b}x[31785]=0;d=R(1211,x[a+252>>2])|0;g=x[31785];x[31785]=0;if((g|0)==1){break e}if(Wn(d,16,b,a+180|0,a+8|0,0,x[h+4>>2],y[h+11|0],a+16|0,a+12|0,a+208|0)){break c}x[31785]=0;R(1213,a+252|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){continue}}break}break b}b=N()|0;Zb(a+16|0);break a}x[31785]=0;O(47,c|0,x[a+180>>2]-b|0);b=x[31785];x[31785]=0;f:{if((b|0)==1){break f}b=Jb(c);d=Kd();x[a>>2]=f;if((SJ(b,d,a)|0)!=1){x[e>>2]=4}x[31785]=0;b=P(1210,a+252|0,a+248|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break f}if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(c);tb(h);fb=a+256|0;return b|0}}b=N()|0;tb(c)}tb(h);Q(b|0);p()}function EB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{e=255;b:{c:{g=a+62|0;d=y[xb(g,b)|0];if((d|0)==255){break c}if(v[xb(g,b)|0]>=0){break b}f=a+26|0;d=d&127;if(z[_b(f,d)>>1]!=65535){if(z[_b(f,d)>>1]!=(b|0)){break c}}j=_b(f,d),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k;break b}i=a+8|0;f=a+26|0;d=0;h=255;d:{while(1){if((d|0)==18){break d}if(z[_b(f,d)>>1]!=65535){if(!(y[xb(i,d)|0]&32)){h=v[xb(g,z[_b(f,d)>>1])|0]<0?d:h;e=d}d=d+1|0;continue}break}j=_b(f,d),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k;break b}if((e&255)!=255){d=(h&255)==255?e:h;e=d&255;j=xb(g,z[_b(f,e)>>1]),k=255,v[j|0]=k;j=_b(f,e),k=b,w[j>>1]=k;j=xb(g,b),k=d,v[j|0]=k}d=Nl(a,b)}g=d&255;if((g|0)==255){break a}if(Ak(x[a>>2])){break a}e=Dd(a+318|0,g);d=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[e+8|0]=d;v[e+9|0]=d>>>8;v[e+10|0]=d>>>16;v[e+11|0]=d>>>24;d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=f;v[e+1|0]=f>>>8;v[e+2|0]=f>>>16;v[e+3|0]=f>>>24;v[e+4|0]=d;v[e+5|0]=d>>>8;v[e+6|0]=d>>>16;v[e+7|0]=d>>>24;f=nU(g);h=f+3|0;d=0;while(1){if((d|0)==2){wh(x[a>>2],x[a+4>>2],b,Lu(g)|192,y[xb(c,10)|0])}else{e=d?h:f;wh(x[a>>2],x[a+4>>2],b,e|32,y[xb(c,d)|0]);wh(x[a>>2],x[a+4>>2],b,e|64,y[xb(c,d+2|0)|0]);wh(x[a>>2],x[a+4>>2],b,e|96,y[xb(c,d+4|0)|0]);wh(x[a>>2],x[a+4>>2],b,e|128,y[xb(c,d+6|0)|0]);wh(x[a>>2],x[a+4>>2],b,e|224,y[xb(c,d+8|0)|0]);d=d+1|0;continue}break}}}function cU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{b:{switch(e<<31|e-2>>>1){case 4:rB(a,b,c,d);return;case 0:e=32-G(d|1)|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<17){while(1){b=b-1|0;v[b|0]=y[(d&1)+15639|0];e=d>>>0>1;d=d>>>1|0;if(e){continue}break}}else{b=b-4|0;e=x[(d<<2&60)+79040>>2];v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;d=d>>>4|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 3:e=(34-G(d|1)>>>0)/3|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<65){while(1){b=b-1|0;v[b|0]=y[(d&7)+14921|0];e=d>>>0>7;d=d>>>3|0;if(e){continue}break}}else{b=b-2|0;e=z[(d<<1&126)+79104>>1];v[b|0]=e;v[b+1|0]=e>>>8;d=d>>>6|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;case 7:e=35-G(d|1)>>>2|0;if((e|0)<=(c-b|0)){c=b+e|0;b=c;while(1){if(d>>>0<257){while(1){b=b-1|0;v[b|0]=y[(d&15)+11186|0];e=d>>>0>15;d=d>>>4|0;if(e){continue}break}}else{b=b-2|0;e=z[(d<<1&510)+79232>>1];v[b|0]=e;v[b+1|0]=e>>>8;d=d>>>8|0;continue}break}b=0}else{b=61}x[a+4>>2]=b;break a;default:break b}}g=d;i=D(e,e);k=D(i,e);j=D(i,i);c:{while(1){h=f|1;if(e>>>0>g>>>0){break c}h=f|2;if(g>>>0<i>>>0){break c}h=f|3;if(g>>>0<k>>>0){break c}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){x[a+4>>2]=61;break a}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;v[c|0]=y[(d-D(b,e)|0)+4915|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}x[a+4>>2]=0;x[a>>2]=f;return}x[a>>2]=c}function s7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=fb-416|0;fb=i;x[i+408>>2]=37;x[i+412>>2]=0;l=Rs(i+408|1,13979,x[c+4>>2]);x[i+364>>2]=i+368;a=Kd();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=nh(i+368|0,30,a,i+408|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=nh(i+368|0,30,a,i+408|0,i+80|0)}x[i+128>>2]=1208;k=Ae(i+356|0,0,i+128|0);b=i+368|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Kd();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=oj(i+364|0,a,i+408|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=oj(i+364|0,a,i+408|0,i+32|0)}if((j|0)==-1){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)==1){break d}break e}a=x[i+364>>2];Oe(k,a)}f=a+j|0;g=pj(a,f,x[c+4>>2]);x[i+116>>2]=1208;e=Ae(i+120|0,0,i+116|0);g:{h:{if((i+368|0)==(a|0)){j=i+128|0;break h}j=Ed(j<<3);if(!j){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)!=1){break e}a=N()|0;break g}Oe(e,j);b=a}a=i+108|0;$c(a,x[c+28>>2]);x[31785]=0;ga(1239,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[31785];x[31785]=0;i:{if((a|0)!=1){Zb(i+108|0);x[31785]=0;a=ea(1240,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break i}Kc(e);Kc(k);fb=i+416|0;break b}a=N()|0;Zb(i+108|0);break g}a=N()|0}Kc(e);break c}p()}a=N()|0}Kc(k);Q(a|0);p()}return a|0}function C7(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=fb-256|0;fb=i;x[i+248>>2]=37;x[i+252>>2]=0;l=Rs(i+248|1,13979,x[c+4>>2]);x[i+204>>2]=i+208;a=Kd();a:{if(l){b=x[c+8>>2];j=i- -64|0;x[j>>2]=g;x[j+4>>2]=h;x[i+56>>2]=e;x[i+60>>2]=f;x[i+48>>2]=b;j=nh(i+208|0,30,a,i+248|0,i+48|0);break a}x[i+80>>2]=e;x[i+84>>2]=f;x[i+88>>2]=g;x[i+92>>2]=h;j=nh(i+208|0,30,a,i+248|0,i+80|0)}x[i+128>>2]=1208;k=Ae(i+196|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Kd();f:{if(l){j=x[c+8>>2];x[i+16>>2]=g;x[i+20>>2]=h;x[i+8>>2]=e;x[i+12>>2]=f;x[i>>2]=j;j=oj(i+204|0,a,i+248|0,i);break f}x[i+32>>2]=e;x[i+36>>2]=f;x[i+40>>2]=g;x[i+44>>2]=h;j=oj(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)==1){break d}break e}a=x[i+204>>2];Oe(k,a)}f=a+j|0;g=pj(a,f,x[c+4>>2]);x[i+116>>2]=1208;e=Ae(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Ed(j<<1);if(!j){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)!=1){break e}a=N()|0;break g}Oe(e,j);b=a}a=i+108|0;$c(a,x[c+28>>2]);x[31785]=0;ga(1234,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=x[31785];x[31785]=0;i:{if((a|0)!=1){Zb(i+108|0);x[31785]=0;a=ea(23,m|0,j|0,x[i+116>>2],x[i+112>>2],c|0,d|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break i}Kc(e);Kc(k);fb=i+256|0;break b}a=N()|0;Zb(i+108|0);break g}a=N()|0}Kc(e);break c}p()}a=N()|0}Kc(k);Q(a|0);p()}return a|0}function Fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>18|0;e=((((x[f+20>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+(j<<1)|0;h=w[g>>1];x[(f+8|0)+(j<<2)>>2]=h+((D(i,w[g+4>>1]-h|0)|0)/16384|0);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=sua(o,z,e,e>>31);i=hb;k=e;e=Xb(h,-16777216,16776704);e=sua(n,y,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Xb(j,-16777216,16776704);i=sua(m,v,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Qb(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function Vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;r=x[a+16>>2];l=ig(1,2);b=hb;s=b;Qb(a,l,b);b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;k=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=((((x[f+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=w[g+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=sua(o,A,e,e>>31);i=hb;j=e;e=Xb(h,-16777216,16776704);e=sua(n,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Xb(C,-16777216,16776704);i=sua(m,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&v);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[f+12>>2]);Qb(f+16|0,k,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Dg(a,l,s);fb=f+48|0}function Gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;f=fb-48|0;fb=f;r=x[a+16>>2];b=0;while(1){if((b|0)!=2){g=b<<3;l=g+(f+28|0)|0;g=a+g|0;x[l+4>>2]=x[g+44>>2];x[l+8>>2]=x[g+48>>2];b=b+1|0;continue}break}s=x[a+24>>2];t=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;u=x[a+72>>2];m=x[a+68>>2];w=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){if(d){g=x[f+16>>2];i=g>>>10&4194048;e=(((x[f+20>>2]&2147483647)<<1|g>>>31)&-2)+r|0;b=0;j=0;while(1){if((j|0)!=2){g=e+j|0;h=v[g|0];x[(f+8|0)+(j<<2)>>2]=((D(i,v[g+2|0]-h|0)|0)/16384|0)+(h<<8);j=j+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;j=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=sua(o,z,e,e>>31);i=hb;k=e;e=Xb(h,-16777216,16776704);e=sua(n,y,e,e>>31);h=k+e|0;k=hb+i|0;k=e>>>0>h>>>0?k+1|0:k;e=Xb(j,-16777216,16776704);i=sua(m,w,e,e>>31);h=i+h|0;e=hb+k|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&u);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],t);x[c+4>>2]=x[c+4>>2]+D(s,x[f+12>>2]);Qb(f+16|0,l,A);c=c+8|0;d=d-1|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}fb=f+48|0}function z2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-2096|0;fb=d;cu(d+48|0);a:{b:{c:{if(up(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){a=ac(8);x[31785]=0;c=P(37,d+36|0,10463)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}g=_L(c);if(g){b=YL(c)}else{b=0}x[d+24>>2]=b;x[d+28>>2]=0;h=c+16|0;b=2048;d:{while(1){e:{if(!b){break e}if(!ZL(x[x[x[c>>2]-12>>2]+h>>2])){break e}e=x[x[x[zj(c,(d+48|0)+f|0,b)>>2]-12>>2]+h>>2];if(up(e)){a=ac(8);x[31785]=0;c=P(37,d+36|0,10463)|0;b=x[31785];x[31785]=0;if((b|0)==1){break d}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}f:{if(BF(e)){break f}if(!pk(e)){break f}a=ac(8);x[31785]=0;c=P(37,d+36|0,10463)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}e=x[c+4>>2];b=b-e|0;f=e+f|0;continue}break}b=gc(d+16|0,d+48|0,f);c=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=c;a=hu(a,d+8|0,g?d+24|0:0);if(a+1>>>0>=3){a=ac(8);x[31785]=0;c=P(37,d+36|0,8077)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}b=N()|0;tb(c);break c}b=N()|0;jc(a);break c}fb=d+2096|0;break a}b=N()|0;jc(a)}Q(b|0)}p()}return a|0}function EA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=92;j=91;k=85;l=84;m=83;n=5;o=118;p=113;q=111;r=107;s=106;t=96;c=88;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;a=Qr(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1),119,1),120,1);if(!c){break a}d=111;e=105;f=99;break b;case 3:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1);o=112;p=98;q=93;r=90;s=89;t=88;c=86;u=76;v=75;w=74;x=73;y=72;z=71;A=70;d=69;e=68;g=67;case 1:Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1),v,1);n=u;m=c;l=t;k=s;j=r;i=q;c=p;h=o;break;case 2:break c;case 0:break d}}Lb(Lb(Lb(Lb(a,n,1),m,1),l,1),k,1);g=j;f=i;e=c;d=h}Lb(a,g,1)}Lb(Lb(Lb(a,f,1),e,1),d,1)}}function vla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){k=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];l=0;break a}b=x[a+12>>2];n=b;k=x[a+8>>2];o=Cg(k,b,m);p=hb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];bg(h,e,sf(k,n,d),hb);l=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;l=l-1|0;b=l;o=b?o:0;p=b?p:0;h=(e<<1)+r|0;b=m;while(1)if((b|0)<=0){Qb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){_d(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Zd(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Ag(i,s);v=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=sua(e,e>>31,b,b>>31);y=hb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Xb(q,-16777216,16776704);j=sua(j,z,b,b>>31);e=e+j|0;b=hb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=sua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Qb(g,k,n);b=b-(h&v)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue b}else{_d(i,w[h+(x[g+12>>2]<<1)>>1]/4<<16>>16);Zd(i,4);Qb(g+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function X7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;oy(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Lc(d);x[31785]=0;O(47,d|0,b|0);b=x[31785];x[31785]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=y[a+206|0]<<24>>24;i=y[a+207|0]<<24>>24;while(1){d:{x[31785]=0;b=P(1210,a+252|0,a+248|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31785]=0;O(47,d|0,b<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+176>>2]=b+c}x[31785]=0;b=R(1211,x[a+252>>2])|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(ny(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31785]=0;R(1213,a+252|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=WJ(c,x[a+176>>2],e),B[j>>2]=k;Qf(a+192|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1210,a+252|0,a+248|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function AO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb+-64|0;fb=e;f=Nb(a);a=0;c=x[b+24>>2];g=Lj(Wb(x[c+484360>>2],y[c+484376|0]));x[31785]=0;O(179,f|0,g|0);c=x[31785];x[31785]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=x[b+24>>2];d=x[c+484344>>2];h=x[c+484348>>2];c=z[_b(x[Wb(x[c+484360>>2],y[c+484376|0])>>2],a)>>1];if(tn(d,h,c)){x[31785]=0;O(1075,e+40|0,Vb(d,c)|0);c=x[31785];x[31785]=0;c:{d:{e:{if((c|0)!=1){c=x[b+24>>2];x[31785]=0;S(1062,e+52|0,c|0,e+40|0);c=x[31785];x[31785]=0;if((c|0)==1){break e}x[31785]=0;O(181,f|0,e+52|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}tb(e+52|0);tb(e+40|0);break b}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(e+52|0)}tb(e+40|0);break a}f:{switch(c-65534|0){case 0:x[31785]=0;c=P(37,e+28|0,9260)|0;d=x[31785];x[31785]=0;g:{if((d|0)!=1){x[31785]=0;O(181,f|0,c|0);d=x[31785];x[31785]=0;if((d|0)==1){break g}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;case 1:x[31785]=0;c=P(37,e+16|0,9222)|0;d=x[31785];x[31785]=0;h:{if((d|0)!=1){x[31785]=0;O(181,f|0,c|0);d=x[31785];x[31785]=0;if((d|0)==1){break h}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a;default:break f}}x[31785]=0;c=P(37,e+4|0,14759)|0;d=x[31785];x[31785]=0;i:{if((d|0)!=1){x[31785]=0;O(181,f|0,c|0);d=x[31785];x[31785]=0;if((d|0)==1){break i}tb(c);break b}a=N()|0;break a}a=N()|0;tb(c);break a}fb=e- -64|0;return}a=a+1|0;continue}}a=N()|0}Pd(f);Q(a|0);p()}function r0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-16|0;fb=f;xc(c);while(1){a:{if(!Mb(x[c>>2],x[c+8>>2],3)){break a}d=f+13|0;Fr(d,c);i=Ic(d);h=Ze(d);d=y[f+13|0];if(d>>>0>=A[a+12>>2]){break a}g=gd(x[a>>2],x[x[a+48>>2]+12>>2],d,b);d=y[i|0];if(d>>>0<=126){if(!(d|y[h|0])){v[g|0]=254;continue}v[g|0]=d+1;if(y[h|0]==255){continue}v[g+2|0]=1;v[g+4|0]=y[h|0];continue}b:{switch(d-127|0){case 1:v[g+1|0]=y[h|0]+1;continue;case 0:continue;default:break b}}e=v[h|0];v[f+12|0]=e;h=0;j=y[i|0];d=j&127;if(d>>>0<=23){h=y[d+24800|0]}c:{d:{e:{f:{g:{switch(d-2|0){case 0:case 8:case 9:if((e|0)>=0){break f}d=0-e&15;break e;case 1:v[f+8|0]=64;e=y[Ub(f+12|0,f+8|0)|0];if(y[g+2|0]>1){break d}v[g+4|0]=e;v[g+2|0]=1;continue;case 2:d=3;if((e|0)>=0){break c}d=0-e&127;break e;case 15:if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e;case 16:case 20:if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;v[f+12|0]=e;j=y[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;v[f+12|0]=e;break c;case 17:d=e&15|-48;break e;case 18:d=e&15|-64;break e;case 21:break g;default:break d}}d=164;if((e|0)==100){break e}x[f+8>>2]=e- -64;x[f+4>>2]=0;x[f>>2]=128;e=x[bk(f+8|0,f+4|0,f)>>2];if(!y[g+3|0]){break d}h:{switch(y[g+2|0]){case 0:case 2:break h;default:continue}}v[g+2|0]=2;v[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;v[f+12|0]=e}d=h;if(!d){continue}}v[g+5|0]=e;v[g+3|0]=d;continue}break}fb=f+16|0}function Wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;f=fb-48|0;fb=f;r=x[a+16>>2];l=ig(1,2);b=hb;s=b;Qb(a,l,b);b=0;while(1){if((b|0)!=2){g=b<<3;k=g+(f+28|0)|0;g=a+g|0;x[k+4>>2]=x[g+44>>2];x[k+8>>2]=x[g+48>>2];b=b+1|0;continue}break}t=x[a+24>>2];u=x[a+20>>2];b=x[a+4>>2];x[f+16>>2]=x[a>>2];x[f+20>>2]=b;w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;k=x[a+8>>2];B=x[a+12>>2];while(1){if(d){d=d-1|0;b=x[f+16>>2];g=(((x[f+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=0;e=0;while(1){if((e|0)!=2){x[(f+8|0)+(e<<2)>>2]=v[e+g|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){p=(f+8|0)+(b<<2)|0;e=x[p>>2];g=(f+28|0)+(b<<3)|0;C=x[g+8>>2];h=x[g+4>>2];x[g+8>>2]=h;q=e<<8;e=q;e=sua(o,A,e,e>>31);i=hb;j=e;e=Xb(h,-16777216,16776704);e=sua(n,z,e,e>>31);h=j+e|0;j=hb+i|0;j=e>>>0>h>>>0?j+1|0:j;e=Xb(C,-16777216,16776704);i=sua(m,y,e,e>>31);h=i+h|0;e=hb+j|0;e=h>>>0<i>>>0?e+1|0:e;i=h+8388608|0;e=i>>>0<8388608?e+1|0:e;e=Rc(i,e,24);x[g+4>>2]=e-(q&w);x[p>>2]=(e|0)/256;b=b+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[f+8>>2],u);x[c+4>>2]=x[c+4>>2]+D(t,x[f+12>>2]);Qb(f+16|0,k,B);c=c+8|0;continue}break}b=x[f+20>>2];x[a>>2]=x[f+16>>2];x[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+28|0)|0;x[d+44>>2]=x[c+4>>2];x[d+48>>2]=x[c+8>>2];b=b+1|0;continue}break}Dg(a,l,s);fb=f+48|0}function W7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-256|0;fb=a;x[a+248>>2]=c;x[a+252>>2]=b;oy(a+192|0,d,a+208|0,a+207|0,a+206|0);d=Fb(a+180|0);b=Lc(d);x[31785]=0;O(47,d|0,b|0);b=x[31785];x[31785]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+176>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=y[a+206|0]<<24>>24;i=y[a+207|0]<<24>>24;while(1){d:{x[31785]=0;b=P(1210,a+252|0,a+248|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(b){break c}g=x[a+176>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31785]=0;O(47,d|0,b<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+176>>2]=b+c}x[31785]=0;b=R(1211,x[a+252>>2])|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(ny(b,a+7|0,a+6|0,c,a+176|0,i,h,a+192|0,a+16|0,a+12|0,a+8|0,a+208|0)){break c}x[31785]=0;R(1213,a+252|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+196>>2],y[a+203|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=UJ(c,x[a+176>>2],e),C[j>>3]=k;Qf(a+192|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1210,a+252|0,a+248|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+252>>2];tb(d);tb(a+192|0);fb=a+256|0;break a}}b=N()|0;tb(d);tb(a+192|0);Q(b|0);p()}return b|0}function Qta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=fb-32|0;fb=k;e=b;b=x[a>>2];b=(dp(e,vb(b))<<1)+b|0;h=x[a+4>>2];a:{b:{if(h>>>0<A[Ab(a)>>2]){if((b|0)!=(h|0)){break b}d=fb-16|0;fb=d;a=vi(d+4|0,a,1);dj(x[a+4>>2],y[c|0]|y[c+1|0]<<8);x[a+4>>2]=x[a+4>>2]+2;hc(a);fb=d+16|0;break a}d=Ab(a);d=hk(k+8|0,ik(a,Xc(x[a>>2],h)+1|0),b-x[a>>2]>>1,d);x[31785]=0;O(297,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)!=1){h=fb-16|0;fb=h;c=x[d+4>>2];e=zb(h+12|0,b);f=zb(h+8|0,x[a>>2]);i=zb(h+4|0,x[d+4>>2]);g=x[e>>2];j=x[f>>2];e=fb-16|0;fb=e;x[e+8>>2]=x[i>>2];x[e+12>>2]=g;while(1){i=x[e+8>>2];if(Pg(g,j)){f=fb-16|0;fb=f;x[f+12>>2]=i;s$(f+12|0,-1);fb=f+16|0;i=x[f+12>>2];g=t$(g);dj(i,y[g|0]|y[g+1|0]<<8);g=aw(e+12|0);aw(e+8|0);g=x[g>>2];continue}break}fb=e+16|0;x[d+4>>2]=i;e=x[a+4>>2];f=x[d+8>>2];while(1){if((b|0)!=(e|0)){dj(f,y[b|0]|y[b+1|0]<<8);f=f+2|0;b=b+2|0;continue}break}x[d+8>>2]=f;wc(a,d+4|0);wc(a+4|0,d+8|0);wc(Ab(a),Ac(d));x[d>>2]=x[d+4>>2];fb=h+16|0;b=c;fj(d);break a}a=N()|0;fj(d);Q(a|0);p()}i=fb-16|0;fb=i;f=x[a+4>>2];e=(f-(b+2|0)|0)+b|0;j=vi(i+4|0,a,h-e>>1);g=x[j+4>>2];d=e;while(1){if(d>>>0>=h>>>0){hc(j);while(1){if((b|0)!=(e|0)){e=e-2|0;f=r$(f-2|0,e);continue}break}fb=i+16|0}else{dj(g,y[d|0]|y[d+1|0]<<8);g=g+2|0;x[j+4>>2]=g;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&A[a+4>>2]>c>>>0)<<1)+c|0;c=y[a|0];v[b+1|0]=y[a+1|0];v[b|0]=c}zb(k+28|0,b);fb=k+32|0}function bma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}r=x[a+16>>2];e=x[a+48>>2];s=x[a+24>>2];t=x[a+20>>2];b=x[a+44>>2];j=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=j;u=x[a+72>>2];o=x[a+68>>2];v=o>>31;p=x[a+64>>2];y=p>>31;q=x[a+60>>2];z=q>>31;while(1){j=b;if(d){b=Xb(j,-16777216,16776704);k=sua(p,y,b,b>>31);l=hb;b=x[g+8>>2];f=(x[g+12>>2]<<1)+r|0;b=(b>>>16&65520)+n|0;f=(((((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+4>>1],w[b+10>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/32768<<8;b=f;b=sua(b,b>>31,q,z);k=b+k|0;m=hb+l|0;m=b>>>0>k>>>0?m+1|0:m;b=Xb(e,-16777216,16776704);e=sua(o,v,b,b>>31);l=e+k|0;b=hb+m|0;b=e>>>0>l>>>0?b+1|0:b;e=l+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,t)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,s);Qb(g+8|0,i,h);b=e-(f&u)|0;c=c+8|0;d=d-1|0;e=j;continue}break}b=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=b;x[a+48>>2]=e;x[a+44>>2]=j;fb=g+16|0}function O7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=E(0);d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;jy(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Lc(d);x[31785]=0;O(47,d|0,b|0);b=x[31785];x[31785]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31785]=0;b=P(1225,a+364|0,a+360|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31785]=0;O(47,d|0,b<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+188>>2]=b+c}x[31785]=0;b=R(1226,x[a+364>>2])|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(iy(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31785]=0;R(1228,a+364|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=WJ(c,x[a+188>>2],e),B[j>>2]=k;Qf(a+204|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1225,a+364|0,a+360|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function N7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;d=x[d+28>>2];a=fb-368|0;fb=a;x[a+360>>2]=c;x[a+364>>2]=b;jy(a+204|0,d,a+224|0,a+220|0,a+216|0);d=Fb(a+192|0);b=Lc(d);x[31785]=0;O(47,d|0,b|0);b=x[31785];x[31785]=0;a:{b:{c:{if((b|0)!=1){c=cc(d,0);x[a+188>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;v[a+7|0]=1;v[a+6|0]=69;h=x[a+216>>2];i=x[a+220>>2];while(1){d:{x[31785]=0;b=P(1225,a+364|0,a+360|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(b){break c}g=x[a+188>>2];b=Bb(x[d+4>>2],y[d+11|0]);if((g|0)==(b+c|0)){x[31785]=0;O(47,d|0,b<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+188>>2]=b+c}x[31785]=0;b=R(1226,x[a+364>>2])|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}if(iy(b,a+7|0,a+6|0,c,a+188|0,i,h,a+204|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}x[31785]=0;R(1228,a+364|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+208>>2],y[a+215|0])|!y[a+7|0]){break e}b=x[a+12>>2];if((b-(a+16|0)|0)>159){break e}x[a+12>>2]=b+4;x[b>>2]=x[a+8>>2]}j=f,k=UJ(c,x[a+188>>2],e),C[j>>3]=k;Qf(a+204|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1225,a+364|0,a+360|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+364>>2];tb(d);tb(a+204|0);fb=a+368|0;break a}}b=N()|0;tb(d);tb(a+204|0);Q(b|0);p()}return b|0}function cma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;g=fb-16|0;fb=g;e=x[a+12>>2];h=e;a:{b:{c:{i=x[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((h|0)>=-2&i>>>0>=3489660928|(h|0)>-2){break c}if((h|0)==-2&i>>>0>2147483647|(h|0)==-1){break d}break b}if((h|0)==1&i>>>0>2147483648|h>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}p=b;q=x[a+16>>2];b=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];j=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=j;t=x[a+72>>2];l=x[a+68>>2];u=l>>31;m=x[a+64>>2];y=m>>31;n=x[a+60>>2];z=n>>31;while(1){j=e;if(d){e=Xb(j,-16777216,16776704);f=sua(m,y,e,e>>31);e=hb;b=Xb(b,-16777216,16776704);b=sua(l,u,b,b>>31);f=b+f|0;e=hb+e|0;e=b>>>0>f>>>0?e+1|0:e;b=x[g+8>>2];k=f;f=x[g+12>>2]+q|0;b=(b>>>16&65520)+p|0;o=(((((((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])|0)+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+2|0],w[b+10>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8)/32768<<8;b=o;f=sua(b,b>>31,n,z);k=k+f|0;b=hb+e|0;b=f>>>0>k>>>0?b+1|0:b;e=k+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;x[c>>2]=D(b,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(b,r);Qb(g+8|0,i,h);e=e-(t&o)|0;c=c+8|0;d=d-1|0;b=j;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=b;x[a+44>>2]=j;fb=g+16|0}function K6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-480|0;fb=a;$c(a+476|0,x[d+28>>2]);x[31785]=0;n=R(1220,x[a+476>>2])|0;g=x[31785];x[31785]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Bb(x[f+4>>2],y[f+11|0])){g=x[Sd(f,0)>>2];x[31785]=0;h=P(1237,n|0,45)|0;j=x[31785];x[31785]=0;if((j|0)==1){break e}o=(g|0)==(h|0)}j=Fb(a+452|0);g=Fb(a+440|0);h=Fb(a+428|0);x[31785]=0;ka(1259,c|0,o|0,x[a+476>>2],a+472|0,a+468|0,a+464|0,j|0,g|0,h|0,a+424|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}x[a+4>>2]=1208;c=Ae(a+8|0,0,a+4|0);k=a+16|0;l=Bb(x[f+4>>2],y[f+11|0]);m=x[a+424>>2];f:{if((l|0)>(m|0)){i=((Bb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Bb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Bb(x[h+4>>2],y[h+11|0])+Bb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Oe(c,Ed(i<<2));k=x[c>>2];if(!k){break g}l=Bb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Jb(f);x[31785]=0;ma(1260,k|0,a+4|0,a|0,i|0,f|0,f+(l<<2)|0,n|0,o|0,a+472|0,x[a+468>>2],x[a+464>>2],j|0,g|0,h|0,m|0);f=x[31785];x[31785]=0;if((f|0)==1){break c}x[31785]=0;b=ea(1240,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break c}Kc(c);Sb(h);Sb(g);tb(j);Zb(a+476|0);fb=a+480|0;return b|0}x[31785]=0;X(1209);b=x[31785];x[31785]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Kc(c)}Sb(h);Sb(g);tb(j)}Zb(a+476|0);Q(f|0);p()}function G6(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=fb-16|0;fb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!x[b>>2]){break a}b=b+4|0;continue}break}x[h>>2]=f;x[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=fb-16|0;fb=r;s=Jh(r+12|0,x[a+8>>2]);i=f;j=g-f|0;m=0;o=fb-16|0;fb=o;k=x[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=Py(j>>>0<4?o+12|0:i,x[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}yc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!x[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){x[e>>2]=k}fb=o+16|0;Ih(s);fb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:x[h>>2]=f;while(1){i:{if(x[e>>2]==(c|0)){break i}b=_x(f,x[c>>2],x[a+8>>2]);if((b|0)==-1){break i}f=b+x[h>>2]|0;x[h>>2]=f;c=c+4|0;continue}break};x[e>>2]=c;break g;case 1:break c;default:break h}}f=x[h>>2]+m|0;x[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=x[e>>2];b=d;continue}b=_x(n+12|0,0,x[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-x[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=y[c|0];i=x[h>>2];x[h>>2]=i+1;v[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=x[e>>2]+4|0;x[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!x[b>>2]){break b}b=b+4|0;continue}}c=x[e>>2]}q=(c|0)!=(d|0)}fb=n+16|0;return q|0}f=x[h>>2];continue}}function wla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;g=fb-16|0;fb=g;r=x[a+16>>2];s=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){k=x[a+8>>2];n=x[a+12>>2];h=x[a>>2];e=x[a+4>>2];l=0;break a}b=x[a+12>>2];n=b;k=x[a+8>>2];o=Cg(k,b,m);p=hb;b=x[a+76>>2];h=x[a>>2];e=x[a+4>>2];bg(h,e,sf(k,n,d),hb);l=hb>>>0>b>>>0?d:0}i=a+112|0;f=x[a+48>>2];t=x[a+24>>2];u=x[a+20>>2];b=x[a+44>>2];x[g>>2]=h;x[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;x[g+8>>2]=h;x[g+12>>2]=0;l=l-1|0;b=l;o=b?o:0;p=b?p:0;h=e+r|0;b=m;while(1)if((b|0)<=0){Qb(i,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){_d(i,v[h+x[g+12>>2]|0]<<6);Zd(i,b);x[i>>2]=x[i>>2];x[i+4>>2]=0}b=Ag(i,s);w=x[a+72>>2];h=b<<8;b=h;e=x[a+60>>2];b=sua(e,e>>31,b,b>>31);y=hb;e=b;b=x[a+64>>2];j=b;z=b>>31;b=Xb(q,-16777216,16776704);j=sua(j,z,b,b>>31);e=e+j|0;b=hb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=x[a+68>>2];f=Xb(f,-16777216,16776704);e=sua(e,e>>31,f,f>>31);f=j+e|0;b=hb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;x[c>>2]=D(f,u)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,t);Qb(g,k,n);b=b-(h&w)|0;c=c+8|0;h=x[g>>2];e=x[g+4>>2];f=q;continue b}else{_d(i,v[h+x[g+12>>2]|0]<<6);Zd(i,4);Qb(g+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=h;x[a+4>>2]=e;x[a+48>>2]=f;x[a+44>>2]=q;fb=g+16|0}function R7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=sj(x[d+4>>2]);i=Vp(x[d+28>>2],a+208|0);Up(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+324>>2];while(1){d:{x[31785]=0;g=P(1225,a+332|0,a+328|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31785]=0;O(47,d|0,g<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31785]=0;g=R(1226,x[a+332>>2])|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(Vn(g,b,c,a+180|0,a+8|0,j,x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31785]=0;R(1228,a+332|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=aK(c,x[a+180>>2],e,b),x[k>>2]=l;x[f+4>>2]=hb;Qf(a+196|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1225,a+332|0,a+328|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function P7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=sj(x[d+4>>2]);i=Vp(x[d+28>>2],a+208|0);Up(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+324>>2];while(1){d:{x[31785]=0;g=P(1225,a+332|0,a+328|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31785]=0;O(47,d|0,g<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31785]=0;g=R(1226,x[a+332>>2])|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(Vn(g,b,c,a+180|0,a+8|0,j,x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31785]=0;R(1228,a+332|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=XJ(c,x[a+180>>2],e,b),x[k>>2]=l;x[f+4>>2]=hb;Qf(a+196|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1225,a+332|0,a+328|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function lqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=y[f+4|0];j=xb(h,d),k=i+1|0,v[j|0]=k;f=y[f+6|0]|y[f+7|0]<<8;j=_b(g,d),k=f+1|0,w[j>>1]=k;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;g=y[g+6|0]|y[g+7|0]<<8;j=_b(f,d+12|0),k=g+1|0,w[j>>1]=k;d=d+1|0;continue}}JC(a+484|0,b+48|0,0);JC(a+590|0,b+68|0,0);JC(a+696|0,b+88|0,5);x[b>>2]=y[a+806|0]|y[a+807|0]<<8;d=v[a+808|0];b:{if((d|0)<0){v[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(v[a|0]&1){v[b+31|0]=d+1;break b}if(!d){break b}v[b+31|0]=d+1}if(y[b+31|0]){c:{d:{if((c|0)==4){d=y[a+810|0];break d}d=v[a+809|0];if((d|0)>=0){w[b+28>>1]=(d&255)+1}d=v[a+810|0];if((d|0)<0){break c}}v[b+30|0]=d+1}v[b+33|0]=y[a+811|0]}if((c|0)==32){v[e+15|0]=y[a+812|0];v[e+14|0]=128;j=b,k=y[Ub(e+15|0,e+14|0)|0]>>>1|0,x[j+4>>2]=k}c=y[a+813|0]|y[a+814|0]<<8;if(c>>>0<=256){x[b+8>>2]=c;v[b+15|0]=y[b+15|0]|1}v[b+16|0]=y[a+815|0];v[b+26|0]=y[a+816|0];v[b+27|0]=y[a+817|0];v[b+17|0]=y[a+818|0];v[b+18|0]=y[a+819|0];w[e+12>>1]=y[a+820|0]|y[a+821|0]<<8;w[e+10>>1]=100;j=b,k=y[Mc(e+12|0,e+10|0)|0],v[j+20|0]=k;w[e+8>>1]=y[a+822|0]|y[a+823|0]<<8;w[e+6>>1]=256;j=b,k=z[Mc(e+8|0,e+6|0)>>1]>>>2|0,v[j+19|0]=k;c=y[a+824|0];gk(b,c&127,c>>>7|0);a=y[a+825|0];fk(b,a&127,a>>>7|0);fb=e+16|0}function _7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=sj(g);Wp(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=y[a+215|0]<<24>>24;while(1){d:{x[31785]=0;g=P(1210,a+220|0,a+216|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31785]=0;O(47,d|0,g<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31785]=0;g=R(1211,x[a+220>>2])|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(Wn(g,b,c,a+184|0,a+8|0,i,x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111968)){break c}x[31785]=0;R(1213,a+220|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=aK(c,x[a+184>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Qf(a+200|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1210,a+220|0,a+216|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function Y7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=sj(g);Wp(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=y[a+215|0]<<24>>24;while(1){d:{x[31785]=0;g=P(1210,a+220|0,a+216|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31785]=0;O(47,d|0,g<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31785]=0;g=R(1211,x[a+220>>2])|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(Wn(g,b,c,a+184|0,a+8|0,i,x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111968)){break c}x[31785]=0;R(1213,a+220|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=XJ(c,x[a+184>>2],e,b),x[j>>2]=k;x[f+4>>2]=hb;Qf(a+200|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1210,a+220|0,a+216|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function O6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=fb-176|0;fb=a;$c(a+172|0,x[d+28>>2]);x[31785]=0;n=R(28,x[a+172>>2])|0;g=x[31785];x[31785]=0;a:{b:{c:{d:{e:{if((g|0)!=1){if(Bb(x[f+4>>2],y[f+11|0])){g=y[cc(f,0)|0];x[31785]=0;h=P(29,n|0,45)|0;j=x[31785];x[31785]=0;if((j|0)==1){break e}o=(g|0)==(h&255)}j=Fb(a+152|0);g=Fb(a+140|0);h=Fb(a+128|0);x[31785]=0;ka(1257,c|0,o|0,x[a+172>>2],a+168|0,a+167|0,a+166|0,j|0,g|0,h|0,a+124|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}x[a+4>>2]=1208;c=Ae(a+8|0,0,a+4|0);k=a+16|0;l=Bb(x[f+4>>2],y[f+11|0]);m=x[a+124>>2];f:{if((l|0)>(m|0)){i=((Bb(x[h+4>>2],y[h+11|0])+(l-m<<1)|0)+Bb(x[g+4>>2],y[g+11|0])|0)+1|0;break f}i=(Bb(x[h+4>>2],y[h+11|0])+Bb(x[g+4>>2],y[g+11|0])|0)+2|0}g:{i=i+m|0;if(i>>>0>=101){Oe(c,Ed(i));k=x[c>>2];if(!k){break g}l=Bb(x[f+4>>2],y[f+11|0])}i=x[d+4>>2];f=Jb(f);x[31785]=0;ma(1258,k|0,a+4|0,a|0,i|0,f|0,f+l|0,n|0,o|0,a+168|0,v[a+167|0],v[a+166|0],j|0,g|0,h|0,m|0);f=x[31785];x[31785]=0;if((f|0)==1){break c}x[31785]=0;b=ea(23,b|0,k|0,x[a+4>>2],x[a>>2],d|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break c}Kc(c);tb(h);tb(g);tb(j);Zb(a+172|0);fb=a+176|0;return b|0}x[31785]=0;X(1209);b=x[31785];x[31785]=0;if((b|0)==1){break c}p()}f=N()|0;break a}f=N()|0;break a}f=N()|0;break b}f=N()|0;Kc(c)}tb(h);tb(g);tb(j)}Zb(a+172|0);Q(f|0);p()}function S7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=sj(x[d+4>>2]);i=Vp(x[d+28>>2],a+208|0);Up(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+324>>2];while(1){d:{x[31785]=0;g=P(1225,a+332|0,a+328|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31785]=0;O(47,d|0,g<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31785]=0;g=R(1226,x[a+332>>2])|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(Vn(g,b,c,a+180|0,a+8|0,j,x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31785]=0;R(1228,a+332|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=cK(c,x[a+180>>2],e,b),x[k>>2]=l;Qf(a+196|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1225,a+332|0,a+328|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function QJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=sj(x[d+4>>2]);i=Vp(x[d+28>>2],a+208|0);Up(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+324>>2];while(1){d:{x[31785]=0;g=P(1225,a+332|0,a+328|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31785]=0;O(47,d|0,g<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31785]=0;g=R(1226,x[a+332>>2])|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(Vn(g,b,c,a+180|0,a+8|0,j,x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31785]=0;R(1228,a+332|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=ZJ(c,x[a+180>>2],e,b),x[k>>2]=l;Qf(a+196|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1225,a+332|0,a+328|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function Q7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=fb-336|0;fb=a;x[a+328>>2]=c;x[a+332>>2]=b;b=sj(x[d+4>>2]);i=Vp(x[d+28>>2],a+208|0);Up(a+196|0,x[d+28>>2],a+324|0);d=Fb(a+184|0);c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+180>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;j=x[a+324>>2];while(1){d:{x[31785]=0;g=P(1225,a+332|0,a+328|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(g){break c}h=x[a+180>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31785]=0;O(47,d|0,g<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+180>>2]=g+c}x[31785]=0;g=R(1226,x[a+332>>2])|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(Vn(g,b,c,a+180|0,a+8|0,j,x[a+200>>2],y[a+207|0],a+16|0,a+12|0,i)){break c}x[31785]=0;R(1228,a+332|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+200>>2],y[a+207|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}k=f,l=$J(c,x[a+180>>2],e,b),w[k>>1]=l;Qf(a+196|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1225,a+332|0,a+328|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+332>>2];tb(d);tb(a+196|0);fb=a+336|0;break a}}b=N()|0;tb(d);tb(a+196|0);Q(b|0);p()}return b|0}function Jta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31785]=0;k=uh(g,a);O(113,i|0,k|0);a=x[31785];x[31785]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=v[cc(b,a)|0];h=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(h-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(h-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[31785]=0;O(305,i|0,Dd(c,g)|0);h=x[31785];x[31785]=0;g=e;if((h|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}x[31785]=0;O(305,i|0,Dd(c,j)|0);e=x[31785];x[31785]=0;if((e|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(D(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}h=(e|0)!=125;f=-1;e=125;if(h){break d}}f=0;x[31785]=0;O(114,i|0,e|0);e=x[31785];x[31785]=0;if((e|0)!=1){break d}a=N()|0;break b}f=-1}a=a+1|0;continue}break}b=ac(8);x[31785]=0;a=R(99,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){x[31785]=0;S(100,a|0,40484,17);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;jc(b);break b}a=N()|0}tb(i);Q(a|0)}p()}function oS(a){var b=0,c=0,d=0,e=0,f=0,g=0;g=fb-48|0;fb=g;c=vw(g+30|0,x[a>>2]);b=_p(g+29|0,x[a+4>>2]);hY(g+32|0,z[c>>1],b);c=_p(g+28|0,x[a+8>>2]);b=z[g+32>>1];e=fb-16|0;fb=e;v[e+15|0]=y[g+34|0];iS(g+36|0,b,e+15|0,c);fb=e+16|0;d=fb-16|0;fb=d;f=fb-16|0;fb=f;c=z[g+36>>1]<<16>>16;e=y[g+38|0];b=vf(2)>>>0>=vf(e)>>>0;e=vf(e);c=c-b|0;b=(((c|0)<0?c-399|0:c)|0)/400|0;c=D(b,-400)+c|0;b=x[zb(f+12|0,((((vf(y[g+39|0])+D(b,146097)|0)+((D(e+(e>>>0>2?-3:9)|0,153)+2>>>0)/5|0)+(c>>>2)|0)+D(c,365)|0)-((c>>>0)/100|0)|0)-719469|0)>>2];fb=f+16|0;b=x[zb(d+12|0,b)>>2];fb=d+16|0;c=zb(g+24|0,x[a+12>>2]);f=fb-16|0;fb=f;d=fb-16|0;fb=d;e=fb-16|0;fb=e;b=x[zb(e+12|0,D(b,24))>>2];fb=e+16|0;x[d+8>>2]=b;b=x[zb(d+12|0,x[c>>2]+x[d+8>>2]|0)>>2];fb=d+16|0;b=x[zb(f+12|0,b)>>2];fb=f+16|0;c=zb(g+20|0,x[a+16>>2]);f=fb-16|0;fb=f;d=fb-16|0;fb=d;e=fb-16|0;fb=e;b=x[zb(e+12|0,D(b,60))>>2];fb=e+16|0;x[d+8>>2]=b;b=x[zb(d+12|0,x[c>>2]+x[d+8>>2]|0)>>2];fb=d+16|0;b=x[zb(f+12|0,b)>>2];fb=f+16|0;f=te(g+8|0,x[a+24>>2],x[a+28>>2]);e=fb-16|0;fb=e;d=fb-16|0;fb=d;c=fb-16|0;fb=c;a=te(c+8|0,sua(b,b>>31,60,0),hb);b=x[a>>2];a=x[a+4>>2];fb=c+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];c=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=te(d+8|0,c,a>>>0>c>>>0?f+1|0:f);a=x[b>>2];fb=d+16|0;b=te(e+8|0,a,x[b+4>>2]);a=x[b>>2];fb=e+16|0;b=nu(g+40|0,a,x[b+4>>2]);a=x[b>>2];fb=g+48|0;hb=x[b+4>>2];return a}function boa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;i=fb-16|0;fb=i;jd(d,32);g=i+8|0;PV(g,y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24),y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24),x[b>>2]);g=ec(g);PV(i,y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24),y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24),x[c>>2]);a=0;a:{g=x[g>>2];if(g-838861>>>0<4294128436){break a}f=x[ec(i)>>2];x[d>>2]=D(g,320);w[d+34>>1]=1;if(!Bh(d)){break a}l=g<<2;e=+(l>>>0);p=+(f>>>0)/e;q=+(g>>>0)/e;r=1/+A[d>>2];s=+A[i>>2];t=+A[i+8>>2];g=0;b:while(1){if((g|0)==(l|0)){a=1;break a}m=+(g>>>0);n=0;o=0;a=x[b+20>>2];if(ge(x[b>>2],a)){e=m*q+t;c:{if(e<4294967296&e>=0){f=~~e>>>0;break c}f=0}k=z[b+34>>1];j=Xd(k);h=D(f,j);e=e-+(f>>>0);d:{if(k&1){f=z[a+(h<<1)>>1];a=z[a+(h+j<<1)>>1];break d}f=y[a+h|0]<<8;a=y[a+(h+j|0)|0]<<8}o=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}a=x[c+20>>2];if(ge(x[c>>2],a)){e=m*p+s;e:{if(e<4294967296&e>=0){f=~~e>>>0;break e}f=0}k=z[c+34>>1];j=Xd(k);h=D(f,j);e=e-+(f>>>0);f:{if(k&1){f=z[a+(h<<1)>>1];a=z[a+(h+j<<1)>>1];break f}f=y[a+h|0]<<8;a=y[a+(h+j|0)|0]<<8}n=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}f=0;a=g;while(1)if((f|0)==80){g=g+1|0;continue b}else{e=r*+(a>>>0);u=x[d+20>>2]+(a<<1)|0,v=dC(o*(1-e)+n*e),w[u>>1]=v;a=a+l|0;f=f+1|0;continue}}}fb=i+16|0;return a|0}function Aoa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;jd(b,2);f=e+24|0;Lk(f,2,a+1|0);d=e+36|0;Ec(d,f);ye(b+43|0,d);tb(d);a:{b:{c:{d:{switch(y[a|0]){case 0:f=x[b+4>>2];d=x[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b>>2]=d;x[e+36>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[e+24>>2]=d-1;d=e+36|0;f=x[Gb(d,e+24|0)>>2];x[b+4>>2]=f;x[e+36>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);d=x[Gb(d,b)>>2];x[b+8>>2]=d;w[b+34>>1]=z[b+34>>1]&65533|y[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}w[b+34>>1]=0;x[b+4>>2]=0;x[b+8>>2]=0;break a}f=e+24|0;lh(f,a+16|0);d=x[e+24>>2];x[e+36>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);lh(f,a+20|0);d=x[e+24>>2];x[e+40>>2]=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);lh(f,a+24|0);d=x[e+24>>2];d=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);x[e+44>>2]=d;x[e+16>>2]=d;d=x[e+40>>2];x[e+8>>2]=x[e+36>>2];x[e+12>>2]=d;Vk(b,1,e+8|0)}v[e+36|0]=y[a+28|0];v[e+24|0]=64;g=b,h=y[Ub(e+36|0,e+24|0)|0]<<2,w[g+30>>1]=h;d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);x[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(y[a|0]==2){d=d&65535;x[b>>2]=d;break e}if(A[b>>2]>=65536){x[b>>2]=65535}d=x[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}x[b>>2]=a}fb=e+48|0}function _J(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=sj(g);Wp(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=y[a+215|0]<<24>>24;while(1){d:{x[31785]=0;g=P(1210,a+220|0,a+216|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31785]=0;O(47,d|0,g<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31785]=0;g=R(1211,x[a+220>>2])|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(Wn(g,b,c,a+184|0,a+8|0,i,x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111968)){break c}x[31785]=0;R(1213,a+220|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=ZJ(c,x[a+184>>2],e,b),x[j>>2]=k;Qf(a+200|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1210,a+220|0,a+216|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function Z7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=sj(g);Wp(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=y[a+215|0]<<24>>24;while(1){d:{x[31785]=0;g=P(1210,a+220|0,a+216|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31785]=0;O(47,d|0,g<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31785]=0;g=R(1211,x[a+220>>2])|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(Wn(g,b,c,a+184|0,a+8|0,i,x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111968)){break c}x[31785]=0;R(1213,a+220|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=$J(c,x[a+184>>2],e,b),w[j>>1]=k;Qf(a+200|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1210,a+220|0,a+216|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function FI(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{c:{while(1){c=x[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[c|0];j=i&255;d:{if((i|0)>=0){w[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=y[c+1|0];if((i&192)!=128){break a}w[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=y[c+2|0];i=y[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}w[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=y[c+3|0];i=y[c+2|0];c=y[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;w[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;x[a+8>>2]=f+2;w[f+2>>1]=i<<6&960|k&63|56320;b=x[a+12>>2]+4|0}x[a+12>>2]=b;f=x[a+8>>2]+2|0;x[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return b|0}function $7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=x[d+4>>2];d=x[d+28>>2];a=fb-224|0;fb=a;x[a+216>>2]=c;x[a+220>>2]=b;b=sj(g);Wp(a+200|0,d,a+215|0);d=Fb(a+188|0);c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){c=cc(d,0);x[a+184>>2]=c;x[a+12>>2]=a+16;x[a+8>>2]=0;i=y[a+215|0]<<24>>24;while(1){d:{x[31785]=0;g=P(1210,a+220|0,a+216|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(g){break c}h=x[a+184>>2];g=Bb(x[d+4>>2],y[d+11|0]);if((h|0)==(g+c|0)){x[31785]=0;O(47,d|0,g<<1);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(d);x[31785]=0;O(47,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=cc(d,0);x[a+184>>2]=g+c}x[31785]=0;g=R(1211,x[a+220>>2])|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}if(Wn(g,b,c,a+184|0,a+8|0,i,x[a+204>>2],y[a+211|0],a+16|0,a+12|0,111968)){break c}x[31785]=0;R(1213,a+220|0)|0;g=x[31785];x[31785]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Bb(x[a+204>>2],y[a+211|0])){break e}g=x[a+12>>2];if((g-(a+16|0)|0)>159){break e}x[a+12>>2]=g+4;x[g>>2]=x[a+8>>2]}j=f,k=cK(c,x[a+184>>2],e,b),x[j>>2]=k;Qf(a+200|0,a+16|0,x[a+12>>2],e);x[31785]=0;b=P(1210,a+220|0,a+216|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if(b){x[e>>2]=x[e>>2]|2}b=x[a+220>>2];tb(d);tb(a+200|0);fb=a+224|0;break a}}b=N()|0;tb(d);tb(a+200|0);Q(b|0);p()}return b|0}function dN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=fb-16|0;fb=h;g=x[a+32>>2];f=gq(g);if(!f){f=fq(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ac(8);x[31785]=0;c=P(37,h+4|0,6020)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}if(c>>>0>=120){b=ac(8);x[31785]=0;c=P(37,h+4|0,11339)|0;a=x[31785];x[31785]=0;if((a|0)!=1){nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=N()|0;jc(b);break b}f=SA(g,65535);j=(f|0)==65535?255:f;w[h+4>>1]=j;f=g+D(j,872)|0;i=f+1074992|0;Jo(i,g,65535,1024);c=c+1|0;v[f+1075794|0]=c;v[f+1075791|0]=c;w[f+1075778>>1]=0;Wm(i);Eo(x[a+32>>2],i,b+1|0,0,1,1);x[f+1075688>>2]=65536;zu(x[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=Xi(Jv(e*128,-128,128)+128),x[l>>2]=m;l=f+1075680|0,m=Xi(Jv(d*256,0,256)),x[l>>2]=m;c=x[a+32>>2];i=c+1074478|0;b=i;c=b+(z[c+480212>>1]<<1)|0;g=z[h+4>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=z[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=z[f>>1];if((k|0)==(g|0)){continue}w[b>>1]=k;b=b+2|0;g=z[h+4>>1];continue}}l=x[a+32>>2],m=vB(i,c),w[l+480212>>1]=m;fb=h+16|0;return j|0}a=N()|0;jc(b)}Q(a|0)}p()}function X3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Fb(a);a=y[b+11|0];g=x[b+4>>2];x[31785]=0;k=uh(g,a);O(96,h|0,k|0);a=x[31785];x[31785]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=y[cc(b,a)|0];d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(e-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(e-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}x[31785]=0;O(97,h|0,Dd(c,g)|0);j=x[31785];x[31785]=0;g=e;if((j|0)!=1){break d}a=N()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;i=e;break d;case 3:f=-1;j:{switch(e-123|0){case 2:f=0;if(d>>>0<=i>>>0){break d}x[31785]=0;O(97,h|0,Dd(c,i)|0);e=x[31785];x[31785]=0;if((e|0)!=1){break d}a=N()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}i=(D(i,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}j=(e|0)!=125;f=-1;e=125;if(j){break d}}f=0;x[31785]=0;O(98,h|0,e|0);e=x[31785];x[31785]=0;if((e|0)!=1){break d}a=N()|0;break b}f=-1}a=a+1|0;continue}break}b=ac(8);x[31785]=0;a=R(99,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){x[31785]=0;S(100,a|0,40484,17);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;break b}a=N()|0;jc(b);break b}a=N()|0}tb(h);Q(a|0)}p()}function BI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){uc(a,9760);break j}d=b>>>24|0;if(!(b&65535)){e=fb-16|0;fb=e;f=uc(e+4|0,4419);Yc(c+68|0,f);tb(f);fb=e+16|0;x[31785]=0;x[c+24>>2]=d;O(90,c+56|0,c+24|0);d=x[31785];x[31785]=0;k:{l:{m:{n:{if((d|0)!=1){x[31785]=0;x[c+8>>2]=b>>>16&255;O(91,c+44|0,c+8|0);b=x[31785];x[31785]=0;if((b|0)==1){break n}x[31785]=0;V(92,a|0,c+68|0,c+56|0,c+44|0);a=x[31785];x[31785]=0;if((a|0)==1){break m}tb(c+44|0);tb(c+56|0);Eb(c+68|0);break j}b=N()|0;break k}b=N()|0;break l}b=N()|0;tb(c+44|0)}tb(c+56|0)}break a}e=fb-16|0;fb=e;f=uc(e+4|0,4143);Yc(c+68|0,f);tb(f);fb=e+16|0;x[31785]=0;x[c+40>>2]=d;O(90,c+56|0,c+40|0);d=x[31785];x[31785]=0;if((d|0)==1){break i}x[31785]=0;x[c+36>>2]=b>>>16&255;O(91,c+44|0,c+36|0);d=x[31785];x[31785]=0;if((d|0)==1){break h}x[31785]=0;x[c+20>>2]=b>>>8&255;O(91,c+24|0,c+20|0);d=x[31785];x[31785]=0;if((d|0)==1){break g}x[31785]=0;x[c+4>>2]=b&255;O(91,c+8|0,c+4|0);b=x[31785];x[31785]=0;if((b|0)==1){break f}x[31785]=0;ja(93,a|0,c+68|0,c+56|0,c+44|0,c+24|0,c+8|0);a=x[31785];x[31785]=0;if((a|0)==1){break e}tb(c+8|0);tb(c+24|0);tb(c+44|0);tb(c+56|0);Eb(c+68|0)}fb=c+80|0;return}b=N()|0;break a}b=N()|0;break b}b=N()|0;break c}b=N()|0;break d}b=N()|0;tb(c+8|0)}tb(c+24|0)}tb(c+44|0)}tb(c+56|0)}Eb(c+68|0);Q(b|0);p()}function y7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=Gy(x[g>>2]);g=my(x[g>>2]);ph(k+4|0,g);a:{b:{if(yd(x[k+8>>2],y[k+15|0])){x[31785]=0;V(1231,l|0,a|0,c|0,d|0);g=x[31785];x[31785]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31785]=0;j=P(1237,l|0,h<<24>>24)|0;h=x[31785];x[31785]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+4;x[h>>2]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31785]=0;h=P(1237,l|0,48)|0;i=x[31785];x[31785]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;h=v[j+1|0];x[31785]=0;h=P(1237,l|0,h|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=h;j=j+2|0}ym(j,c);i=0;x[31785]=0;o=R(1229,g|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Us((j-a<<2)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[cc(k+4|0,h)|0]){break e}if(v[cc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+4;x[i>>2]=o;h=(Bb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31785]=0;n=P(1237,l|0,n|0)|0;m=x[31785];x[31785]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+4;x[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;tb(k+4|0);fb=k+16|0}function qU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;c=x[a>>2];a:{if(Ak(c)){i=fb-16|0;fb=i;e=Dc(3848);d=e+808|0;c=e+16|0;while(1){x[c+16>>2]=0;x[c+20>>2]=0;x[c+36>>2]=0;v[c+42|0]=1;w[c+40>>1]=257;x[c+24>>2]=0;x[c+28>>2]=0;w[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){x[d>>2]=0;x[d+4>>2]=0;x[d+68>>2]=0;x[d+72>>2]=0;x[d+24>>2]=0;x[d+28>>2]=0;w[d+20>>1]=511;x[d+16>>2]=-1;w[d+14>>1]=1;w[d+6>>1]=0;w[d+8>>1]=0;w[d+10>>1]=0;w[d+12>>1]=0;v[d+73|0]=0;v[d+74|0]=0;v[d+75|0]=0;v[d+76|0]=0;v[d+77|0]=0;v[d+78|0]=0;v[d+79|0]=0;v[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}x[e+3832>>2]=0;x[e+3836>>2]=0;c=e+3837|0;v[c|0]=0;v[c+1|0]=0;v[c+2|0]=0;v[c+3|0]=0;v[c+4|0]=0;v[c+5|0]=0;v[c+6|0]=0;v[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}Io((e+D(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+D(f,44)|0)+16|0;c=x[(f<<2)+27520>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+D(c,84)|0;vU(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+D(c,84)|0;vU(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{x[(e+D(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}uU(e,b)}else{vd((e+D(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=x[uf(i+12|0,e)>>2];fb=i+16|0;x[h+12>>2]=b;b=h+12|0;iA(a,b);Cj(b);break a}uU(c,b)}pU(a);fb=h+16|0}function HL(a){var b=0,c=0,d=0,e=0;He(x[a+80>>2],x[a+20>>2]);while(1){c=x[a+28>>2];if((b|0)<x[a+24>>2]){He(x[a+80>>2],x[c+(b<<2)>>2]);b=b+1|0;continue}break}He(x[a+80>>2],c);a:{if(!x[a+396>>2]){break a}c=0;while(1){if(x[a+264>>2]<=(c|0)){break a}e=x[a+396>>2]+D(c,24)|0;d=x[e+16>>2];if(d){b=0;while(1){if((b|0)<x[(x[a+124>>2]+D(y[e+13|0],2096)|0)+4>>2]){He(x[a+80>>2],x[(b<<2)+d>>2]);b=b+1|0;d=x[e+16>>2];continue}break}He(x[a+80>>2],d)}He(x[a+80>>2],x[e+20>>2]);c=c+1|0;continue}}d=x[a+124>>2];if(d){c=0;while(1){if((c|0)<x[a+120>>2]){b=D(c,2096)+d|0;He(x[a+80>>2],x[b+8>>2]);He(x[a+80>>2],x[b+28>>2]);He(x[a+80>>2],x[b+32>>2]);He(x[a+80>>2],x[b+2084>>2]);b=x[b+2088>>2];He(x[a+80>>2],b?b-4|0:0);c=c+1|0;d=x[a+124>>2];continue}break}He(x[a+80>>2],d)}He(x[a+80>>2],x[a+260>>2]);He(x[a+80>>2],x[a+396>>2]);c=x[a+404>>2];if(c){b=0;while(1){if((b|0)<x[a+400>>2]){He(x[a+80>>2],x[(D(b,40)+c|0)+4>>2]);b=b+1|0;c=x[a+404>>2];continue}break}He(x[a+80>>2],c)}c=0;b=0;while(1){if(!(x[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;He(x[a+80>>2],x[d+800>>2]);He(x[a+80>>2],x[d+928>>2]);He(x[a+80>>2],x[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;He(x[a+80>>2],x[b+1068>>2]);He(x[a+80>>2],x[b+1076>>2]);He(x[a+80>>2],x[b+1084>>2]);He(x[a+80>>2],x[b+1092>>2]);He(x[a+80>>2],x[b+1100>>2]);c=c+1|0;continue}break}}function sP(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-240|0;fb=e;if(!y[127304]){if(!y[127176]){b=fb-16|0;fb=b;Fb(127152);x[31791]=0;v[127168]=0;x[31793]=0;x[31785]=0;a=ca(57)|0;c=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{if((c|0)!=1){x[b+12>>2]=a;a=b+12|0;uA(127164,ie(a));Cj(a);v[127168]=0;break f}a=ta(125240,125824)|0;c=gb;if(($(125240)|0)==(c|0)){Y(a|0)|0;x[31785]=0;X(58);b=x[31785];x[31785]=0;if((b|0)==1){break d}p()}if(($(125824)|0)!=(c|0)){break c}Y(a|0)|0;x[31785]=0;v[127168]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){a=N()|0;break c}if(y[127168]){break e}}x[31785]=0;W(59,127148);a=x[31785];x[31785]=0;if((a|0)!=1){break e}a=N()|0;break c}fb=b+16|0;break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}}Cj(127172);Cj(127164);tb(127152);Q(a|0);p()}T(0)|0;Rb();p()}v[127176]=1}c=fb+-64|0;fb=c;b=c+16|0;g=fb-16|0;fb=g;h=aP(g+8|0);j=e+120|0;l=c+4|0;while(1){if((i|0)==12){fb=g+16|0}else{f=fb-48|0;fb=f;a=x[h+4>>2];d=x[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=ZO(_O(f+12|0,32));break g}d=G(a);d=_O(f+12|0,(a<<d&2147483647?32:31)-d|0);while(1){k=ZO(d);if(a>>>0<=k>>>0){continue}break}a=x[h>>2]+k|0}fb=f+48|0;m=wb(b,i),n=a,x[m>>2]=n;i=i+1|0;continue}break}b=jP(l,b,oP(b));fP(j,b);Tm(b);fb=c- -64|0;yc(127184,yc(e,j,120),116);v[127304]=1}fb=e+240|0}function yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=fb-16|0;fb=f;s=x[a+16>>2];t=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){l=x[a+8>>2];n=x[a+12>>2];b=x[a>>2];e=x[a+4>>2];i=0;break a}b=x[a+12>>2];n=b;l=x[a+8>>2];o=Cg(l,b,m);p=hb;i=x[a+76>>2];b=x[a>>2];e=x[a+4>>2];bg(b,e,sf(l,n,d),hb);i=hb>>>0>i>>>0?d:0}h=a+112|0;j=x[a+40>>2];k=x[a+36>>2];x[f>>2]=b;x[f+4>>2]=e;while(1){if(d){d=d-1|0;x[f+8>>2]=b;x[f+12>>2]=0;i=i-1|0;o=i?o:0;p=i?p:0;r=(((e&2147483647)<<1|b>>>31)&-2)+s|0;e=m;b:{c:while(1){d:{if((e|0)<=0){Qb(h,x[a+120>>2],x[a+124>>2]);e=x[a+116>>2];if(!e){break b}g=x[f+8>>2];q=((x[f+12>>2]&2147483647)<<1|g>>>31)&-2;g=0;b=0;break d}g=x[f+8>>2];q=((x[f+12>>2]&2147483647)<<1|g>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){_d(h,g>>>3<<16>>16);Zd(h,4);Qb(f+8|0,o,p);e=e-1|0;continue c}else{g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(v[(b+q|0)+r|0]<<8)+g|0;b=b+1|0;continue}break}_d(h,g>>>3<<16>>16);Zd(h,e);x[h>>2]=x[h>>2];x[h+4>>2]=0}b=Ag(h,t);e=x[a+32>>2];k=x[a+28>>2]+k|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=e+j|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Qb(f,l,n);c=c+8|0;b=x[f>>2];e=x[f+4>>2];continue}break}x[a>>2]=b;x[a+4>>2]=e;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=f+16|0}function Zra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;b=b&4095;w[d+62>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=fb-16|0;fb=e;f=uc(e+4|0,4471);Yc(d+48|0,f);tb(f);fb=e+16|0;x[31785]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=sua(e,e>>31,1e4,0);b=hb;c=c+14780|0;b=c>>>0<14780?b+1|0:b;b=tua(c,b,3652425,0);c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+D(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(D(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;x[d+32>>2]=g+f;O(76,d+36|0,d+32|0);g=x[31785];x[31785]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){x[31785]=0;x[d+16>>2]=(e+D(f,-12)|0)+1;O(79,d+20|0,d+16|0);e=x[31785];x[31785]=0;if((e|0)==1){break j}x[31785]=0;x[d>>2]=(((D(b,306)+5|0)/-10|0)+c|0)+1;O(79,d+4|0,d|0);b=x[31785];x[31785]=0;if((b|0)==1){break i}x[31785]=0;aa(417,a|0,d+48|0,d+36|0,d+20|0,d+4|0);a=x[31785];x[31785]=0;if((a|0)==1){break h}tb(d+4|0);tb(d+20|0);break d}b=N()|0;break e}b=N()|0;break f}b=N()|0;break g}b=N()|0;tb(d+4|0)}tb(d+20|0)}tb(d+36|0)}break a}cg(d+48|0,4451);x[31785]=0;O(418,d+36|0,d+62|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}x[31785]=0;S(142,a|0,d+48|0,d+36|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}}tb(d+36|0);Eb(d+48|0);fb=d- -64|0;return}b=N()|0;break a}b=N()|0;tb(d+36|0)}Eb(d+48|0);Q(b|0);p()}function I7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-16|0;fb=k;l=lw(x[g>>2]);g=ty(x[g>>2]);ph(k+4|0,g);a:{b:{if(yd(x[k+8>>2],y[k+15|0])){x[31785]=0;V(1218,l|0,a|0,c|0,d|0);g=x[31785];x[31785]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;x[f>>2]=g;break a}x[f>>2]=d;c:{d:{j=a;h=y[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}x[31785]=0;j=P(29,l|0,h<<24>>24)|0;h=x[31785];x[31785]=0;if((h|0)==1){break b}h=x[f>>2];x[f>>2]=h+1;v[h|0]=j;j=a+1|0}if(!(y[j|0]!=48|(c-j|0)<2|(y[j+1|0]|32)!=120)){x[31785]=0;h=P(29,l|0,48)|0;i=x[31785];x[31785]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;h=v[j+1|0];x[31785]=0;h=P(29,l|0,h|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break b}i=x[f>>2];x[f>>2]=i+1;v[i|0]=h;j=j+2|0}ym(j,c);i=0;x[31785]=0;o=R(1216,g|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){ym((j-a|0)+d|0,x[f>>2]);g=x[f>>2];break a}e:{if(!y[cc(k+4|0,h)|0]){break e}if(v[cc(k+4|0,h)|0]!=(i|0)){break e}i=x[f>>2];x[f>>2]=i+1;v[i|0]=o;h=(Bb(x[k+8>>2],y[k+15|0])-1>>>0>h>>>0)+h|0;i=0}n=v[g|0];x[31785]=0;n=P(29,l|0,n|0)|0;m=x[31785];x[31785]=0;if((m|0)!=1){m=x[f>>2];x[f>>2]=m+1;v[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=N()|0;tb(k+4|0);Q(a|0);p()}x[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;tb(k+4|0);fb=k+16|0}function lB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;f=x[c+656>>2];a:{if(!Oj(f)){i=x[c+704>>2];f=fb-16|0;fb=f;x[f+12>>2]=d;g=0;b:{if(!d){break b}j=x[b+480180>>2];if(j&20){e=b+1074312|0;d=Pb(e,73)?d&65535:d;if(y[b+480208|0]&16){e=Pb(e,73)?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=x[((d>>>0)%768<<2)+32608>>2]<<6>>>e|0;break b}g=229079296/((d>>>0<=1?1:d)>>>0)|0;break b}g=227001280/(d>>>0)|0;if(on(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}vc(f+12|0,16777215);if(j&17408){g=Bc(uua(sua(i?i:8363,0,3506176,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}if(Ej(b)){d=x[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(y[b+480208|0]&16){g=Bc(uua(sua(i?i:8363,0,7012352,0),hb,(x[f+12>>2]<<8)+e|0,0),hb);break b}g=Bc(uua(-1485242368,13,(x[f+12>>2]<<8)+e|0,0),hb)}e=g;fb=f+16|0;f=x[c+656>>2];break a}e=x[c+700>>2]}x[h+12>>2]=e;c=w[c+774>>1];c:{if(!c){break c}c=f?D(v[f+33|0],c):c;if(!c){break c}e=Xe(zi(+(c|0)/393216)*+(e>>>0));x[h+12>>2]=e}d:{if(!f){break d}c=x[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=x[b+1074420>>2];e=sua(f,f>>31,e,e>>31);f=d+e|0;d=hb+(d>>31)|0;k=h,l=Fc(tua(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),hb),x[k+12>>2]=l}vc(h+12|0,2147483647);c=x[h+12>>2];b=ig(c,x[b+24620>>2]<<4);x[a+8>>2]=c;x[a>>2]=b;x[a+4>>2]=hb;fb=h+16|0}function I3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=Ws(c,d);x[k+4>>2]=1208;n=Vs(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Ed(j);if(!i){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break a}Oe(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(!h){break b}x[f>>2]=x[f>>2]|2;break b}g=x[g>>2];x[31785]=0;s=P(1227,e|0,g|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+4;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Bb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=x[Sd(g,o)>>2];x[31785]=0;q=P(1227,e|0,q|0)|0;t=x[31785];x[31785]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Bb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=yd(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Kc(n);fb=k+128|0;return d|0}a=N()|0;Kc(n);Q(a|0);p()}function y3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;k=fb-128|0;fb=k;j=Ws(c,d);x[k+4>>2]=1208;n=Vs(k+8|0,k+4|0);i=k+16|0;a:{b:{c:{if(j>>>0>=101){i=Ed(j);if(!i){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break a}Oe(n,i)}h=i;g=c;while(1)if((d|0)==(g|0)){d:while(1){g=x[a>>2];h=(g|0)==(b|0);if(j?h:1){if(!h){break b}x[f>>2]=x[f>>2]|2;break b}g=v[g|0];x[31785]=0;s=P(1212,e|0,g|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break a}l=o+1|0;r=0;h=i;g=c;while(1){if((d|0)==(g|0)){o=l;if(!r){continue d}x[a>>2]=x[a>>2]+1;h=i;g=c;if(j+m>>>0<2){continue d}while(1){if((d|0)==(g|0)){continue d}e:{if(y[h|0]!=2){break e}if((Bb(x[g+4>>2],y[g+11|0])|0)==(o|0)){break e}v[h|0]=0;m=m-1|0}h=h+1|0;g=g+12|0;continue}}f:{if(y[h|0]!=1){break f}q=v[cc(g,o)|0];x[31785]=0;q=P(1212,e|0,q|0)|0;t=x[31785];x[31785]=0;if((t|0)==1){break a}g:{if((q|0)==(s|0)){r=1;if((Bb(x[g+4>>2],y[g+11|0])|0)!=(l|0)){break f}v[h|0]=2;m=m+1|0;break g}v[h|0]=0}j=j-1|0}h=h+1|0;g=g+12|0;continue}}}else{l=yd(x[g+4>>2],y[g+11|0]);v[h|0]=l?2:1;m=m+l|0;j=j-l|0;h=h+1|0;g=g+12|0;continue}}p()}h:{i:{while(1){if((c|0)==(d|0)){break i}if(y[i|0]!=2){i=i+1|0;c=c+12|0;continue}break}d=c;break h}x[f>>2]=x[f>>2]|4}Kc(n);fb=k+128|0;return d|0}a=N()|0;Kc(n);Q(a|0);p()}function wA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=yR(b,c);a:{if(!x[b+656>>2]|!(v[h+6|0]&1)){break a}e=x[h>>2];i=a+1074312|0;f=Pb(i,31);d=yw(x[b+656>>2],c);if(mc(x[d>>2],x[d+4>>2])){break a}f=e+(f^1)|0;g=Pb(i,31);e=y[d+12|0];b:{c:{if(!g){d:{if(!(e&2)){break d}j=y[d+14|0];k=!(x[a+480180>>2]&1048580)+z[wb(x[d>>2],j)>>1]|0;g=0;if(!(!(y[b+89|0]&8)|(!(e&4)|(j|0)!=y[d+16|0]))){g=Pb(i,70)}if(g|(f|0)!=(k|0)){break d}f=z[wb(x[d>>2],y[d+13|0])>>1]}if(!(!(y[d+12|0]&4)|y[b+89|0]&8)){a=x[d>>2];if((z[wb(a,y[d+16|0])>>1]+1|0)!=(f|0)){break b}f=z[wb(a,y[d+15|0])>>1];if(!Pb(i,93)|(c|0)!=1|y[b+89|0]&8){break b}v[h+6|0]=y[h+6|0]&254;break b}j=1;e=z[qi(x[d+4>>2])>>1];if(f>>>0>e>>>0){break c}break b}e:{f:{if(!(!(e&4)|y[b+669|0]&8)){if(z[h+4>>1]==65535){break f}if(Pb(i,97)){break f}e=y[d+12|0]}if(e&2){g=x[d>>2];e=z[wb(g,y[d+13|0])>>1];g=z[wb(g,y[d+14|0])>>1]+1|0;break e}e=z[qi(x[d+4>>2])>>1];j=f>>>0>e>>>0;g=e;break e}g=x[d>>2];e=z[wb(g,y[d+15|0])>>1];g=z[wb(g,y[d+16|0])>>1]+1|0}e=f>>>0<g>>>0?f:e}g:{if(!j|c){break g}f=x[a+480180>>2];c=x[b+88>>2];if(!(!(f&16777248)&(!(c&2048)|(f|0)==16384))){c=c|4096;x[b+88>>2]=c}if(y[qi(x[d+4>>2])+2|0]|!(z[b+786>>1]|x[a+480180>>2]&16777248)){break g}x[b+696>>2]=0;x[b+720>>2]=0;x[b+680>>2]=0;x[b+88>>2]=c|4096}f=e}l=h,m=Pb(i,31)+f|0,x[l>>2]=m}}function QX(a,b){var c=0;a:{b:{c:{if(me(a,16934)){break c}if(me(a,17719)){break c}if(me(a,13684)){break c}if(me(a,13794)){break c}if(!me(a,14391)){break b}}w[b+10>>1]=4;x[b>>2]=12057;break a}d:{e:{if(me(a,17714)){break e}if(me(a,13694)){break e}if(!me(a,16919)){break d}}v[b+15|0]=1;v[b+12|0]=1;x[b>>2]=8411;w[b+10>>1]=4;break a}f:{if(!me(a,14440)){if(!me(a,14445)){break f}}w[b+10>>1]=8;x[b>>2]=8189;break a}g:{if(!me(a,15532)){if(!me(a,15537)){break g}}x[b>>2]=17306;w[b+10>>1]=v[a+2|0]-48;break a}h:{if(!me(a,25482)){if(!me(a,25487)){break h}}x[b+4>>2]=1;x[b>>2]=17112;w[b+10>>1]=y[a|0]==56?8:4;break a}if(!(Ob(a,15702,3)|(y[a+3|0]-52&255)>>>0>4)){x[b>>2]=8529;a=v[a+3|0];w[b+8>>1]=1088;w[b+10>>1]=a-48;break a}i:{j:{if(Ob(a,13722,3)){if(Ob(a,13856,3)){break j}}if((y[a+3|0]-52&255)>>>0>5){break j}v[b+15|0]=1;v[b+13|0]=1;x[b>>2]=8288;break i}k:{if((y[a|0]-49&255)>>>0>8){break k}if(!Ob(a+1|0,13880,3)){v[b+14|0]=1;x[b>>2]=8593;w[b+10>>1]=v[a|0]-48;break a}if((y[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Ob(c,14217,2)){if(Ob(c,13884,2)){break k}}v[b+14|0]=1;x[b>>2]=8593;w[b+10>>1]=(v[a+1|0]+D(v[a|0],10)|0)-528;break a}if(!(Ob(a,13550,3)|(y[a+3|0]-49&255)>>>0>8)){x[b>>2]=8438;break i}if(me(a,13985)){v[b+16|0]=1;w[b+10>>1]=4;a=1}else{a=0}return a}w[b+10>>1]=v[a+3|0]-48}return 1}function EO(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-160|0;fb=e;d=Cc(e+4|0,11621);x[31785]=0;b=d+12|0;P(37,b|0,11015)|0;c=x[31785];x[31785]=0;a:{if((c|0)==1){break a}x[31785]=0;b=d+24|0;P(37,b|0,11451)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=d+36|0;P(37,b|0,11007)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=d+48|0;P(37,b|0,8263)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=d+60|0;P(37,b|0,10992)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=d+72|0;P(37,b|0,8329)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=d+84|0;P(37,b|0,5640)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=d+96|0;P(37,b|0,12025)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=d+108|0;P(37,b|0,11394)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=d+120|0;P(37,b|0,12294)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=d+132|0;P(37,b|0,5492)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;b=d+144|0;P(37,b|0,7355)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;U(1072,a|0,d|0,13)|0;a=x[31785];x[31785]=0;if((a|0)!=1){b=d+156|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}fb=e+160|0;return}b=d+156|0}a=N()|0;while(1){b=tb(b-12|0);if((d|0)!=(b|0)){continue}break}Q(a|0);p()}function _V(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=x[a>>2];c=Ph(e,x[a+4>>2]);if(c>>>0<b>>>0){h=fb-32|0;fb=h;g=b-c|0;c=x[Ab(a)>>2];b=x[a+4>>2];a:{if(g>>>0<=c-b>>8>>>0){c=fb-16|0;fb=c;b=c+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(g<<8);a=x[b+4>>2];e=x[b+8>>2];while(1){if((a|0)==(e|0)){hc(b);fb=c+16|0}else{BV(a);a=a+256|0;x[b+4>>2]=a;continue}break}break a}i=Ab(a);c=h+12|0;e=a;f=Ph(x[a>>2],b)+g|0;b=fb-16|0;fb=b;x[b+12>>2]=f;d=fb-16|0;fb=d;x[d+12>>2]=16777215;x[d+8>>2]=2147483647;a=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=f>>>0){d=_B(e);if(d>>>0<a>>>1>>>0){x[b+8>>2]=d<<1;a=x[_c(b+8|0,b+12|0)>>2]}fb=b+16|0;break b}cd();p()}f=Ph(x[e>>2],x[e+4>>2]);d=fb-16|0;fb=d;Gg(c+12|0,i);c:{if(!a){b=0;a=0;break c}if(a>>>0>=16777216){Xj();p()}b=Dc(a<<8);x[d+12>>2]=a;x[d+8>>2]=b;b=x[d+12>>2];a=x[d+8>>2]}x[c>>2]=a;f=a+(f<<8)|0;x[c+8>>2]=f;x[c+4>>2]=f;j=Ac(c),k=a+(b<<8)|0,x[j>>2]=k;fb=d+16|0;d=fb-16|0;fb=d;a=d+4|0;x[a>>2]=x[c+8>>2];b=x[c+8>>2];x[a+8>>2]=c+8;x[a+4>>2]=b+(g<<8);b=x[a>>2];while(1){if(x[a+4>>2]!=(b|0)){BV(b);b=x[a>>2]+256|0;x[a>>2]=b;continue}break}ee(a);fb=d+16|0;Id(e,c);a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)!=(b|0)){b=b-256|0;x[c+8>>2]=b;continue}break}a=x[c>>2];if(a){Ac(c);Db(a)}}fb=h+32|0;return}if(b>>>0<c>>>0){CV(a,e+(b<<8)|0)}}function mna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;d=fb-32|0;fb=d;l=a+480190|0;c=z[l>>1];v[d+20|0]=0;OT(b,c+1|0,d+20|0);j=a+480192|0;if(z[j>>1]){h=Nb(d+20|0);q=d,r=vb(x[a+484344>>2]),x[q+16>>2]=r;o=vb(x[a+484348>>2]);m=a+480188|0;while(1){i=x[d+16>>2];if(Ib(i,o)){a:{if(!Ib(x[i>>2],x[i+4>>2])){break a}c=z[m>>1];x[31785]=0;v[d+4|0]=0;S(784,h|0,c|0,d+4|0);c=x[31785];x[31785]=0;if((c|0)!=1){q=d,r=vb(x[i>>2]),x[q+12>>2]=r;k=0;b:while(1){f=0;if(A[i+12>>2]<=k>>>0){break a}while(1)if(z[m>>1]<=f>>>0){k=k+1|0;continue b}else{c:{c=x[d+12>>2];if(!zd(y[c|0])){break c}d:{e:{c=y[c+1|0];if(c){g=z[j>>1];break e}g=z[j>>1];c=y[xb(x[h>>2],f)|0];if(c){break e}c=1;break d}q=xb(x[h>>2],f),r=c,v[q|0]=r;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break c}e=x[((e<<2)+a|0)+900380>>2];f:{if(!e){break f}e=z[_b(e+236|0,y[x[d+12>>2]]-1|0)>>1];if(e>>>0>z[l>>1]){break f}n=d+4|0;Kb(n,x[b>>2],e);Df(n,1)}c=c+1|0;continue}}f=f+1|0;vC(d+12|0);continue}}}a=N()|0;dc(h);Q(a|0);p()}nv(d+16|0);continue}else{c=z[a+480190>>1];while(1){if(c){Kb(d+4|0,x[b>>2],c);if(!Hb(x[x[d+4>>2]>>2],x[d+8>>2])){e=f;f=D(c,104)+a|0;f=e+ge(x[f+484380>>2],x[f+484400>>2])|0}c=c-1|0;continue}else{dc(h)}break}}break}}fb=d+32|0;return f&65535}function GI(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;c=x[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=z[c>>1];c:{if(b>>>0<=127){f=1;c=x[a+8>>2];if((g-c|0)<=0){break a}x[a+8>>2]=c+1;v[c|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if(b>>>0<=55295){c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=z[c+2>>1];if((i&64512)!=56320){break e}if((g-x[a+8>>2]|0)<4){break a}x[a+12>>2]=c+2;c=x[a+8>>2];x[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;v[f|0]=c>>>2|240;f=x[a+8>>2];x[a+8>>2]=f+1;v[f|0]=c<<4&48|b>>>2&15|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=i>>>6&15|b<<4&48|128;b=x[a+8>>2];x[a+8>>2]=b+1;v[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=x[a+8>>2];if((g-c|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}c=x[a+12>>2]+2|0;x[a+12>>2]=c;continue}break}f=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return f|0}function lra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=Bf(a,c);Yd(e,x[a+36>>2]);i=a;a:{if(!h){Pc(e,a+32|0,5);c=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=fb-160|0;fb=d;f=Gm(d+48|0,x[a+36>>2]);x[31785]=0;a=P(465,d+36|0,42516)|0;c=x[31785];x[31785]=0;b:{c:{d:{e:{if((c|0)!=1){x[31785]=0;x[d+16>>2]=19988519;x[d+20>>2]=0;S(466,f|0,a|0,d+16|0);c=x[31785];x[31785]=0;if((c|0)==1){break e}Eb(a);if(!ml(y[f|0])){break d}break b}c=N()|0;break c}c=N()|0;Eb(a);break c}k=d,l=pg(x[b>>2],x[b+4>>2]),w[k+34>>1]=l;w[d+32>>1]=65535;x[31785]=0;a=P(465,d+16|0,10115)|0;c=x[31785];x[31785]=0;f:{if((c|0)!=1){x[31785]=0;c=U(495,f|0,d+32|0,a|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break f}Eb(a);if(c){w[d+34>>1]=z[d+32>>1]}Pf(d+34|0,4e3);a=z[d+34>>1];g:{if(pg(x[b>>2],x[b+4>>2])>>>0>=a>>>0){break g}x[31785]=0;O(226,b|0,a|0);c=x[31785];x[31785]=0;if((c|0)!=1){break g}c=N()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}g=x[b>>2];x[31785]=0;O(496,d+4|0,c|0);j=x[31785];x[31785]=0;if((j|0)!=1){x[31785]=0;V(497,f|0,Vb(g,c)|0,d+4|0,498);g=x[31785];x[31785]=0;if((g|0)==1){break h}c=c+1|0;Eb(d+4|0);continue}break}c=N()|0;break c}c=N()|0;Eb(d+4|0);break c}c=N()|0;break c}c=N()|0;Eb(a)}yh(f);Q(c|0);p()}yh(f);fb=d+160|0;c=h}cf(i,c);fb=e+16|0}function Ila(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];v=m>>31;n=x[a+64>>2];y=n>>31;o=x[a+60>>2];z=o>>31;l=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=sua(n,y,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=sua(m,v,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=p;g=sua(e,e>>31,o,z);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Qb(h+8|0,l,A);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function Ce(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0),i=0,k=0;d=(q(b),j(2));c=UH(d);a:{b:{c:{d:{e=(q(a),j(2));e:{if(e-2139095040>>>0>=2164260864){if(c){break e}break c}if(!c){break d}}h=E(1);if((e|0)==1065353216){break b}c=d<<1;if(!c){break b}i=c>>>0<4278190081;c=e<<1;a=E(a+b);if(!(i&c>>>0<=4278190080)){break a}if((c|0)==2130706432){break b}a=c>>>0>2130706431^(d|0)>=0?E(0):E(b*b);break a}if(UH(e)){h=E(a*a);if((e|0)<0){h=(TH(d)|0)==1?E(-h):h}if((d|0)>=0){break b}a=nx(E(E(1)/h));break a}if((e|0)<0){c=TH(d);if(!c){a=SH(a);break a}e=e&2147483647;i=((c|0)==1)<<16}if(e>>>0>8388607){break c}e=((q(E(a*E(8388608))),j(2))&2147483647)-192937984|0}d=e-1060306944|0;c=d>>>15&240;f=+(l(2,e-(d&-8388608)|0),r())*C[c+125864>>3]+-1;g=f*f;f=((f*.288457581109214+-.36092606229713164)*(g*g)+((f*.480898481472577+-.7213474675006291)*g+(f*1.4426950408774342+(C[c+125872>>3]+ +(d>>23)))))*+b;o(+f);c=j(1)|0;j(0)|0;f:{c=c&2147450880;if((c|0)==1079967744|c>>>0<1079967744){break f}if(f>127.99999995700433){a=HF(i);break a}if(!(f<=-150)){break f}a=qF(i);break a}k=f;g=C[160];f=g+f;g=k-(f-g);g=(C[161]*g+C[162])*(g*g)+(C[163]*g+1);o(+f);j(1)|0;e=j(0)|0;d=i+e|0;i=d<<15;d=((e&31)<<3)+1024|0;c=x[d>>2];d=x[d+4>>2]+i|0;l(0,c|0);l(1,(c>>>0>c>>>0?d+1|0:d)|0);h=E(g*+n())}a=h}return a}function wL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=E(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=qe(a,k),x[p>>2]=q;g=d+1076|0;p=g,q=qe(a,k),x[p>>2]=q;i=qe(a,c&-4);x[d+1084>>2]=i;a:{h=x[h>>2];if(!h){break a}g=x[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=E(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+E(E(E(g<<1)*E(3.1415927410125732))/j);p=i+(e<<2)|0,r=E(ff(f)),B[p>>2]=r;p=i+(g<<2)|0,r=E(-E(Ti(f))),B[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+E(E(E(e<<2)*E(3.1415927410125732))/j);p=h+l|0,r=E(ff(f)),B[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=E(-E(Ti(f))),B[p>>2]=r;f=+E(E(E(E(m|0)*E(3.1415927410125732))/j)*E(.5));p=g+l|0,r=E(E(ff(f))*E(.5)),B[p>>2]=r;p=g+n|0,r=E(E(Ti(f))*E(.5)),B[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=qe(a,k);x[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=E(Ti((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=E(Ti(+E(j*j)*1.5707963705062866)),B[p>>2]=r;b=b+1|0;continue}break}b=qe(a,c>>2&-2);x[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Fm(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Dm(a)>>>c<<2,w[p>>1]=q;a=a+1|0;continue}break}return 1}fc(a,3);return 0}function vh(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=x[a+480180>>2];if(!on(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=z[((D(a,-12)+e&255)<<1)+31920>>1]<<4>>>a|0;break a}if(!d){x[f+12>>2]=8363;d=8363}if(Ej(a)){a=((e&255)>>>0)/12|0;b=sua(x[(D(a,-12)+e<<6&960)+35808>>2]<<a,0,d,0);a=hb;c=a>>>21|0;h=f,i=Bc((a&2097151)<<11|b>>>21,c),x[h+8>>2]=i;vc(f+8|0,2147483647);e=x[f+8>>2];break a}if(y[a+480208|0]&16){a=e&255;e=z[((a>>>0)%12<<1)+31920>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;vc(f+12|0,-1>>>a|0);e=Bc(uua(sua(z[((D(a,-12)+e&255)<<1)+31920>>1],0,267616,0),hb,x[f+12>>2]<<a,0),hb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{b=Pb(a+1074312|0,76)?c&-8:c}c=d?e:12;if(y[a+480208|0]&16){a=((b|0)/-2|0)-(c<<6)|0;e=((a|0)<=-8447?-8447:a)+8448|0;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(D(c,-12)+a<<3&248)|0;x[f+4>>2]=d+8;Ee(f+4|0,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)<=-8?-8:a;e=D(b,z[(((a|0)>=95?95:a)<<1)+32416>>1])+D(z[(x[f+4>>2]<<1)+32400>>1],16-b|0)<<1>>>c|0;break a}if(!(b-25>>>0<84&(c&255)>>>0<=15)){a=((e&255)>>>0)/12|0;e=z[(D((c&240)>>>4|0,12)+(D(a,-12)+e&255)<<1)+31520>>1]<<5>>>a|0;break a}e=z[(b<<1)+31294>>1]<<2}fb=f+16|0;return e}function S0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-1088|0;fb=g;e=_h(a);Tb(e+20|0,0,1040);x[e+1064>>2]=0;x[e+1068>>2]=0;x[e+1060>>2]=c;v[e+1084|0]=d;a=e+1072|0;x[a>>2]=0;x[a+4>>2]=0;x[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(Xd(z[a+34>>1])>>>0<=d>>>0){break a}x[e+1064>>2]=0;x[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(A[c>>2]<=a>>>0){break j}a=x[b+8>>2];f=x[b>>2];x[31785]=0;a=U(153,f|0,a|0,2)|0;f=x[31785];x[31785]=0;if((f|0)==1){break i}if(!a){break j}x[31785]=0;a=R(192,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break h}if(!a){break e}x[31785]=0;S(188,g+8|0,b|0,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break g}h=g+8|0;a=Zr(g+28|0,h);f=hd(e,a);yc(f+20|0,a+20|0,1040);ub(a);ub(h);x[e+1076>>2]=0;x[e+1080>>2]=0;h=x[e+1060>>2];a=x[h+20>>2];if(Cn(z[h+34>>1])>>>0>=2){x[31785]=0;O(193,f|0,a+(d<<1)|0);a=x[31785];x[31785]=0;if((a|0)!=1){break e}break f}x[31785]=0;O(194,f|0,a+d|0);a=x[31785];x[31785]=0;if((a|0)==1){break f}break e}d=d+1|0;a=x[e+1060>>2];continue c}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=T(29088)|0;if((gb|0)!=($(29088)|0)){break b}Y(a|0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break d}}a=x[i>>2];continue}break}break}a=N()|0}ub(e);Q(a|0);p()}fb=g+1088|0;return e|0}function Pka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;k=fb-32|0;fb=k;h=k+28|0;f=k+24|0;g=fb-16|0;fb=g;a:{b:{if(!mc(b,x[zb(g+12|0,mg(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=qd(b);m=z[j>>1];j=x[j+4>>2];if(!Ll(e,i,m,j)){break b}}x[g+12>>2]=b;e=zb(g+8|0,vb(x[a>>2]));c:{f=x[g+12>>2];if(!mc(f,x[e>>2])){f=x[zB(g+12|0)>>2];e=qd(f);j=z[e>>1];m=x[e+4>>2];e=z[c>>1];i=x[c+4>>2];if(!Ll(j,m,e,i)){break c}}if(!x[b>>2]){x[h>>2]=b;break a}x[h>>2]=f;b=f+4|0;break a}b=yB(a,h,e,i);break a}if(Ll(m,j,e,i)){d:{f=xB(b);if(!mc(f,x[zb(g+12|0,mg(a))>>2])){e=z[c>>1];i=x[c+4>>2];j=qd(f);if(!Ll(e,i,z[j>>1],x[j+4>>2])){break d}}if(!x[b+4>>2]){x[h>>2]=b;b=b+4|0;break a}x[h>>2]=f;b=f;break a}b=yB(a,h,e,i);break a}x[h>>2]=b;x[f>>2]=b;b=f}fb=g+16|0;f=b;b=x[b>>2];if(!b){b=fb-16|0;fb=b;g=ec(a);h=k+12|0;e=zh(h,Dc(36),Kg(b+8|0,g));g=x[e>>2]+16|0;i=x[c+4>>2];x[g>>2]=x[c>>2];x[g+4>>2]=i;Tl(g+8|0,d);o=ec(e),p=1,v[o+4|0]=p;fb=b+16|0;Xg(a,x[k+28>>2],f,x[k+12>>2]);b=ie(h);IT(h);n=1}a=l+4|0;Wg(a,x[zb(k+12|0,b)>>2],n);fb=k+32|0;if(!y[ec(a)|0]){a=qd(x[l+4>>2])+8|0;HT(a);x[a>>2]=x[d>>2];x[a+4>>2]=x[d+4>>2];b=Ab(d);o=Ab(a),p=x[b>>2],x[o>>2]=p;x[b>>2]=0;x[d>>2]=0;x[d+4>>2]=0}a=x[zb(l+12|0,x[l+4>>2])>>2];fb=l+16|0;return a|0}function lM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Sf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{k=x[c+4>>2];if(k>>>0>=g>>>0){l=x[c+20>>2];if(l>>>0<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}m=x[c+28>>2];if(f>>>0>x[c+24>>2]-m>>>0){break b}n=b+12|0;o=x[c+16>>2];q=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}r=D(h,k);s=D(h+m|0,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=wb(x[b>>2],d);i=De(Eg(C[(d+r<<3)+q>>3])*134217728);j=e;e=(x[e>>2]>>1)+mn(i)|0;t=e;e=Gt(n)+e&-4096;x[j>>2]=t-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=(d+s<<1)+o|0;i=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}u=j,v=dd(e),w[u>>1]=v;d=d+1|0;continue}}}_(7264,9065,77,8745);p()}_(7229,9065,78,8745);p()}_(5917,9065,79,8745);p()}_(5887,9065,80,8745);p()}fb=a+32|0;fb=c- -64|0}function rM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];g=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=g;Sf(c+48|0,c+32|0,f);a=x[d+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{l=x[c+4>>2];if(l>>>0>=g>>>0){if(A[c+20>>2]<g>>>0){break d}if(f>>>0>A[c+8>>2]){break c}m=x[c+28>>2];if(f>>>0>x[c+24>>2]-m>>>0){break b}n=b+12|0;o=x[c+16>>2];q=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}r=h+m|0;s=D(h,l);d=0;while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{e=wb(x[b>>2],d);i=De(Eg(C[(d+s<<3)+q>>3])*134217728);j=e;e=(x[e>>2]>>1)+mn(i)|0;k=e;e=Gt(n)+e&-4096;x[j>>2]=k-e;C[a+24>>3]=+(e|0)*7.450580596923828e-9;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;j=r<<1;k=(d<<2)+o|0;i=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){e=~~i;break f}e=-2147483648}t=j+x[k>>2]|0,u=dd(e),w[t>>1]=u;d=d+1|0;continue}}}_(7264,9065,77,8745);p()}_(7229,9065,78,8745);p()}_(5917,9065,79,8745);p()}_(5887,9065,80,8745);p()}fb=a+32|0;fb=c- -64|0}function Mj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!ge(x[a>>2],x[a+20>>2])){break a}Xk(a);b:{switch(Cn(z[a+34>>1])-1|0){case 1:h=fb-48|0;fb=h;g=x[a+20>>2];c=x[a>>2];d=Xd(z[a+34>>1]);e=g+(D(c,d)<<1)|0;while(1){c:{d:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break d}f=e+(d<<5)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;MU(h+28|0,f,g+(D(d,e)<<1)|0,i,d,(c&4)>>>2|0,Pb(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;MU(h+8|0,f+(d<<7)|0,g+(D(a,d)<<1)|0,e,d,(c&16)>>>4|0,Pb(b+1074312|0,33))}fb=h+48|0;break c}while(1){if((c|0)!=(d|0)){w[e+(c+i<<1)>>1]=z[e+(c-d<<1)>>1];w[g+(c+j<<1)>>1]=z[g+(c<<1)>>1];c=c+1|0;continue}break}f=f+1|0;continue}break};return;case 0:break b;default:break a}}h=fb-48|0;fb=h;g=x[a+20>>2];c=x[a>>2];d=Xd(z[a+34>>1]);e=g+D(c,d)|0;while(1){e:{f:{if((f|0)!=16){i=D(d,f);j=D(d,f^-1);c=0;break f}f=e+(d<<4)|0;c=z[a+34>>1];if(c&2){e=x[a+4>>2];i=x[a+8>>2]-e|0;LU(h+28|0,f,g+D(d,e)|0,i,d,(c&4)>>>2|0,Pb(b+1074312|0,33));c=z[a+34>>1]}if(c&8){e=x[a+16>>2];a=x[a+12>>2];e=e-a|0;LU(h+8|0,f+(d<<6)|0,g+D(a,d)|0,e,d,(c&16)>>>4|0,Pb(b+1074312|0,33))}fb=h+48|0;break e}while(1){if((c|0)!=(d|0)){v[e+(c+i|0)|0]=y[e+(c-d|0)|0];v[g+(c+j|0)|0]=y[c+g|0];c=c+1|0;continue}break}f=f+1|0;continue}break}}}function Jla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0,B=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];q=x[a+16>>2];l=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=l;r=b+24|0;s=x[a+32>>2];t=x[a+28>>2];u=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;l=x[a+8>>2];B=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=sua(n,z,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=sua(m,y,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;p=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=p;g=sua(e,e>>31,o,A);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+t|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+s|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Qb(h+8|0,l,B);f=f-(u&p)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function dO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb+-64|0;fb=e;a:{b:{c:{d:{f=a+36|0;d=x[f>>2];c=x[a+40>>2];e:{if(Ib(d,c)){rc(e+60|0);break e}c=e+24|0;oo(c,a);x[31785]=0;c=R(1065,c|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break d}x[e+60>>2]=c;mf(e+24|0);c=x[a+40>>2];d=x[a+36>>2]}c=(k=f,l=x[e+60>>2],m=Ib(d,c),m?k:l);f=x[a+8>>2];if((f|0)==-1){d=x[c+4>>2];f=At(d);g=x[c>>2];i=lj(g,d);j=C[f>>3];d=0;while(1){if((d|0)==(i|0)){c=f;break c}c=tf(g,d);if(h+C[c>>3]>b){break c}d=d+1|0;h=h+j;continue}}c=tf(x[c>>2],f);break b}d=N()|0;mf(e+24|0);break a}b=b-h}f=z[c+12>>1];d=x[a+24>>2];x[31785]=0;O(1099,d|0,f|0);f=x[31785];x[31785]=0;if((f|0)!=1){f:{f=x[a+24>>2];d=y[a+64|0];c=ER(JX(e+24|0,b),y[c+16|0],z[c+12>>1],x[c+8>>2]);x[31785]=0;g=x[c+12>>2];x[e+8>>2]=x[c+8>>2];x[e+12>>2]=g;g=x[c+20>>2];x[e+16>>2]=x[c+16>>2];x[e+20>>2]=g;g=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=g;V(1100,e+48|0,f|0,(d?7:1)|0,e|0);c=x[31785];x[31785]=0;if((c|0)==1){break f}c=KB(x[e+52>>2]);f=v[c+26|0]&1;d=x[(f?c+8|0:c+12|0)>>2];f=z[(f?c+20|0:c+22|0)>>1];b=C[c>>3];Ui(e+48|0);c=x[a+24>>2];w[c+1074450>>1]=f;w[c+1074448>>1]=f;x[c+1074428>>2]=d;x[c+1074392>>2]=-2;b=h+b;C[a+16>>3]=b;vl(e+60|0);fb=e- -64|0;return+b}}d=N()|0;vl(e+60|0)}Q(d|0);p()}function UP(a){var b=0,c=E(0),d=0,e=0,f=0,g=E(0),h=0,i=0,k=E(0),m=0,n=0,o=E(0);d=fb-16|0;fb=d;b=x[x[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=Ce(E(10),E(E(E(B[wb(e,0)>>2]*E(120))+E(-60))/E(20))),B[n+4232>>2]=o;k=E(E(b>>>0)/E(1e3));n=a,o=Ce(E(10),E(E(-1)/E(k*E(E(B[wb(e,1)>>2]*E(499.989990234375))+E(.009999999776482582))))),B[n+4236>>2]=o;n=a,o=Ce(E(10),E(E(-1)/E(k*E(E(B[wb(e,2)>>2]*E(2950))+E(50))))),B[n+4240>>2]=o;x[d+12>>2]=1325400064;c=E(Ce(E(10),E(E(E(B[wb(e,3)>>2]*E(60))+E(-60))/E(20)))*E(2147483648));b=(q(c),j(2));g=E(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){g=E(nx(E(-1))/E(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=SH(c);break a}b=(q(E(c*E(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),r())*C[h+3568>>3]+-1;m=i*i;c=E((C[479]*m+(C[480]*i+C[481]))*m+(+(f>>23)*C[478]+C[h+3576>>3]+i))}g=c}B[d+8>>2]=E(E(g*E(67108864))/E(.6931471824645996))+E(67108864);n=a,o=E(B[Pm(d+12|0,d+8|0)>>2]*E(4.656612873077393e-10)),B[n+4244>>2]=o;n=a,o=E(E(E(-1)/E(E(B[wb(e,4)>>2]*E(99))+E(1)))+E(1)),B[n+4248>>2]=o;c=E(E(E(B[wb(e,5)>>2]*E(4))*k)+E(2));c:{if(E(F(c))<E(2147483648)){h=~~c;break c}h=-2147483648}x[a+4252>>2]=h;fb=d+16|0}function uK(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=x[a+4>>2];h:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break h}c=ud(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=x[a+4>>2];i:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break i}c=ud(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(D(e,10)+c|0)-48|0;d=(e|0)<214748364;c=x[a+4>>2];j:{if((c|0)!=x[a+104>>2]){x[a+4>>2]=c+1;c=y[c|0];break j}c=ud(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=sua(e,d,10,0);d=b+c|0;c=hb;e=d-48|0;d=(b>>>0>d>>>0?c+1|0:c)-(d>>>0<48)|0;b=x[a+4>>2];l:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;c=y[b|0];break l}c=ud(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=x[a+4>>2];m:{if((b|0)!=x[a+104>>2]){x[a+4>>2]=b+1;b=y[b|0];break m}b=ud(a)}if(b-48>>>0<10){continue}break}}b=x[a+116>>2];if((b|0)>0|(b|0)>=0){x[a+4>>2]=x[a+4>>2]-1}hb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}x[a+4>>2]=x[a+4>>2]-1;break b}if(x[a+116>>2]<0){break a}}x[a+4>>2]=x[a+4>>2]-1}hb=-2147483648;return 0}function Bd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-80|0;fb=e;x[a+480180>>2]=b;c=dr(a);cr(e+12|0,c);f=x[e+24>>2];d=a+1074320|0;x[d>>2]=x[e+20>>2];x[d+4>>2]=f;d=x[e+16>>2];x[a+1074312>>2]=x[e+12>>2];x[a+1074316>>2]=d;if(!((b|0)==32|(c|0)!=32)){Yf(a+1074312|0,120)}iu(a+8|0,c);b=1;while(1){c=b&65535;if(c>>>0>z[a+480192>>1]){x[a+480184>>2]=0;x[a+480188>>2]=0;x[a+480236>>2]=65536;x[a+480228>>2]=48;x[a+480232>>2]=48;v[a+480268|0]=5;x[a+480260>>2]=16;x[a+480264>>2]=32767;x[a+480204>>2]=125e4;x[a+480208>>2]=0;x[a+480196>>2]=6;x[a+480200>>2]=256;x[a+1074304>>2]=0;x[a+1074308>>2]=0;w[a+480192>>1]=0;FA(a,4);d=fb+-64|0;fb=d;b=a+484344|0;ku(b);f=Sk(x[b>>2],x[b+4>>2]);c=hA(d+12|0,b);x[31785]=0;S(861,b|0,f|0,c|0);b=x[31785];x[31785]=0;a:{if((b|0)!=1){Dl(c);fb=d- -64|0;break a}a=N()|0;Dl(c);Q(a|0);p()}CU(a+484360|0);rf(a+1298308|0);rf(a+1298320|0);rf(a+1298332|0);b=e+12|0;Tb(b,0,68);b=gS(b);c=yb(a+1298344|0,b);yb(c+12|0,b+12|0);yb(c+24|0,b+24|0);yb(c+36|0,b+36|0);yb(c+48|0,b+48|0);d=x[b+64>>2];x[c+60>>2]=x[b+60>>2];x[c+64>>2]=d;LA(b);Wv(a+1298412|0);Gf(a+480248|0);if(x[a+480180>>2]&738230281){x[a+480208>>2]=x[a+480208>>2]|8388608}fb=e+80|0;return}c=((c<<2)+a|0)+900380|0;d=x[c>>2];if(d){Db(xv(d))}x[c>>2]=0;b=b+1|0;continue}}function dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];v=w[b+2>>1];y=w[b>>1];k=0;while(1){if((k|0)!=2){b=(k<<1)+o|0;x[(k<<2)+e>>2]=(((((((D(w[b-8>>1],v)+D(w[b-12>>1],y)|0)+D(w[b-4>>1],u)|0)+D(w[b>>1],t)|0)+D(w[b+4>>1],s)|0)+D(w[b+8>>1],r)|0)+D(w[b+12>>1],q)|0)+D(w[b+16>>1],p)|0)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Qb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function Dla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=Cg(k,b,l);o=hb;h=x[a+76>>2];b=x[a>>2];g=x[a+4>>2];bg(b,g,sf(k,m,d),hb);h=hb>>>0>h>>>0?d:0}f=a+112|0;s=x[a+24>>2];t=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;while(1){if(d){i=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;d=d-1|0;p=(((i&2147483647)<<1|b>>>31)&-2)+q|0;i=l;b:{c:while(1){d:{if((i|0)<=0){Qb(f,x[a+120>>2],x[a+124>>2]);g=x[a+116>>2];if(!g){break b}b=x[e+8>>2];i=((x[e+12>>2]&2147483647)<<1|b>>>31)&-2;j=0;b=0;break d}b=x[e+8>>2];g=((x[e+12>>2]&2147483647)<<1|b>>>31)&-2;b=0;j=0;while(1)if((b|0)==2){_d(f,j>>>3<<16>>16);Zd(f,4);Qb(e+8|0,n,o);i=i-1|0;continue c}else{j=(v[(b+g|0)+p|0]<<8)+j|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){j=(v[(b+i|0)+p|0]<<8)+j|0;b=b+1|0;continue}break}_d(f,j>>>3<<16>>16);Zd(f,g);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Ag(f,r);x[c>>2]=x[c>>2]+D(b,t);x[c+4>>2]=x[c+4>>2]+D(b,s);Qb(e,k,m);c=c+8|0;continue}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function xla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;q=x[a+16>>2];r=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);m=x[a+128>>2];a:{if(!m){l=x[a+8>>2];n=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];i=0;break a}b=x[a+12>>2];n=b;l=x[a+8>>2];o=Cg(l,b,m);p=hb;i=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];bg(b,f,sf(l,n,d),hb);i=hb>>>0>i>>>0?d:0}g=a+112|0;j=x[a+40>>2];k=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;o=i?o:0;p=i?p:0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+q|0;b=m;while(1)if((b|0)<=0){Qb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;_d(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);Zd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Ag(g,r);f=x[a+32>>2];k=x[a+28>>2]+k|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=f+j|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Qb(e,l,n);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue b}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;_d(g,(w[(h<<1|2)+f>>1]+w[f+((h&2147483646)<<1)>>1]|0)/8<<16>>16);Zd(g,4);Qb(e+8|0,o,p);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function u7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-368|0;fb=f;x[f+360>>2]=37;x[f+364>>2]=0;h=Rs(f+360|1,22485,x[c+4>>2]);x[f+316>>2]=f+320;a=Kd();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=nh(f+320|0,30,a,f+360|0,f+32|0);break a}C[f+48>>3]=e;g=nh(f+320|0,30,a,f+360|0,f+48|0)}x[f+80>>2]=1208;i=Ae(f+308|0,0,f+80|0);b=f+320|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Kd();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=oj(f+316|0,a,f+360|0,f);break f}C[f+16>>3]=e;g=oj(f+316|0,a,f+360|0,f+16|0)}if((g|0)==-1){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)==1){break d}break e}a=x[f+316>>2];Oe(i,a)}j=a+g|0;l=pj(a,j,x[c+4>>2]);x[f+68>>2]=1208;h=Ae(f+72|0,0,f+68|0);g:{h:{if((f+320|0)==(a|0)){g=f+80|0;break h}g=Ed(g<<3);if(!g){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)!=1){break e}a=N()|0;break g}Oe(h,g);b=a}a=f+60|0;$c(a,x[c+28>>2]);x[31785]=0;ga(1239,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[31785];x[31785]=0;i:{if((a|0)!=1){Zb(f+60|0);x[31785]=0;a=ea(1240,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break i}Kc(h);Kc(i);fb=f+368|0;break b}a=N()|0;Zb(f+60|0);break g}a=N()|0}Kc(h);break c}p()}a=N()|0}Kc(i);Q(a|0);p()}return a|0}function Qja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=fb-16|0;fb=i;d=x[b+1298304>>2];if(!xd(d)){e=fb-16|0;fb=e;c=Dc(12);x[31785]=0;d=R(960,c|0)|0;f=x[31785];x[31785]=0;a:{if((f|0)!=1){c=x[uf(e+12|0,d)>>2];fb=e+16|0;break a}a=N()|0;Db(c);Q(a|0);p()}x[i+12>>2]=c;c=b+1298304|0;e=i+12|0;_R(c,ie(e));KA(e);d=x[c>>2]}f=fb-32|0;fb=f;c=f+8|0;OR(c,a);x[31785]=0;O(961,f+20|0,c|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){tb(f+8|0);m=f,n=vb(x[d>>2]),x[m+4>>2]=n;l=vb(x[d+4>>2]);c=0;d=0;while(1){d:{h=x[f+4>>2];if(!Ib(h,l)){e:{if(!d){break e}c=x[d+4>>2];if(!c){break e}x[31785]=0;b=U(c|0,d|0,b|0,a|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}if(b){c=x[d>>2];x[b+4>>2]=c;if(c){x[c+8>>2]=b}x[d>>2]=b}x[a>>2]=b}tb(f+20|0);fb=f+32|0;break b}j=0;e=x[h>>2];if(x[e+32>>2]==x[a+16>>2]){j=x[e+36>>2]==x[a+20>>2]}x[31785]=0;O(962,f+8|0,e+8|0);e=x[31785];x[31785]=0;if((e|0)!=1){g=fb-16|0;fb=g;k=f+8|0;ue(g+8|0,k);ue(g,f+20|0);e=rR(x[g+8>>2],x[g+12>>2],x[g>>2],x[g+4>>2]);fb=g+16|0;tb(k);f:{if(!(!j|(e|0)!=0)){d=x[h>>2];c=3;break f}if((c|0)<2&j){d=x[h>>2];c=2;break f}e=!e&(c|0)<=0;d=e?x[h>>2]:d;c=e?1:c}Pe(f+4|0);continue}}break}d=N()|0;tb(f+20|0);break c}d=N()|0;tb(f+8|0)}Q(d|0);p()}fb=i+16|0}
function E7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=fb-208|0;fb=f;x[f+200>>2]=37;x[f+204>>2]=0;h=Rs(f+200|1,22485,x[c+4>>2]);x[f+156>>2]=f+160;a=Kd();a:{if(h){b=x[c+8>>2];C[f+40>>3]=e;x[f+32>>2]=b;g=nh(f+160|0,30,a,f+200|0,f+32|0);break a}C[f+48>>3]=e;g=nh(f+160|0,30,a,f+200|0,f+48|0)}x[f+80>>2]=1208;i=Ae(f+148|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Kd();f:{if(h){g=x[c+8>>2];C[f+8>>3]=e;x[f>>2]=g;g=oj(f+156|0,a,f+200|0,f);break f}C[f+16>>3]=e;g=oj(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)==1){break d}break e}a=x[f+156>>2];Oe(i,a)}j=a+g|0;l=pj(a,j,x[c+4>>2]);x[f+68>>2]=1208;h=Ae(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Ed(g<<1);if(!g){x[31785]=0;X(1209);a=x[31785];x[31785]=0;if((a|0)!=1){break e}a=N()|0;break g}Oe(h,g);b=a}a=f+60|0;$c(a,x[c+28>>2]);x[31785]=0;ga(1234,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=x[31785];x[31785]=0;i:{if((a|0)!=1){Zb(f+60|0);x[31785]=0;a=ea(23,k|0,g|0,x[f+68>>2],x[f+64>>2],c|0,d|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break i}Kc(h);Kc(i);fb=f+208|0;break b}a=N()|0;Zb(f+60|0);break g}a=N()|0}Kc(h);break c}p()}a=N()|0}Kc(i);Q(a|0);p()}return a|0}function P2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(kh(a,x[b+8>>2],e)){Hx(b,c,d);return}a:{if(kh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;if(x[b+44>>2]!=4){f=a+16|0;h=f+(x[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}w[b+52>>1]=0;Ex(x[f>>2],x[f+4>>2],b,c,c,1,e);if(y[b+54|0]){break d}e:{if(!y[b+53|0]){break e}if(y[b+52|0]){d=1;if(x[b+24>>2]==1){break c}g=1;if(y[a+8|0]&2){break e}break c}g=1;if(!(v[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}x[b+44>>2]=a;if(d&1){break a}}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}g=x[a+12>>2];h=a+16|0;zs(x[h>>2],x[a+20>>2],b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=x[a+8>>2];if(!(!(a&2)&x[b+36>>2]!=1)){while(1){if(y[b+54|0]){break a}zs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(y[b+54|0]|x[b+36>>2]==1){break a}zs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(y[b+54|0]|x[b+36>>2]==1&x[b+24>>2]==1){break a}zs(x[f>>2],x[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=fb-16|0;fb=l;x[l+12>>2]=b;q=Jf(a);while(1){if(Vg(b,c)){b=x[zb(l+8|0,q)>>2];k=qd(x[l+12>>2]);o=fb-16|0;fb=o;p=0;m=fb-16|0;fb=m;i=fb-32|0;fb=i;g=i+28|0;d=i+24|0;e=fb-16|0;fb=e;a:{b:{if(!mc(b,x[zb(e+12|0,mg(a))>>2])){f=y[k|0];j=x[k+4>>2];h=qd(b);n=y[h|0];h=x[h+4>>2];if(!uo(f,j,n,h)){break b}}x[e+12>>2]=b;f=zb(e+8|0,vb(x[a>>2]));c:{d=x[e+12>>2];if(!mc(d,x[f>>2])){d=x[zB(e+12|0)>>2];f=qd(d);h=y[f|0];n=x[f+4>>2];f=y[k|0];j=x[k+4>>2];if(!uo(h,n,f,j)){break c}}if(!x[b>>2]){x[g>>2]=b;break a}x[g>>2]=d;b=d+4|0;break a}b=UA(a,g,f,j);break a}if(uo(n,h,f,j)){d:{d=xB(b);if(!mc(d,x[zb(e+12|0,mg(a))>>2])){f=y[k|0];j=x[k+4>>2];h=qd(d);if(!uo(f,j,y[h|0],x[h+4>>2])){break d}}if(!x[b+4>>2]){x[g>>2]=b;b=b+4|0;break a}x[g>>2]=d;b=d;break a}b=UA(a,g,f,j);break a}x[g>>2]=b;x[d>>2]=b;b=d}fb=e+16|0;d=b;b=x[b>>2];if(!b){b=fb-16|0;fb=b;e=ec(a);g=i+12|0;e=zh(g,Dc(28),Kg(b+8|0,e));hC(x[e>>2]+16|0,k);r=ec(e),s=1,v[r+4|0]=s;fb=b+16|0;Xg(a,x[i+28>>2],d,x[i+12>>2]);b=ie(g);Xl(g);p=1}Wg(m+8|0,x[zb(i+12|0,b)>>2],p);fb=i+32|0;fb=m+16|0;zb(o+12|0,x[m+8>>2]);fb=o+16|0;b=x[Yg(l+12|0)>>2];continue}else{fb=l+16|0}break}}function Lia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0);g=w[d>>1];h=w[d+2>>1];a:{if((g|0)>(h|0)){break a}k=x[b>>2];i=oc(k,x[b+4>>2]);if(!i){break a}j=w[e>>1];if((j|0)<(g|0)|(h|0)<(j|0)|(i-1&65535)>>>0>(h-j&65535)>>>0|A[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(i|0)){break b}j=wb(k,f);f=f+1|0;if(!(B[j>>2]<E(0))){continue}break}return 0}f=0;l=B[c>>2];if(l<=E(0)){break a}w[a+28>>1]=g;w[a>>1]=1;m=a,n=TQ(i),w[m+30>>1]=n;B[a+32>>2]=F(l);vk(a+4|0,(h-g|0)+1|0);c=vb(x[b>>2]);h=vb(x[b+4>>2]);f=Ek(vb(x[a+4>>2]),w[e>>1]-w[d>>1]|0);g=fb-16|0;fb=g;b=fb-32|0;fb=b;Vl(b+24|0,c,h);Fk(b+16|0,x[b+24>>2],x[b+28>>2],f);c=cA(c,x[b+16>>2]);m=b,n=SQ(f,x[b+20>>2]),x[m+12>>2]=n;Td(g+8|0,c,b+12|0);fb=b+32|0;fb=g+16|0;c=x[a+4>>2];g=w[a+30>>1];h=w[a+28>>1];b=w[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;i=wb(c,b+g|0);m=wb(c,b),o=E(B[i>>2]/B[a+32>>2]),B[m>>2]=o;b=z[e>>1];continue}else{c=w[a+30>>1];e=w[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=x[a+4>>2];d=w[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=wb(b,f-h|0);m=wb(b,f-e|0),o=E(B[a+32>>2]*B[g>>2]),B[m>>2]=o;f=f+1|0;continue}else{kq(a)}break}}break}f=1}return f|0}function yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Sf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>A[c+20>>2]){break d}if(A[c+8>>2]<e>>>0){break c}h=x[c+28>>2];if(x[c+24>>2]-h>>>0<e>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}n=b+h|0;o=D(b,g);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{s=a,t=+(mn(De(Eg(C[(d+o<<3)+m>>3])*134217728))+od(Ft(k),21)|0)*7.450580596923828e-9,C[s+24>>3]=t;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=n<<1;r=(d<<2)+l|0;i=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}s=x[r>>2]+q|0,u=dd(j),w[s>>1]=u;d=d+1|0;continue}}}_(7264,9065,77,8745);p()}_(7229,9065,78,8745);p()}_(5917,9065,79,8745);p()}_(5887,9065,80,8745);p()}fb=a+32|0;fb=c- -64|0}function ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}l=x[a+16>>2];i=x[a+40>>2];j=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];o=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+l|0;b=(b>>>16&65520)+g|0;p=w[b+14>>1];q=w[b+12>>1];r=w[b+10>>1];s=w[b+8>>1];t=w[b+6>>1];u=w[b+4>>1];y=w[b+2>>1];z=w[b>>1];k=0;while(1){if((k|0)!=2){b=k+o|0;x[(k<<2)+e>>2]=(((((((D(v[b-4|0],y)+D(v[b-6|0],z)|0)+D(v[b-2|0],u)|0)+D(v[b|0],t)|0)+D(v[b+2|0],s)|0)+D(v[b+4|0],r)|0)+D(v[b+6|0],q)|0)+D(v[b+8|0],p)<<8)/32768;k=k+1|0;continue}break}j=j+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],j>>12);i=i+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i>>12);Qb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;c=fb+-64|0;fb=c;d=x[a>>2];a=x[d>>2];e=x[a+4>>2];x[c+40>>2]=x[a+20>>2];f=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=f;Sf(c+48|0,c+32|0,e);a=x[d+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[c+4>>2];if(f>>>0<=g>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(A[c+8>>2]<e>>>0){break c}i=x[c+28>>2];if(x[c+24>>2]-i>>>0<e>>>0){break b}l=b+12|0;m=x[c+16>>2];n=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}o=D(b,g);q=D(b+i|0,h);d=0;while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{s=a,t=+(mn(De(Eg(C[(d+o<<3)+n>>3])*134217728))+od(Ft(l),21)|0)*7.450580596923828e-9,C[s+24>>3]=t;x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;r=(d+q<<1)+m|0;j=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}s=r,u=dd(k),w[s>>1]=u;d=d+1|0;continue}}}_(7264,9065,77,8745);p()}_(7229,9065,78,8745);p()}_(5917,9065,79,8745);p()}_(5887,9065,80,8745);p()}fb=a+32|0;fb=c- -64|0}function II(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;a:{b:{while(1){j=x[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=v[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=y[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=y[j+2|0];i=y[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=y[j+3|0];m=y[j+2|0];k=y[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}x[f>>2]=c;x[a+12>>2]=i+j;f=x[a+8>>2]+4|0;x[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return b|0}function Ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=fb-48|0;fb=k;if(pg(x[b>>2],x[b+4>>2])>>>0>c>>>0){while(1){i=m&65535;if(i>>>0<=c>>>0){g=sg(x[b>>2],i);e=x[g>>2];if(Ib(e,x[g+4>>2])){n=k+28|0;e=vb(e);o=vb(x[sg(x[b>>2],i)+4>>2]);f=oV(k+8|0,d);l=fb-16|0;fb=l;x[l+12>>2]=e;while(1){if(Ib(e,o)){j=fb-16|0;fb=j;if(!(y[e+5|0]|y[e+3|0]!=4)){g=j+8|0;Kb(g,x[f>>2],z[f+14>>1]);Df(g,0);v[e+3|0]=0}h=y[e+2|0];if(!(y[e+4|0]|(h|0)!=11)){g=j+8|0;Kb(g,x[f>>2],z[f+14>>1]);Df(g,0);v[e+2|0]=0;h=0}a:{b:{if(!y[e|0]){Kb(j+8|0,x[f>>2],z[f+14>>1]);if(Hb(x[x[j+8>>2]>>2],x[j+12>>2])){break b}h=y[e+2|0]}i=y[e+3|0];g=j+8|0;Kb(g,x[f>>2],z[f+14>>1]);Df(g,(i|0)==4|(h|0)==11);h=y[e+3|0];break a}h=y[e+3|0];g=y[e+2|0];if(!(h|(g|0)==11)){v[e+5|0]=0;h=4;v[e+3|0]=4;break a}if(g|(h|0)==4){break a}v[e+4|0]=0;v[e+2|0]=11}c:{d:{e:{if(!(!y[f+16|0]|h)){v[e+3|0]=17;i=0;h=125;break e}i=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(y[e+5|0]){break c}i=1;h=6}v[e+5|0]=h}v[f+16|0]=i}e=z[f+14>>1]+1|0;w[f+14>>1]=z[f+12>>1]>(e&65535)>>>0?e:0;fb=j+16|0;e=x[ah(l+12|0)>>2];continue}break}mV(n,f);fb=l+16|0;$e(n);$e(f)}m=m+1|0;continue}break}}mV(a,d);fb=k+48|0}function iqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;jd(b,0);np(b);f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);a:{if(c&34){if(d){x[b+24>>2]=f;break a}g=b,h=Xe(zi(+(f+1408|0)/1536)*8363),x[g+24>>2]=h;break a}v[b+37|0]=(c|0)==16?f:f^128;v[b+36|0]=y[a+4|0]}v[e+15|0]=y[a+5|0];v[e+14|0]=64;g=b,h=y[Ub(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;d=y[a+6|0]|y[a+7|0]<<8;if(d>>>0<=256){w[b+28>>1]=d;w[b+34>>1]=z[b+34>>1]|32}x[b>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+4>>2]=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);x[b+8>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);d=y[a+20|0]|y[a+21|0]<<8;if(d&16){w[b+34>>1]=z[b+34>>1]|2;d=y[a+20|0]|y[a+21|0]<<8}if(d&32){w[b+34>>1]=z[b+34>>1]|4;d=y[a+20|0]|y[a+21|0]<<8}if(d&256){w[b+34>>1]=z[b+34>>1]|8;d=y[a+20|0]|y[a+21|0]<<8}if(d&512){w[b+34>>1]=z[b+34>>1]|16}v[b+38|0]=y[(y[a+22|0]&7)+38368|0];v[b+39|0]=y[a+23|0];v[b+40|0]=y[a+24|0];v[b+41|0]=y[a+25|0];if((c|0)==32){v[e+13|0]=y[a+26|0];v[e+12|0]=64;g=b,h=y[Ub(e+13|0,e+12|0)|0],w[g+32>>1]=h}x[b+12>>2]=y[a+27|0]|y[a+28|0]<<8|(y[a+29|0]<<16|y[a+30|0]<<24);x[b+16>>2]=y[a+31|0]|y[a+32|0]<<8|(y[a+33|0]<<16|y[a+34|0]<<24);fb=e+16|0}function N0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;if(!Ob(a,13752,4)){jd(b,32);np(b);c=d+8|0;ui(c,1,a+4|0);e=d+20|0;Ec(e,c);ye(b+43|0,e);tb(e);w[b+30>>1]=y[a+19|0]<<2;Pf(b+30|0,256);w[b+32>>1]=y[a+17|0];Pf(b+32|0,64);w[b+28>>1]=(y[a+47|0]&127)<<2;Pf(b+28|0,256);if(v[a+47|0]<0){w[b+34>>1]=z[b+34>>1]|32}c=y[a+18|0];if(c&16){w[b+34>>1]=z[b+34>>1]|2;c=y[a+18|0]}if(c&32){w[b+34>>1]=z[b+34>>1]|8;c=y[a+18|0]}if(c&64){w[b+34>>1]=z[b+34>>1]|4;c=y[a+18|0]}if(c<<24>>24<0){w[b+34>>1]=z[b+34>>1]|16}c=y[a+60|0]|y[a+61|0]<<8|(y[a+62|0]<<16|y[a+63|0]<<24);x[b+24>>2]=c?c>>>0<=256?256:c:8363;x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+12>>2]=y[a+64|0]|y[a+65|0]<<8|(y[a+66|0]<<16|y[a+67|0]<<24);x[b+16>>2]=y[a+68|0]|y[a+69|0]<<8|(y[a+70|0]<<16|y[a+71|0]<<24);Xk(b);v[b+38|0]=y[(y[a+79|0]&7)+38368|0];v[b+41|0]=y[a+76|0];v[b+40|0]=y[a+77|0]&127;v[b+39|0]=y[a+78|0];c=y[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}w[b+34>>1]=c|z[b+34>>1]}c=y[a+72|0]|y[a+73|0]<<8|(y[a+74|0]<<16|y[a+75|0]<<24)}fb=d+32|0;return c|0}function Pia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=x[a>>2];d=Sk(e,x[a+4>>2]);if(d>>>0<b>>>0){i=fb-32|0;fb=i;a:{b:{f=b-d|0;b=x[Ab(a)>>2];e=x[a+4>>2];c:{if(f>>>0<=(b-e|0)/52>>>0){gA(a,f,c);break c}h=Ab(a);d=YQ(a,Sk(x[a>>2],e)+f|0);j=Sk(x[a>>2],x[a+4>>2]);g=fb-16|0;fb=g;b=i+12|0;Gg(b+12|0,h);d:{if(!d){e=0;d=0;break d}XQ(g+8|0,d);e=x[g+12>>2];d=x[g+8>>2]}x[b>>2]=d;h=d+D(j,52)|0;x[b+8>>2]=h;x[b+4>>2]=h;k=Ac(b),l=d+D(e,52)|0,x[k>>2]=l;fb=g+16|0;x[31785]=0;S(931,b|0,f|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}g=fb-16|0;fb=g;c=zb(g+12|0,x[a+4>>2]);d=zb(g+8|0,x[a>>2]);f=zb(g+4|0,x[b+4>>2]);e=x[c>>2];h=x[d>>2];c=fb-16|0;fb=c;x[c+8>>2]=x[f>>2];x[c+12>>2]=e;while(1){f=x[c+8>>2];if(Pg(e,h)){d=fb-16|0;fb=d;x[d+12>>2]=f;x[d+12>>2]=x[d+12>>2]-52;fb=d+16|0;j=x[d+12>>2];d=e-52|0;e=Tl(j,d);x[e+20>>2]=x[d+20>>2];f=x[d+16>>2];x[e+12>>2]=x[d+12>>2];x[e+16>>2]=f;bW(e+24|0,d+24|0);Yc(e+36|0,d+36|0);x[e+48>>2]=x[d+48>>2];d=VQ(c+12|0);VQ(c+8|0);e=x[d>>2];continue}break}fb=c+16|0;x[b+4>>2]=f;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),Ac(b));x[b>>2]=x[b+4>>2];fb=g+16|0;WQ(b)}fb=i+32|0;break a}a=N()|0;WQ(b);Q(a|0);p()}return}if(b>>>0<d>>>0){ZQ(a,e+D(b,52)|0)}}function _L(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+8|0;mz(d,a);b=fb-96|0;fb=b;a=x[d+4>>2];eg(x[x[a>>2]-12>>2]+a|0,0);Yd(b+80|0,x[d+4>>2]);a:{b:{c=x[d+4>>2];if(!pk(x[(x[x[c>>2]-12>>2]+c|0)+16>>2])){a=ei(b- -64|0,-1,-1);if(!Un(x[b+88>>2],x[b+92>>2],x[a+8>>2],x[a+12>>2])){break b}}eg(c+x[x[c>>2]-12>>2]|0,0);break a}Ei(c,0,0,0);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(pk(x[a+16>>2])){eg(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+8>>2]=x[b+88>>2];x[b+12>>2]=a;a=x[b+84>>2];x[b>>2]=x[b+80>>2];x[b+4>>2]=a;Qm(c,b);a=x[d+4>>2];eg(x[x[a>>2]-12>>2]+a|0,0);break a}Ei(c,0,0,2);c=x[d+4>>2];a=x[x[c>>2]-12>>2]+c|0;if(pk(x[a+16>>2])){eg(a,0);c=x[d+4>>2];a=x[b+92>>2];x[b+24>>2]=x[b+88>>2];x[b+28>>2]=a;a=x[b+84>>2];x[b+16>>2]=x[b+80>>2];x[b+20>>2]=a;Qm(c,b+16|0);a=x[d+4>>2];eg(x[x[a>>2]-12>>2]+a|0,0);break a}Yd(b- -64|0,c);c=x[d+4>>2];c:{if(!pk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2])){a=ei(b+48|0,-1,-1);f=1;if(!Un(x[b+72>>2],x[b+76>>2],x[a+8>>2],x[a+12>>2])){break c}}eg(x[x[c>>2]-12>>2]+c|0,0);c=x[d+4>>2];f=0}a=x[b+92>>2];x[b+40>>2]=x[b+88>>2];x[b+44>>2]=a;a=x[b+84>>2];x[b+32>>2]=x[b+80>>2];x[b+36>>2]=a;Qm(c,b+32|0);a=x[d+4>>2];eg(x[x[a>>2]-12>>2]+a|0,0)}fb=b+96|0;fb=e+16|0;return f|0}function vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=0;i=fb-16|0;fb=i;if(wi(a+44|0)){n=x[a+44>>2];j=Hc(n,0);k=Hc(n,1);n=x[a+56>>2];t=Hc(n,0);n=Hc(n,1);u=B[wb(a+4208|0,1)>>2];x[i+12>>2]=d;s=x[a+4220>>2];q=E(E(1)/E(s>>>0));v=x[a+4216>>2];o=d;f=n;g=t;while(1){if(o){h=x[a+4224>>2];a:{if(s>>>0>h>>>0){x[i+8>>2]=s-h;r=x[Gb(i+12|0,i+8|0)>>2];m=0;b:{if(u<E(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break b}p=E(h>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){B[g>>2]=B[j>>2];B[f>>2]=B[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;x[i+12>>2]=o;break a}m=v-h|0;x[i+4>>2]=m;l=x[Gb(i+12|0,i+4|0)>>2];e=0;c:{if(u<E(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break c}p=E(m>>>0);B[g>>2]=q*E(B[j>>2]*p);B[f>>2]=q*E(B[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){x[g>>2]=0;x[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;x[i+12>>2]=o;e=h+l|0;l=e>>>0<v>>>0?e:0}x[a+4224>>2]=l;continue}else{Li(a,b,c,t,n,d)}break}}fb=i+16|0}function LR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Wb(x[a+484360>>2],y[a+484376|0]);f=Xc(x[c>>2],x[c+4>>2]);a:{while(1){e=b&65535;if(e>>>0>=f>>>0){break a}if(!$i(c,e)){b=b+1|0;continue}break}f=a+1074312|0;e=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(e|0)){KR(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){Fo(a+1298264|0,1);x[a+1074456>>2]=x[a+480200>>2];x[a+1074416>>2]=x[a+480196>>2];x[a+1074420>>2]=x[a+480204>>2];x[a+480208>>2]=x[a+480208>>2]&-769;fB(a+1074376|0);w[a+1074450>>1]=0;x[a+1074392>>2]=-2;b=a+1074428|0;x[b>>2]=0;x[b+4>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074376>>2]=0;x[a+1074380>>2]=0}else{Jo((D(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}v[c+797|0]=0;x[c+700>>2]=0;v[c+841|0]=0;v[c+805|0]=0;x[c+708>>2]=0;v[c+821|0]=0;x[c+764>>2]=0;v[c+819|0]=0;v[c+820|0]=0;Kb(d+8|0,f,23);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){v[c+807|0]=1;v[c+808|0]=0}v[c+839|0]=0;c=c+872|0;continue}break}w[a+1074450>>1]=b;w[a+1074446>>1]=0;b=a+1074424|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074392>>2]=-2;x[a+1074432>>2]=0;b=a+1074396|0;x[b>>2]=0;x[b+4>>2]=0;x[a+1074380>>2]=0}x[a+480208>>2]=x[a+480208>>2]&-769}fb=d+16|0}function Dda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=fb-2160|0;fb=b;cu(b+112|0);a:{b:{c:{f=x[c+4>>2];if(!f){a=ac(8);x[31785]=0;b=P(37,b+100|0,10463)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}g=x[c>>2];d=x[c+12>>2];e=x[c+8>>2];x[b+92>>2]=e;x[b+96>>2]=d;c=x[b+96>>2];x[b+40>>2]=x[b+92>>2];x[b+44>>2]=c;x[b+88>>2]=f;x[b+84>>2]=g;c=x[b+88>>2];x[b+32>>2]=x[b+84>>2];x[b+36>>2]=c;h=hM(b+32|0);if(h){c=b- -64|0;x[c>>2]=e;x[b+68>>2]=d;d=x[c+4>>2];x[b+24>>2]=x[c>>2];x[b+28>>2]=d;x[b+60>>2]=f;x[b+56>>2]=g;c=x[b+60>>2];x[b+16>>2]=x[b+56>>2];x[b+20>>2]=c;c=aM(b+16|0)}else{c=0}x[b+72>>2]=c;x[b+76>>2]=0;d=0;c=2048;while(1){if(c){e=ib[f|0](g,(b+112|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=gc(b+48|0,b+112|0,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a=hu(a,b+8|0,h?b+72|0:0);if(a+1>>>0>=3){a=ac(8);x[31785]=0;b=P(37,b+100|0,8077)|0;c=x[31785];x[31785]=0;if((c|0)!=1){nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a);break b}fb=b+2160|0;return a|0}c=N()|0;jc(a)}Q(c|0)}p()}function $2(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;x[d+12>>2]=0;h=a>>>0<=1?1:a;b=h;if(b>>>0<=4294967216){a:{if(b>>>0>=4294967216){x[31660]=48;a=0;break a}e=b>>>0<11?16:b+11&-8;c=Ed(e+28|0);a=0;if(!c){break a}b=c-8|0;b:{if(!(c&15)){a=b;break b}g=c-4|0;i=x[g>>2];a=(c+15&-16)-8|0;a=(a-b>>>0<=15?16:0)+a|0;c=a-b|0;f=(i&-8)-c|0;if(!(i&3)){b=x[b>>2];x[a+4>>2]=f;x[a>>2]=b+c;break b}x[a+4>>2]=f|x[a+4>>2]&1|2;f=a+f|0;x[f+4>>2]=x[f+4>>2]|1;x[g>>2]=c|x[g>>2]&1|2;f=b+c|0;x[f+4>>2]=x[f+4>>2]|1;mv(b,c)}b=x[a+4>>2];c:{if(!(b&3)){break c}c=b&-8;if(c>>>0<=e+16>>>0){break c}x[a+4>>2]=e|b&1|2;b=a+e|0;e=c-e|0;x[b+4>>2]=e|3;c=a+c|0;x[c+4>>2]=x[c+4>>2]|1;mv(b,e)}a=a+8|0}if(a){x[d+12>>2]=a}}fb=d+16|0;a=x[d+12>>2];if(!a){d:{b=0;a=x[125610];if(!a){x[125610]=502448;w[251225]=128;j=502448,k=Jx(502960),w[j>>1]=k;a=x[125610]}d=(h+3>>>2|0)+1|0;while(1){e:{if(!a|(a|0)==502960){a=0}else{e=z[a+2>>1];if(e>>>0>d>>>0){b=e-d|0;w[a+2>>1]=b;a=((b&65535)<<2)+a|0;w[a+2>>1]=d;w[a>>1]=0;a=a+4|0;break d}if((d|0)!=(e|0)){break e}d=z[a>>1];f:{if(!b){j=502440,k=Kx(d),x[j>>2]=k;break f}w[b>>1]=d}w[a>>1]=0;a=a+4|0}break d}b=a;a=Kx(z[a>>1]);continue}}}return a|0}function _ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=fb-32|0;fb=j;e=b;b=x[a>>2];h=D(eu(e,vb(b)),6)+b|0;a:{if(!c){break a}b=x[Ab(a)>>2];i=x[a+4>>2];if((b-i|0)/6>>>0>=c>>>0){b=c;e=(i-h|0)/6|0;if(e>>>0<c>>>0){dD(a,c-e|0,d);b=e;if((h|0)==(i|0)){break a}}l=fb-16|0;fb=l;f=x[a+4>>2];g=D((f-(D(c,6)+h|0)|0)/6|0,6)+h|0;m=nr(l+4|0,a,(i-g|0)/6|0);k=x[m+4>>2];e=g;while(1){if(e>>>0>=i>>>0){hc(m);e=h;if((g|0)!=(e|0)){g=g-e|0;ai(D((g|0)/-6|0,6)+f|0,e,g)}fb=l+16|0}else{Dv(k,e);k=k+6|0;x[m+4>>2]=k;e=e+6|0;continue}break}c=D(d>>>0>=e>>>0?A[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){a=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[e|0]=a;v[e+1|0]=a>>>8;v[e+2|0]=a>>>16;v[e+3|0]=a>>>24;a=y[c+4|0]|y[c+5|0]<<8;v[e+4|0]=a;v[e+5|0]=a>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Ab(a);f=VY(j+8|0,_C(a,Jk(x[a>>2],i)+c|0),(h-x[a>>2]|0)/6|0,b);UY(f,c,d);g=fb-16|0;fb=g;b=x[f+4>>2];e=zb(g+12|0,h);d=zb(g+8|0,x[a>>2]);c=zb(g+4|0,x[f+4>>2]);n=f,o=RY(x[e>>2],x[d>>2],x[c>>2]),x[n+4>>2]=o;n=f,o=bR(h,x[a+4>>2],x[f+8>>2]),x[n+8>>2]=o;wc(a,f+4|0);wc(a+4|0,f+8|0);wc(Ab(a),Ac(f));x[f>>2]=x[f+4>>2];fb=g+16|0;h=b;TY(f)}zb(j+28|0,h);fb=j+32|0}function mD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-16|0;fb=g;a:{if(b&4){break a}e=y[a+14|0];b:{if(e>>>0>=y[a+15|0]){break b}c=y[a+12|0];if(!(c&2)){break b}v[a+12|0]=c&251}if(!(y[a+12|0]&2)|e>>>0<=y[a+13|0]){break a}d=x[a>>2];c=x[a+4>>2];if(Od(d,c)>>>0<=e>>>0){break a}d=z[Nc(d,c,e)>>1];c=Nc(x[a>>2],x[a+4>>2],y[a+14|0]-1|0);e=y[a+14|0];if(z[c>>1]<(d-1|0)){e=z[Nc(x[a>>2],x[a+4>>2],e)>>1]-1&65535;d=Eq(a,e,64,64);c=zb(g+12|0,Ek(vb(x[a>>2]),y[a+14|0]));h=Yl(g+8|0,e,d&255);i=fb-32|0;fb=i;d=x[c>>2];c=x[a>>2];f=(wv(d,vb(c))<<2)+c|0;c=x[a+4>>2];c:{d:{if(c>>>0<A[Ab(a)>>2]){if((c|0)!=(f|0)){break d}zY(a,h);break c}d=Ab(a);d=hg(i+8|0,Tf(a,oc(x[a>>2],c)+1|0),f-x[a>>2]>>2,d);x[31785]=0;O(785,d|0,h|0);c=x[31785];x[31785]=0;if((c|0)!=1){f=ir(a,d,f);gg(d);break c}a=N()|0;gg(d);Q(a|0);p()}k=fb-16|0;fb=k;m=x[a+4>>2];d=(m-(f+4|0)|0)+f|0;l=th(k+4|0,a,c-d>>2);j=x[l+4>>2];e=d;while(1){if(c>>>0<=e>>>0){hc(l);hr(f,d,m);fb=k+16|0}else{Vo(j,z[e>>1]|z[e+2>>1]<<16);j=j+4|0;x[l+4>>2]=j;e=e+4|0;continue}break}v[f+2|0]=y[h+2|0];w[f>>1]=z[h>>1]}zb(i+28|0,f);fb=i+32|0;break a}v[a+14|0]=e-1}if((b|0)!=16777216){v[a+17|0]=255}fb=g+16|0}function Mla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;h=fb-16|0;fb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];v=m>>31;j=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=sua(l,u,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=sua(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=(x[h+12>>2]<<1)+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=(((((D(w[g+4>>1],w[e+10>>1])+D(w[g+2>>1],w[e+8>>1])|0)+D(w[g+6>>1],w[e+12>>1])|0)+D(w[g+8>>1],w[e+14>>1])|0)/2|0)+((((D(w[g-4>>1],w[e+2>>1])+D(w[g-6>>1],w[e>>1])|0)+D(w[g-2>>1],w[e+4>>1])|0)+D(w[g>>1],w[e+6>>1])|0)/2|0)|0)/16384<<8;e=n;g=sua(e,e>>31,m,v);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Qb(h+8|0,j,y);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function osa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;jd(b,32);Zo(b);f=b,g=ve((y[a+50|0]|y[a+51|0]<<8)<<16>>16)>>>2|0,w[f+32>>1]=g;if((ve((y[a+32|0]|y[a+33|0]<<8)<<16>>16)|0)>0){w[b+34>>1]=z[b+34>>1]|32;c=ve((y[a+32|0]|y[a+33|0]<<8)<<16>>16);e=c>>>24|0;d=(c<<8&-256)+2047|0;c=e&255;f=b,g=Bc(uua(d,d>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}c=$b(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24));x[b>>2]=c;d=$b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24));x[b+4>>2]=d;e=$b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))+$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))|0;x[b+8>>2]=e;if((Cb(y[a+34|0]|y[a+35|0]<<8)|0)==16){x[b+8>>2]=e>>>1;x[b+4>>2]=d>>>1;x[b>>2]=c>>>1}a:{b:{if($b(y[a+42|0]|y[a+43|0]<<8|(y[a+44|0]<<16|y[a+45|0]<<24))){c=z[b+34>>1];break b}c=z[b+34>>1];if($b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))>>>0>=3){break b}c=c&-3;break a}c=c|2}w[b+34>>1]=c;f=b,g=c&65531|Cb(y[a+30|0]|y[a+31|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=Cb(y[a+36|0]|y[a+37|0]<<8)<<1,x[f+24>>2]=g;c=ve((y[a+52|0]|y[a+53|0]<<8)<<16>>16);if(c){_l(b,+(c|0)/96);c=ve((y[a+52|0]|y[a+53|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function Wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;if(!y[a+4242|0]){Rz(a);a:{if(!y[a+4240|0]){break a}e=CA(x[a+16>>2]);if(e==C[a+4288>>3]){break a}C[a+4288>>3]=e;Zt(a)}f=a+4256|0;b:{if(y[a+4244|0]){if(C[f>>3]>1){x[f>>2]=0;x[f+4>>2]=1072693248}break b}i=(x[a+4232>>2]&-2)!=4;e=C[f>>3];c:{if(F(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Qz(a);e=C[a+4256>>3]}C[f>>3]=e-+(g|0)}e=0;d:{e:{switch(x[a+4232>>2]){case 0:e=Ti(C[f>>3]*6.283185307179586);break d;case 1:e=F(C[f>>3]+-.5)*-4+1;break d;case 2:e=C[f>>3];e=e+e+-1;break d;case 3:e=C[f>>3]<.5?-1:1;break d;case 4:e=C[a+4272>>3];break d;case 5:break e;default:break d}}e=C[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=C[a+4280>>3]*e+C[a+4272>>3]*(1-e)}C[h+8>>3]=(y[a+4241|0]?-e:e)*+B[a+4220>>2]+ +B[a+4224>>2];qT(h+8|0,1);g=Aj(a);f:{if(!g){break f}f=x[a+4236>>2];if(y[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|Zl(C[h+8>>3]*127)<<16,j=x[x[g>>2]+68>>2],ib[j](k|0,l|0)|0;break f}ib[x[x[g>>2]+44>>2]](g,f,E(C[h+8>>3]))}C[a+4256>>3]=C[a+4264>>3]*+(d>>>0)+C[a+4256>>3]}g=a;a=x[a+44>>2];Li(g,b,c,Hc(a,0),Hc(a,1),d);fb=h+16|0}function CY(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;a:{if(b>>>0>=22){v[d+14|0]=0;ae(a,0,d+14|0);break a}e=y[b+25280|0];b:{c:{switch(b-8|0){case 0:v[d+15|0]=c<<1;break b;case 4:v[d+15|0]=c+1>>>1;break b;case 5:v[d+15|0]=D(c>>>4|0,10)+(c&15);break b;case 6:d:{switch((c>>>4|0)-1|0){default:e=0;break b;case 0:v[d+13|0]=c&15;v[d+12|0]=14;f=d,g=y[Ub(d+13|0,d+12|0)|0]<<4|15,v[f+15|0]=g;e=29;break b;case 1:v[d+11|0]=c&15;v[d+10|0]=14;f=d,g=y[Ub(d+11|0,d+10|0)|0]|240,v[f+15|0]=g;e=29;break b;case 3:v[d+15|0]=c&15|48;break b;case 4:v[d+15|0]=c<<4^128;e=35;break b;case 5:v[d+15|0]=c&15|176;break b;case 6:v[d+15|0]=c&15|64;break b;case 8:e=15;v[d+15|0]=c&15;break b;case 9:v[d+15|0]=(c<<3&120)+8&240;e=24;break b;case 10:v[d+15|0]=(c&15)+1>>>1;e=24;break b;case 14:break d;case 11:case 12:case 13:break b}}e=10;break b;case 8:if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=(b>>>0>=15?15:b)<<4;break b}if(c>>>0<=239){v[d+15|0]=c<<2&48|15;break b}v[d+15|0]=c<<4|15;break b;case 9:break c;default:break b}}if(c>>>0<=223){b=c>>>2|0;v[d+15|0]=b>>>0>=15?15:b;break b}if(c>>>0>239){break b}v[d+15|0]=c>>>2&3|240}ae(a,e,d+15|0)}fb=d+16|0}function Cla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=fb-16|0;fb=e;o=x[a+16>>2];p=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);k=x[a+128>>2];a:{if(!k){j=x[a+8>>2];l=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];i=0;break a}b=x[a+12>>2];l=b;j=x[a+8>>2];m=Cg(j,b,k);n=hb;i=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];bg(b,f,sf(j,l,d),hb);i=hb>>>0>i>>>0?d:0}g=a+112|0;q=x[a+24>>2];r=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){f=x[e+4>>2];b=x[e>>2];x[e+8>>2]=b;x[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=k;while(1)if((b|0)<=0){Qb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;_d(g,(w[(h<<1|2)+f>>1]+w[((h&2147483646)<<1)+f>>1]|0)/8<<16>>16);Zd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Ag(g,p);x[c>>2]=x[c>>2]+D(b,r);x[c+4>>2]=x[c+4>>2]+D(b,q);Qb(e,j,l);c=c+8|0;continue b}else{h=x[e+8>>2];h=(x[e+12>>2]&2147483647)<<1|h>>>31;_d(g,(w[(h<<1|2)+f>>1]+w[((h&2147483646)<<1)+f>>1]|0)/8<<16>>16);Zd(g,4);Qb(e+8|0,m,n);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function Nla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];f=x[a+44>>2];q=x[a+16>>2];j=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=j;r=b+24|0;s=x[a+72>>2];k=x[a+68>>2];t=k>>31;l=x[a+64>>2];u=l>>31;m=x[a+60>>2];y=m>>31;j=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=sua(l,u,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=sua(k,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+q|0;e=(((e>>>16|0)+4&131064)<<1)+r|0;n=((((D(v[g+2|0],w[e+10>>1])+D(v[g+1|0],w[e+8>>1])|0)+D(v[g+3|0],w[e+12>>1])|0)+D(v[g+4|0],w[e+14>>1])<<8>>1)+(((D(v[g-2|0],w[e+2>>1])+D(v[g-3|0],w[e>>1])|0)+D(v[g-1|0],w[e+4>>1])|0)+D(v[g|0],w[e+6>>1])<<8>>1)|0)/16384<<8;e=n;g=sua(e,e>>31,m,y);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,o);Qb(h+8|0,j,z);f=f-(s&n)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+32>>2];s=x[a+28>>2];t=x[a+72>>2];n=x[a+68>>2];u=n>>31;o=x[a+64>>2];v=o>>31;p=x[a+60>>2];y=p>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);k=sua(o,v,e,e>>31);l=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38386>>1])+D(w[h-2>>1],w[e+38384>>1])|0)+D(w[h+2>>1],w[e+38388>>1])|0)+D(w[h+4>>1],w[e+38390>>1])|0)/16384<<8;e=h;e=sua(e,e>>31,p,y);k=e+k|0;m=hb+l|0;m=e>>>0>k>>>0?m+1|0:m;f=Xb(f,-16777216,16776704);e=sua(n,u,f,f>>31);l=e+k|0;f=hb+m|0;f=e>>>0>l>>>0?f+1|0:f;e=l+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+s|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+r|0;x[c+4>>2]=x[c+4>>2]+D(f,i>>12);Qb(g+8|0,z,A);e=e-(h&t)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=g+16|0}function Lra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=fb-48|0;fb=d;l=b+484344|0;m=b+480280|0;n=b+906300|0;while(1){a:{b:{c:{if(Mb(x[c>>2],x[c+8>>2],9)){f=d+43|0;Yq(c,f);e=Mg(c);d:{e:{if(!Ob(f,14105,4)){break e}if(!Ob(d+43|0,13752,4)){break e}if(!Ob(d+43|0,13928,4)){break e}if(!Ob(d+43|0,13933,4)){break e}if(Mb(x[c>>2],x[c+8>>2],e)){break d}}v[d+47|0]=j;Eh(c,8);break c}ce(d,c,e);f=ic(d+20|0,d);ub(d);e=m;f:{if(!Ob(d+43|0,13663,4)){while(1){if((e|0)==(l|0)){h=1;break a}x[31785]=0;h=R(154,f|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break f}v[e+8|0]=h;e=e+32|0;continue}}if(y[d+43|0]!=70){break b}g=y[d+44|0];k=(g|0)==88;g:{if(!k){if((g-48&255)>>>0>9){break b}e=v[d+45|0];if((e|0)>47){break g}break b}e=v[d+45|0];if((e|0)<48){break b}}if(e>>>0>57){break b}i=v[d+46|0];if((i|0)<48|(i|0)>57){break b}h=1;e=((k?-16:D(g,100)+48|0)+i|0)+D(e,10)&255;if(e>>>0>249){break a}e=rd(n,e);x[31785]=0;O(454,f|0,e|0);e=x[31785];x[31785]=0;if((e|0)!=1){break a}}a=N()|0;ub(f);Q(a|0);p()}v[d+47|0]=j}fD(a,h,d+47|0);fb=d+48|0;return}if(Ob(d+43|0,13679,4)){break a}x[b+1074308>>2]=0;j=1}ub(f);continue}}function cka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=fb-16|0;fb=i;x[i+12>>2]=b;o=Jf(a);while(1){if(Vg(b,c)){b=x[zb(i+8|0,o)>>2];j=qd(x[i+12>>2]);m=fb-16|0;fb=m;n=0;k=fb-16|0;fb=k;h=fb-32|0;fb=h;f=h+28|0;d=h+24|0;e=fb-16|0;fb=e;a:{b:{if(!mc(b,x[zb(e+12|0,mg(a))>>2])){g=y[j|0];l=y[qd(b)|0];if(!vo(g,l)){break b}}x[e+12>>2]=b;g=zb(e+8|0,vb(x[a>>2]));c:{d=x[e+12>>2];if(!mc(d,x[g>>2])){d=x[zB(e+12|0)>>2];l=y[qd(d)|0];g=y[j|0];if(!vo(l,g)){break c}}if(!x[b>>2]){x[f>>2]=b;break a}x[f>>2]=d;b=d+4|0;break a}b=VA(a,f,g);break a}if(vo(l,g)){d:{d=xB(b);if(!mc(d,x[zb(e+12|0,mg(a))>>2])){g=y[j|0];if(!vo(g,y[qd(d)|0])){break d}}if(!x[b+4>>2]){x[f>>2]=b;b=b+4|0;break a}x[f>>2]=d;b=d;break a}b=VA(a,f,g);break a}x[f>>2]=b;x[d>>2]=b;b=d}fb=e+16|0;d=b;b=x[b>>2];if(!b){b=fb-16|0;fb=b;e=ec(a);f=h+12|0;e=zh(f,Dc(24),Kg(b+8|0,e));yS(x[e>>2]+16|0,x[j>>2],x[j+4>>2]);p=ec(e),q=1,v[p+4|0]=q;fb=b+16|0;Xg(a,x[h+28>>2],d,x[h+12>>2]);b=ie(f);Xl(f);n=1}Wg(k+8|0,x[zb(h+12|0,b)>>2],n);fb=h+32|0;fb=k+16|0;zb(m+12|0,x[k+8>>2]);fb=m+16|0;b=x[Yg(i+12|0)>>2];continue}else{fb=i+16|0}break}}function T6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=fb-448|0;fb=a;x[a+440>>2]=c;x[a+444>>2]=b;x[a+20>>2]=1241;b=Ae(a+24|0,a+32|0,a+20|0);$c(a+16|0,x[e+28>>2]);x[31785]=0;h=R(1220,x[a+16>>2])|0;i=x[31785];x[31785]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31785]=0;c=na(1250,a+444|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(Cd(y[g+11|0])){vd(x[g>>2],0);Vd(g,0);break d}vd(g,0);Ke(g,0)}if(y[a+15|0]){x[31785]=0;c=P(1237,h|0,45)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}x[31785]=0;O(36,g|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}}x[31785]=0;d=P(1237,h|0,48)|0;c=x[31785];x[31785]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-4|0;c=x[b>>2];while(1){if(!((d|0)!=x[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}x[31785]=0;U(1255,g|0,c|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break c}break a}x[31785]=0;c=P(1225,a+444|0,a+440|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+444>>2];Zb(a+16|0);Kc(b);fb=a+448|0;return c|0}}}c=N()|0;Zb(a+16|0);Kc(b);Q(c|0);p()}function oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0,A=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];l=x[a+68>>2];t=l>>31;m=x[a+64>>2];u=m>>31;n=x[a+60>>2];y=n>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=sua(m,u,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=sua(l,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];k=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;o=(((D(v[g|0],w[e+38386>>1])+D(v[g-1|0],w[e+38384>>1])|0)+D(v[g+1|0],w[e+38388>>1])|0)+D(v[g+2|0],w[e+38390>>1])<<8)/16384<<8;e=o;g=sua(e,e>>31,n,y);k=k+g|0;e=hb+f|0;e=g>>>0>k>>>0?e+1|0:e;f=k+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Qb(h+8|0,z,A);f=f-(s&o)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function bT(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=x[b+64>>2];a:{b:{g=x[b+60>>2];f=z[b+68>>1];if(!((g|0)==-1&(f|0)==65535)){c:{d:{if((e|0)==-1){break d}e=a+1074312|0;if(Pb(e,68)){break d}if(h=Pb(e,103),i=0,j=(f|0)!=65535,j?h:i){break c}if(h=Pb(e,49),i=0,j=(f|0)!=65535,j?h:i){break c}e=x[b+64>>2];break b}if((f|0)!=65535){break c}w[b+68>>1]=z[b+72>>1]+1}if((g|0)==-1){x[b+60>>2]=0}f=Xc(x[c>>2],x[c+4>>2]);e=z[b+68>>1];if(f>>>0<=e>>>0){e=z[c+28>>1];w[b+68>>1]=e}e:{if(z[b+72>>1]==(e&65535)){break e}c=a+1074312|0;if(Pb(c,26)){break e}if(Pb(c,68)|x[a+480180>>2]==1){break e}c=z[a+480188>>1];e=0;while(1){if((c|0)==(e|0)){break e}v[(D(e,872)+b|0)+1457|0]=0;e=e+1|0;continue}}x[b+52>>2]=x[b+60>>2];if(d){e=1;if(y[a+480208|0]&32){break a}}w[b+74>>1]=z[b+68>>1];return 1}if((e|0)!=-1){break b}e=0;break a}x[b+52>>2]=e;w[b+74>>1]=z[b+72>>1];f:{if(!x[b+20>>2]){break f}c=x[a+480180>>2];if((c|0)==32){if(Pb(a+1074312|0,103)){break f}c=x[a+480180>>2]}if((c|0)==2){break f}x[b+52>>2]=x[b+52>>2]+1}e=0;if(A[b+64>>2]<A[Vb(x[a+484344>>2],z[b+70>>1])+12>>2]){break a}x[b+52>>2]=0;w[b+74>>1]=z[b+74>>1]+1;return 0}return e}function zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Sf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){if(A[b+20>>2]<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}h=x[b+28>>2];if(d>>>0>x[b+24>>2]-h>>>0){break b}k=x[b+16>>2];l=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}m=f+h|0;n=D(f,g);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c+n<<3)+l>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;o=m<<1;q=(c<<2)+k|0;i=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(i)<2147483648){j=~~i;break f}j=-2147483648}r=x[q>>2]+o|0,s=dd(j),w[r>>1]=s;c=c+1|0;continue}}}_(7264,9065,77,8745);p()}_(7229,9065,78,8745);p()}_(5917,9065,79,8745);p()}_(5887,9065,80,8745);p()}fb=a+32|0;fb=b- -64|0}function hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=(i<<1)+m|0;x[(i<<2)+e>>2]=(((((((D(w[b-8>>1],t)+D(w[b-12>>1],u)|0)+D(w[b-4>>1],s)|0)+D(w[b>>1],r)|0)+D(w[b+4>>1],q)|0)+D(w[b+8>>1],p)|0)+D(w[b+12>>1],o)|0)+D(w[b+16>>1],n)|0)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Qb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function gK(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=fb-16|0;fb=l;g=y[a|0];a:{if(!g){f=a;break a}f=a;b:{while(1){if(!pl(g<<24>>24)){break b}g=y[f+1|0];f=f+1|0;if(g){continue}break}break a}c:{g=g&255;switch(g-43|0){case 0:case 2:break c;default:break a}}j=(g|0)==45?-1:0;f=f+1|0}d:{if(!((c|16)!=16|y[f|0]!=48)){n=1;if((y[f+1|0]&223)==88){f=f+2|0;m=16;break d}f=f+1|0;m=c?c:8;break d}m=c?c:10}c=0;while(1){e:{g=-48;i=v[f|0];f:{if((i-48&255)>>>0<10){break f}g=-87;if((i-97&255)>>>0<26){break f}g=-55;if((i-65&255)>>>0>25){break e}}i=g+i|0;if((i|0)>=(m|0)){break e}Hf(l,m,0,0,0,k,h,0,0);g=1;g:{if(x[l+8>>2]|x[l+12>>2]){break g}o=sua(k,h,m,0);p=hb;if((p|0)==-1&(i^-1)>>>0<o>>>0){break g}h=p;k=i+o|0;h=k>>>0<i>>>0?h+1|0:h;n=1;g=c}f=f+1|0;c=g;continue}break}if(b){x[b>>2]=n?f:a}h:{i:{j:{if(c){x[31660]=68;a=d&1;j=a?0:j;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|j)){x[31660]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}x[31660]=68;break h}a=j^k;d=a-j|0;b=j>>31;e=(b^h)-((a>>>0<j>>>0)+b|0)|0}fb=l+16|0;hb=e;return d}function qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=fb+-64|0;fb=b;c=x[a>>2];a=x[c>>2];d=x[a+4>>2];x[b+40>>2]=x[a+20>>2];e=x[a+16>>2];x[b+32>>2]=x[a+12>>2];x[b+36>>2]=e;Sf(b+48|0,b+32|0,d);a=x[c+4>>2];d=x[a+8>>2];e=x[a+4>>2];c=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=c;c=x[b+52>>2];x[b+16>>2]=x[b+48>>2];x[b+20>>2]=c;x[b+8>>2]=x[a+8>>2];c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;a=fb-32|0;fb=a;a:{b:{c:{d:{g=x[b+4>>2];if(g>>>0>=e>>>0){h=x[b+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[b+8>>2]){break c}i=x[b+28>>2];if(d>>>0>x[b+24>>2]-i>>>0){break b}l=x[b+16>>2];m=x[b>>2];e:while(1){if((d|0)==(f|0)){break a}n=D(f,g);o=D(f+i|0,h);c=0;while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{C[a+24>>3]=C[(c+n<<3)+m>>3];x[a+16>>2]=0;x[a+20>>2]=-1074790400;x[a+8>>2]=0;x[a+12>>2]=1072693248;q=(c+o<<1)+l|0;j=De(C[Ug(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(F(j)<2147483648){k=~~j;break f}k=-2147483648}r=q,s=dd(k),w[r>>1]=s;c=c+1|0;continue}}}_(7264,9065,77,8745);p()}_(7229,9065,78,8745);p()}_(5917,9065,79,8745);p()}_(5887,9065,80,8745);p()}fb=a+32|0;fb=b- -64|0}function Do(a,b,c){var d=0,e=0,f=0,g=0;f=a+1074312|0;d=Pb(f,96);x[b+660>>2]=(d?0:x[b+660>>2])+c;e=x[a+480180>>2];d=x[b+84>>2];if(!(!(e&18)|d>>>0>c>>>0|(!(y[b+88|0]&2)|!d))){g=c;c=x[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(x[b+88>>2]&1&(e|0)==16384)|0;a:{b:{if(!zd(y[b+788|0])){if(!Pb(f,114)){break b}}d=x[b+656>>2];c:{if(!d){break c}e=y[b+788|0];if(!zd(e)){break c}if((z[_b(d+236|0,e-1|0)>>1]-1&65535)>>>0>=z[a+480190>>1]){break a}}if(y[a+480210|0]&32){d=c;c=x[b+660>>2];x[b+660>>2]=d+c}x[b>>2]=0;x[b+4>>2]=c;if((!(y[b+88|0]&2)|A[b+84>>2]>c>>>0)&A[b+76>>2]>c>>>0){break a}d:{if(!Pb(f,57)){c=x[a+480180>>2];if((c|0)!=16){break d}}x[b+700>>2]=0;x[b+88>>2]=x[b+88>>2]|2097152;return}if(!(c&1048581)){if(Pb(f,27)){if(y[a+480208|0]&4){c=x[b+76>>2];x[b>>2]=0;x[b+4>>2]=c;return}x[b>>2]=0;x[b+4>>2]=0;return}c=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=c;if(!(y[a+480208|0]&4)){break a}a=x[b+76>>2];if(a>>>0<5){break a}x[b>>2]=0;x[b+4>>2]=a-2;return}if(!(y[b+88|0]&2)|(c|0)!=1){break a}a=x[b+80>>2];x[b>>2]=0;x[b+4>>2]=a;return}if(!(x[a+480180>>2]&268582928)|A[b+76>>2]<=c>>>0){break a}x[b>>2]=0;x[b+4>>2]=c}}function I9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=fb-32|0;fb=f;m=x[d>>2];g=x[d+4>>2];x[f+28>>2]=g;k=b+36|0;d=m;while(1){a:{if(!g){break a}h=0;j=fb-32|0;fb=j;i=b+36|0;e=b+228|0;l=c&-4096;b:{c:{while(1){if((h|0)==16){break c}d:{g=x[wb(e,h)>>2];if(y[Dd(i,g)+8|0]){if(x[Dd(i,g)>>2]==(l|0)){break d}}h=h+1|0;continue}break}i=x[wb(e,h)>>2];h=e+(h<<2)|0;hr(e,h,h+4|0);o=wb(e,0),p=i,x[o>>2]=p;break b}h=x[wb(e,15)>>2];hr(e,b+288|0,b+292|0);o=wb(e,0),p=h,x[o>>2]=p;g=x[wb(e,0)>>2];e=Dd(i,g);x[e>>2]=l;gz(j+16|0,x[b+24>>2],g);i=x[x[b>>2]+44>>2];h=x[j+20>>2];x[j+8>>2]=x[j+16>>2];x[j+12>>2]=h;ib[i|0](j+24|0,b,l,j+8|0);x[e+4>>2]=x[j+28>>2];v[e+8|0]=1}fb=j+32|0;i=c-x[Dd(k,g)>>2]|0;x[f+12>>2]=4096-i;o=f,p=x[Gb(f+12|0,f+28|0)>>2],x[o+24>>2]=p;if(i>>>0<A[Dd(k,g)+4>>2]){e=x[Dd(k,g)+4>>2]-i|0}else{e=0}x[f+20>>2]=e;e=x[Gb(f+24|0,f+20|0)>>2];gz(f+12|0,x[b+24>>2],g);h=x[f+12>>2];gz(f+4|0,x[b+24>>2],g);Qi(h+i|0,e+(i+x[f+4>>2]|0)|0,d);g=x[f+28>>2]-e|0;x[f+28>>2]=g;n=e+n|0;if(e>>>0<A[f+24>>2]){break a}c=c+e|0;d=d+e|0;continue}break}bc(a,m,n);fb=f+32|0}function eua(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=fb-32|0;fb=g;v[g+16|0]=0;m=P$(g+20|0,d,g+16|0);f=x[m>>2];x[g+16>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=y[a|0];if(!(!i|(k|0)!=(e&255))){x[g+12>>2]=y[a+1|0];i=a+2|0;j=Gb(g+12|0,g+16|0);b:{k=b-2|0;if(!k){break b}j=x[j>>2];if(!(j&255)){break b}i=y[i|0];while(1){if(!(j&255)){break a}v[f|0]=i;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;j=j-1|0;continue}}v[f|0]=e;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;v[f|0]=k;h=x[g+16>>2]-1|0;x[g+16>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=x[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=v[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;v[c|0]=k;e=e-1|0;c=c+1|0;continue}break}dc(m);fb=g+32|0;return}n=y[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;v[l|0]=y[l|0]|D(f&n,257)>>>(h-j&7);b=b+1|0;l=b>>>0>=d>>>0;b=l?0:b;j=j+1|0;h=h+l|0;f=(f<<8|f)>>>1&255;continue}}}function fta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=fb-1072|0;fb=d;x[d+1068>>2]=c;o=d,q=be(b),v[o+8|0]=q;v[d+4|0]=1;c=d+8|0;g=y[af(c,d+4|0)|0];f=OD(c,b);l=lr(f);x[31785]=0;c=R(205,b|0)|0;e=x[31785];x[31785]=0;a:{if((e|0)!=1){x[d+4>>2]=c;x[d>>2]=536870911;vc(d+1068|0,x[Gb(d+4|0,d)>>2]<<3);x[31785]=0;m=x[d+1068>>2];k=P(344,a|0,m|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){x[31785]=0;c=8;h=P(161,f|0,8)|0;a=x[31785];x[31785]=0;b:{if((a|0)!=1){c:{o=xb(x[k>>2],0),q=h,v[o|0]=q;i=1;a=g;while(1){c=c&255;n=c>>>0<=9?9:c;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}x[31785]=0;j=P(161,f|0,c|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=xb(x[k>>2],i),q=h,v[o|0]=q;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=lr(f);x[31785]=0;P(152,b|0,((a-l|0)+3&-4)+l|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break b}}}c=N()|0;dc(k);break a}ub(f);fb=d+1072|0;return}c=N()|0;break a}c=N()|0}ub(f);Q(c|0);p()}function WX(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;g=z[c>>1];a:{if((d&255)>>>0<=4){while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!xf(a,f+15|0)){break a}d=y[f+15|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!xf(a,f+14|0)){break a}d=y[f+14|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!xf(a,f+13|0)){break a}d=y[f+13|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break a}}while(1){d=g<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;d=y[c|0];w[c>>1]=d;if(!d){if(!xf(a,f+12|0)){break a}d=y[f+12|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;w[c>>1]=y[c|0]}w[e>>1]=v[b|0]+(z[e>>1]<<1);d=z[c>>1]<<1;w[c>>1]=d;v[b|0]=(d&65534)>>>0>255;g=y[c|0];w[c>>1]=g;if(!g){if(!xf(a,f+11|0)){break a}d=y[f+11|0];w[c>>1]=d<<1|1;v[b|0]=d>>>7;g=y[c|0];w[c>>1]=g;if(y[b|0]){continue}break a}if(y[b|0]){continue}break}}fb=f+16|0}function V0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;xc(b);zp(a);a:{if(!Pw(b,d+60|0)){break a}if(!IF(d+60|0)){break a}b:{if(!c){break b}if(!Mb(x[b>>2],x[b+8>>2],$b(y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24))-28|0)){break a}fx(a);g=d,h=ex(),x[g+40>>2]=h;e=d+40|0;dx(hj(x[a+4>>2])+32|0,e);_r(e);c=x[hj(x[a+4>>2])+32>>2];f=y[d+64|0]|y[d+65|0]<<8|(y[d+66|0]<<16|y[d+67|0]<<24);x[31785]=0;S(189,e|0,b|0,$b(f)-28|0);b=x[31785];x[31785]=0;c:{d:{if((b|0)!=1){Fn(d+32|0,d+40|0);b=y[d+72|0]|y[d+73|0]<<8|(y[d+74|0]<<16|y[d+75|0]<<24);x[31785]=0;b=ba(190,x[d+32>>2],x[d+36>>2],c|0,$b(b)|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break d}Jc(d+40|0);e=0;if(!b){break a}le(d+16|0,x[c>>2],x[c+4>>2]);kf(d+24|0,x[d+16>>2],x[d+20>>2]);b=Jd(d+8|0);c=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=c;b=bx(d+40|0,x[d+24>>2],x[d+28>>2],d);hd(hj(x[a+4>>2])+12|0,b);ub(b);break b}e=ta(125240,24664)|0;b=gb;break c}e=ta(125240,24664)|0;b=gb;Jc(d+40|0)}e:{if(($(125240)|0)==(b|0)){break e}if(($(24664)|0)==(b|0)){break e}Q(e|0);p()}Y(e|0)|0;Z();e=0;break a}e=1}fb=d+96|0;return e|0}function ima(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;g=x[a+12>>2];f=g;a:{b:{c:{h=x[a+8>>2];d:{if((f|0)<=1&h>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&h>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&h>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&h>>>0>2147483648|f>>>0>1){break b}}g=b+196648|0;break a}g=b+131112|0;break a}g=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];m=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+j|0;b=(b>>>16&65520)+g|0;n=w[b+14>>1];o=w[b+12>>1];p=w[b+10>>1];q=w[b+8>>1];r=w[b+6>>1];s=w[b+4>>1];t=w[b+2>>1];u=w[b>>1];i=0;while(1){if((i|0)!=2){b=i+m|0;x[(i<<2)+e>>2]=(((((((D(v[b-4|0],t)+D(v[b-6|0],u)|0)+D(v[b-2|0],s)|0)+D(v[b|0],r)|0)+D(v[b+2|0],q)|0)+D(v[b+4|0],p)|0)+D(v[b+6|0],o)|0)+D(v[b+8|0],n)<<8)/32768;i=i+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],k);Qb(e+8|0,h,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function cqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;x[g+44>>2]=0;d=g+44|0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){YC(d);break a}lh(c+8|0,d);md(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0;b:{if(!XU(d)){break b}e=y[g+46|0];f=y[g+47|0];d=y[g+45|0];v[a+4|0]=1;h=d>>>3&3;c=(h|0)!=3;d=(d^-1)>>>1&3;f=f>>>0<192;w[a+2>>1]=z[(D(c,6)+(d<<1)|0)+25976>>1]<<f;i=D(D(y[(d+D(c,3)|0)+25752|0],z[((D(c,90)+D(d,30)|0)+(e>>>3&30)|0)+25760>>1]),1e3);e=e>>>1|0;e=((i>>>0)/z[(D(h,6)+(e&6)|0)+25952>>1]|0)+(e&1)<<(!d<<1);w[a>>1]=e;d=y[(f|c<<1)+25988|0];if(d+8>>>0>(e&65535)>>>0){break b}e=Tb(g,0,36);c=fb-32|0;fb=c;x[c+28>>2]=d+4;x[c+8>>2]=36;h=x[b>>2];i=x[b+8>>2];f=x[Gb(c+28|0,c+8|0)>>2];if(!Mb(h,i,f)){f=jf(b)}h=c+8|0;Nr(h,e);i=gc(c+16|0,x[c+8>>2],f);kc(c,x[b>>2],x[b+8>>2],x[i>>2],x[i+4>>2]);Nr(h,e);Tb(x[c+8>>2]+f|0,0,36-f|0);Yb(b,x[c+28>>2]);fb=c+32|0;b=2;c=d>>>0<=2?2:d;while(1){if((b|0)!=(c|0)){f=b+e|0;b=b+1|0;if(!y[f|0]){continue}break b}break}b=d+e|0;if(Ob(b,9586,4)){b=Ob(b,11137,4)}else{b=0}v[a+5|0]=!b}fb=g+48|0;return a|0}function rha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=0,p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=0,v=0,w=0,z=E(0);i=x[a+44>>2];h=Hc(i,0);i=Hc(i,1);j=x[a+56>>2];n=Hc(j,0);j=Hc(j,1);k=a+4208|0;g=oc(x[k>>2],x[a+4212>>2]);o=D(x[x[a+16>>2]+1074404>>2],y[a+4233|0]);e=o<<1;if(g>>>0<e>>>0){vk(k,e)}l=y[a+4232|0];a:{if(l){e=x[a+4220>>2];k=x[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=B[i>>2];e=e>>>0<o>>>0?e:0;g=e-o|0;g=((g|0)<0?e:g)<<1;v=wb(k,g);f=B[wb(k,g|1)>>2];s=B[h>>2];t=B[v>>2];p=E(s+t);B[n>>2]=p;q=E(r+f);B[j>>2]=q;f=E(0);m=E(0);b:{c:{switch(u|0){case 0:f=B[a+4224>>2];m=E(q*f);f=E(p*f);break b;case 1:case 2:f=B[a+4224>>2];m=E(p*f);f=E(q*f);break b;case 3:break c;default:break b}}f=E(E(E(E(s+r)*E(.5))+t)*B[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;i=i+4|0;h=h+4|0;g=e<<1;w=wb(k,g),z=E(F(f))<E(10000000195414814e-40)?E(0):f,B[w>>2]=z;w=wb(k,g|1),z=E(F(m))<E(10000000195414814e-40)?E(0):m,B[w>>2]=z;e=e+1|0;x[a+4220>>2]=e;l=l+1|0;continue}}e=h;h=d<<2;Gk(e,e+h|0,n);Gk(i,i+h|0,j)}h=a;a=x[a+56>>2];Li(h,b,c,Hc(a,0),Hc(a,1),d)}function hD(a,b,c,d){v[a+5|0]=c;a:{b:{switch((b|64)+-64|0){case 0:v[a+3|0]=c?37:0;return;case 1:v[a+3|0]=16;return;case 2:v[a+3|0]=12;return;case 3:v[a+3|0]=14;if(d){break a}v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 4:v[a+3|0]=11;return;case 5:v[a+3|0]=3;return;case 6:v[a+3|0]=2;return;case 7:v[a+3|0]=4;return;case 8:v[a+3|0]=5;return;case 9:v[a+3|0]=18;return;case 10:v[a+3|0]=1;return;case 11:v[a+3|0]=7;return;case 12:v[a+3|0]=6;return;case 13:v[a+3|0]=21;return;case 14:v[a+3|0]=22;return;case 15:v[a+3|0]=10;return;case 16:v[a+3|0]=29;return;case 17:v[a+3|0]=15;return;case 18:v[a+3|0]=8;return;case 19:v[a+3|0]=20;return;case 20:v[a+3|0]=17;return;case 21:v[a+3|0]=26;return;case 22:v[a+3|0]=23;return;case 23:v[a+3|0]=24;return;case 24:v[a+3|0]=9;return;case 25:v[a+3|0]=27;return;case 26:v[a+3|0]=31;return;case 28:v[a+3|0]=d?32:31;return;case 29:v[a+3|0]=d?33:0;return;case 27:v[a+3|0]=d?34:0;return;case 30:v[a+3|0]=d?35:0;return;case 31:v[a+3|0]=d?36:0;return;case 50:v[a+3|0]=d?25:0;return;case 51:v[a+3|0]=d?30:0;return;default:break b}}v[a+3|0]=0}}function oo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-80|0;fb=c;g=Nb(a);a=x[b+24>>2];a:{b:{if(Kj(x[a+484360>>2],x[a+484364>>2])){c:{d:{e:while(1){if(Kj(x[a+484360>>2],x[a+484364>>2])>>>0<=f>>>0){break d}d=ER(KX(c+40|0,1),f&255,0,0);x[31785]=0;e=x[d+12>>2];x[c+16>>2]=x[d+8>>2];x[c+20>>2]=e;e=x[d+20>>2];x[c+24>>2]=x[d+16>>2];x[c+28>>2]=e;e=x[d+4>>2];x[c+8>>2]=x[d>>2];x[c+12>>2]=e;V(1100,c+68|0,a|0,0,c+8|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}j=c,k=vb(x[c+68>>2]),x[j+36>>2]=k;d=vb(x[c+72>>2]);while(1){a=x[c+36>>2];if(!Ib(a,d)){f=f+1|0;Ui(c+68|0);a=x[b+24>>2];continue e}h=C[a>>3];e=x[a+16>>2];i=z[a+24>>1];a=c+40|0;x[a+16>>2]=f;x[a+12>>2]=i;x[a+8>>2]=e;C[a>>3]=h;x[31785]=0;O(1135,g|0,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){av(c+36|0);continue}break}break}a=N()|0;Ui(c+68|0);break b}fb=c+80|0;return}a=N()|0;break b}b=ac(8);x[31785]=0;d=P(37,c+40|0,7330)|0;a=x[31785];x[31785]=0;if((a|0)!=1){nc(b,d);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=N()|0;jc(b)}mf(g);Q(a|0)}p()}function Yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=E(0),f=0,g=E(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=E(0),t=0,u=0,v=0,w=0,y=0,z=E(0);a:{j=x[a+4272>>2];if(!j){break a}if(!wi(a+44|0)){break a}f=x[a+44>>2];l=Hc(f,0);m=Hc(f,1);u=x[a+4252>>2]-1|0;i=x[a+4268>>2];k=x[a+4256>>2];n=d;f=x[a+56>>2];q=Hc(f,0);o=q;r=Hc(f,1);p=r;while(1){if(n){e=B[m>>2];f=i<<1;h=wb(k,f);g=B[l>>2];B[h>>2]=g;y=wb(k,f|1),z=e,B[y>>2]=z;s=B[a+4276>>2];e=E(E(F(TP(E(E(E(F(g))+E(F(e)))*E(536870912)),31,5)))*E(4.656612873077393e-10));e=E(E(E(s-e)*B[(e>=s?4236:4240)+a>>2])+e);B[a+4276>>2]=e;g=B[a+4244>>2];e=E(E(E(E(g-(e<g?g:e))*B[a+4248>>2])+E(.9999998807907104))*E(2147483648));b:{if(e<E(4294967296)&e>=E(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=B[wb(k,t)>>2];h=f<<5;v=h;w=h|-2147483648;h=f>>>0<67108864;e=E(B[a+4232>>2]*E(E((h?v:w)>>>(h?31:32-(f>>>26|0)|0)>>>0)*E(4.656612873077393e-10)));B[o>>2]=g*e;y=p,z=E(B[wb(k,t|1)>>2]*e),B[y>>2]=z;i=((i?0:j)+i|0)-1|0;x[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{Li(a,b,c,q,r,d)}break}}}function RB(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;if(b&5){if((b|0)==1){e=sua(x[a+24>>2],0,8363,0);c=hb;e=e+4143|0;c=e>>>0<4143?c+1|0:c;f=a,g=Bc(uua(e,c,8287,0),hb),x[f+24>>2]=g}aV(a)}if(b&3){w[a+38>>1]=0;w[a+40>>1]=0;v[a+36|0]=0;w[a+34>>1]=z[a+34>>1]&65499}if(b&7){w[a+32>>1]=64;c=z[a+34>>1];if(c&8){e=x[a+16>>2];x[a+4>>2]=x[a+12>>2];x[a+8>>2]=e;c=c&16?c|6:c&65529|2}x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=c&65511}a:{if(!(b&4)){break a}c=z[a+34>>1];if(!(c&32)){w[a+28>>1]=128;w[a+34>>1]=c|32}If(a+40|0,15);If(a+41|0,63);if(!y[a+41|0]){break a}e=y[a+40|0];if(!e){break a}c=y[a+39|0];if(c){c=ej(Bc(((e<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}v[a+39|0]=c}b:{c:{if((b|0)!=4){if((b|0)==16777216){break b}if((b|0)!=32|y[a+38|0]!=2){break c}v[a+38|0]=3;break c}if(y[a+38|0]!=4){break c}v[a+38|0]=0}w[a+34>>1]=z[a+34>>1]&49151}d:{if(!(!(y[a+35|0]&2)|b&16777218)){x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;Vk(a,0,d);break d}if(!(y[a+35|0]&2)|(b|0)!=2){break d}a=a+68|0;b=xb(a,8);v[b|0]=y[b|0]&3;a=xb(a,9);v[a|0]=y[a|0]&3}fb=d+32|0}function Jo(a,b,c,d){var e=0,f=0;e=b+1074312|0;f=Pb(e,120);v[a+797|0]=f;v[a+802|0]=f;w[a+800>>1]=0;v[a+803|0]=0;v[a+804|0]=0;v[a+841|0]=0;v[a+805|0]=0;x[a+708>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+764>>2]=0;x[a+696>>2]=0;x[a+668>>2]=0;x[a+88>>2]=x[a+88>>2]|6144;if(Pb(e,23)){v[a+807|0]=1;v[a+808|0]=0}v[a+846|0]=0;v[a+839|0]=0;w[a+774>>1]=0;v[a+850|0]=255;x[a+660>>2]=0;v[a+851|0]=y[a+851|0]&224;No(a+788|0);x[a+84>>2]=0;x[a+76>>2]=0;x[a+80>>2]=0;x[a+700>>2]=0;x[a+656>>2]=0;x[a+104>>2]=0;x[a+92>>2]=0;x[a+96>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;v[a+845|0]=0;v[a+838|0]=0;v[a+821|0]=0;x[a+688>>2]=0;x[a+672>>2]=0;x[a+676>>2]=0;w[a+836>>1]=32512;v[a+819|0]=0;v[a+820|0]=0;w[a+842>>1]=0;x[a+28>>2]=0;x[a+32>>2]=0;x[a+20>>2]=0;x[a+24>>2]=0;x[a+852>>2]=0;x[a+856>>2]=0;v[a+851|0]=y[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=x[b+480280>>2];x[a+88>>2]=c;x[a+692>>2]=z[b+480284>>1];x[a+748>>2]=z[b+480286>>1];if(!(c&1024)){break a}x[a+88>>2]=c&-1025|d;break a}x[a+748>>2]=64;x[a+692>>2]=128;x[a+88>>2]=0}w[a+784>>1]=0;v[a+795|0]=0;v[a+796|0]=0}function iT(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{switch(y[a+480224|0]-1|0){default:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2]<<1;c=sua(c,c>>31,5e4,0);e=hb;b=x[_c(d+12|0,d+8|0)>>2];c=Fc(tua(c,e,b,b>>31),hb);break a;case 0:c=x[a+24620>>2];x[d+12>>2]=1;x[d+8>>2]=x[b+44>>2];c=sua(c,c>>31,1e4,0);e=hb;b=x[_c(d+12|0,d+8|0)>>2];c=Fc(tua(c,e,b,b>>31),hb);break a;case 1:break b}}f=60/(+A[b+44>>2]/1e4*(+(sua(x[b+32>>2],0,x[b+40>>2],0)>>>0)+ +(hb>>>0)*4294967296))*+A[a+24620>>2];c:{d:{c=x[a+484344>>2];e=z[b+70>>1];if(!Ge(c,x[a+484348>>2],e)){break d}c=Vb(c,e);if(!Ib(x[c+24>>2],x[c+28>>2])){break d}c=DR(c);break c}c=a+480248|0}e=x[c>>2];c=x[c+4>>2];if(!mc(e,c)){f=f*+A[wb(e,A[b+48>>2]%(oc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(F(f)<2147483648){c=~~f;break e}c=-2147483648}f=C[b+8>>3]+(f-+(c>>>0));C[b+8>>3]=f;if(f>=1){C[b+8>>3]=f+-1;c=c+1|0;break a}if(!(C[a+1074384>>3]<=-1)){break a}C[b+8>>3]=f+1;c=c-1|0}b=sua(x[a+480244>>2],0,c,0);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Bc((a&65535)<<16|b>>>16,a>>>16|0);fb=d+16|0;return a>>>0<=1?1:a}function Fha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb+-64|0;fb=b;g=Nb(a);x[31785]=0;W(963,g|0);a=x[31785];x[31785]=0;a:{if((a|0)!=1){a=43280;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==43592){fb=b- -64|0;return g|0}k:{h=gu(44);if(h){x[31785]=0;d=P(37,b+36|0,x[a+4>>2])|0;c=x[31785];x[31785]=0;if((c|0)==1){break k}c=x[a>>2];x[31785]=0;O(964,b+48|0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break j}x[31785]=0;e=P(37,b+12|0,x[a+8>>2])|0;f=x[31785];x[31785]=0;if((f|0)==1){break i}x[31785]=0;O(964,b+24|0,e|0);f=x[31785];x[31785]=0;if((f|0)==1){break h}x[31785]=0;c=ba(965,h|0,c|0,b+48|0,b+24|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break g}Eb(b+24|0);tb(e);Eb(b+48|0);tb(d);x[b+60>>2]=c;x[31785]=0;O(966,g|0,b+60|0);d=x[31785];x[31785]=0;if((d|0)==1){break b}v[c+40|0]=y[a+20|0];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;v[c+41|0]=y[c+41|0]&253|y[a+21|0]<<1}a=a+24|0;continue}break}a=N()|0;break c}a=N()|0;break d}a=N()|0;break e}a=N()|0;break f}a=N()|0;Eb(b+24|0)}tb(e)}Eb(b+48|0)}tb(d)}Db(h);break a}a=N()|0;break a}a=N()|0}sc(g);Q(a|0);p()}function Z6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=fb-144|0;fb=a;x[a+136>>2]=c;x[a+140>>2]=b;x[a+20>>2]=1241;b=Ae(a+24|0,a+32|0,a+20|0);$c(a+16|0,x[e+28>>2]);x[31785]=0;h=R(28,x[a+16>>2])|0;i=x[31785];x[31785]=0;if((i|0)!=1){a:{v[a+15|0]=0;e=x[e+4>>2];x[31785]=0;c=na(1242,a+140|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}rf(g);if(y[a+15|0]){x[31785]=0;c=P(29,h|0,45)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}x[31785]=0;O(118,g|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}}x[31785]=0;d=P(29,h|0,48)|0;c=x[31785];x[31785]=0;if((c|0)==1){break b}e=x[a+20>>2];h=e-1|0;c=x[b>>2];d=d&255;while(1){if(!((d|0)!=y[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}x[31785]=0;U(1248,g|0,c|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break c}break a}x[31785]=0;c=P(1210,a+140|0,a+136|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}if(c){x[f>>2]=x[f>>2]|2}c=x[a+140>>2];Zb(a+16|0);Kc(b);fb=a+144|0;return c|0}}}c=N()|0;Zb(a+16|0);Kc(b);Q(c|0);p()}function DL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=E(0),q=0;a:{if(y[b+21|0]){q=D(d,g);j=x[e>>2];l=x[f>>2];m=x[b>>2];b:{while(1){if((h|0)>0){if(x[a+1396>>2]<=9){tl(a)}g=x[a+1392>>2];k=w[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=y[k+x[b+8>>2]|0];x[a+1392>>2]=i>>>g;g=x[a+1396>>2]-g|0;x[a+1396>>2]=(g|0)>0?g:0;k=(g|0)<0?-1:k;break c}k=Em(a,b)}if((k|0)>=x[b+2092>>2]?y[b+23|0]:0){break a}if((k|0)<0){if(!y[a+1376|0]){b=0;if(x[a+1384>>2]){break b}}fc(a,21);return 0}else{g=0;n=D(d,l);m=((m+n|0)+j|0)>(q|0)?(q-n|0)+j|0:m;n=(m|0)>0?m:0;k=D(k,x[b>>2]);o=E(0);d:{if(y[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=E(o+B[x[b+28>>2]+(g+k<<2)>>2]);i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=o+B[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=x[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;B[i>>2]=B[i>>2]+E(B[x[b+28>>2]+(g+k<<2)>>2]+E(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}}break}x[e>>2]=j;x[f>>2]=l;b=1}return b}fc(a,21);return 0}_(7572,13279,1887,6606);p()}function $R(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=fb-32|0;fb=g;b=Mu(g);d=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);c=(f<<5)+a|0;e=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[c|0]=e;v[c+1|0]=e>>>8;v[c+2|0]=e>>>16;v[c+3|0]=e>>>24;v[c+4|0]=d;v[c+5|0]=d>>>8;v[c+6|0]=d>>>16;v[c+7|0]=d>>>24;d=y[b+28|0]|y[b+29|0]<<8|(y[b+30|0]<<16|y[b+31|0]<<24);e=y[b+24|0]|y[b+25|0]<<8|(y[b+26|0]<<16|y[b+27|0]<<24);v[c+24|0]=e;v[c+25|0]=e>>>8;v[c+26|0]=e>>>16;v[c+27|0]=e>>>24;v[c+28|0]=d;v[c+29|0]=d>>>8;v[c+30|0]=d>>>16;v[c+31|0]=d>>>24;d=y[b+20|0]|y[b+21|0]<<8|(y[b+22|0]<<16|y[b+23|0]<<24);e=y[b+16|0]|y[b+17|0]<<8|(y[b+18|0]<<16|y[b+19|0]<<24);v[c+16|0]=e;v[c+17|0]=e>>>8;v[c+18|0]=e>>>16;v[c+19|0]=e>>>24;v[c+20|0]=d;v[c+21|0]=d>>>8;v[c+22|0]=d>>>16;v[c+23|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8|(y[b+14|0]<<16|y[b+15|0]<<24);b=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[c+8|0]=b;v[c+9|0]=b>>>8;v[c+10|0]=b>>>16;v[c+11|0]=b>>>24;v[c+12|0]=d;v[c+13|0]=d>>>8;v[c+14|0]=d>>>16;v[c+15|0]=d>>>24;fb=g+32|0;f=f+1|0;continue}break}}function poa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=x[a>>2];c=Qd(d,x[a+4>>2]);if(c>>>0<b>>>0){h=fb-32|0;fb=h;c=b-c|0;b=x[Ab(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=fb-16|0;fb=d;c=dv(d+4|0,a,c);a=x[c+4>>2];b=x[c+8>>2];while(1){if((a|0)==(b|0)){hc(c);fb=d+16|0}else{dW(a);a=a+12|0;x[c+4>>2]=a;continue}break}break a}b=Ab(a);e=um(h+12|0,Dp(a,Qd(x[a>>2],d)+c|0),Qd(x[a>>2],x[a+4>>2]),b);b=fb-16|0;fb=b;c=cW(b+4|0,e+8|0,c);d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){dW(d);d=x[c>>2]+12|0;x[c>>2]=d;continue}break}ee(c);fb=b+16|0;g=fb-16|0;fb=g;c=zb(g+12|0,x[a+4>>2]);d=zb(g+8|0,x[a>>2]);b=zb(g+4|0,x[e+4>>2]);c=x[c>>2];d=x[d>>2];f=fb-16|0;fb=f;x[f+8>>2]=x[b>>2];x[f+12>>2]=c;while(1){b=x[f+8>>2];if(Pg(c,d)){bW(mx(b),On(c));b=tm(f+12|0);tm(f+8|0);c=x[b>>2];continue}break}fb=f+16|0;x[e+4>>2]=b;wc(a,e+4|0);wc(a+4|0,e+8|0);wc(Ab(a),Ac(e));x[e>>2]=x[e+4>>2];fb=g+16|0;b=x[e+4>>2];while(1){a=x[e+8>>2];if((a|0)!=(b|0)){a=a-12|0;x[e+8>>2]=a;eW(a);continue}break}a=x[e>>2];if(a){fs(e);Db(a)}}fb=h+32|0;return}if(b>>>0<c>>>0){fW(a,d+D(b,12)|0)}}function nQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=E(0);c=fb-80|0;fb=c;d=x[b>>2];b=x[b+4>>2];e=Jd(c+52|0);f=x[e+4>>2];x[c+8>>2]=x[e>>2];x[c+12>>2]=f;b=bx(c+60|0,d,b,c+8|0);x[31785]=0;d=R(205,b|0)|0;e=x[31785];x[31785]=0;a:{if((e|0)==1){break a}x[31785]=0;d=U(958,b|0,c+19|0,d|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Ob(c+19|0,18443,4)|(y[c+23|0]|y[c+24|0]<<8|(y[c+25|0]<<16|y[c+26|0]<<24))){break b}g=a,h=Ld((l(2,y[c+27|0]|y[c+28|0]<<8|(y[c+29|0]<<16|y[c+30|0]<<24)),r()),E(0)),B[g+4220>>2]=h;g=a,h=Ld((l(2,y[c+31|0]|y[c+32|0]<<8|(y[c+33|0]<<16|y[c+34|0]<<24)),r()),E(0)),B[g+4224>>2]=h;g=a,h=Ld((l(2,y[c+35|0]|y[c+36|0]<<8|(y[c+37|0]<<16|y[c+38|0]<<24)),r()),E(0)),B[g+4228>>2]=h;d=y[c+39|0]|y[c+40|0]<<8|(y[c+41|0]<<16|y[c+42|0]<<24);if(d>>>0<=5){x[a+4232>>2]=d}x[a+4236>>2]=y[c+43|0]|y[c+44|0]<<8|(y[c+45|0]<<16|y[c+46|0]<<24);v[a+4240|0]=y[c+47|0]!=0;v[a+4241|0]=y[c+48|0]!=0;v[a+4242|0]=y[c+49|0]!=0;v[a+4243|0]=y[c+50|0]!=0;v[a+4244|0]=y[c+51|0]!=0;_t(a)}ub(b);fb=c+80|0;return}a=N()|0;ub(b);Q(a|0);p()}function jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31785]=0;W(1030,a|0);e=x[31785];x[31785]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}x[31785]=0;W(1006,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break e}e=0;x[31785]=0;W(1031,c|0);f=x[31785];x[31785]=0;if((f|0)==1){break e}a=Tb(c,0,d);if(!y[b|0]){break b}if(li(b,47600)|(d|0)!=8){break d}x[a+4>>2]=1032;x[a>>2]=1033;break c}Y(T(0)|0)|0;x[31785]=0;V(992,12365,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();return 0}if(!(li(b,47612)|(d|0)!=64)){x[a+60>>2]=1034;x[a+56>>2]=1035;x[a+52>>2]=1036;x[a+48>>2]=1037;x[a+44>>2]=1038;x[a+40>>2]=1039;x[a+36>>2]=1040;x[a+32>>2]=1041;x[a+28>>2]=1042;x[a+24>>2]=1043;x[a+20>>2]=1044;x[a+16>>2]=1045;x[a+12>>2]=1046;x[a+8>>2]=1047;x[a+4>>2]=1048;x[a>>2]=1049;break c}if(!(li(b,47624)|(d|0)!=24)){x[a+20>>2]=1050;x[a+16>>2]=1051;x[a+12>>2]=1052;x[a+8>>2]=1053;x[a+4>>2]=1054;x[a>>2]=1055;break c}if(li(b,47637)|(d|0)!=4){break b}x[a>>2]=1056}e=1}return e|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Jha(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=E(0),h=0,i=0;c=fb-32|0;fb=c;a:{d=x[a+20>>2];b:{if(!d){break b}x[d+148>>2]=-1;h=c,i=ib[x[x[a>>2]+40>>2]](a)|0,x[h+16>>2]=i;x[c+8>>2]=1073741822;f=x[Gb(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=x[a+20>>2];d=0;x[31785]=0;O(290,e+4|0,b+4|0);b=x[31785];x[31785]=0;c:{d:{if((b|0)!=1){b=x[a+20>>2];le(c+8|0,x[b+4>>2],x[b+8>>2]);x[c>>2]=0;x[c+4>>2]=0;e=x[c+12>>2];b=c+16|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=e;e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;e=fb-16|0;fb=e;x[e+12>>2]=0;kQ(b,e+12|0);fb=e+16|0;b=x[x[a>>2]+184>>2];x[31785]=0;O(b|0,a|0,-1);b=x[31785];x[31785]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=x[x[a>>2]+188>>2];x[31785]=0;W(d|0,a|0);d=x[31785];x[31785]=0;if((d|0)!=1){break b}break d}b=x[x[a>>2]+48>>2];x[31785]=0;g=E(_a(b|0,a|0,d|0));b=x[31785];x[31785]=0;if((b|0)!=1){B[c+8>>2]=g;d=d+1|0;kQ(c+16|0,c+8|0);continue}break}d=T(125240)|0;break c}d=T(125240)|0;break c}d=T(125240)|0}if((gb|0)!=($(125240)|0)){break a}Y(d|0)|0;So(x[a+20>>2]+4|0);Z()}fb=c+32|0;return}Q(d|0);p()}function Ema(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];w=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=sua(n,u,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=sua(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=x[h+12>>2]+p|0;k=v[g|0];k=((D(v[g+1|0]-k|0,x[h+8>>2]>>>10&4194048)|0)/16384<<8)+(k<<16)|0;e=k;g=sua(e,e>>31,o,w);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Qb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function zla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=Cg(k,b,l);o=hb;h=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];bg(b,f,sf(k,m,d),hb);h=hb>>>0>h>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;h=h-1|0;b=h;n=b?n:0;o=b?o:0;f=(f<<1)+p|0;b=l;while(1)if((b|0)<=0){Qb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){_d(g,w[f+(x[e+12>>2]<<1)>>1]/4<<16>>16);Zd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Ag(g,q);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Qb(e,k,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue b}else{_d(g,w[f+(x[e+12>>2]<<1)>>1]/4<<16>>16);Zd(g,4);Qb(e+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function Dma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0;h=fb-16|0;fb=h;e=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+32>>2];r=x[a+28>>2];s=x[a+72>>2];m=x[a+68>>2];t=m>>31;n=x[a+64>>2];u=n>>31;o=x[a+60>>2];v=o>>31;y=x[a+8>>2];z=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=sua(n,u,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=sua(m,t,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;l=g;g=(x[h+12>>2]<<1)+p|0;k=w[g>>1];k=k+((D(w[g+2>>1]-k|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=k;g=sua(e,e>>31,o,v);l=g+l|0;e=hb+f|0;e=g>>>0>l>>>0?e+1|0:e;f=l+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;j=j+r|0;x[c>>2]=D(e,j>>12)+x[c>>2];i=i+q|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,e);Qb(h+8|0,y,z);f=f-(k&s)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=e;x[a+44>>2]=b;x[a+24>>2]=i>>12;fb=h+16|0}function IW(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-80|0;fb=c;x[c+72>>2]=0;x[c+76>>2]=0;b=c- -64|0;x[b>>2]=0;x[b+4>>2]=0;x[c+56>>2]=0;x[c+60>>2]=0;x[c+48>>2]=0;x[c+52>>2]=0;WB(a,_U(a),c+48|0);b=pc(c+40|0,14321);qf(Me(a,0),x[b>>2],x[b+4>>2]);b=pc(c+32|0,14425);qf(Me(a,1),x[b>>2],x[b+4>>2]);b=pc(c+24|0,5516);qf(Me(a,3),x[b>>2],x[b+4>>2]);b=pc(c+16|0,15913);qf(Me(a,4),x[b>>2],x[b+4>>2]);b=pc(c+8|0,9285);qf(Me(a,8),x[b>>2],x[b+4>>2]);e=Me(a+288|0,0);b=fb-16|0;fb=b;d=e;e=pc(b+8|0,4952);qf(d,x[e>>2],x[e+4>>2]);fb=b+16|0;e=a+800|0;b=0;a=fb+-64|0;fb=a;a:{b:{while(1){if((b|0)==128){break a}x[a+60>>2]=b<<3;c:{d:{if(b>>>0<=15){bw(a+28|0,4104);x[31785]=0;O(292,a+16|0,a+60|0);d=x[31785];x[31785]=0;if((d|0)==1){break c}x[31785]=0;S(293,a+40|0,a+28|0,a+16|0);d=x[31785];x[31785]=0;if((d|0)!=1){d=a+40|0;ue(a+52|0,d);qf(Me(e,b),x[a+52>>2],x[a+56>>2]);tb(d);tb(a+16|0);Eb(a+28|0);break d}b=N()|0;tb(a+16|0);break b}d=pc(a+8|0,22485);qf(Me(e,b),x[d>>2],x[a+12>>2])}b=b+1|0;continue}break}b=N()|0}Eb(a+28|0);Q(b|0);p()}fb=a- -64|0;fb=c+80|0}function fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Qb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function uua(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(b){if(!c){break k}if(!d){break j}e=G(d)-G(b)|0;if(e>>>0<=31){break i}break c}if((d|0)==1|d>>>0>1){break c}hb=0;a=(a>>>0)/(c>>>0)|0;break a}if(!a){break h}if(!d|d-1&d){break g}a=b>>>rua(d)|0;hb=0;break a}if(!(c-1&c)){break f}h=(G(c)+33|0)-G(b)|0;g=0-h|0;break d}h=e+1|0;g=63-e|0;break d}hb=0;a=(b>>>0)/(d>>>0)|0;break a}e=G(d)-G(b)|0;if(e>>>0<31){break e}break c}if((c|0)==1){break b}d=rua(c);c=d&31;if((d&63)>>>0>=32){a=b>>>c|0}else{e=b>>>c|0;a=((1<<c)-1&b)<<32-c|a>>>c}hb=e;break a}h=e+1|0;g=63-e|0}e=h&63;f=e&31;if(e>>>0>=32){e=0;i=b>>>f|0}else{e=b>>>f|0;i=((1<<f)-1&b)<<32-f|a>>>f}g=g&63;f=g&31;if(g>>>0>=32){b=a<<f;a=0}else{b=(1<<f)-1&a>>>32-f|b<<f;a=a<<f}if(h){f=d-1|0;g=c-1|0;m=(g|0)!=-1?f+1|0:f;while(1){j=e<<1|i>>>31;e=i<<1|b>>>31;f=m-(j+(e>>>0>g>>>0)|0)>>31;k=c&f;i=e-k|0;e=j-((d&f)+(e>>>0<k>>>0)|0)|0;b=b<<1|a>>>31;a=l|a<<1;l=f&1;h=h-1|0;if(h){continue}break}}hb=b<<1|a>>>31;a=l|a<<1;break a}a=0;b=0}hb=b}return a}function eja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;jd(c,0);w[d+14>>1]=y[a+36|0]|y[a+37|0]<<8;w[d+12>>1]=32767;g=c,h=(z[Mc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,w[g+28>>1]=h;w[d+10>>1]=y[a+38|0]|y[a+39|0]<<8;w[d+8>>1]=32767;g=c,h=(z[Mc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,w[g+30>>1]=h;w[c+32>>1]=64;x[c>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+4>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+8>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[c+24>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);e=y[b+166|0];if(e>>>0<=4){v[c+38|0]=y[e+41418|0]}e=y[b+167|0]|y[b+168|0]<<8;v[c+39|0]=e;f=(y[b+171|0]|y[b+172|0]<<8)>>>4|0;v[c+41|0]=f;b=(y[b+169|0]|y[b+170|0]<<8)>>>2|0;v[c+40|0]=b;if((b|f)&255){v[c+39|0]=e^-1}b=y[a+40|0]|y[a+41|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+40|0]|y[a+41|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+40|0]|y[a+41|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+40|0]|y[a+41|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}fb=d+16|0}function Tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=ig(1,2);b=hb;s=b;Qb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];v=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=w[(x[g+12>>2]<<1)+r>>1]<<8;e=p;e=sua(e,e>>31,o,A);k=hb;h=e;e=Xb(b,-16777216,16776704);e=sua(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Xb(f,-16777216,16776704);e=sua(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Qb(g+8|0,B,C);e=e-(v&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Dg(a,l,s);fb=g+16|0}function xL(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=a;d=fb-208|0;fb=d;x[d+8>>2]=1;x[d+12>>2]=0;h=b<<2;a:{if(!h){break a}x[d+16>>2]=4;x[d+20>>2]=4;a=4;b=4;e=2;while(1){g=a;a=(a+b|0)+4|0;x[(d+16|0)+(e<<2)>>2]=a;e=e+1|0;b=g;if(a>>>0<h>>>0){continue}break}g=(f+h|0)-4|0;b:{if(g>>>0<=f>>>0){e=1;a=1;b=0;break b}e=1;a=1;while(1){c:{if((e&3)==3){Uy(f,c,a,d+16|0);ut(d+8|0,2);a=a+2|0;break c}b=a-1|0;d:{if(A[(d+16|0)+(b<<2)>>2]>=g-f>>>0){tt(f,c,e,x[d+12>>2],a,0,d+16|0);break d}Uy(f,c,a,d+16|0)}if((a|0)==1){st(d+8|0,1);a=0;break c}st(d+8|0,b);a=1}e=x[d+8>>2]|1;x[d+8>>2]=e;f=f+4|0;if(g>>>0>f>>>0){continue}break}b=x[d+12>>2]}tt(f,c,e,b,a,0,d+16|0);if(!((a|0)!=1|(e|0)!=1|b)){break a}while(1){e:{if((a|0)<=1){g=rL(e,b);ut(d+8|0,g);b=x[d+12>>2];e=x[d+8>>2];a=a+g|0;break e}e=d+8|0;st(e,2);x[d+8>>2]=x[d+8>>2]^7;ut(e,1);b=f-4|0;h=d+16|0;g=a-2|0;tt(b-x[h+(g<<2)>>2]|0,c,x[d+8>>2],x[d+12>>2],a-1|0,1,h);st(e,1);e=x[d+8>>2]|1;x[d+8>>2]=e;a=b;b=x[d+12>>2];tt(a,c,e,b,g,1,h);a=g}f=f-4|0;if((a|0)!=1|(e|0)!=1|b){continue}break}}fb=d+208|0}function qM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Sf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=h+j|0;o=D(e,h);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=wb(x[b>>2],a);i=d;d=x[(a+o<<2)+m>>2]+(x[d>>2]>>1)|0;q=d;d=Gt(k)+d&-4096;x[i>>2]=q-d;i=x[(a<<2)+l>>2]+(n<<1)|0;d=od(d|2048,12);d=(d|0)>=32767?32767:d;w[i>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7264,9065,33,8778);p()}_(7229,9065,34,8778);p()}_(5917,9065,35,8778);p()}_(5887,9065,36,8778);p()}fb=c- -64|0}function kM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Sf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];e=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=e;e=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=e;x[c+8>>2]=x[a+8>>2];e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a:{b:{c:{d:{e=x[c+4>>2];if(g>>>0<=e>>>0){i=x[c+20>>2];if(g>>>0>i>>>0){break d}if(f>>>0>A[c+8>>2]){break c}j=x[c+28>>2];if(f>>>0>x[c+24>>2]-j>>>0){break b}k=b+12|0;l=x[c+16>>2];m=x[c>>2];e:while(1){if((f|0)==(h|0)){break a}n=D(e,h);o=D(h+j|0,i);a=0;while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{d=wb(x[b>>2],a);q=d;d=x[(a+n<<2)+m>>2]+(x[d>>2]>>1)|0;r=d;d=Gt(k)+d&-4096;x[q>>2]=r-d;d=od(d|2048,12);d=(d|0)>=32767?32767:d;w[(a+o<<1)+l>>1]=(d|0)<=-32768?-32768:d;a=a+1|0;continue}}}_(7264,9065,33,8778);p()}_(7229,9065,34,8778);p()}_(5917,9065,35,8778);p()}_(5887,9065,36,8778);p()}fb=c- -64|0}function Uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0,B=0,C=0;g=fb-16|0;fb=g;r=x[a+16>>2];l=ig(1,2);b=hb;s=b;Qb(a,l,b);f=x[a+48>>2];i=x[a+40>>2];j=x[a+36>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+32>>2];u=x[a+28>>2];w=x[a+72>>2];m=x[a+68>>2];y=m>>31;n=x[a+64>>2];z=n>>31;o=x[a+60>>2];A=o>>31;B=x[a+8>>2];C=x[a+12>>2];while(1){b=e;if(d){p=v[x[g+12>>2]+r|0]<<16;e=p;e=sua(e,e>>31,o,A);k=hb;h=e;e=Xb(b,-16777216,16776704);e=sua(n,z,e,e>>31);q=h+e|0;h=hb+k|0;h=e>>>0>q>>>0?h+1|0:h;f=Xb(f,-16777216,16776704);e=sua(m,y,f,f>>31);k=e+q|0;f=hb+h|0;f=e>>>0>k>>>0?f+1|0:f;e=k+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;j=j+u|0;x[c>>2]=D(f,j>>12)+x[c>>2];i=i+t|0;x[c+4>>2]=x[c+4>>2]+D(i>>12,f);Qb(g+8|0,B,C);e=e-(w&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+48>>2]=f;x[a+44>>2]=b;x[a+24>>2]=i>>12;Dg(a,l,s);fb=g+16|0}function CL(a,b,c,d,e){var f=E(0),g=0,h=E(0),i=0,j=E(0),k=E(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=B[b>>2];j=B[c>>2];k=B[d>>2];B[c>>2]=j+k;g=c-4|0;f=B[g>>2];B[g>>2]=f+B[b>>2];j=E(j-k);f=E(f-h);B[d>>2]=E(j*B[e>>2])-E(B[e+4>>2]*f);B[b>>2]=E(f*B[e>>2])+E(j*B[e+4>>2]);b=d-12|0;j=B[b>>2];g=c-8|0;f=B[g>>2];i=g;g=d-8|0;k=B[g>>2];B[i>>2]=f+k;i=c-12|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+32>>2])-E(B[e+36>>2]*h);B[b>>2]=E(h*B[e+32>>2])+E(f*B[e+36>>2]);b=d-20|0;j=B[b>>2];g=c-16|0;f=B[g>>2];i=g;g=d-16|0;k=B[g>>2];B[i>>2]=f+k;i=c-20|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+64>>2])-E(B[e+68>>2]*h);B[b>>2]=E(h*B[e+64>>2])+E(f*B[e+68>>2]);b=d-28|0;j=B[b>>2];g=c-24|0;f=B[g>>2];i=g;g=d-24|0;k=B[g>>2];B[i>>2]=f+k;i=c-28|0;h=B[i>>2];B[i>>2]=h+B[b>>2];f=E(f-k);h=E(h-j);B[g>>2]=E(f*B[e+96>>2])-E(B[e+100>>2]*h);B[b>>2]=E(h*B[e+96>>2])+E(f*B[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}_(16002,13279,2423,9231);p()}function gma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}l=x[a+16>>2];j=x[a+40>>2];k=x[a+36>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;m=x[a+32>>2];n=x[a+28>>2];while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+l|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;k=k+n|0;x[c>>2]=x[c>>2]+D(b,k>>12);j=j+m|0;x[c+4>>2]=x[c+4>>2]+D(b,j>>12);Qb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=j;x[a+20>>2]=k>>12;x[a+36>>2]=k;x[a+24>>2]=j>>12;fb=e+16|0}function WB(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);e=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a|0]=e;v[a+1|0]=e>>>8;v[a+2|0]=e>>>16;v[a+3|0]=e>>>24;v[a+4|0]=d;v[a+5|0]=d>>>8;v[a+6|0]=d>>>16;v[a+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[a+24|0]=e;v[a+25|0]=e>>>8;v[a+26|0]=e>>>16;v[a+27|0]=e>>>24;v[a+28|0]=d;v[a+29|0]=d>>>8;v[a+30|0]=d>>>16;v[a+31|0]=d>>>24;d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[a+16|0]=e;v[a+17|0]=e>>>8;v[a+18|0]=e>>>16;v[a+19|0]=e>>>24;v[a+20|0]=d;v[a+21|0]=d>>>8;v[a+22|0]=d>>>16;v[a+23|0]=d>>>24;d=y[c+12|0]|y[c+13|0]<<8|(y[c+14|0]<<16|y[c+15|0]<<24);e=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+8|0]=e;v[a+9|0]=e>>>8;v[a+10|0]=e>>>16;v[a+11|0]=e>>>24;v[a+12|0]=d;v[a+13|0]=d>>>8;v[a+14|0]=d>>>16;v[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function hsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;d=Xh(b,c);n=e,o=Cb(y[a|0]|y[a+1|0]<<8),w[n+14>>1]=o;w[e+12>>1]=64;dh(d,z[Mc(e+14|0,e+12|0)>>1]);n=d,o=Cb(y[a+14|0]|y[a+15|0]<<8),v[n+13|0]=o;n=d,o=Cb(y[a+16|0]|y[a+17|0]<<8),v[n+14|0]=o;n=d,o=Cb(y[a+20|0]|y[a+21|0]<<8),v[n+15|0]=o;n=d,o=Cb(y[a+22|0]|y[a+23|0]<<8),v[n+16|0]=o;h=x[d>>2];j=x[d+4>>2];b=y[d+12|0]&-2|mc(h,j)^1;v[d+12|0]=b;b=Cb(y[a+12|0]|y[a+13|0]<<8)>>>3&2|b&-3;v[d+12|0]=b;n=d,o=Cb(y[a+12|0]|y[a+13|0]<<8)>>>3&4|b&251,v[n+12|0]=o;b=4096;a:{b:{switch(c-1|0){case 0:i=-128;b=127;break a;case 1:break b;default:break a}}i=-1616;b=1616}k=b-i|0;l=k>>>1|0;b=0;while(1){if(Od(h,j)>>>0<=b>>>0){fb=e+16|0}else{d=wb(h,b);w[d>>1]=m;f=(b<<2)+a|0;c=ve((y[f+28|0]|y[f+29|0]<<8)<<16>>16)+i|0;g=c;c=c>>31<<6|c>>>26;g=l+(g<<6)|0;c=g>>>0<l>>>0?c+1|0:c;n=d,o=Zg(Fc(tua(g,c,k,0),hb)),v[n+2|0]=o;n=e,o=Cb(y[f+26|0]|y[f+27|0]<<8),w[n+10>>1]=o;w[e+8>>1]=1;b=b+1|0;m=z[se(e+10|0,e+8|0)>>1]+m|0;continue}break}}function Tta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-144|0;fb=f;x[31785]=0;l=R(276,a|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){m=c+480192|0;while(1){a:{if((j&65535)>>>0>=l>>>0){ub(a);fb=f+144|0;return}x[31785]=0;O(295,a|0,f+8|0);e=x[31785];x[31785]=0;if((e|0)!=1){b:{e=Cb(z[f+8>>1]);if((e-1&65535)>>>0>=z[m>>1]){break b}e=x[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Xh(e,b);g=y[f+11|0];c:{if(!g){break c}h=y[f+10|0];if(h&1){v[e+12|0]=y[e+12|0]|1}if(h&2){v[e+12|0]=y[e+12|0]|4}if(!(h&4)){break c}v[e+12|0]=y[e+12|0]|2}v[f+4|0]=g;v[f+7|0]=31;h=y[Ub(f+4|0,f+7|0)|0];x[31785]=0;h=h+1&255;O(296,e|0,h|0);g=x[31785];x[31785]=0;if((g|0)==1){break a}v[e+13|0]=y[f+13|0];v[e+14|0]=y[f+14|0];g=y[f+12|0];v[e+15|0]=g;v[e+16|0]=g;g=x[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;n=Cb(z[i+8>>1]);k=wb(g,e);w[k>>1]=n;i=Cb(z[i+10>>1]);w[f+4>>1]=d?i+128>>>2|0:i;Pf(f+4|0,64);v[k+2|0]=y[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=N()|0;ub(a);Q(b|0);p()}function Usa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=fb-288|0;fb=e;rf(b);a:{if(!Mb(x[a>>2],x[a+8>>2],1)){break a}while(1){d=e+32|0;lo(e+8|0,d,fr(d));kc(e+20|0,x[a>>2],x[a+8>>2],x[e+8>>2],x[e+12>>2]);x[e+28>>2]=x[e+24>>2];o=e,q=c-Wc(x[b+4>>2],y[b+11|0])|0,x[o+4>>2]=q;d=x[Gb(e+28|0,e+4|0)>>2];if(!d){break a}k=e+32|0;m=d+k|0;j=Ii(k,m,0);d=x[zb(e,yf(b))>>2];l=fb-16|0;fb=l;h=zk(d,wd(b));b:{c:{d=k;f=Tj(d,j);d:{if(!f){wd(b);break d}if(!Dz(b,d)){i=Bb(x[b+4>>2],y[b+11|0]);g=Lc(b);e:{if(f>>>0<=g-i>>>0){g=Jb(b);if((h|0)==(i|0)){break e}n=h+g|0;Ri(f+n|0,n,i-h|0);break e}Nm(b,g,(f+i|0)-g|0,i,h,0,f);g=x[b>>2]}f=f+i|0;jg(b,f);ed(f+g|0,0);f=h+g|0;while(1){if((d|0)!=(j|0)){ed(f,y[d|0]);d=d+1|0;f=f+1|0;continue}break}Ne(wd(b),h);break d}d=pi(l+4|0,d,j);i=wd(d);g=yf(d);x[31785]=0;ha(367,b|0,f|0,h|0,i|0,g|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break c}tb(d)}fb=l+16|0;break b}a=N()|0;tb(d);Q(a|0);p()}Yb(a,j-k|0);if(j>>>0>=m>>>0){continue}break}Yb(a,1)}fb=e+288|0}function rma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;g=fb-16|0;fb=g;f=x[a+48>>2];o=x[a+24>>2];p=x[a+20>>2];e=x[a+44>>2];q=x[a+16>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;r=x[a+72>>2];l=x[a+68>>2];s=l>>31;m=x[a+64>>2];t=m>>31;n=x[a+60>>2];u=n>>31;v=x[a+8>>2];y=x[a+12>>2];while(1){b=e;if(d){e=Xb(b,-16777216,16776704);i=sua(m,t,e,e>>31);j=hb;e=x[g+8>>2];h=(x[g+12>>2]<<1)+q|0;e=e>>>21&2040;h=(((D(w[h>>1],w[e+38386>>1])+D(w[h-2>>1],w[e+38384>>1])|0)+D(w[h+2>>1],w[e+38388>>1])|0)+D(w[h+4>>1],w[e+38390>>1])|0)/16384<<8;e=h;e=sua(e,e>>31,n,u);i=e+i|0;k=hb+j|0;k=e>>>0>i>>>0?k+1|0:k;f=Xb(f,-16777216,16776704);e=sua(l,s,f,f>>31);j=e+i|0;f=hb+k|0;f=e>>>0>j>>>0?f+1|0:f;e=j+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,p)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,o);Qb(g+8|0,v,y);e=e-(h&r)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;fb=g+16|0}function oD(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;v[d+15|0]=c;e=a;a:{b:{c:{switch(b-14|0){case 0:b=14;if(!c){break b}d:{if((c|0)!=15){if((c|0)!=240){break d}v[d+15|0]=239;break b}v[d+15|0]=254;break b}if(c>>>0>=16){v[d+15|0]=c|15;break b}v[d+15|0]=c|240;break b;case 1:v[d+15|0]=c^128;b=15;break b;case 6:case 7:if(c>>>0>=16){v[d+15|0]=c>>>4|240;break b}v[d+15|0]=c|224;break b;case 8:v[d+15|0]=((c^-1)&254)>>>1;b=22;break b;case 9:v[d+15|0]=c&15|128;b=23;break b;case 17:f=d,g=Zg(c<<1),v[f+15|0]=g;b=31;break b;case 19:a=32;b=33;e:{f:{switch(c>>>4|0){default:b=0;break b;case 8:a=64;break e;case 10:a=176;break e;case 11:a=224;break e;case 12:case 13:b=c?33:0;break b;case 14:g:{switch(c&15){case 0:v[d+15|0]=119;break b;case 1:v[d+15|0]=119;break b;case 2:v[d+15|0]=121;break b;case 3:break g;default:break b}}v[d+15|0]=123;break b;case 3:break e;case 5:break f;case 0:break b}}a=48}v[d+15|0]=c&15|a;break b;default:break c}}a=0;if(b>>>0>35){break a}}a=y[b+25216|0]}ae(e,a,d+15|0);fb=d+16|0}function RU(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=E(0),l=0,m=0,n=0;if(Oj(x[a+656>>2])){e=y[a+797|0];e=(l=e,m=y[a+799|0],n=zd(e),n?l:m);a:{b:{c:{if(!Pb(d+1074312|0,34)){break c}d=e&255;if(!d){break c}if(d>>>0<121){break b}}d=x[a+656>>2];break a}d=x[a+656>>2];e=y[xb(d+108|0,(e&255)-1|0)|0]}k=E(E(x[a+704>>2])*b);d=x[d+44>>2];f=((e&255)+c|0)-61<<16>>16;d:{e:{c=x[a+852>>2]+w[a+772>>1]|0;if(c){g=x[d+36>>2];if(g){break e}}b=Sm(d,c+f<<16>>16);break d}j=g+1|0;h=$z(c,j);e=aA(c,j);b=E(1);i=w[d+28>>1];c=f+h<<16>>16;f:{if((i|0)>(c|0)){break f}f=x[d+4>>2];if((c|0)>(oc(f,x[d+8>>2])+i|0)-1<<16>>16){break f}if(!e){b=B[wb(f,c-i|0)>>2];break d}g:{h:{i:{switch(z[d>>1]-1|0){case 2:g=x[d+16>>2];if(!oc(g,x[d+20>>2])){break h}b=B[wb(g,e-1|0)>>2];break g;case 0:break i;default:break h}}h=x[d+16>>2];if(!oc(h,x[d+20>>2])){break h}b=B[wb(h,(e+D(g,eA(c,z[d+30>>1])<<16>>16)|0)-1|0)>>2];break g}b=Ce(E(Sm(d,c+1<<16>>16)/Sm(d,c)),E(E(e|0)/E(j|0)))}b=E(b*B[wb(f,c-i|0)>>2])}}l=a,m=Bk(E(E(k*b)*E(16))),x[l+700>>2]=m}}function KK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;q=a;i=fb-1040|0;fb=i;r=x[31660];a:{b:{a=i+16|0;l=z[((b>>>0<=153?b:0)<<1)+123696>>1]+121772|0;c=x[x[124291]+20>>2];if(c){j=x[c+4>>2];c=x[c>>2];e=x[c>>2]+1794895138|0;h=zm(x[c+8>>2],e);f=zm(x[c+12>>2],e);d=zm(x[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}s=d>>>2|0;t=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+t<<2)|0;o=zm(x[d>>2],e);d=zm(x[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|y[c+(d+o|0)|0]){break c}d=li(l,c+d|0);if(!d){f=c+(s+n<<2)|0;h=zm(x[f>>2],e);e=zm(x[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=y[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=gf(g);d:{if(c>>>0>=1024){yc(a,g,1023);v[a+1023|0]=0;g=68;break d}yc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=22485}break a}va();p()}if(!y[a|0]){x[i>>2]=b;a=i+16|0;yy(a,1024,13096,i)}x[31660]=r;Cc(q,a);fb=i+1040|0}function Bla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;p=x[a+16>>2];q=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);l=x[a+128>>2];a:{if(!l){k=x[a+8>>2];m=x[a+12>>2];b=x[a>>2];f=x[a+4>>2];h=0;break a}b=x[a+12>>2];m=b;k=x[a+8>>2];n=Cg(k,b,l);o=hb;h=x[a+76>>2];b=x[a>>2];f=x[a+4>>2];bg(b,f,sf(k,m,d),hb);h=hb>>>0>h>>>0?d:0}g=a+112|0;i=x[a+40>>2];j=x[a+36>>2];x[e>>2]=b;x[e+4>>2]=f;b:while(1){if(d){d=d-1|0;x[e+8>>2]=b;x[e+12>>2]=0;h=h-1|0;b=h;n=b?n:0;o=b?o:0;f=f+p|0;b=l;while(1)if((b|0)<=0){Qb(g,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){_d(g,v[f+x[e+12>>2]|0]<<6);Zd(g,b);x[g>>2]=x[g>>2];x[g+4>>2]=0}b=Ag(g,q);f=x[a+32>>2];j=x[a+28>>2]+j|0;x[c>>2]=x[c>>2]+D(b,j>>12);i=f+i|0;x[c+4>>2]=x[c+4>>2]+D(b,i>>12);Qb(e,k,m);c=c+8|0;b=x[e>>2];f=x[e+4>>2];continue b}else{_d(g,v[f+x[e+12>>2]|0]<<6);Zd(g,4);Qb(e+8|0,n,o);b=b-1|0;continue}}break}x[a>>2]=b;x[a+4>>2]=f;x[a+40>>2]=i;x[a+20>>2]=j>>12;x[a+36>>2]=j;x[a+24>>2]=i>>12;fb=e+16|0}function sk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;$c(i+4|0,x[d+28>>2]);c=0;x[31785]=0;j=R(28,x[i+4>>2])|0;b=x[31785];x[31785]=0;if((b|0)!=1){Zb(i+4|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(qh(i+12|0,i+8|0)){break b}c:{if((jl(j,v[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=jl(j,v[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=jl(j,v[g+2|0])}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,b,k)|0,x[l+12>>2]=m;g=c+2|0;break c}b=x[j+8>>2];if(Ef(b,1,v[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(Ef(b,1,v[g|0])){continue}}break}while(1){if(qh(i+12|0,i+8|0)){break c}b=rl(x[i+12>>2]);if(!Ef(x[j+8>>2],1,b)){break c}Bm(i+12|0);continue}}if((ry(j,rl(x[i+12>>2]))|0)==(ry(j,v[g|0])|0)){g=g+1|0;Bm(i+12|0);break c}x[e>>2]=4}c=x[e>>2];continue}break}x[e>>2]=4}if(qh(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;Zb(i+4|0);Q(a|0);p()}function sma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];j=x[a+68>>2];r=j>>31;k=x[a+64>>2];s=k>>31;l=x[a+60>>2];t=l>>31;u=x[a+8>>2];y=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=sua(k,s,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=sua(j,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;e=x[h+8>>2];i=g;g=x[h+12>>2]+p|0;e=e>>>21&2040;m=(((D(v[g|0],w[e+38386>>1])+D(v[g-1|0],w[e+38384>>1])|0)+D(v[g+1|0],w[e+38388>>1])|0)+D(v[g+2|0],w[e+38390>>1])<<8)/16384<<8;e=m;g=sua(e,e>>31,l,t);i=i+g|0;e=hb+f|0;e=g>>>0>i>>>0?e+1|0:e;f=i+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Qb(h+8|0,u,y);f=f-(q&m)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Ola(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];v=w[b+4>>1];y=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=(i<<1)+p|0;x[(i<<2)+e>>2]=(((((D(w[f+8>>1],s)+D(w[f+4>>1],t)|0)+D(w[f+12>>1],r)|0)+D(w[f+16>>1],q)|0)/2|0)+((((D(w[f-8>>1],y)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],v)|0)+D(w[f>>1],u)|0)/2|0)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Qb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function zi(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=kj(a)&2047;c=kj(5551115123125783e-32);a:{if(e-c>>>0>=kj(512)-c>>>0){if(c>>>0>e>>>0){return a+1}o(+a);c=j(1)|0;d=j(0)|0;b:{if(kj(1024)>>>0>e>>>0){break b}b=0;if(!d&(c|0)==-1048576){break a}if(kj(Infinity)>>>0<=e>>>0){return a+1}if((c|0)>0|(c|0)>=0){return ys(3105036184601418e216)}if(c>>>0<3230714880){break b}return ys(12882297539194267e-247)}c=c<<1|d>>>31;e=!(d<<1)&(c|0)==-2129002496|c>>>0<2165964800?e:0}b=C[177];f=b+a;a=a-(f-b);b=a*a;g=b*b*(a*C[182]+C[181]);b=b*(a*C[180]+C[179]);a=a*C[178];o(+f);j(1)|0;i=j(0)|0;d=i<<4&2032;a=g+(b+(a+C[d+1464>>3]));d=d+1472|0;h=x[d>>2];c=x[d+4>>2];d=h;h=0;d=d+h|0;c=(i<<13)+c|0;c=d>>>0<h>>>0?c+1|0:c;if(!e){c:{if(!(i&-2147483648)){l(0,d|0);l(1,c+-1048576|0);b=+n();a=b*a+b;a=a+a;break c}l(0,d|0);l(1,c+1071644672|0);b=+n();f=b*a;a=f+b;if(a<1){kI(CI()*22250738585072014e-324);g=a+1;a=g+(f+(b-a)+(a+(1-g)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);b=+n();b=b*a+b}return b}function T7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}$c(g,x[d+28>>2]);x[31785]=0;b=R(1220,x[g>>2])|0;a=x[31785];x[31785]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);$c(g,x[d+28>>2]);x[31785]=0;a=R(1221,x[g>>2])|0;d=x[31785];x[31785]=0;if((d|0)==1){break g}Zb(g);x[31785]=0;O(1222,g|0,a|0);d=x[31785];x[31785]=0;if((d|0)==1){b=N()|0;break d}x[31785]=0;O(1223,g|12,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break f}x[31785]=0;d=g+24|0;a=sa(1224,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=Sb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Zb(g);break d}b=N()|0;Zb(g);break d}b=N()|0;Sb(g);break d}b=N()|0;while(1){d=Sb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function c8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-32|0;fb=g;x[g+28>>2]=b;a:{b:{if(!(v[d+4|0]&1)){x[g>>2]=-1;b=ib[x[x[a>>2]+16>>2]](a,b,c,d,e,g)|0;c:{switch(x[g>>2]){case 1:v[f|0]=1;break a;case 0:break b;default:break c}}v[f|0]=1;x[e>>2]=4;break a}$c(g,x[d+28>>2]);x[31785]=0;b=R(28,x[g>>2])|0;a=x[31785];x[31785]=0;d:{e:{f:{g:{if((a|0)!=1){Zb(g);$c(g,x[d+28>>2]);x[31785]=0;a=R(1204,x[g>>2])|0;d=x[31785];x[31785]=0;if((d|0)==1){break g}Zb(g);x[31785]=0;O(1205,g|0,a|0);d=x[31785];x[31785]=0;if((d|0)==1){b=N()|0;break d}x[31785]=0;O(1206,g|12,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break f}x[31785]=0;d=g+24|0;a=sa(1207,g+28|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}v[f|0]=(a|0)==(g|0);b=x[g+28>>2];while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=N()|0;Zb(g);break d}b=N()|0;Zb(g);break d}b=N()|0;tb(g);break d}b=N()|0;while(1){d=tb(d-12|0);if((g|0)!=(d|0)){continue}break}}Q(b|0);p()}v[f|0]=0}fb=g+32|0;return b|0}function Xsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;jd(b,32);g=b,h=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24)),x[g>>2]=h;f=$b(y[a+10|0]|y[a+11|0]<<8|(y[a+12|0]<<16|y[a+13|0]<<24));x[b+4>>2]=f;g=b,h=$b(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))+f|0,x[g+8>>2]=h;if(!(d?0:c)){c=$b(y[a+46|0]|y[a+47|0]<<8|(y[a+48|0]<<16|y[a+49|0]<<24))}x[b+24>>2]=c;c=y[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Cb(y[a+42|0]|y[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}_l(b,+(c|0)*.0006510416666666666);v[e+15|0]=y[a+9|0];v[e+14|0]=64;g=b,h=y[Ub(e+15|0,e+14|0)|0]<<2,w[g+30>>1]=h;if(v[a+40|0]&1){w[b+34>>1]=z[b+34>>1]|64;x[b>>2]=x[b>>2]>>>1;x[b+4>>2]=x[b+4>>2]>>>1;x[b+8>>2]=x[b+8>>2]>>>1}b:{if(y[a+41|0]<=8){a=x[b+4>>2];c=x[b+8>>2];break b}w[b+34>>1]=z[b+34>>1]|1;x[b>>2]=x[b>>2]>>>1;a=x[b+4>>2]>>>1|0;x[b+4>>2]=a;c=x[b+8>>2]>>>1|0;x[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){w[b+34>>1]=z[b+34>>1]|2;break c}x[b+4>>2]=0;x[b+8>>2]=0}fb=e+16|0}function Qqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=zv(c,d);d=b&63;if(e>>>0>d>>>0){c=DY(c,d);d=0;g=fb-16|0;fb=g;v[a+12|0]=0;Gf(a);e=fb-32|0;fb=e;a:{b:{if(Rg(a)>>>0<=14){if(Hh(1073741823)>>>0<=14){break b}f=Ab(a);f=hg(e+12|0,15,oc(x[a>>2],x[a+4>>2]),f);Id(a,f);gg(f)}fb=e+32|0;break a}cd();p()}h=0-y[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=y[e+1|0];if(!f){break c}v[g+11|0]=64;h=f+(h<<16>>16)|0;f=Yl(g+12|0,h&65535,y[Ub(e+2|0,g+11|0)|0]);d:{if(A[a+4>>2]<A[Ab(a)>>2]){zY(a,f);break d}i=fb-32|0;fb=i;e=Ab(a);e=hg(i+12|0,Tf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),e);Vo(x[e+8>>2],z[f>>1]|z[f+2>>1]<<16);x[e+8>>2]=x[e+8>>2]+4;Id(a,e);gg(e);fb=i+32|0}d=d+1|0;continue}break}d=y[c+32|0];v[a+14|0]=d>>>4;v[a+13|0]=d&15;c=y[c+31|0];d=c&15;v[a+15|0]=d;v[a+16|0]=d;if(c&16){v[a+12|0]=y[a+12|0]|4}if(c&32){v[a+12|0]=y[a+12|0]|2}fb=g+16|0}e:{if(b<<24>>24>=0){c=y[a+12|0]&-2;a=a+12|0;break e}c=y[a+12|0]&-2|mc(x[a>>2],x[a+4>>2])^1;a=a+12|0}v[a|0]=c}function rk(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=fb-16|0;fb=i;x[i+8>>2]=c;x[i+12>>2]=b;$c(i+4|0,x[d+28>>2]);b=0;x[31785]=0;j=R(1220,x[i+4>>2])|0;c=x[31785];x[31785]=0;if((c|0)!=1){Zb(i+4|0);x[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(ji(i+12|0,i+8|0)){break b}c:{if((qk(j,x[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}d:{e:{c=qk(j,x[b>>2]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=qk(j,x[g+8>>2])}l=i,m=ib[x[x[a>>2]+36>>2]](a,x[i+12>>2],x[i+8>>2],d,e,f,c,k)|0,x[l+12>>2]=m;g=b+8|0;break c}if(uj(j,1,x[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(uj(j,1,x[g>>2])){continue}}break}while(1){if(ji(i+12|0,i+8|0)){break c}if(!uj(j,1,ql(x[i+12>>2]))){break c}ao(i+12|0);continue}}if((gm(j,ql(x[i+12>>2]))|0)==(gm(j,x[g>>2])|0)){g=g+4|0;ao(i+12|0);break c}x[e>>2]=4}b=x[e>>2];continue}break}x[e>>2]=4}if(ji(i+12|0,i+8|0)){x[e>>2]=x[e>>2]|2}fb=i+16|0;return x[i+12>>2]}a=N()|0;Zb(i+4|0);Q(a|0);p()}function lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;g=fb-16|0;fb=g;x[g+12>>2]=1;a:{if(Po(a)){c=x[a>>2];k=Hg(c,x[a+4>>2]);x[g+8>>2]=k;l=x[Gb(g+12|0,g+8|0)>>2];while(1){if(l){l=l-1|0;if((b|0)!=(c|0)){i=vb(x[b>>2]);e=vb(x[b+4>>2]);f=fb-16|0;fb=f;h=ZD(i,e);b:{if(h>>>0<=Bn(c)>>>0){x[f+12>>2]=e;m=x[c>>2];d=Xc(m,x[c+4>>2]);n=d>>>0>=h>>>0;if(n){d=e}else{x[f+12>>2]=i;EU(f+12|0,d);d=x[f+12>>2]}j=fb-16|0;fb=j;GU(j+8|0,i,d,m);d=x[j+12>>2];fb=j+16|0;if(!n){IU(c,x[f+12>>2],e,h-Xc(x[c>>2],x[c+4>>2])|0);break b}xn(c,d);break b}HU(c);tC(c,ik(c,h));IU(c,i,e,h)}fb=f+16|0;bs(c+12|0,b+12|0);w[c+28>>1]=z[b+28>>1]}c=c+32|0;continue}break}if(!k){NB(a,1-k|0,b);break a}zU(a,x[a>>2]+32|0);break a}if(x[a>>2]){BU(a);e=x[a>>2];Po(a);Db(e);o=Ab(a),q=0,x[o>>2]=q;x[a>>2]=0;x[a+4>>2]=0}d=Hq(a,1);e=fb-16|0;fb=e;if(Hh(134217727)>>>0<d>>>0){cd();p()}tV(e+8|0,d);d=x[e+8>>2];x[a+4>>2]=d;x[a>>2]=d;o=Ab(a),q=d+(x[e+12>>2]<<5)|0,x[o>>2]=q;fb=e+16|0;NB(a,1,b)}fb=g+16|0}function kx(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=c<<4|b>>>28;c=d<<4|c>>>28;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){f=c+1073741824|0;e=e+1|0;f=e?f:f+1|0;break a}f=c+1073741824|0;if(a|(b|0)!=134217728){break a}a=e&1;e=a+e|0;f=a>>>0>e>>>0?f+1|0:f;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){a=d<<4|c>>>28;e=c<<4|b>>>28;f=a&524287|2146959360;break a}e=0;f=2146435072;if(h>>>0>1140785151){break a}f=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;Vf(g+16|0,a,b,c,e,h-15233|0);Vm(g,a,b,c,e,15361-h|0);b=x[g+8>>2];e=b<<4;b=x[g+12>>2]<<4|b>>>28;c=x[g>>2];f=x[g+4>>2];h=f;e=f>>>28|e;f=b;a=h&268435455;b=c|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){e=e+1|0;f=e?f:f+1|0;break a}if(b|(a|0)!=134217728){break a}a=e;e=e+(e&1)|0;f=a>>>0>e>>>0?f+1|0:f}fb=g+32|0;l(0,e|0);l(1,d&-2147483648|f);return+n()}function Bf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;c=x[a+36>>2];eg(x[x[c>>2]-12>>2]+c|0,0);c=a+32|0;Pc(d+12|0,c,4);if(!Hb(x[x[d+12>>2]>>2],x[d+16>>2])){hy(a)}a:{if(!x[a+8>>2]){break a}Pc(d+12|0,c,6);if(Hb(x[x[d+12>>2]>>2],x[d+16>>2])){break a}Pc(d+24|0,c,7);if(Hb(x[x[d+24>>2]>>2],x[d+28>>2])){break a}f=x[a+36>>2];e=x[a+92>>2];g=D(x[a+28>>2],x[a+8>>2]);h=g;g=g+x[a+88>>2]|0;e=h>>>0>g>>>0?e+1|0:e;Ei(f,g,e,0)}Pc(d+12|0,c,5);c=0;b:{if(!Hb(x[x[d+12>>2]>>2],x[d+16>>2])){break b}e=lj(x[a+52>>2],x[a+56>>2]);while(1){if((e|0)==(i|0)){break b}g=(x[a+108>>2]+i>>>0)%(e>>>0)|0;h=tf(x[a+52>>2],g);f=x[h>>2];c:{j=x[a+40>>2];if(Sc(j,x[a+44>>2])>>>0<=f>>>0){break c}f=ol(d+12|0,xb(j,f),z[h+20>>1]);h=zy(b,f);Eb(f);if(!h){break c}b=g+1|0;x[a+108>>2]=(b|0)!=(e|0)?b:0;c=tf(x[a+52>>2],g);b=x[c+8>>2];e=x[c+12>>2];if(!(b|e)){break b}f=x[a+16>>2];c=f+b|0;b=x[a+20>>2]+e|0;Ei(x[a+36>>2],c,c>>>0<f>>>0?b+1|0:b,0);c=tf(x[a+52>>2],g);break b}i=i+1|0;continue}}fb=d+32|0;return c}function Zp(a,b,c,d,e,f){var g=E(0),h=0,i=E(0),j=0,k=E(0),l=E(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=B[f>>2];k=B[c>>2];l=B[d>>2];B[c>>2]=k+l;h=c-4|0;g=B[h>>2];B[h>>2]=g+B[f>>2];k=E(k-l);g=E(g-i);B[d>>2]=E(k*B[e>>2])-E(B[e+4>>2]*g);B[f>>2]=E(g*B[e>>2])+E(k*B[e+4>>2]);f=d-12|0;k=B[f>>2];h=c-8|0;g=B[h>>2];j=h;h=d-8|0;l=B[h>>2];B[j>>2]=g+l;j=c-12|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-20|0;k=B[f>>2];h=c-16|0;g=B[h>>2];j=h;h=d-16|0;l=B[h>>2];B[j>>2]=g+l;j=c-20|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);f=d-28|0;k=B[f>>2];h=c-24|0;g=B[h>>2];j=h;h=d-24|0;l=B[h>>2];B[j>>2]=g+l;j=c-28|0;i=B[j>>2];B[j>>2]=i+B[f>>2];g=E(g-l);e=b+e|0;i=E(i-k);B[h>>2]=E(g*B[e>>2])-E(B[e+4>>2]*i);B[f>>2]=E(i*B[e>>2])+E(g*B[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function waa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb+-64|0;fb=c;f=x[a>>2];a=x[f>>2];g=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Sf(c+48|0,c+32|0,g);a=x[f+4>>2];f=x[a+8>>2];g=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(g>>>0<=d>>>0){if(g>>>0>A[c+20>>2]){break d}if(f>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(f>>>0>x[c+24>>2]-h>>>0){break b}i=b+12|0;j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(f|0)){break a}l=b+h|0;m=D(b,d);a=0;while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{e=x[(a+m<<2)+k>>2];n=Ft(i);o=x[(a<<2)+j>>2]+(l<<1)|0;e=od((od(n,21)+e|0)+2048|0,12);e=(e|0)>=32767?32767:e;w[o>>1]=(e|0)<=-32768?-32768:e;a=a+1|0;continue}}}_(7264,9065,33,8778);p()}_(7229,9065,34,8778);p()}_(5917,9065,35,8778);p()}_(5887,9065,36,8778);p()}fb=c- -64|0}function jH(a,b,c){var d=0,e=0,f=0;e=fb-32|0;fb=e;a:{f=Bs(e+28|0,b);d=x[f>>2];if(!xd(d)){x[31785]=0;b=P(37,e+4|0,b|0)|0;a=x[31785];x[31785]=0;b:{c:{d:{if((a|0)!=1){x[31785]=0;S(1020,e+16|0,17888,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break d}x[31785]=0;W(1348,e+16|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}p()}a=N()|0;break a}a=N()|0;break b}a=N()|0;tb(e+16|0)}tb(b);break a}Qp(d);if(!As(a+8|0,22485,x[f>>2])){v[a+8|0]=127}if(!As(a+9|0,22485,x[f>>2])){v[a+9|0]=127}x[31785]=0;O(275,a+12|0,22485);b=x[31785];x[31785]=0;e:{f:{if((b|0)==1){break f}x[31785]=0;b=a+24|0;O(275,b|0,22485);d=x[31785];x[31785]=0;if((d|0)==1){break f}x[a+60>>2]=0;x[31785]=0;O(275,a+36|0,22485);d=x[31785];x[31785]=0;if((d|0)==1){break f}x[31785]=0;O(275,a+48|0,22485);d=x[31785];x[31785]=0;if((d|0)==1){break f}x[31785]=0;b=P(73,e+16|0,b|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break e}a=N()|0;break a}a=N()|0;break a}fi(a- -64|0,c);fi(a+68|0,c);tb(b);gl(f);fb=e+32|0;return}gl(f);Q(a|0);p()}function pta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=fb-2608|0;fb=f;d=OD(f+4|0,a);x[d+1060>>2]=0;x[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){v[a+4|0]=0;w[a>>1]=0;w[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}x[31785]=0;W(326,d|0);a=x[31785];x[31785]=0;a:{b:{if((a|0)!=1){if((w[d+1068>>1]|w[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}x[31785]=0;j=P(161,d|0,1)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}a=0;d:{while(1){x[31785]=0;k=P(161,d|0,1)|0;e=x[31785];x[31785]=0;if((e|0)==1){break d}a=w[(d+D(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+D(a,6)|0;h=y[e+1072|0];if(w[e+1068>>1]<0){break e}if(w[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;v[b+g|0]=i;g=g+1|0;continue}break}a=T(29088)|0;break b}a=T(29088)|0;break b}a=T(29088)|0}if((gb|0)==($(29088)|0)){Y(a|0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0}ub(d);Q(a|0);p()}a=lr(d);ub(d);fb=f+2608|0;return a|0}function Uz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=E(0);c=fb-48|0;fb=c;a:{b=x[a+20>>2];b:{if(!b){break b}d=x[b+4>>2];b=x[b+8>>2];if(Sc(d,b)>>>0<4){break b}le(c+16|0,d,b);b=Jd(c+8|0);d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=B_(c+28|0,x[c+16>>2],x[c+20>>2],c);x[31785]=0;b=R(154,d|0)|0;f=x[31785];x[31785]=0;c:{if((f|0)!=1){if(b){break c}b=x[x[a>>2]+40>>2];x[31785]=0;f=R(b|0,a|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}b=x[a+20>>2];if(Sc(x[b+4>>2],x[b+8>>2])-4>>>0<f<<2>>>0){break c}e=x[x[a>>2]+176>>2];b=0;x[31785]=0;O(e|0,a|0,-1);e=x[31785];x[31785]=0;if((e|0)==1){break a}while(1){if((b|0)==(f|0)){b=x[x[a>>2]+180>>2];x[31785]=0;W(b|0,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break a}x[31785]=0;g=E(xa(477,d|0));e=x[31785];x[31785]=0;d:{if((e|0)==1){break d}e=x[x[a>>2]+44>>2];x[31785]=0;wa(e|0,a|0,b|0,E(Rm(g)?g:E(0)));e=x[31785];x[31785]=0;if((e|0)==1){break d}b=b+1|0;continue}break}break a}break a}ub(d)}fb=c+48|0;return}a=N()|0;ub(d);Q(a|0);p()}function Cz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;a:{b:{c:{d:{e:{f:{g:{f=a+36|0;e=x[f>>2];c=x[a+40>>2];h:{if(Ib(e,c)){rc(d+12|0);break h}oo(d,a);x[31785]=0;c=R(1065,d|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break g}x[d+12>>2]=c;mf(d);c=x[a+40>>2];e=x[a+36>>2]}e=(h=f,i=x[d+12>>2],j=Ib(e,c),j?h:i);if((b|0)==-1){f=x[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=x[e>>2];if((lj(f,x[e+4>>2])|0)>(b|0)){break e}}b=ac(8);x[31785]=0;c=P(37,d|0,10976)|0;a=x[31785];x[31785]=0;if((a|0)==1){break f}nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}a=N()|0;tb(c);break d}a=N()|0;mf(d);break c}a=N()|0;jc(b);break d}x[a+8>>2]=b;b=x[a+24>>2];x[b+480208>>2]=x[b+480208>>2]&-4194305|g;ak(b+484360|0,y[tf(f,c)+16|0]);b=tf(x[e>>2],c);c=x[b+8>>2];b=x[b+12>>2];x[31785]=0;+oa(1097,a|0,b|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break a}a=N()|0}vl(d+12|0)}Q(a|0)}p()}x[a+16>>2]=0;x[a+20>>2]=0;vl(d+12|0);fb=d+16|0}function Lta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=fb-32|0;fb=g;i=a+8|0;d=x[a+8>>2];h=Ac(a);a:{if((d|0)!=x[h>>2]){break a}j=a+4|0;c=x[a+4>>2];e=x[a>>2];if(c>>>0>e>>>0){f=fb-16|0;fb=f;m=f+8|0;a=fb-16|0;fb=a;k=a+8|0;l=((c-e>>1)+1|0)/-2<<1;e=l+c|0;h=fb-16|0;fb=h;while(1){if((c|0)!=(d|0)){e=r$(e,c)+2|0;c=c+2|0;continue}break}x[h+12>>2]=e;Td(k,d,h+12|0);fb=h+16|0;c=x[a+8>>2];x[a+4>>2]=x[a+12>>2];Td(m,c,a+4|0);fb=a+16|0;fb=f+16|0;d=x[f+12>>2];x[i>>2]=d;x[j>>2]=l+x[j>>2];break a}x[g+8>>2]=d-e;x[g+28>>2]=1;d=g+8|0;c=x[_c(d,g+28|0)>>2];d=hk(d,c,c>>>2|0,x[a+16>>2]);c=zb(g+4|0,x[a+4>>2]);e=x[zb(g,x[a+8>>2])>>2];f=fb-16|0;fb=f;c=x[c>>2];x[f+12>>2]=c;e=rp(f,d+8|0,ZD(c,e));c=x[e>>2];while(1){if(x[e+4>>2]!=(c|0)){k=c;c=x[f+12>>2];dj(k,y[c|0]|y[c+1|0]<<8);c=x[e>>2]+2|0;x[e>>2]=c;Wd(f+12|0);continue}break}ee(e);fb=f+16|0;wc(a,d);wc(j,d+4|0);wc(i,d+8|0);wc(h,Ac(d));fj(d);d=x[a+8>>2]}dj(d,y[b|0]|y[b+1|0]<<8);x[i>>2]=x[i>>2]+2;fb=g+32|0}function naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb+-64|0;fb=c;e=x[a>>2];a=x[e>>2];f=x[a+4>>2];x[c+40>>2]=x[a+20>>2];d=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=d;Sf(c+48|0,c+32|0,f);a=x[e+4>>2];e=x[a+8>>2];f=x[a+4>>2];d=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=d;d=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=d;x[c+8>>2]=x[a+8>>2];d=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=d;a:{b:{c:{d:{d=x[c+4>>2];if(f>>>0<=d>>>0){h=x[c+20>>2];if(f>>>0>h>>>0){break d}if(e>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(e>>>0>x[c+24>>2]-i>>>0){break b}j=b+12|0;k=x[c+16>>2];l=x[c>>2];b=0;e:while(1){if((b|0)==(e|0)){break a}m=D(b,d);n=D(b+i|0,h);a=0;while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=od((x[(a+m<<2)+l>>2]+od(Ft(j),21)|0)+2048|0,12);g=(g|0)>=32767?32767:g;w[(a+n<<1)+k>>1]=(g|0)<=-32768?-32768:g;a=a+1|0;continue}}}_(7264,9065,33,8778);p()}_(7229,9065,34,8778);p()}_(5917,9065,35,8778);p()}_(5887,9065,36,8778);p()}fb=c- -64|0}function Pla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,y=0,z=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];k=x[a+16>>2];j=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=j;l=b+24|0;m=x[a+32>>2];n=x[a+28>>2];j=x[a+8>>2];o=x[a+12>>2];while(1){if(d){b=x[e+8>>2];p=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;q=w[b+14>>1];r=w[b+12>>1];s=w[b+10>>1];t=w[b+8>>1];u=w[b+6>>1];y=w[b+4>>1];z=w[b+2>>1];b=w[b>>1];i=0;while(1){if((i|0)!=2){f=i+p|0;x[(i<<2)+e>>2]=((((D(v[f+4|0],s)+D(v[f+2|0],t)|0)+D(v[f+6|0],r)|0)+D(v[f+8|0],q)<<8>>1)+(((D(v[f-4|0],z)+D(v[f-6|0],b)|0)+D(v[f-2|0],y)|0)+D(v[f|0],u)<<8>>1)|0)/16384;i=i+1|0;continue}break}h=h+n|0;x[c>>2]=x[c>>2]+D(x[e>>2],h>>12);g=g+m|0;x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],g>>12);Qb(e+8|0,j,o);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function JI(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=fb-16|0;fb=a;x[a+12>>2]=c;x[a+8>>2]=f;x[a+12>>2]=c;x[a+8>>2]=f;b=x[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=x[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=x[a+8>>2];if((g-f|0)<=0){break a}x[a+8>>2]=f+1;v[f|0]=b;break c}if(b>>>0<=2047){c=x[a+8>>2];if((g-c|0)<2){break b}x[a+8>>2]=c+1;v[c|0]=b>>>6|192;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}c=x[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}x[a+8>>2]=c+1;v[c|0]=b>>>12|224;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128;break c}if((f|0)<4){break b}x[a+8>>2]=c+1;v[c|0]=b>>>18|240;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>12&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b>>>6&63|128;c=x[a+8>>2];x[a+8>>2]=c+1;v[c|0]=b&63|128}b=x[a+12>>2]+4|0;x[a+12>>2]=b;continue}break}c=1}x[e>>2]=x[a+12>>2];x[h>>2]=x[a+8>>2];fb=a+16|0;return c|0}function jA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=fb-16|0;fb=d;f=y[a+2|0];if(!(!f|(f|0)==255)){x[d+12>>2]=f+1;x[d+8>>2]=10;dh(b,x[pd(d+12|0,d+8|0)>>2]);i=y[a+3|0];v[b+15|0]=i;v[b+16|0]=i;j=y[a+4|0];v[b+13|0]=j;l=y[a+5|0];v[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=x[b>>2];k=Od(c,x[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=y[b+12|0]&-2|v[a|0]&1;v[b+12|0]=c;if(y[a|0]&2){break d}c=c&251;break c}}else{m=wb(c,e);h=(e<<2)+a|0;g=(y[h+6|0]|y[h+7|0]<<8)>>>4|0;w[m>>1]=g;e:{if(e){n=z[wb(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=wb(c,e),q=g,w[p>>1]=q}x[d+12>>2]=(((y[h+8|0]|y[h+9|0]<<8)<<16>>16)+o|0)/(f|0);x[d+8>>2]=0;x[d+4>>2]=64;p=m,q=x[bk(d+12|0,d+8|0,d+4|0)>>2],v[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}v[b+12|0]=c;if(j>>>0<=l>>>0?y[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}v[b+12|0]=a}fb=d+16|0}function pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=x[a>>2];c=jk(d,x[a+4>>2]);if(c>>>0<b>>>0){g=fb-32|0;fb=g;f=b-c|0;b=x[Ab(a)>>2];c=x[a+4>>2];a:{if(f>>>0<=b-c>>11>>>0){c=fb-16|0;fb=c;b=c+4|0;x[b>>2]=a;a=x[a+4>>2];x[b+4>>2]=a;x[b+8>>2]=a+(f<<11);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{cu(a);a=a+2048|0;x[b+4>>2]=a;continue}break}break a}h=Ab(a);i=g+12|0;b=a;e=jk(x[a>>2],c)+f|0;c=fb-16|0;fb=c;x[c+12>>2]=e;d=fb-16|0;fb=d;x[d+12>>2]=2097151;x[d+8>>2]=2147483647;a=x[Gb(d+12|0,d+8|0)>>2];fb=d+16|0;b:{if(a>>>0>=e>>>0){d=Wz(b);if(d>>>0<a>>>1>>>0){x[c+8>>2]=d<<1;a=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;break b}cd();p()}d=BQ(i,a,jk(x[b>>2],x[b+4>>2]),h);c=d;e=fb-16|0;fb=e;a=e+4|0;x[a>>2]=x[c+8>>2];h=x[c+8>>2];x[a+8>>2]=c+8;x[a+4>>2]=h+(f<<11);c=x[a>>2];while(1){if(x[a+4>>2]!=(c|0)){cu(c);c=x[a>>2]+2048|0;x[a>>2]=c;continue}break}ee(a);fb=e+16|0;Id(b,d);AQ(d)}fb=g+32|0;return}if(b>>>0<c>>>0){yQ(a,d+(b<<11)|0)}}function Ec(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=x[b>>2];e=fb-48|0;fb=e;f=x[b+4>>2];b=y[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Fb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){a=Ii(c,c+d|0,0);x[31785]=0;U(72,f|0,c|0,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break h}a=N()|0;break b}if((b-3&255)>>>0>1){break h}x[31785]=0;b=U(72,f|0,c|0,c+d|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break g}c=wd(b);d=yf(b);g=wd(b);a=fb-16|0;fb=a;x[a+8>>2]=g;x[a+12>>2]=c;while(1){if(Ib(c,d)){c=v[c|0];v[x[a+8>>2]]=c?c:32;c=je(a+12|0);je(a+8|0);c=x[c>>2];continue}break}fb=a+16|0;x[31785]=0;c=P(73,e+24|0,b|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break f}x[31785]=0;d=P(37,e+12|0,18645)|0;a=x[31785];x[31785]=0;if((a|0)==1){break e}x[31785]=0;S(74,e+36|0,c|0,d|0);a=x[31785];x[31785]=0;if((a|0)==1){break d}a=e+36|0;yb(b,a);tb(a);tb(d);tb(c)}fb=e+48|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break c}a=N()|0;tb(d)}tb(c)}tb(f);Q(a|0);p()}}function dr(a){var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=x[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(z[a+480192>>1]){break a}c=vb(x[a+484344>>2]);x[e+12>>2]=c;a=vb(x[a+484348>>2]);while(1){if(!Ib(c,a)){d=1;break a}if(!(!Ib(x[c>>2],x[c+4>>2])|x[c+12>>2]==64)){break a}c=x[nv(e+12|0)>>2];continue}}d=16777216;break a}d=32;f=z[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(v[b+480281|0]&1){break a}c=c+1|0;if(z[b+480286>>1]==64){continue}break}break a}d=2}fb=e+16|0;return d}function T1(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-48|0;fb=b;e=Fb(a);x[31785]=0;a=ca(120)|0;c=x[31785];x[31785]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}x[31785]=0;c=P(1,b+24|0,8983)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;a=ca(120)|0;d=x[31785];x[31785]=0;e:{f:{g:{h:{if((d|0)==1){break h}x[31785]=0;x[b+8>>2]=a;O(129,b+12|0,b+8|0);a=x[31785];x[31785]=0;if((a|0)==1){break h}x[31785]=0;S(2,b+36|0,c|0,b+12|0);a=x[31785];x[31785]=0;if((a|0)==1){break g}d=b+36|0;a=yb(e,d);tb(d);tb(b+12|0);tb(c);x[31785]=0;c=ca(122)|0;d=x[31785];x[31785]=0;if((d|0)==1){break b}if(!c){break e}x[31785]=0;P(130,a|0,17722)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break e}break b}a=N()|0;break f}a=N()|0;tb(b+12|0)}tb(c);break a}x[31785]=0;c=ca(121)|0;d=x[31785];x[31785]=0;if((d|0)==1){break b}if(!c){break d}x[31785]=0;P(130,a|0,17008)|0;a=x[31785];x[31785]=0;if((a|0)==1){break b}}fb=b+48|0;return}a=N()|0;break a}a=N()|0}tb(e);Q(a|0);p()}function kz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Sf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{l=De(Eg(C[(a+k<<3)+i>>3])*134217728);m=x[(a<<2)+h>>2]+(j<<2)|0,n=E(+(mn(l)|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}_(7264,9065,77,8745);p()}_(7229,9065,78,8745);p()}_(5917,9065,79,8745);p()}_(5887,9065,80,8745);p()}fb=c- -64|0}function Mf(a,b,c){v[a+5|0]=c;a:{switch(b|0){case 0:v[a+3|0]=(c|0)!=0;return;case 1:v[a+3|0]=2;return;case 2:v[a+3|0]=3;return;case 3:v[a+3|0]=4;return;case 4:v[a+3|0]=5;return;case 5:v[a+3|0]=6;return;case 6:v[a+3|0]=7;return;case 7:v[a+3|0]=8;return;case 8:v[a+3|0]=9;return;case 9:v[a+3|0]=10;return;case 10:v[a+3|0]=11;return;case 11:v[a+3|0]=12;return;case 12:v[a+3|0]=13;return;case 13:v[a+3|0]=14;v[a+5|0]=D(c>>>4|0,10)+(c&15);return;case 14:v[a+3|0]=19;return;case 15:if(c>>>0<=31){v[a+3|0]=16;return}v[a+3|0]=17;return;case 16:v[a+3|0]=23;return;case 17:v[a+3|0]=24;return;case 20:v[a+3|0]=25;return;case 21:v[a+3|0]=30;return;case 25:v[a+3|0]=29;return;case 27:v[a+3|0]=15;return;case 29:v[a+3|0]=18;return;case 32:v[a+3|0]=37;return;case 33:v[a+3|0]=28;return;case 34:v[a+3|0]=27;return;case 35:v[a+3|0]=31;return;case 36:v[a+3|0]=32;return;case 37:v[a+3|0]=32;return;case 38:v[a+3|0]=34;return;default:break a}}v[a+3|0]=0}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;h=g+4|0;e=fb-160|0;fb=e;d=e+24|0;f=d+56|0;c=vt(f);x[d>>2]=94396;x[c>>2]=94416;x[d+56>>2]=94456;x[d>>2]=94436;i=f;f=d+4|0;go(i,f);x[d>>2]=94396;x[c>>2]=94416;c=rt(f);x[c>>2]=93880;Fb(c+32|0);x[c+44>>2]=0;x[c+48>>2]=16;c=x[x[d>>2]-12>>2];x[31785]=0;f=ca(107)|0;i=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{if((i|0)==1){break f}x[31785]=0;S(108,e+20|0,c+d|0,f|0);c=x[31785];x[31785]=0;if((c|0)==1){break f}Zb(e+20|0);c=fb-16|0;fb=c;x[c+12>>2]=17;fb=c+16|0;nn(x[x[d>>2]-12>>2]+d|0,x[c+12>>2]);j=C[b>>3];x[31785]=0;b=Sa(1139,d|0,+j)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}x[31785]=0;O(1140,e+8|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}x[31785]=0;O(306,h|0,e+8|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}tb(e+8|0);Yp(b);fb=e+160|0;break a}a=N()|0;break b}a=N()|0;break b}a=N()|0;break b}a=N()|0;tb(e+8|0)}Yp(d);Q(a|0);p()}Oh(a,h);tb(h);fb=g+16|0}function jz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0);c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Sf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=(a+l<<2)+i|0,n=E(+(mn(De(Eg(C[(a+k<<3)+j>>3])*134217728))|0)*7.450580596923828e-9),B[m>>2]=n;a=a+1|0;continue}}}_(7264,9065,77,8745);p()}_(7229,9065,78,8745);p()}_(5917,9065,79,8745);p()}_(5887,9065,80,8745);p()}fb=c- -64|0}function Ela(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+128>>2];a:{if(!j){i=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];h=0;break a}b=x[a+12>>2];k=b;i=x[a+8>>2];l=Cg(i,b,j);m=hb;h=x[a+76>>2];b=x[a>>2];g=x[a+4>>2];bg(b,g,sf(i,k,d),hb);h=hb>>>0>h>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;b:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(g<<1)+n|0;b=j;while(1)if((b|0)<=0){Qb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){_d(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);Zd(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Ag(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Qb(e,i,k);c=c+8|0;continue b}else{_d(f,w[(x[e+12>>2]<<1)+g>>1]/4<<16>>16);Zd(f,4);Qb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Sf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=b+h|0;l=D(b,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{m=x[(a<<2)+i>>2]+(k<<1)|0;f=od(x[(a+l<<2)+j>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[m>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}_(7264,9065,33,8778);p()}_(7229,9065,34,8778);p()}_(5917,9065,35,8778);p()}_(5887,9065,36,8778);p()}fb=c- -64|0}function Ps(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{d=kj(a)&2047;c=kj(5551115123125783e-32);if(d-c>>>0<kj(512)-c>>>0){i=d;break b}if(c>>>0>d>>>0){return a+1}if(kj(1024)>>>0>d>>>0){break b}o(+a);c=j(1)|0;b=0;if(!(j(0)|0)&(c|0)==-1048576){break a}if(kj(Infinity)>>>0<=d>>>0){return a+1}if((c|0)<0){return ys(12882297539194267e-247)}return ys(3105036184601418e216)}b=C[170];e=C[169]*a+b;b=e-b;a=b*C[172]+(b*C[171]+a);b=a*a;f=b*b*(a*C[176]+C[175]);b=b*(a*C[174]+C[173]);o(+e);j(1)|0;h=j(0)|0;c=h<<4&2032;a=f+(b+(C[c+1464>>3]+a));c=c+1472|0;g=x[c>>2];d=x[c+4>>2];c=g;g=0;c=c+g|0;d=(h<<13)+d|0;d=c>>>0<g>>>0?d+1|0:d;if(!i){c:{if(!(h&-2147483648)){l(0,c|0);l(1,d-1058013184|0);b=+n();a=(b*a+b)*5486124068793689e288;break c}l(0,c|0);l(1,d+1071644672|0);b=+n();e=b*a;a=e+b;if(a<1){kI(CI()*22250738585072014e-324);f=a+1;a=f+(e+(b-a)+(a+(1-f)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,c|0);l(1,d|0);b=+n();b=b*a+b}return b}function oaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Sf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{g=x[c+4>>2];if(g>>>0>=e>>>0){h=x[c+20>>2];if(h>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}i=x[c+28>>2];if(d>>>0>x[c+24>>2]-i>>>0){break b}j=x[c+16>>2];k=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}l=D(b,g);m=D(b+i|0,h);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=od(x[(a+l<<2)+k>>2]+2048|0,12);f=(f|0)>=32767?32767:f;w[(a+m<<1)+j>>1]=(f|0)<=-32768?-32768:f;a=a+1|0;continue}}}_(7264,9065,33,8778);p()}_(7229,9065,34,8778);p()}_(5917,9065,35,8778);p()}_(5887,9065,36,8778);p()}fb=c- -64|0}function ssa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;jd(b,32);Zo(b);f=b,g=Cb(y[a+40|0]|y[a+41|0]<<8)>>>2|0,w[f+32>>1]=g;d=z[b+34>>1];if((ve((y[a+38|0]|y[a+39|0]<<8)<<16>>16)|0)>0){d=d|32;w[b+34>>1]=d;c=ve((y[a+38|0]|y[a+39|0]<<8)<<16>>16);e=(c<<8&-256)+2047|0;c=c>>>24|0;f=b,g=Bc(uua(e,e>>>0<2047?c+1|0:c,4095,0),hb),w[f+28>>1]=g}f=b,g=$b(y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24)),x[f>>2]=g;f=b,g=$b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24)),x[f+4>>2]=g;f=b,g=$b(y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24))+$b(y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24))|0,x[f+8>>2]=g;c=d&-3|((Cb(y[a+44|0]|y[a+45|0]<<8)|0)!=0)<<1;w[b+34>>1]=c;f=b,g=c&65531|Cb(y[a+44|0]|y[a+45|0]<<8)<<1&4,w[f+34>>1]=g;f=b,g=$b(y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24))<<1,x[f+24>>2]=g;c=ve((y[a+42|0]|y[a+43|0]<<8)<<16>>16);if(c){_l(b,+(c|0)/96);c=ve((y[a+42|0]|y[a+43|0]<<8)<<16>>16)}v[b+37|0]=c<<4}function c2(){var a=0,b=0,c=0,d=0;c=fb-32|0;fb=c;a:{b=Cc(c+20|0,15187);if(!Wc(x[b+4>>2],y[b+11|0])){break a}b:{if((Og(b,14788)|0)!=-1){a=Og(b,14788);x[31785]=0;V(124,c+8|0,b|0,a+1|0,-1);a=x[31785];x[31785]=0;if((a|0)==1){break b}a=c+8|0;yb(b,a);tb(a)}if((Og(b,17006)|0)!=-1){a=Og(b,17006);x[31785]=0;V(124,c+8|0,b|0,a+1|0,-1);a=x[31785];x[31785]=0;if((a|0)==1){break b}a=c+8|0;yb(b,a);tb(a)}if((Og(b,13962)|0)!=-1){a=Og(b,13962);x[31785]=0;V(124,c+8|0,b|0,0,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}a=c+8|0;yb(b,a);tb(a)}if((Og(b,13811)|0)!=-1){a=Og(b,13811);x[31785]=0;V(124,c+8|0,b|0,0,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}a=c+8|0;yb(b,a);tb(a)}if((Og(b,13854)|0)!=-1){a=Og(b,13854);x[31785]=0;V(124,c+8|0,b|0,0,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}a=c+8|0;yb(b,a);tb(a)}x[31785]=0;a=R(125,b|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break a}}c=N()|0;tb(b);Q(c|0);p()}tb(b);fb=c+32|0;return a|0}function a1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=fb-32|0;fb=j;e=En(j+12|0,a);c=fb-48|0;fb=c;k=-1;a:{if(!JF(e,c+12|0)){break a}k=0;if(!OF(c+12|0)){break a}l=gf(13186);if(l){o=x[e+12>>2];b:{if(!Wl(e,y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))){break b}while(1){c:{if((y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24))>>>0>n>>>0){if(ih(e,5)){break c}}f=m&1;break b}f=0;g=1;d:{if((y[c+16|0]|y[c+17|0]<<8)>>>0>=64){d=vr(e);a=d&63;h=d<<24>>24;e:{if(!(d&64)){break e}d=6;while(1){i=vr(e);a=(i&127)<<d|a;if(i<<24>>24>=0){break e}i=d>>>0<25;d=d+7|0;if(i){continue}break}}if((((h|0)<0?(a|0)<0?-2147483648:0-a|0:a)|0)<=0){break d}}while(1){d=vr(e);if(d){h=f>>>0>=l>>>0;a=h&g;if(!((g^1)&1|h)){a=(xq(d<<24>>24)&255)==y[f+13186|0]}g=a;f=f+1|0;continue}break}fd(e,4);m=(f|0)==(l|0)?g&1?1:m:m}n=n+1|0;continue}}Wl(e,o)}if(!f){break a}k=xe(e,b,MF(c+12|0),0)}fb=c+48|0;fb=j+32|0;return k|0}function Kga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=0,p=0,q=0,r=0,s=0,t=E(0),u=E(0),v=E(0),w=E(0),z=0,A=0,C=0,D=0,G=0,H=E(0);g=fb-16|0;fb=g;m=x[a+4240>>2];a:{if(!m){break a}if(!wi(a+44|0)){break a}n=B[a+4220>>2];e=x[a+44>>2];D=g,G=Hc(e,0),x[D+8>>2]=G;D=g,G=Hc(e,1),x[D+12>>2]=G;e=x[a+56>>2];o=Hc(e,0);x[g>>2]=o;p=Hc(e,1);x[g+4>>2]=p;w=E(E(1)-n);q=x[a+4208>>2];z=y[a+4264|0];e=d;b:while(1){if(e){k=x[a+4244>>2];A=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;x[a+4244>>2]=(f|0)!=(m|0)?f:0;e=e-1|0;continue b}else{h=(z?1-l|0:f)&255;j=x[((h<<2)+a|0)+4248>>2];C=x[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=x[s>>2];x[s>>2]=i+4;j=k-j|0;t=B[wb(q,h+((j>>31&C)+j<<1)|0)>>2];u=B[i>>2];v=E(E(t*B[a+4224>>2])+E(u*B[a+4260>>2]));D=wb(q,f+A|0),H=E(F(v))<E(10000000195414814e-40)?E(0):v,B[D>>2]=H;h=g+r|0;i=x[h>>2];x[h>>2]=i+4;B[i>>2]=E(u*w)+E(n*t);l=l+1|0;f=f+1|0;continue}}break}Li(a,b,c,o,p,d)}fb=g+16|0}function iy(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Bb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Bb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=ky(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=y[(a>>2)+111968|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=x[e>>2];if((a|0)!=(d|0)){f=-1;if((y[a-1|0]&95)!=(y[c|0]&127)){break b}}x[e>>2]=a+1;v[a|0]=g;return 0}v[c|0]=80;break d}d=g&95;if((d|0)!=y[c|0]){break d}v[c|0]=d|128;if(!y[b|0]){break d}v[b|0]=0;if(!Bb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>84){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function kq(a){a=a|0;var b=0,c=0,d=0,e=0,f=E(0),g=E(0),h=0,i=0,j=0,k=0,l=0,m=E(0),n=0,o=E(0);b=x[a+36>>2];if(!b){Gf(a+16|0);return}a:{b:{switch(z[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Gf(c);return}vk(c,b);b=x[a+36>>2]+1|0;c=b>>>0<=1?1:b;e=w[a+28>>1];g=Ce(E(Sm(a,e+1<<16>>16)/Sm(a,e)),E(E(1)/E(b>>>0)));a=x[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}f=Ce(g,E(b>>>0));n=wb(a,b-1|0),o=f,B[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;e=z[a+30>>1];if(e>>>0>1e3/(b>>>0)>>>0){Gf(c);return}vk(c,D(b,e));h=z[a+30>>1];j=eA(w[a+28>>1],h);i=x[a+36>>2];g=E(E(1)/E(i+1>>>0));c=0;c:while(1){if(e>>>0<=(c&65535)>>>0){break a}b=1;d=eA(c+j<<16>>16,h);f=Sm(a,d+1<<16>>16);d=d<<16>>16;f=Ce(E(f/Sm(a,d)),g);k=D(d,x[a+36>>2]);l=x[a+16>>2];while(1){d=b&65535;if(d>>>0>i>>>0){c=c+1|0;continue c}else{m=Ce(f,E(d>>>0));n=wb(l,(d+k|0)-1|0),o=m,B[n>>2]=o;b=b+1|0;continue}}};case 0:Gf(a+16|0);return;default:break b}}Gf(a+16|0);x[a+36>>2]=0}}function Ima(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];w=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=sua(l,s,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=sua(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=x[h+12>>2]+p|0;i=v[g|0];i=((D(v[g+1|0]-i|0,x[h+8>>2]>>>10&4194048)|0)/16384<<8)+(i<<16)|0;e=i;g=sua(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Qb(h+8|0,u,w);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function Gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-80|0;fb=e;x[e+76>>2]=c;a=oe(a,e+76|0);c=rc(a+4|0);g=rc(a+24|0);h=rc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31785]=0;O(1e3,a|0,d|0);f=x[31785];x[31785]=0;a:{b:{c:{d:{if((f|0)!=1){f=x[b>>2];k=x[b+4>>2];l=x[b+12>>2];x[e+48>>2]=x[b+8>>2];x[e+52>>2]=l;x[e+40>>2]=f;x[e+44>>2]=k;b=Jd(e+32|0);f=x[e+52>>2];x[e+24>>2]=x[e+48>>2];x[e+28>>2]=f;x[31785]=0;f=x[e+44>>2];x[e+16>>2]=x[e+40>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;S(989,e+56|0,e+16|0,e+8|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;S(1001,a|0,e+56|0,d|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}ub(e+56|0);x[31785]=0;W(1002,a|0);b=x[31785];x[31785]=0;if((b|0)==1){break b}Uc(e+76|0);fb=e+80|0;return a|0}d=N()|0;break a}d=N()|0;break a}d=N()|0;ub(e+56|0);break a}d=N()|0}Pd(j);mf(i);yl(h);sh(g);rh(c);Uc(a);Uc(e+76|0);Q(d|0);p()}function ny(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!y[b|0]){break a}f=0;v[b|0]=0;a=x[e>>2];x[e>>2]=a+1;v[a|0]=46;if(!Bb(x[h+4>>2],y[h+11|0])){break b}a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Bb(x[h+4>>2],y[h+11|0])){break c}if(!y[b|0]){break a}f=0;a=x[j>>2];if((a-i|0)>159){break b}b=x[k>>2];x[j>>2]=a+4;x[a>>2]=b;x[k>>2]=0;return 0}f=-1;a=Ii(l,l+32|0,a)-l|0;if((a|0)>31){break b}g=y[a+111968|0];d:{e:{switch((a&-2)-22|0){case 2:a=x[e>>2];if((a|0)!=(d|0)&(y[a-1|0]&95)!=(y[c|0]&127)){break b}x[e>>2]=a+1;v[a|0]=g;return 0;case 0:v[c|0]=80;break d;default:break e}}d=g&95;if((d|0)!=y[c|0]){break d}v[c|0]=d|128;if(!y[b|0]){break d}v[b|0]=0;if(!Bb(x[h+4>>2],y[h+11|0])){break d}b=x[j>>2];if((b-i|0)>159){break d}c=x[k>>2];x[j>>2]=b+4;x[b>>2]=c}b=x[e>>2];x[e>>2]=b+1;v[b|0]=g;f=0;if((a|0)>21){break b}x[k>>2]=x[k>>2]+1}return f}return-1}function Hma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=fb-16|0;fb=h;e=x[a+48>>2];n=x[a+24>>2];o=x[a+20>>2];f=x[a+44>>2];p=x[a+16>>2];b=x[a+4>>2];x[h+8>>2]=x[a>>2];x[h+12>>2]=b;q=x[a+72>>2];k=x[a+68>>2];r=k>>31;l=x[a+64>>2];s=l>>31;m=x[a+60>>2];t=m>>31;u=x[a+8>>2];v=x[a+12>>2];while(1){b=f;if(d){f=Xb(b,-16777216,16776704);g=sua(l,s,f,f>>31);f=hb;e=Xb(e,-16777216,16776704);e=sua(k,r,e,e>>31);g=e+g|0;f=hb+f|0;f=e>>>0>g>>>0?f+1|0:f;j=g;g=(x[h+12>>2]<<1)+p|0;i=w[g>>1];i=i+((D(w[g+2>>1]-i|0,x[h+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;g=sua(e,e>>31,m,t);j=g+j|0;e=hb+f|0;e=g>>>0>j>>>0?e+1|0:e;f=j+8388608|0;e=f>>>0<8388608?e+1|0:e;f=Rc(f,e,24);e=(f|0)/256|0;x[c>>2]=D(e,o)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(e,n);Qb(h+8|0,u,v);f=f-(i&q)|0;c=c+8|0;d=d-1|0;e=b;continue}break}c=x[h+12>>2];x[a>>2]=x[h+8>>2];x[a+4>>2]=c;x[a+48>>2]=e;x[a+44>>2]=b;fb=h+16|0}function jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=(x[e+12>>2]<<1)+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(w[g-4>>1],w[b+2>>1])+D(w[g-6>>1],w[b>>1])|0)+D(w[g-2>>1],w[b+4>>1])|0)+D(w[g>>1],w[b+6>>1])|0)+D(w[g+2>>1],w[b+8>>1])|0)+D(w[g+4>>1],w[b+10>>1])|0)+D(w[g+6>>1],w[b+12>>1])|0)+D(w[g+8>>1],w[b+14>>1])|0)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Qb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function gqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;w[e+12>>1]=0;x[e+8>>2]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(l|0)){i=(l<<1)+b|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){w[e+6>>1]=0;WX(a,e+15|0,e+12|0,j,e+6|0);g=z[e+6>>1];f=z[e+12>>1];c=j;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!xf(a,e+5|0)){break c}f=y[e+5|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&65535;e:{if(h>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+z[e+8>>1]|0;w[e+6>>1]=f;w[i>>1]=f;x[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);i=(d<<1)+i|0;j=(c+j&254)>>>1|0;c=-32768;k=x[e+8>>2];f:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break f}}x[e+8>>2]=c}k=f;continue}}break}fb=e+16|0}function kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=E(0),q=E(0),r=0,s=0,t=0,u=E(0),v=E(0),w=E(0),y=E(0),z=0,A=0,C=0,D=E(0);r=x[a+4220>>2];if(r){f=x[a+44>>2];k=Hc(f,0);l=Hc(f,1);g=x[a+56>>2];s=Hc(g,0);j=x[a+4208>>2];z=x[a+4228>>2];f=d;t=Hc(g,1);m=t;g=s;while(1){if(f){h=x[a+4224>>2];e=h-z|0;e=(x[a+4220>>2]&e>>31)+e<<1;A=wb(j,e);n=B[wb(j,e|1)>>2];u=B[a+4244>>2];o=B[A>>2];v=B[a+4252>>2];p=B[l>>2];w=B[a+4248>>2];q=B[k>>2];y=B[a+4256>>2];i=E(E(n*u)+E(E(o*v)+E(E(p*w)+E(q*y))));e=h<<1;C=wb(j,e),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;i=E(E(o*u)+E(E(n*v)+E(E(q*w)+E(p*y))));C=wb(j,e|1),D=E(F(i))<E(10000000195414814e-40)?E(0):i,B[C>>2]=D;h=h+1|0;x[a+4224>>2]=(h|0)!=(r|0)?h:0;B[g>>2]=E(q*B[a+4240>>2])+E(o*B[a+4236>>2]);B[m>>2]=E(p*B[a+4240>>2])+E(n*B[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{Li(a,b,c,s,t,d)}break}}}function zK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[We(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=Zu(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){v[c+23|0]=y[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(NK(x[a+36>>2],f,i,g,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=Zu(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}v[c+23|0]=y[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((ht(vf(v[e+(c+24|0)|0]),x[a+32>>2])|0)!=-1){continue}break a}}d=vf(v[c+23|0]);x[a+48>>2]=d;break a}d=vf(v[c+23|0]);break a}d=-1}fb=c+32|0;return d}function GM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;x[e+12>>2]=c;a:{b:{if(!b){a=a+120|0;mo(a);c=x[e+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(b+8|0,x[zb(b+4|0,a)>>2]);c:{if(c){x[31785]=0;O(1146,a|0,c|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}CM(a,c)}c=b+8|0;Md(c);aj(c);fb=b+16|0;break c}v[a+20|0]=0;break b}d=fb-16|0;fb=d;x[d+12>>2]=c;d:{if((b|0)==1){b=a+120|0;mo(b);h=pz(b,a,x[d+12>>2]),i=1,v[h+20|0]=i;break d}f=fb-16|0;fb=f;x[f+12>>2]=c;e:{if((b|0)==2){a=a+120|0;mo(a);c=x[f+12>>2];b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(b+8|0,x[zb(b+4|0,a)>>2]);f:{if(c){x[31785]=0;O(1145,a|0,c|0);g=x[31785];x[31785]=0;if((g|0)==1){break a}CM(a,c)}c=b+8|0;Md(c);aj(c);fb=b+16|0;break f}Jd(a+12|0);v[a+20|0]=2;break e}b=fb-16|0;fb=b;x[b+12>>2]=c;c=a+120|0;mo(c);h=pz(c,a,x[b+12>>2]),i=3,v[h+20|0]=i;fb=b+16|0}fb=f+16|0}fb=d+16|0}fb=e+16|0;return}a=N()|0;aj(b+8|0);Q(a|0);p()}function xr(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;a:{if(y[a+3|0]!=19){break a}v[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=y[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}v[a+3|0]=0;break a}v[a+3|0]=2;v[a+5|0]=b|240;break a}v[a+3|0]=3;v[a+5|0]=b|240;break a}v[a+5|0]=b&15|16;break a}v[a+5|0]=b&3|48;break a}v[a+5|0]=b&223^120;break a}v[a+5|0]=b&15|176;break a}v[a+5|0]=b&3|64;break a}v[a+3|0]=15;v[a+5|0]=b&15;break a}if(b&15){v[a+3|0]=11;v[a+5|0]=b<<4|15;break a}v[a+3|0]=0;break a}b=b&15;if(b){v[a+3|0]=11;x[c+12>>2]=b;x[c+8>>2]=14;d=a,e=y[pd(c+12|0,c+8|0)|0]|240,v[d+5|0]=e;break a}v[a+3|0]=0;break a}if((b|0)!=192){break a}v[a|0]=254;v[a+3|0]=0;break a}if((b|0)!=208){break a}v[a+3|0]=0}fb=c+16|0}function Xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=ig(1,2);b=hb;q=b;Qb(a,j,b);f=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];v=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=w[(x[g+12>>2]<<1)+p>>1]<<8;e=n;e=sua(e,e>>31,m,y);i=hb;h=e;e=Xb(b,-16777216,16776704);e=sua(l,v,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Xb(f,-16777216,16776704);e=sua(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Qb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Dg(a,j,q);fb=g+16|0}function Laa(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[31785]=0;g=P(21,d+8|0,a|0)|0;c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){d:{if(!Ad(y[g|0])){break d}$c(d+4|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31785]=0;c=R(1141,x[d+4>>2])|0;e=x[31785];x[31785]=0;e:{f:{if((e|0)!=1){Zb(d+4|0);e=hp(d,a);f=x[x[a>>2]-12>>2];x[31785]=0;f=a+f|0;h=R(22,f|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break f}e=x[e>>2];x[31785]=0;c=Ra(1142,c|0,e|0,f|0,h|0,+b)|0;e=x[31785];x[31785]=0;if((e|0)==1){break f}if(c){break d}c=x[x[a>>2]-12>>2];x[31785]=0;O(24,a+c|0,5);c=x[31785];x[31785]=0;if((c|0)!=1){break d}c=T(0)|0;break e}c=T(0)|0;Zb(d+4|0);break e}c=T(0)|0}em(g);break c}em(g);break b}c=T(0)|0}Y(c|0)|0;c=x[x[a>>2]-12>>2];x[31785]=0;W(25,a+c|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31785]=0;X(26);d=x[31785];x[31785]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Qna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;d=x[b>>2];e=Dk(d,x[b+4>>2]);a:{if(e>>>0<c>>>0){i=fb-32|0;fb=i;f=c-e|0;e=x[Ab(b)>>2];d=x[b+4>>2];b:{if(f>>>0<=e-d>>4>>>0){g=fb-16|0;fb=g;d=Ru(g+4|0,b,f);e=x[d+4>>2];f=x[d+8>>2];while(1){if((e|0)==(f|0)){hc(d);fb=g+16|0}else{or(e);e=e+16|0;x[d+4>>2]=e;continue}break}break b}e=Ab(b);e=xV(i+12|0,yV(b,Dk(x[b>>2],d)+f|0),Dk(x[b>>2],x[b+4>>2]),e);g=fb-16|0;fb=g;d=g+4|0;x[d>>2]=x[e+8>>2];j=x[e+8>>2];x[d+8>>2]=e+8;x[d+4>>2]=(f<<4)+j;f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){or(f);f=x[d>>2]+16|0;x[d>>2]=f;continue}break}ee(d);fb=g+16|0;Id(b,e);d=x[e+4>>2];f=x[e+8>>2];while(1){if((d|0)!=(f|0)){f=f-16|0;x[e+8>>2]=f;continue}break}d=x[e>>2];if(d){fs(e);Db(d)}}fb=i+32|0;break a}if(c>>>0<e>>>0){zV(b,d+(c<<4)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<4)){c=x[b>>2];bc(h+8|0,c,Dk(c,x[b+4>>2])<<4);md(h,a,x[h+8>>2],x[h+12>>2])}fb=h+16|0}function Fla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=fb-16|0;fb=e;n=x[a+16>>2];o=Bg(b+327720|0,x[b+20>>2],(x[a+88>>2]&16384)>>>14|0);j=x[a+128>>2];a:{if(!j){i=x[a+8>>2];k=x[a+12>>2];b=x[a>>2];g=x[a+4>>2];h=0;break a}b=x[a+12>>2];k=b;i=x[a+8>>2];l=Cg(i,b,j);m=hb;h=x[a+76>>2];b=x[a>>2];g=x[a+4>>2];bg(b,g,sf(i,k,d),hb);h=hb>>>0>h>>>0?d:0}f=a+112|0;p=x[a+24>>2];q=x[a+20>>2];x[e>>2]=b;x[e+4>>2]=g;b:while(1){if(d){g=x[e+4>>2];x[e+8>>2]=x[e>>2];x[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=g+n|0;b=j;while(1)if((b|0)<=0){Qb(f,x[a+120>>2],x[a+124>>2]);b=x[a+116>>2];if(b){_d(f,v[x[e+12>>2]+g|0]<<6);Zd(f,b);x[f>>2]=x[f>>2];x[f+4>>2]=0}b=Ag(f,o);x[c>>2]=x[c>>2]+D(b,q);x[c+4>>2]=x[c+4>>2]+D(b,p);Qb(e,i,k);c=c+8|0;continue b}else{_d(f,v[x[e+12>>2]+g|0]<<6);Zd(f,4);Qb(e+8|0,l,m);b=b-1|0;continue}}break}b=x[e+4>>2];x[a>>2]=x[e>>2];x[a+4>>2]=b;fb=e+16|0}function zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(Wc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Sd(f,g)>>2];if(b>>>0>=2097152){x[31785]=0;O(972,d|0,63);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31785]=0;O(972,d|0,a<<24>>24);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=v[j|0];x[31785]=0;O(972,d|0,(a|i)<<24>>24);h=x[31785];x[31785]=0;a=e;break e}x[31785]=0;a=a-1|0;O(972,d|0,v[a+(c+10|0)|0]|-128);h=x[31785];x[31785]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function EI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=v[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((y[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];f=y[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=y[a+3|0];i=y[a+2|0];f=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function Yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,y=0,z=0,A=0;g=fb-16|0;fb=g;p=x[a+16>>2];j=ig(1,2);b=hb;q=b;Qb(a,j,b);f=x[a+48>>2];r=x[a+24>>2];s=x[a+20>>2];e=x[a+44>>2];b=x[a+4>>2];x[g+8>>2]=x[a>>2];x[g+12>>2]=b;t=x[a+72>>2];k=x[a+68>>2];u=k>>31;l=x[a+64>>2];w=l>>31;m=x[a+60>>2];y=m>>31;z=x[a+8>>2];A=x[a+12>>2];while(1){b=e;if(d){n=v[x[g+12>>2]+p|0]<<16;e=n;e=sua(e,e>>31,m,y);i=hb;h=e;e=Xb(b,-16777216,16776704);e=sua(l,w,e,e>>31);o=h+e|0;h=hb+i|0;h=e>>>0>o>>>0?h+1|0:h;f=Xb(f,-16777216,16776704);e=sua(k,u,f,f>>31);i=e+o|0;f=hb+h|0;f=e>>>0>i>>>0?f+1|0:f;e=i+8388608|0;f=e>>>0<8388608?f+1|0:f;e=Rc(e,f,24);f=(e|0)/256|0;x[c>>2]=D(f,s)+x[c>>2];x[c+4>>2]=x[c+4>>2]+D(f,r);Qb(g+8|0,z,A);e=e-(t&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=x[g+12>>2];x[a>>2]=x[g+8>>2];x[a+4>>2]=c;x[a+48>>2]=f;x[a+44>>2]=b;Dg(a,j,q);fb=g+16|0}function nV(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;v[e+15|0]=c;f=b&15;b=y[f+25680|0];a:{b:{switch(f|0){case 0:b=c?d>>>0>=51?b:0:0;break a;case 5:c:{d:{f=c&15;e:{if(!((f|0)!=2&(c&240)!=32)){c=159;v[e+15|0]=159;b=20;break e}if((f|0)==12){break d}}if(d>>>0<51){break a}if((c&240)==192){break c}break a}if(d>>>0<51){break a}}v[e+15|0]=0;b=25;break a;case 7:b=d>>>0>=52?b:0;break a;case 10:c=c&240;if(!c){break a}v[e+15|0]=c;break a;case 11:v[e+15|0]=D(c&15,17);break a;case 13:v[e+15|0]=D(c>>>4|0,10)+(c&15);break a;case 14:f:{switch((c>>>4|0)-1|0){case 0:v[e+15|0]=c|240;b=2;break a;case 1:v[e+15|0]=c|240;b=3;break a;case 7:if(d>>>0<52){break a}v[e+15|0]=c&15|96;case 11:case 12:b=20;break a;case 8:b=15;v[e+15|0]=c&15;break a;case 9:v[e+15|0]=c<<4|15;b=11;break a;case 10:break f;default:break a}}v[e+15|0]=c|240;b=11;break a;case 15:break b;default:break a}}b=c>>>0>47?17:b}ae(a,b,e+15|0);fb=e+16|0}function AK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;a:{if(y[a+52|0]){d=x[a+48>>2];if(!b){break a}v[a+52|0]=0;x[a+48>>2]=-1;break a}x[c+24>>2]=1;e=x[We(c+24|0,a+44|0)>>2];g=(e|0)>0?e:0;while(1){if((f|0)!=(g|0)){d=-1;h=Zu(x[a+32>>2]);if((h|0)==-1){break a}v[(c+24|0)+f|0]=h;f=f+1|0;continue}break}b:{c:{if(y[a+53|0]){x[c+20>>2]=v[c+24|0];break c}h=c+24|0;while(1){d:{f=x[a+40>>2];d=x[f>>2];j=x[f+4>>2];i=c+24|0;g=i+e|0;e:{switch(NK(x[a+36>>2],f,i,g,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}f=x[a+40>>2];x[f>>2]=d;x[f+4>>2]=j;if((e|0)==8){break b}d=Zu(x[a+32>>2]);if((d|0)==-1){break b}v[g|0]=d;e=e+1|0;continue}break}x[c+20>>2]=v[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((ht(v[e+(c+24|0)|0],x[a+32>>2])|0)!=-1){continue}break a}}d=x[c+20>>2];x[a+48>>2]=d;break a}d=x[c+20>>2];break a}d=-1}fb=c+32|0;return d}function kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+12>>2];f=h;a:{b:{c:{i=x[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|(f|0)==-1){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}h=b+196648|0;break a}h=b+131112|0;break a}h=b+262184|0}j=x[a+16>>2];k=x[a+24>>2];l=x[a+20>>2];b=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=b;while(1){if(d){b=x[e+8>>2];g=x[e+12>>2]+j|0;b=(b>>>16&65520)+h|0;b=(((((((D(v[g-2|0],w[b+2>>1])+D(v[g-3|0],w[b>>1])|0)+D(v[g-1|0],w[b+4>>1])|0)+D(v[g|0],w[b+6>>1])|0)+D(v[g+1|0],w[b+8>>1])|0)+D(v[g+2|0],w[b+10>>1])|0)+D(v[g+3|0],w[b+12>>1])|0)+D(v[g+4|0],w[b+14>>1])<<8)/32768|0;x[c>>2]=x[c>>2]+D(b,l);x[c+4>>2]=x[c+4>>2]+D(b,k);Qb(e+8|0,i,f);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Xna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;w[f+12>>1]=c;w[f+14>>1]=b;w[f+10>>1]=d;i=z[x[x[a+24>>2]+8>>2]+12>>1];a:{if(i>>>0<=b>>>0){break a}if(!c|Lj(a)>>>0>=i>>>0){break a}Pf(f+12|0,i-b&65535);k=f,l=dm(x[a>>2],x[a+4>>2]),w[k+8>>1]=l;d=z[f+12>>1];kY(a,d+z[se(f+14|0,f+8|0)>>1]|0);h=f+4|0;c=x[a>>2];e=a;if(Xc(c,x[a+4>>2])>>>0<b>>>0){tg(e,b);c=x[e>>2]}a=x[zb(h,FU(vb(c),b))>>2];j=f+10|0;h=fb-32|0;fb=h;b=a;a=x[e>>2];g=(dp(b,vb(a))<<1)+a|0;a=d;b:{if(!a){break b}b=x[Ab(e)>>2];d=x[e+4>>2];if(a>>>0<=b-d>>1>>>0){b=a;c=d-g>>1;if(c>>>0<a>>>0){jp(e,a-c|0,j);b=c;if((d|0)==(g|0)){break b}}DU(e,g,d,(a<<1)+g|0);uv(g,b,((g>>>0<=j>>>0?A[e+4>>2]>j>>>0?a:0:0)<<1)+j|0);break b}b=Ab(e);b=hk(h+8|0,ik(e,Xc(x[e>>2],d)+a|0),g-x[e>>2]>>1,b);cF(b,a,j);g=ir(e,b,g);fj(b)}zb(h+28|0,g);fb=h+32|0;if(Xc(x[e>>2],x[e+4>>2])>>>0<=i>>>0){break a}tg(e,i)}fb=f+16|0}function HI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=v[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((y[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=y[a+2|0];b=y[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=y[a+3|0];h=y[a+2|0];b=y[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function jE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-560|0;fb=f;w[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=x[e>>2];b:{if(b){c=PU(f,c);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;d=y[c+11|0]|y[c+12|0]<<8|(y[c+13|0]<<16|y[c+14|0]<<24);e=y[c+7|0]|y[c+8|0]<<8|(y[c+9|0]<<16|y[c+10|0]<<24);v[b+7|0]=e;v[b+8|0]=e>>>8;v[b+9|0]=e>>>16;v[b+10|0]=e>>>24;v[b+11|0]=d;v[b+12|0]=d>>>8;v[b+13|0]=d>>>16;v[b+14|0]=d>>>24;v[b+15|0]=y[c+15|0];d=x[c+44>>2];x[b+40>>2]=x[c+40>>2];x[b+44>>2]=d;d=x[c+36>>2];x[b+32>>2]=x[c+32>>2];x[b+36>>2]=d;d=x[c+28>>2];x[b+24>>2]=x[c+24>>2];x[b+28>>2]=d;d=x[c+20>>2];x[b+16>>2]=x[c+16>>2];x[b+20>>2]=d;BA(b+48|0,c+48|0);BA(b+68|0,c+68|0);BA(b+88|0,c+88|0);yc(b+108|0,c+108|0,448);d=b;xv(c);break b}b=gu(556);if(!b){x[e>>2]=0;break a}d=PU(b,c);x[e>>2]=d}g=a,h=z[se(a+480192|0,f+558|0)>>1],w[g+480192>>1]=h}fb=f+560|0;return d|0}function Ct(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Sf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a+l<<2)+i>>2]=E(x[(a+k<<2)+j>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7264,9065,33,8778);p()}_(7229,9065,34,8778);p()}_(5917,9065,35,8778);p()}_(5887,9065,36,8778);p()}fb=c- -64|0}function L0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=b;c=fb-16|0;fb=c;d=Fb(a);while(1){b:{c:{d:{if(Wc(x[f+4>>2],y[f+11|0])>>>0>g>>>0){b=x[Sd(f,g)>>2];if(b>>>0>=2097152){x[31785]=0;O(51,d|0,63);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;v[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=y[c+10|0]|64}else{a=y[c+10|0]}x[31785]=0;O(51,d|0,a&255);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break b}fb=c+16|0;break a}i=(2<<a)+255<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=y[j|0];x[31785]=0;O(51,d|0,a|i&255);h=x[31785];x[31785]=0;a=e;break e}x[31785]=0;a=a-1|0;O(51,d|0,y[a+(c+10|0)|0]|128);h=x[31785];x[31785]=0}if((h|0)!=1){continue}break}break b}g=g+1|0;continue}break}a=N()|0;tb(d);Q(a|0);p()}}function Fqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=fb-432|0;fb=d;xc(b);RC(b,d+380|0,d+300|0,d+16|0);k=d,l=Zg((m=y[d+431|0]+1|0,n=1,o=$b(y[d+412|0]|y[d+413|0]<<8|(y[d+414|0]<<16|y[d+415|0]<<24)),o?m:n)),v[k+12|0]=l;i=y[Ub(25408,d+12|0)|0];v[d+15|0]=i;w[d+12>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Cb(z[d+16>>1])<<16>>16;if(!((e|0)<0|y[d+299|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=$b(x[d+300>>2]);if(e>>>0<g>>>0){if(bd(b,g)){break c}}v[d+15|0]=h+1;break b}}else{d:{if(!bd(b,$b(y[d+396|0]|y[d+397|0]<<8|(y[d+398|0]<<16|y[d+399|0]<<24))+(f<<2)|0)){break d}if(!bd(b,fp(b))){break d}e:{if(!c){j=be(b);break e}j=Qk(b)}w[d+10>>1]=j;k=d,l=z[se(d+12|0,d+10|0)>>1],w[k+12>>1]=l}f=f+1|0;continue}break}g=$b(x[d+300>>2]);RC(b,d+380|0,d+300|0,d+16|0);h=h+1|0;continue}break}Hw(a);break a}hY(a,z[d+12>>1],d+15|0)}fb=d+432|0}function dra(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;b=fb-16|0;fb=b;x[b+4>>2]=1073741824;w[b+10>>1]=12;c=Dc(64);x[31785]=0;d=R(882,c|0)|0;f=x[31785];x[31785]=0;a:{b:{c:{if((f|0)!=1){c=uf(b,d);d=x[c>>2];x[31785]=0;O(883,d|0,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}a=x[c>>2];x[31785]=0;a=U(884,a|0,b+10|0,b+4|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break c}d:{if(!a){rc(b+12|0);break d}a=x[c>>2];x[31785]=0;O(885,a|0,15);a=x[31785];x[31785]=0;if((a|0)==1){break c}oe(b+12|0,c)}Ig(c);fb=b+16|0;b=x[b+12>>2];break a}a=N()|0;Db(c);break b}a=N()|0;Ig(c)}Q(a|0);p()}x[e+12>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}x[31785]=0;c=P(1,e|0,(a<<2)+30816|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){x[31785]=0;S(503,b|0,a|0,c|0);d=x[31785];x[31785]=0;if((d|0)==1){break g}tb(c);a=a+1|0;continue}break}a=N()|0;break f}a=N()|0;tb(c)}Ig(e+12|0);Q(a|0);p()}fb=e+16|0;return b|0}function Et(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Sf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[x[(a<<2)+h>>2]+(j<<2)>>2]=E(x[(a+k<<2)+i>>2])*E(7.450580596923828e-9);a=a+1|0;continue}}}_(7264,9065,33,8778);p()}_(7229,9065,34,8778);p()}_(5917,9065,35,8778);p()}_(5887,9065,36,8778);p()}fb=c- -64|0}function cB(a,b,c,d,e){var f=0,g=0,h=0;g=D(c,872)+b|0;a:{if(d){if(!Pb(a+1074312|0,90)){v[(D(c,872)+b|0)+1427|0]=d}v[(D(c,872)+b|0)+1428|0]=d;break a}d=y[g+1428|0]}f=x[a+480180>>2];if(!e){h=qu(f)}g=g+616|0;b:{if((f|0)!=268435456){if((f|0)!=16777216){break b}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){HS(b,c,240-a|0);return}if(!(a>>>0<224|e)){GS(g,224-a|0);return}FS(g,0-a|0);return}x[(D(c,872)+b|0)+1324>>2]=65535}e=d&255;c:{d:{if(!(e>>>0>223&h)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}$A(a,g,f);return}if(x[a+480180>>2]==524288){break d}_A(a,g,f);return}if(x[a+480180>>2]!=524288){break c}}b=D(c,872)+b|0;f:{if(!(v[b+1467|0]&1)){break f}if(x[a+1074416>>2]==1){if(Pb(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}xk(a,g,b+1316|0,0-(e<<2)|0,0)}}function uG(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-32|0;fb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;h=e;c=c&33554431;if(!(!e&(c|0)==16777216?!(a|b):!e&c>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(c^16777216|a|(b|h)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;Vf(g+16|0,a,b,c,e,f-16129|0);Vm(g,a,b,c,e,16257-f|0);a=x[g+8>>2];e=(x[g+12>>2]&33554431)<<7|a>>>25;c=x[g>>2]|(x[g+16>>2]|x[g+24>>2]|(x[g+20>>2]|x[g+28>>2]))!=0;f=x[g+4>>2];b=0;a=a&33554431;if(!(!b&(a|0)==16777216?!(c|f):!b&a>>>0<16777216)){e=e+1|0;break a}if(a^16777216|c|(b|f)){break a}e=(e&1)+e|0}fb=g+32|0;return l(2,d&-2147483648|e),r()}function dqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;w[e+12>>1]=0;x[e+8>>2]=0;n=D(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){v[e+7|0]=0;VX(a,e+15|0,e+12|0,e+7|0);g=y[e+7|0];f=z[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!xf(a,e+6|0)){break c}f=y[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}w[e+12>>1]=f;break b}l=l+1|0;continue a}w[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;v[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+y[e+8|0]|0;v[e+7|0]=f;v[i|0]=f;x[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=x[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}x[e+8>>2]=c}j=f;continue}}break}fb=e+16|0}function Sla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=((((x[e+12>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=(g<<1)+n|0;x[(g<<2)+e>>2]=(((((D(w[f+8>>1],q)+D(w[f+4>>1],r)|0)+D(w[f+12>>1],p)|0)+D(w[f+16>>1],o)|0)/2|0)+((((D(w[f-8>>1],u)+D(w[f-12>>1],b)|0)+D(w[f-4>>1],t)|0)+D(w[f>>1],s)|0)/2|0)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Qb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=E(0),m=0,n=0,o=E(0),p=E(0),q=E(0),r=E(0),s=E(0),t=E(0),u=E(0),v=E(0),w=E(0);h=fb-16|0;fb=h;if(wi(a+44|0)){f=x[a+44>>2];g=Hc(f,0);x[h+8>>2]=g;f=Hc(f,1);x[h+12>>2]=f;j=x[a+56>>2];m=Hc(j,0);x[h>>2]=m;j=Hc(j,1);x[h+4>>2]=j;a:{if(B[wb(a+4208|0,2)>>2]!=E(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=x[e>>2];x[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=B[n>>2];l=B[i>>2];r=B[a+4236>>2];s=B[a+4232>>2];t=B[a+4228>>2];u=B[a+4220>>2];v=B[a+4224>>2];i=e+4240|0;o=B[i>>2];B[n>>2]=o;B[i>>2]=l;i=e+4264|0;w=B[i>>2];e=e+4256|0;p=B[e>>2];B[i>>2]=p;l=E(E(E(E(t*q)+E(E(u*l)+E(v*o)))-E(s*p))-E(r*w));B[e>>2]=l;k=h+k|0;e=x[k>>2];x[k>>2]=e+4;B[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;yc(m,e,g);yc(j,f,g);f=x[a+56>>2];m=Hc(f,0);j=Hc(f,1)}Li(a,b,c,m,j,d)}fb=h+16|0}function dB(a,b,c,d,e){var f=0,g=0,h=0;g=D(c,872)+b|0;a:{if(d){if(!Pb(a+1074312|0,90)){v[(D(c,872)+b|0)+1428|0]=d}v[(D(c,872)+b|0)+1427|0]=d;break a}d=y[g+1427|0]}f=x[a+480180>>2];if(!e){h=qu(f)}g=g+616|0;b:{if((f|0)!=268435456){if((f|0)!=16777216){break b}f=x[(D(c,872)+b|0)+1272>>2];if(!f|!x[f+44>>2]){break b}a=d&255;if(!(a>>>0<240|e)){HS(b,c,a-240|0);return}if(!(a>>>0<224|e)){GS(g,a-224|0);return}FS(g,a);return}x[(D(c,872)+b|0)+1324>>2]=1}e=d&255;c:{d:{if(!(e>>>0>223&h)){break d}e:{f=e&15;if(!f){break e}d=d&240;if((d|0)!=224){if((d|0)!=240){break e}aB(a,g,f);return}if(x[a+480180>>2]==524288){break d}bB(a,g,f);return}if(x[a+480180>>2]!=524288){break c}}b=D(c,872)+b|0;f:{if(!(v[b+1467|0]&1)){break f}if(x[a+1074416>>2]==1){if(Pb(a+1074312|0,6)){break f}}c=x[a+480180>>2];if(c&32832){break f}if(!(y[a+480208|0]&2)|(c|0)!=8){break c}}xk(a,g,b+1316|0,e<<2,0)}}function GC(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=fb-32|0;fb=i;h=fb-16|0;fb=h;jd(b,1);g=Cb(y[a+22|0]|y[a+23|0]<<8)<<1;x[b>>2]=g;v[b+37|0]=y[a+24|0]<<4;v[h+15|0]=y[a+25|0];v[h+14|0]=64;l=b,m=y[Ub(h+15|0,h+14|0)|0]<<2,w[l+30>>1]=m;f=Cb(y[a+26|0]|y[a+27|0]<<8);e=f<<1;k=Cb(y[a+28|0]|y[a+29|0]<<8);j=k<<1;e=k>>>0>=2?e+j>>>0<=g>>>0?e:f+j>>>0>g>>>0?e:f:e;a:{b:{switch(g|0){case 2:x[b>>2]=0;break a;case 0:break a;default:break b}}x[b+4>>2]=e;f=e+j|0;x[b+8>>2]=f;if(e>>>0>=g>>>0){e=g-1|0;x[b+4>>2]=e}if(!(!(f>>>0<4|e>>>0>f>>>0)&f-e>>>0>3)){x[b+4>>2]=0;x[b+8>>2]=0;f=0;e=0}if(!(f>>>0>8|f>>>0>=g>>>0|(!d|e))){x[b+8>>2]=0;break a}if(e>>>0>=f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=h+16|0;d=i+8|0;im(d,3,a);b=i+20|0;Ec(b,d);c=zc(c,b);tb(b);d=0;while(1){if((d|0)!=32){b=c+d|0;if((y[b|0]-1&255)>>>0<=30){v[b|0]=32}d=d+1|0;continue}break}a=IC(a);fb=i+32|0;return a}function vna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;e=fb-16|0;fb=e;c=a+33|0;x[b>>2]=y[c+206|0]|y[c+207|0]<<8;jR(c,b+48|0,y[c+192|0],y[c+200|0],y[c+194|0],y[c+195|0],y[c+196|0],0);jR(c,b+68|0,y[c+193|0],y[c+201|0],y[c+197|0],y[c+198|0],y[c+199|0],1);f=b+236|0;while(1){if((d|0)==96){if(y[c+208|0]){v[b+31|0]=y[c+209|0]+1;f=y[b+31|0];a:{b:{if(!f){d=1;break b}d=16;if(f>>>0<17){break a}}v[b+31|0]=d}w[e+14>>1]=y[c+210|0]|y[c+211|0]<<8;w[e+12>>1]=127;j=b,k=y[Mc(e+14|0,e+12|0)|0]+1|0,v[j+30|0]=k}v[b+33|0]=y[c+212|0];fb=e+16|0}else{i=y[c+d|0];j=_b(f,d+12|0),k=i,w[j>>1]=k;d=d+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){d=y[c+h|0];f=y[a+27|0]|y[a+28|0]<<8;j=_b(e,h+12|0),k=d>>>0<f>>>0?d:0,w[j>>1]=k;h=h+1|0;continue}break}d=g+8|0;im(d,3,a+4|0);c=g+20|0;Ec(c,d);zc(b+492|0,c);tb(c);if(!y[a+241|0]){v[b+30|0]=y[a+26|0]}fb=g+32|0}function tH(a,b,c,d,e,f,g,h){var i=0,j=0,k=E(0);i=fb-96|0;fb=i;zA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[i+92>>2]=f;x[i+88>>2]=e;x[i+84>>2]=d;x[i+80>>2]=c;a:{d=i+80|0;c=0;while(1){b:{if((c|0)!=4){if(x[(c<<2)+d>>2]){break b}}else{c=4}break a}c=c+1|0;continue}}x[i+44>>2]=b;x[i+40>>2]=c;x[i+36>>2]=d;e=x[a+32>>2];k=B[a+48>>2];x[i+8>>2]=b;c=x[i+40>>2];x[i>>2]=x[i+36>>2];x[i+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[i+8>>2];c=x[i+4>>2];x[d>>2]=x[i>>2];x[d+4>>2]=c;c=uM(i+48|0);x[c+8>>2]=e;x[c+4>>2]=0;x[c>>2]=h;e=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=e;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=k;x[c>>2]=g;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[i+24>>2]=b;x[i+28>>2]=0;x[i+16>>2]=134217727;x[i+20>>2]=0;d=vM(d,x[Hr(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|j)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=i+96|0;return j}function G$(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;v[e+15|0]=c;a:{if(b>>>0>35){break a}b:{c:{d:{e:{f:{g:{h:{d=y[b+24896|0];switch(d-6|0){case 2:case 3:case 4:case 6:case 7:case 9:case 10:case 12:break a;case 11:break c;case 13:break d;case 0:case 1:case 5:break f;case 8:break g;default:break h}}if((d|0)==31){break b}if((d|0)==23){break e}if((d|0)!=1){break a}d=(c|0)!=0;break a}v[e+15|0]=D(c>>>4|0,10)+(c&15);d=14;break a}b=c&240;if(!b|(b|0)==240|(c&15)==15){break a}v[e+15|0]=b;break a}if(c>>>0<=64){v[e+15|0]=c<<1;d=23;break a}v[e+15|0]=128;d=23;break a}d=19;i:{switch((c&240)-48>>>4|0){case 0:v[e+15|0]=159;d=20;break a;case 1:v[e+15|0]=192;d=20;break a;case 2:if(c&14){break a}v[e+15|0]=((c|0)!=80)<<6;d=21;break a;case 4:break i;default:break a}}v[e+15|0]=c&15|160;d=20;break a}d=c>>>0<32?16:17;break a}v[e+15|0]=(b<<5|c>>>3)^128;d=31}ae(a,d,e+15|0);fb=e+16|0}function kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Sf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){g=x[c+20>>2];if(g>>>0<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}h=x[c+28>>2];if(d>>>0>x[c+24>>2]-h>>>0){break b}i=x[c+16>>2];j=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}k=D(b,f);l=D(b+h|0,g);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[(a+l<<2)+i>>2]=C[(a+k<<3)+j>>3];a=a+1|0;continue}}}_(7264,9065,77,8745);p()}_(7229,9065,78,8745);p()}_(5917,9065,79,8745);p()}_(5887,9065,80,8745);p()}fb=c- -64|0}function Km(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-16|0;fb=e;x[a+4>>2]=0;if(Ad(y[Cm(e+15|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){b=a+24|0;while(1){c=x[b+x[x[a>>2]-12>>2]>>2];x[31785]=0;c=R(86,c|0)|0;d=x[31785];x[31785]=0;d:{if((d|0)!=1){if(!mc(c,-1)){break d}break b}break c}x[a+4>>2]=x[a+4>>2]+1;continue}}if(x[a+4>>2]>=(b|0)){break a}c=a+24|0;e:{while(1){d=x[c+x[x[a>>2]-12>>2]>>2];x[31785]=0;d=R(86,d|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break e}if(mc(d,-1)){break b}d=x[a+4>>2]+1|0;x[a+4>>2]=d;if((b|0)>(d|0)){continue}break}c=0;break a}}Y(T(0)|0)|0;c=1;Am(x[x[a>>2]-12>>2]+a|0,1);f:{g:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31785]=0;X(87);a=x[31785];x[31785]=0;if((a|0)!=1){break f}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break g}Q(a|0);p()}Z();break a}T(0)|0;Rb()}p()}c=2}$j(x[x[a>>2]-12>>2]+a|0,c)}fb=e+16|0;return a|0}function Em(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;tl(a);a:{b:{c:{f=x[b+32>>2];d:{if(!f){e=x[b+2084>>2];if(e){break d}break b}c=x[b+4>>2];if((c|0)<9){break c}e=x[b+2084>>2];if(!e){break c}}h=x[a+1392>>2];j=Dm(h);d=x[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=A[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=x[a+1396>>2];c=y[b+23|0]?c:x[x[b+2088>>2]+(c<<2)>>2];b=y[c+x[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}x[a+1392>>2]=h>>>b;b=d-b|0}x[a+1396>>2]=b;return c}if(y[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=y[x[b+8>>2]+d|0];if((c|0)==255){break f}g=x[a+1392>>2];if(x[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=x[a+1396>>2];if((e|0)>=(c|0)){x[a+1392>>2]=g>>>c;x[a+1396>>2]=e-y[x[b+8>>2]+d|0];return d}x[a+1396>>2]=0;break b}d=d+1|0;continue}break}fc(a,21);x[a+1396>>2]=0}return-1}_(11399,13279,1705,5465);p()}function O$(a){var b=0,c=0,d=0,e=0,f=0,g=0;if((y[a|0]-16&255)>>>0>=241){e=a+1954|0;c=a+1698|0;a:{b:{while(1){if((c|0)==(e|0)){c=0;e=0;while(1){b=32;if((c|0)==32){break a}d=D(c,13)+a|0;if(y[d+14|0]){break b}b=(c<<4)+a|0;if(y[b+418|0]|y[b+419|0]<<8|(y[b+420|0]<<16|y[b+421|0]<<24)){break b}f=y[b+422|0]|y[b+423|0]<<8|(y[b+424|0]<<16|y[b+425|0]<<24);if(y[d+942|0]|f>>>0>1048575){break b}d=D(c,11)+a|0;g=d+1346|0;if(y[g|0]>15|y[d+1351|0]>3|y[d+1356|0]>3){break b}c:{d:{e:{if(f){d=y[b+430|0]|y[b+431|0]<<8|(y[b+432|0]<<16|y[b+433|0]<<24);if(d>>>0<=1048574&(d>>>0<(y[b+426|0]|y[b+427|0]<<8|(y[b+428|0]<<16|y[b+429|0]<<24))>>>0|d>>>0>f>>>0)){break b}b=1;if(e){break c}if(f){break d}break e}b=1;if(e){break c}}if(Ob(g,24861,11)){break d}b=0;break c}b=1}e=b;c=c+1|0;continue}}b=v[c|0];c=c+1|0;if((b|0)>-2){continue}break}return 0}b=c}a=b>>>0>31&e}else{a=0}return a}function taa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;b=x[a>>2];a=x[b>>2];d=x[a+4>>2];x[c+40>>2]=x[a+20>>2];e=x[a+16>>2];x[c+32>>2]=x[a+12>>2];x[c+36>>2]=e;Sf(c+48|0,c+32|0,d);a=x[b+4>>2];d=x[a+8>>2];e=x[a+4>>2];b=x[c+60>>2];x[c+24>>2]=x[c+56>>2];x[c+28>>2]=b;b=x[c+52>>2];x[c+16>>2]=x[c+48>>2];x[c+20>>2]=b;x[c+8>>2]=x[a+8>>2];b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;a:{b:{c:{d:{f=x[c+4>>2];if(f>>>0>=e>>>0){if(A[c+20>>2]<e>>>0){break d}if(d>>>0>A[c+8>>2]){break c}g=x[c+28>>2];if(d>>>0>x[c+24>>2]-g>>>0){break b}h=x[c+16>>2];i=x[c>>2];b=0;e:while(1){if((b|0)==(d|0)){break a}j=b+g|0;k=D(b,f);a=0;while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{B[x[(a<<2)+h>>2]+(j<<2)>>2]=C[(a+k<<3)+i>>3];a=a+1|0;continue}}}_(7264,9065,77,8745);p()}_(7229,9065,78,8745);p()}_(5917,9065,79,8745);p()}_(5887,9065,80,8745);p()}fb=c- -64|0}function xy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=y[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=x[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=x[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;e=y[b|0];if((e|0)!=61){b=c+1|0;if(e){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;c:{if(y[g+a|0]){break c}f=x[125082];if(!f){break c}b=x[f>>2];if(!b){break c}while(1){d:{c=a;e=b;i=0;h=g;d=0;e:{if(!g){break e}d=y[c|0];f:{if(!d){break f}while(1){g:{j=y[e|0];if(!j){break g}h=h-1|0;if(!h|(d|0)!=(j|0)){break g}e=e+1|0;d=y[c+1|0];c=c+1|0;if(d){continue}break f}break}i=d}d=(i&255)-y[e|0]|0}if(!d){b=b+g|0;if(y[b|0]==61){break d}}b=x[f+4>>2];f=f+4|0;if(b){continue}break c}break}k=b+1|0}return k}function ZO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;b=x[a>>2];zb(g+12|0,b);a:{b:{c:{d:{e:{if(xd(x[b+16>>2])){while(1){if(c>>>0>31){break e}x[31785]=0;d=ca(71)|0;e=x[31785];x[31785]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=T(125824)|0;if((gb|0)!=($(125824)|0)){break c}Y(c|0)|0;v[b+20|0]=0;x[31785]=0;W(59,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}Z();break e}v[b+20|0]=0}if(!y[b+20|0]){d=x[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=x[d+2496>>2];e=d+(b<<2)|0;i=x[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=x[d+(h<<2)>>2];b=i^(b&2147483647|x[e>>2]&-2147483648)>>>1^0-(b&1)&-1727483681;x[e>>2]=b;x[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}fb=g+16|0;break a}c=N()|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break b}}Q(c|0);p()}T(0)|0;Rb();p()}return x[a+28>>2]&f}function oq(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;a:{b:{switch(y[a+480224|0]-1|0){default:b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2]<<1;e=sua(b,d,5e4,0);f=hb;b=x[_c(c+8|0,c)>>2];b=Fc(tua(e,f,b,b>>31),hb);x[a+1074404>>2]=b;break a;case 1:b=x[a+24620>>2];x[c+8>>2]=1;x[c+12>>2]=0;g=c,h=sua(x[a+1074420>>2],0,sua(x[a+1074408>>2],0,x[a+1074416>>2],0),hb),x[g>>2]=h;x[c+4>>2]=hb;b=sua(b,0,6e5,0);d=c+8|0;f=b;e=hb;b=Cw(x[d>>2],x[d+4>>2],x[c>>2],x[c+4>>2])?c:d;b=uua(f,e,x[b>>2],x[b+4>>2]);x[a+1074404>>2]=b;break a;case 0:break b}}b=x[a+24620>>2];d=b>>31;x[c+8>>2]=1;x[c>>2]=x[a+1074420>>2];e=sua(b,d,1e4,0);f=hb;b=x[_c(c+8|0,c)>>2];b=Fc(tua(e,f,b,b>>31),hb);x[a+1074404>>2]=b}d=a+1074404|0;a=x[a+480244>>2];b=sua(a,a>>31,b,b>>31);a=hb;b=b+32768|0;a=b>>>0<32768?a+1|0:a;a=Fc(tua(b,a,65536,0),hb);x[d>>2]=a>>>0<=1?1:a;fb=c+16|0}function zG(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:ne(a,0,c);break a;case 1:ne(a,1,c);break a;case 2:ne(a,2,c);break a;case 3:ne(a,3,c);break a;case 4:ne(a,4,c);break a;case 5:ne(a,5,c);break a;case 6:ne(a,6,c);break a;case 7:ne(a,7,c);break a;case 8:ne(a,8,c);break a;case 9:ne(a,9,c);break a;case 10:ne(a,10,c);break a;case 11:ne(a,11,c);break a;case 12:ne(a,12,c);break a;case 13:ne(a,13,c);break a;case 14:ne(a,14,c);break a;case 15:ne(a,15,c);break a;case 16:ne(a,16,c);break a;case 17:ne(a,17,c);break a;case 18:ne(a,18,c);break a;case 19:ne(a,19,c);break a;case 20:yG(a,71696,c);break a;case 21:yG(a,72720,c);break a;case 22:ne(a,20,c);break a;case 23:ne(a,21,c);break a;case 24:ne(a,22,c);break a;case 25:ne(a,23,c);break a;case 26:ne(a,24,c);break a;case 27:ne(a,25,c);break a;case 28:ne(a,26,c);break a;default:break b}}Fb(a)}}function rE(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{switch(b|0){case 0:pe(a,0,c);break a;case 1:pe(a,1,c);break a;case 2:pe(a,2,c);break a;case 3:pe(a,3,c);break a;case 4:pe(a,4,c);break a;case 5:pe(a,5,c);break a;case 6:pe(a,6,c);break a;case 7:pe(a,7,c);break a;case 8:pe(a,8,c);break a;case 9:pe(a,9,c);break a;case 10:pe(a,10,c);break a;case 11:pe(a,11,c);break a;case 12:pe(a,12,c);break a;case 13:pe(a,13,c);break a;case 14:pe(a,14,c);break a;case 15:pe(a,15,c);break a;case 16:pe(a,16,c);break a;case 17:pe(a,17,c);break a;case 18:pe(a,18,c);break a;case 19:pe(a,19,c);break a;case 20:qE(a,71696,c);break a;case 21:qE(a,72720,c);break a;case 22:pe(a,20,c);break a;case 23:pe(a,21,c);break a;case 24:pe(a,22,c);break a;case 25:pe(a,23,c);break a;case 26:pe(a,24,c);break a;case 27:pe(a,25,c);break a;case 28:pe(a,26,c);break a;default:break b}}Fb(a)}}function Gw(a,b,c,d){var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;a:{if(!c){break a}if(d){b=gc(g+8|0,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];b:{if(!d){d=x[b>>2];break b}c=32-d|0;x[a+8>>2]=c;e=x[b>>2];h=c;c=x[Gb(a+8|0,a+12|0)>>2];x[e>>2]=-1<<d&-1>>>h-c|x[e>>2];c=x[a+12>>2]-c|0;x[a+12>>2]=c;d=e+4|0;x[b>>2]=d}x[a+4>>2]=-1;e=d;d=c>>>5|0;sF(e,d,a+4|0);e=x[a+12>>2];c=c&-32;f=e-c|0;x[a+12>>2]=f;if((c|0)!=(e|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]|-1>>>32-f}fb=a+16|0;break a}b=gc(g,a,b);a=fb-16|0;fb=a;x[a+12>>2]=c;d=x[b+4>>2];c:{if(!d){d=x[b>>2];break c}e=32-d|0;x[a+8>>2]=e;c=x[b>>2];f=x[c>>2];h=e;e=x[Gb(a+8|0,a+12|0)>>2];x[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=x[a+12>>2];d=c+4|0;x[b>>2]=d;c=f-e|0}e=d;d=c>>>5|0;rF(e,d);e=c&31;x[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=x[b>>2]+(d<<2)|0;x[c>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-e^-1)}fb=a+16|0}fb=g+16|0}function lka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;b=x[a+4>>2];if(Ad(y[b+223884|0])){oT(b+223860|0);b=x[a+4>>2]}x[a+24>>2]=0;x[a+28>>2]=0;x[b>>2]=0;c=x[a>>2];x[b+40>>2]=x[c+480196>>2];x[b+44>>2]=x[c+480204>>2];x[b+80>>2]=x[c+480200>>2];c=z[c+480188>>1];x[f+8>>2]=0;x[f+12>>2]=0;d=f+8|0;w[d+4>>1]=65280;x[d>>2]=0;e=fb-16|0;fb=e;x[e+12>>2]=c;b=a+8|0;a:{if(Ln(b)>>>0>=c>>>0){g=x[b>>2];h=gh(g,x[b+4>>2]);x[e+8>>2]=h;i=x[Gb(e+12|0,e+8|0)>>2];while(1){if(i){x[g>>2]=x[d>>2];w[g+4>>1]=z[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){zS(b,c-h|0,d);break a}aG(b,x[b>>2]+(c<<3)|0);break a}HT(b);WT(b,Wr(b,c));zS(b,c,d)}fb=e+16|0;b=0;while(1){c=x[a>>2];if(z[c+480188>>1]<=b>>>0){fb=f+16|0}else{d=D(b,872);Jo((d+x[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+x[a+4>>2]|0;w[c+1432>>1]=0;v[c+1415|0]=0;b=b+1|0;continue}break}}function Tla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=fb-16|0;fb=e;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];h=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=h;l=b+24|0;h=x[a+8>>2];m=x[a+12>>2];while(1){if(d){b=x[e+8>>2];n=(((x[e+12>>2]&2147483647)<<1|b>>>31)&-2)+k|0;b=(((b>>>16|0)+4&131064)<<1)+l|0;o=w[b+14>>1];p=w[b+12>>1];q=w[b+10>>1];r=w[b+8>>1];s=w[b+6>>1];t=w[b+4>>1];u=w[b+2>>1];b=w[b>>1];g=0;while(1){if((g|0)!=2){f=g+n|0;x[(g<<2)+e>>2]=((((D(v[f+4|0],q)+D(v[f+2|0],r)|0)+D(v[f+6|0],p)|0)+D(v[f+8|0],o)<<8>>1)+(((D(v[f-4|0],u)+D(v[f-6|0],b)|0)+D(v[f-2|0],t)|0)+D(v[f|0],s)<<8>>1)|0)/16384;g=g+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[e>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[e+4>>2],i);Qb(e+8|0,h,m);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;e=Fb(d+20|0);a:{b:{c:{if(c>>>0<64){break c}x[31785]=0;c=R(187,b|0)|0;f=x[31785];x[31785]=0;d:{if((f|0)!=1){x[d+16>>2]=c;if((c|0)>0){break d}x[31785]=0;P(37,a|0,22485)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break b}}break a}x[31785]=0;c=R(205,b|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){g=d,h=Vi(c),x[g+12>>2]=h;c=x[pd(d+16|0,d+12|0)>>2];x[31785]=0;O(117,e|0,c|0);c=x[31785];x[31785]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{x[31785]=0;c=R(200,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break f}if(!c){break e}x[31785]=0;U(897,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=x[31785];x[31785]=0;if((c|0)!=1){continue}}break}break a}x[31785]=0;P(186,b|0,4)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}Yc(a,e)}tb(e);fb=d+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=XB(c+4|0,a);Yz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}h=fb-32|0;fb=h;c=Ab(a);c=hg(h+12|0,Tf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Yz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+4;f=fb-16|0;fb=f;b=zb(f+12|0,x[a+4>>2]);d=zb(f+8|0,x[a>>2]);g=zb(f+4|0,x[c+4>>2]);e=x[b>>2];i=x[d>>2];b=fb-16|0;fb=b;x[b+8>>2]=x[g>>2];x[b+12>>2]=e;while(1){g=x[b+8>>2];if(Pg(e,i)){d=fb-16|0;fb=d;x[d+12>>2]=g;fY(d+12|0,-1);fb=d+16|0;Yz(x[d+12>>2],qi(e));e=EQ(b+12|0);EQ(b+8|0);e=x[e>>2];continue}break}fb=b+16|0;x[c+4>>2]=g;wc(a,c+4|0);wc(a+4|0,c+8|0);wc(Ab(a),Ac(c));x[c>>2]=x[c+4>>2];fb=f+16|0;a=x[c+4>>2];while(1){b=x[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;x[c+8>>2]=b;Ig(b);continue}break}a=x[c>>2];if(a){Kz(c);Db(a)}fb=h+32|0}function iua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;jd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=zr(a+4|0,a);d=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=d;c=zr(a+8|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=f;c=(y[a+15|0]|y[a+16|0]<<8)<<1;x[b+24>>2]=c;c=y[a+15|0]|y[a+16|0]<<8?c:16726;x[b+24>>2]=c;g=b,h=(D(iw(v[a+17|0],y[a+14|0]<<28>>24),c)>>>0)/8363|0,x[g+24>>2]=h;v[e+15|0]=y[a+18|0];v[e+14|0]=127;g=b,h=(((y[Ub(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;c=y[a+14|0];if(c>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=c&240}c=y[a+19|0];if(c&4){w[b+34>>1]=z[b+34>>1]|1;c=y[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=z[b+34>>1];d=f|2;w[b+34>>1]=d;c=y[a+19|0];if(c&16){d=f|6;w[b+34>>1]=d;c=y[a+19|0]}if(!(c&64)){break a}w[b+34>>1]=d|128}fb=e+16|0}function XZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!y[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=y[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?((i|0)==10&y[d-1|0]==13)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&y[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}rf(a);js(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=v[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Ep(a,e);c=c+1|0;continue}break}}function KL(a,b,c,d){var e=0,f=E(0),g=0,h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=0;e=fb-96|0;fb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){B[e+48>>2]=-B[a>>2];B[e>>2]=B[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=B[g+4>>2];f=B[g+8>>2];B[i+4>>2]=h+f;k=d<<1;B[(8-k<<2)+e>>2]=h-f;h=B[g+16>>2];f=B[g+12>>2];B[(7-k<<2)+e>>2]=h-f;B[i+8>>2]=-E(h+f);d=d+1|0;continue}break}JL(e+48|0);JL(e);B[e+4>>2]=-B[e+4>>2];B[e+12>>2]=-B[e+12>>2];B[e+20>>2]=-B[e+20>>2];B[e+28>>2]=-B[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=B[i>>2];f=B[d+(e+48|0)>>2];l=B[d+87840>>2];m=B[d+87876>>2];n=B[d+e>>2];B[i>>2]=E(f*l)-E(m*n);i=a+d|0;d=c+d|0;f=E(E(f*m)+E(n*l));B[i>>2]=E(h*B[d>>2])-E(B[d+36>>2]*f);B[(17-g<<2)+a>>2]=E(h*B[d+36>>2])+E(f*B[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}fb=e+96|0}function DP(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0),k=0,l=E(0),m=0,n=0,o=E(0);e=a+4208|0;j=E(E(B[wb(e,2)>>2]*E(2999.9990234375))+E(.0010000000474974513));l=E(B[wb(e,3)>>2]*E(.9980000257492065));f=-3e3/(+A[x[a+16>>2]+24620>>2]*+j);e=a+4272|0;c=nk(10,f*+A[wb(e,4)>>2]);g=a+4232|0;n=wb(g,0),o=E(c),B[n>>2]=o;c=nk(10,f*+A[wb(e,5)>>2]);n=wb(g,1),o=E(c),B[n>>2]=o;m=f*(1/+E(l+E(.0010000000474974513))+-1);c=0;while(1){if((d|0)==4){d=a+4208|0;f=nk(10,+BP(B[wb(d,0)>>2])*.05);b=4/M(c)*f;c=nk(10,+BP(B[wb(d,1)>>2])*.1);B[a+4228>>2]=b*M(c);B[a+4224>>2]=f*M(1-c)}else{h=x[wb(e,d)>>2];k=d>>>1|0;i=nk(10,m*+(x[wb(e,d)>>2]+x[wb(e,k+4|0)>>2]>>>0));b=nk(10,f*+(h>>>0));j=B[wb(g,k)>>2];h=d<<1;i=(1-i)*.5;n=wb(g,h+2|0),o=E(b*(1-i)),B[n>>2]=o;n=wb(g,h+3|0),o=E(b*i),B[n>>2]=o;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;d=d+1|0;continue}break}}function q4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=TI(a,0);h=fb-32|0;fb=h;c=wI(f+12|0,b);d=c+172|0;i=c+4|0;a=i;while(1){a=Fb(a)+12|0;if((d|0)!=(a|0)){continue}break}e=c+460|0;a=d;while(1){a=Fb(a)+12|0;if((e|0)!=(a|0)){continue}break}g=c+484|0;a=e;while(1){a=Fb(a)+12|0;if((g|0)!=(a|0)){continue}break}g=Fb(g);j=Fb(c+496|0);k=Fb(c+508|0);l=Fb(c+520|0);x[31785]=0;a=P(1357,h+12|0,b|0)|0;b=x[31785];x[31785]=0;a:{b:{c:{if((b|0)!=1){x[31785]=0;O(1358,c|0,a|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}Ds(a);fb=h+32|0;break a}b=N()|0;break b}b=N()|0;Ds(a)}tb(l);tb(k);tb(j);a=tb(g);while(1){a=tb(a-12|0);if((e|0)!=(a|0)){continue}break}while(1){e=tb(e-12|0);if((e|0)!=(d|0)){continue}break}while(1){d=tb(d-12|0);if((i|0)!=(d|0)){continue}break}Fs(c);Q(b|0);p()}x[f+8>>2]=116844;x[f>>2]=116768;return f|0}function o4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=SI(a,0);h=fb-16|0;fb=h;c=wI(f+12|0,b);d=c+172|0;i=c+4|0;a=i;while(1){a=Fb(a)+12|0;if((d|0)!=(a|0)){continue}break}e=c+460|0;a=d;while(1){a=Fb(a)+12|0;if((e|0)!=(a|0)){continue}break}g=c+484|0;a=e;while(1){a=Fb(a)+12|0;if((g|0)!=(a|0)){continue}break}g=Fb(g);j=Fb(c+496|0);k=Fb(c+508|0);l=Fb(c+520|0);x[31785]=0;a=P(1359,h+4|0,b|0)|0;b=x[31785];x[31785]=0;a:{b:{c:{if((b|0)!=1){x[31785]=0;O(1360,c|0,a|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}Gs(a);fb=h+16|0;break a}b=N()|0;break b}b=N()|0;Gs(a)}Sb(l);Sb(k);Sb(j);a=Sb(g);while(1){a=Sb(a-12|0);if((e|0)!=(a|0)){continue}break}while(1){e=Sb(e-12|0);if((e|0)!=(d|0)){continue}break}while(1){d=Sb(d-12|0);if((i|0)!=(d|0)){continue}break}Fs(c);Q(b|0);p()}x[f+8>>2]=117140;x[f>>2]=117064;return f|0}function fO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb+-64|0;fb=e;a:{b:{if((b|0)>=0){d=x[a+24>>2];if(Lj(Wb(x[d+484360>>2],y[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=x[a+24>>2];g=x[f+484344>>2];i=x[f+484348>>2];h=z[_b(x[Wb(x[f+484360>>2],y[f+484376|0])>>2],b)>>1];if(!tn(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<x[Vb(g,h)+12>>2]){break c}}a=a+16|0;break a}w[f+1074448>>1]=b;c=f;f=b&65535;LR(c,f);c=x[a+24>>2];x[c+1074392>>2]=-2;x[c+1074428>>2]=d;g=y[a+64|0];b=e+24|0;w[b+4>>1]=0;v[b+6|0]=255;x[b+16>>2]=2;x[b>>2]=0;w[b+12>>1]=f;x[b+8>>2]=d;d=x[b+20>>2];x[e+16>>2]=x[b+16>>2];x[e+20>>2]=d;d=x[b+12>>2];x[e+8>>2]=x[b+8>>2];x[e+12>>2]=d;d=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=d;b=e+52|0;qv(b,c,g?7:1,e);j=a,k=C[KB(x[e+56>>2])>>3],C[j+16>>3]=k;Ui(b);a=a+16|0}fb=e- -64|0;return+C[a>>3]}function mra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;c=Bf(a,c);Yd(e,x[a+36>>2]);i=a;a:{if(!c){Pc(e,a+32|0,5);d=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}d=fb-32|0;fb=d;f=x[a+36>>2];kg(f,d+30|0);b:{c:{d:{e:{a=z[d+30>>1];if(a>>>0>=4001){j=x[b+12>>2];a=fb-16|0;fb=a;g=d+4|0;h=uc(a+4|0,16138);Yc(g,h);tb(h);fb=a+16|0;x[31785]=0;S(494,d+16|0,g|0,d+30|0);a=x[31785];x[31785]=0;if((a|0)==1){break e}a=x[j+1298472>>2];x[31785]=0;S(389,a|0,2,d+16|0);a=x[31785];x[31785]=0;if((a|0)==1){break d}tb(d+16|0);Eb(d+4|0);a=4e3}tg(Sj(x[b>>2],0),a);b=Sj(x[b>>2],0);k=d,l=vb(x[b>>2]),x[k+16>>2]=l;b=vb(x[b+4>>2]);break b}b=N()|0;break c}b=N()|0;tb(d+16|0)}Eb(d+4|0);Q(b|0);p()}while(1){a=x[d+16>>2];if(Ib(a,b)){kg(f,d+4|0);w[a>>1]=z[d+4>>1];Wd(d+16|0);continue}break}fb=d+32|0;d=c}cf(i,d);fb=e+16|0}function dK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0;o(+a);b=j(1)|0;e=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){if(!(b&2147483647|e)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}c=1072693248;k=-1023;if((b|0)!=1072693248){c=b;break b}if(e){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;e=j(0)|0;c=b;k=-1077}l(0,e|0);c=c+614242|0;l(1,(c&1048575)+1072079006|0);d=+n()+-1;f=d*(d*.5);g=d/(d+2);h=g*g;a=h*h;o(+(d-f));b=j(1)|0;j(0)|0;l(0,0);l(1,b|0);i=+n();m=i*1.4426950407214463;p=+((c>>>20|0)+k|0);q=m+p;a=g*(f+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+h*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+(d-i-f);a=q+(m+(p-q)+((a+i)*1.6751713164886512e-10+a*1.4426950407214463))}return a}function jR(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=fb-16|0;fb=k;v[k+15|0]=c;v[k+14|0]=12;dh(b,y[Ub(k+15|0,k+14|0)|0]);c=0;l=x[b>>2];m=x[b+4>>2];p=Od(l,m);while(1){if((c|0)==(p|0)){c=0;v[b+12|0]=0;a:{if(!(d&1)){break a}if(mc(l,m)){break a}c=1;v[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;v[b+12|0]=c}v[b+15|0]=e;v[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){v[b+12|0]=c|2}v[b+14|0]=g;v[b+13|0]=f}fb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=wb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+96|0]|y[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=wb(l,c);i=(c<<2)+a|0;w[j>>1]=y[i+144|0]|y[i+145|0]<<8;i=i+146|0}v[j+2|0]=y[i|0]}e:{if(!c){break e}i=wb(l,c);j=z[i>>1];n=wb(l,c-1|0);o=z[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;w[i>>1]=j;if(j>>>0>=z[n>>1]){break e}w[i>>1]=j+256}c=c+1|0;continue}break}}function tma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;p=w[e+38390>>1];q=w[e+38388>>1];r=w[e+38386>>1];e=w[e+38384>>1];h=0;while(1){if((h|0)!=2){i=(h<<1)+o|0;x[(h<<2)+b>>2]=(((D(w[i>>1],r)+D(w[i-4>>1],e)|0)+D(w[i+4>>1],q)|0)+D(w[i+8>>1],p)|0)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Qb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function jja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;jd(c,0);w[c+28>>1]=y[a+36|0]<<2;d=y[a+37|0];w[c+32>>1]=64;w[c+30>>1]=d<<2;x[c>>2]=y[a+40|0]|y[a+41|0]<<8|(y[a+42|0]<<16|y[a+43|0]<<24);x[c+4>>2]=y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24);x[c+8>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[c+24>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);d=y[b+151|0];if(d>>>0<=4){v[c+38|0]=y[d+41418|0]}d=y[b+152|0]|y[b+153|0]<<8;v[c+39|0]=d;e=(y[b+156|0]|y[b+157|0]<<8)>>>4|0;v[c+41|0]=e;b=(y[b+154|0]|y[b+155|0]<<8)>>>2|0;v[c+40|0]=b;if((b|e)&255){v[c+39|0]=d^-1}b=y[a+38|0]|y[a+39|0]<<8;if(b&4){w[c+34>>1]=z[c+34>>1]|1;b=y[a+38|0]|y[a+39|0]<<8}if(b&8){w[c+34>>1]=z[c+34>>1]|2;b=y[a+38|0]|y[a+39|0]<<8}if(b&16){w[c+34>>1]=z[c+34>>1]|4;b=y[a+38|0]|y[a+39|0]<<8}if(b&32){w[c+34>>1]=z[c+34>>1]|32}}function SA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=z[a+480188>>1];h=d>>>0<=256?256:d;f=x[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=D(c,872)+a|0;if(!x[e+1075068>>2]){if(!Gj(x[e+1075648>>2])|y[e+1075081|0]&24){break a}}if(y[e+1075081|0]&2){if(!xd(f)){break a}if(!wS(f,c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=D(b,872)+a|0;if(!x[b+1075688>>2]){c=65535;if(x[b+1075068>>2]){break a}}g=x[b+1075680>>2]|x[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=D(d,872)+a|0;if(!(x[b+1075688>>2]?0:x[b+1075068>>2])){c=(x[b+1075680>>2]|x[b+1075672>>2]<<9)>>>(x[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=x[(D(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=x[(D(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function M6(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=qJ(c);b:{if(b){b=k+4|0;il(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;hl(b,a);break b}b=k+4|0;Ls(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;hi(b,a)}mh(i,b);Sb(b);l=e,m=qj(a),x[l>>2]=m;l=f,m=rj(a),x[l>>2]=m;b=k+4|0;ph(b,a);yb(g,b);tb(b);ii(b,a);mh(h,b);Sb(b);a=Kk(a);break a}a=pJ(c);c:{if(b){b=k+4|0;il(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;hl(b,a);break c}b=k+4|0;Ls(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;hi(b,a)}mh(i,b);Sb(b);l=e,m=qj(a),x[l>>2]=m;l=f,m=rj(a),x[l>>2]=m;b=k+4|0;ph(b,a);yb(g,b);tb(b);ii(b,a);mh(h,b);Sb(b);a=Kk(a)}x[j>>2]=a;fb=k+16|0}function Gja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-48|0;fb=b;e=30864;a=Nb(a);a:{while(1){b:{if((e|0)==31288){e=31296;break b}c=pc(b+40|0,x[e+4>>2]);f=x[b+44>>2];c:{if(!f){break c}d=x[a+4>>2];if(!mc(x[a>>2],d)){c=x[c>>2];d=pc(b+32|0,x[qi(d)>>2]);g=x[d+4>>2];x[b+8>>2]=x[d>>2];x[b+12>>2]=g;if(!pC(c,f,b+8|0)){break c}}x[31785]=0;O(893,a|0,e+4|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}}e=e+8|0;continue}break}d:{while(1){if((e|0)==31344){break d}c=pc(b+40|0,x[e+8>>2]);e:{f=x[b+44>>2];f:{if(!f){break f}d=x[a+4>>2];if(!mc(x[a>>2],d)){g=x[c>>2];d=pc(b+24|0,x[qi(d)>>2]);h=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=h;if(!pC(g,f,b)){break f}}c=x[c>>2];x[31785]=0;x[b+20>>2]=c;O(894,a|0,b+20|0);c=x[31785];x[31785]=0;if((c|0)==1){break e}}e=e+12|0;continue}break}break a}fb=b+48|0;return}b=N()|0;sc(a);Q(b|0);p()}function Roa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=d+11|0;ZW(a,c);if(Ob(c,13684,4)){b=1}else{ZW(a,d+11|0);v[b|0]=1;b=0}a=fb-176|0;fb=a;c=a+12|0;Ew(c,(d+11|0)+b|0);x[31785]=0;O(127,a+24|0,c|0);b=x[31785];x[31785]=0;a:{b:{c:{d:{e:{if((b|0)!=1){x[31785]=0;b=P(106,a+36|0,a+24|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}tb(a+24|0);tb(a+12|0);c=x[x[b>>2]-12>>2];x[31785]=0;e=ca(107)|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}x[31785]=0;S(108,a+8|0,b+c|0,e|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}Zb(a+8|0);x[31785]=0;w[a+24>>1]=0;c=P(690,b|0,a+24|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}b=pk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2]);e=z[a+24>>1];Af(c);fb=a+176|0;a=(b?0:e)&65535;break a}d=N()|0;break d}d=N()|0;tb(a+24|0)}tb(a+12|0);break b}d=N()|0;Af(b)}Q(d|0);p()}fb=d+16|0;return a|0}function OV(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=fb-16|0;fb=f;l=x[a+20>>2];g=z[a+34>>1]&65;x[f+12>>2]=g;x[f+8>>2]=g^65;g=b;m=d+1298224|0;e=d+1074992|0;i=Ej(d);n=a+4|0;o=a+12|0;p=a+8|0;q=a+16|0;r=d+480180|0;while(1){if((e|0)!=(m|0)){if(x[e+104>>2]==(a|0)){if(x[e+16>>2]){x[e+16>>2]=g}if(A[e+4>>2]>c>>>0){x[e>>2]=0;x[e+4>>2]=0}b=a;if(x[e+76>>2]){vc(e+76|0,c);b=x[e+104>>2]}d=x[e+88>>2];b=CF(d,b);h=x[(b?o:n)>>2];x[e+84>>2]=x[(b?q:p)>>2];x[e+80>>2]=h;b=d|x[f+12>>2];x[e+88>>2]=b;x[e+88>>2]=b&(x[f+8>>2]^-1);d=x[e+704>>2];b=x[a+24>>2];a:{if(!d|!b){break a}if(on(x[r>>2])){break a}h=sua(x[e+700>>2],0,i?b:d,0);d=i?d:b;j=h+(d>>>1|0)|0;k=hb;s=e,t=Bc(uua(j,h>>>0>j>>>0?k+1|0:k,d,0),hb),x[s+700>>2]=t}x[e+704>>2]=b}e=e+872|0;continue}break}x[a>>2]=c;x[a+20>>2]=g;QB(l);fb=f+16|0}function Q6(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=fb-16|0;fb=k;a:{if(a){a=uJ(c);b:{if(b){b=k+4|0;il(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;hl(b,a);break b}b=k+4|0;Ls(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;hi(b,a)}yb(i,b);tb(b);l=e,m=qj(a),v[l|0]=m;l=f,m=rj(a),v[l|0]=m;b=k+4|0;ph(b,a);yb(g,b);tb(b);ii(b,a);yb(h,b);tb(b);a=Kk(a);break a}a=tJ(c);c:{if(b){b=k+4|0;il(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;hl(b,a);break c}b=k+4|0;Ls(b,a);c=x[k+4>>2];v[d|0]=c;v[d+1|0]=c>>>8;v[d+2|0]=c>>>16;v[d+3|0]=c>>>24;hi(b,a)}yb(i,b);tb(b);l=e,m=qj(a),v[l|0]=m;l=f,m=rj(a),v[l|0]=m;b=k+4|0;ph(b,a);yb(g,b);tb(b);ii(b,a);yb(h,b);tb(b);a=Kk(a)}x[j>>2]=a;fb=k+16|0}function $ja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-880|0;fb=b;c=Tb(a,0,76);x[c+84>>2]=0;x[c+88>>2]=0;x[c+80>>2]=256;w[c+76>>1]=65535;x[c+92>>2]=0;x[c+96>>2]=0;v[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=DV(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Nb(d);g=XA(c+223860|0);f=b+8|0;Tb(f,0,108);aC(b+120|0,48e3);Tb(b+664|0,0,72);v[b+754|0]=0;w[b+752>>1]=65535;v[b+746|0]=0;w[b+744>>1]=65535;v[b+738|0]=0;w[b+736>>1]=65535;x[b+748>>2]=0;x[b+740>>2]=0;Tb(b+756|0,0,103);x[b+868>>2]=0;x[b+872>>2]=0;v[b+875|0]=0;v[b+876|0]=0;v[b+877|0]=0;v[b+878|0]=0;x[b+860>>2]=0;x[b+864>>2]=0;v[b+859|0]=y[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=sq(e,f)+872|0;continue}break}x[31785]=0;O(556,d|0,32);a=x[31785];x[31785]=0;if((a|0)!=1){fb=b+880|0;return c|0}a=N()|0;tq(g);dc(d);Q(a|0);p()}function GL(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[a+32>>2];a:{b:{b=x[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=x[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=y[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(A[a+40>>2]<c>>>0){fc(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=x[a+40>>2];if(e>>>0<=c+26>>>0){fc(a,1);break a}if(Ob(c,126164,4)){fc(a,21);break a}if(y[c+4|0]){fc(a,21);break a}d:{if(d){if(!x[a+992>>2]|!(v[c+5|0]&1)){break d}fc(a,21);break a}if(v[c+5|0]&1){break d}fc(a,21);break a}b=0;f=c+27|0;d=y[c+26|0];c=f+d|0;if(e>>>0<c>>>0){fc(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=y[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}fc(a,1)}return 0}function zfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;x[31785]=0;W(1005,a|0);d=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}x[31785]=0;W(1006,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break g}x[31785]=0;W(1006,c|0);d=x[31785];x[31785]=0;if((d|0)==1){break g}f=x[a+24>>2];x[31785]=0;d=P(37,e+20|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break g}x[31785]=0;c=P(37,e+8|0,c|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break f}x[31785]=0;V(1021,f|0,d|0,c|0,1);b=x[31785];x[31785]=0;if((b|0)==1){break e}tb(c);tb(d);b=1;break b}b=T(0)|0;break c}b=T(0)|0;break d}b=T(0)|0;tb(c)}tb(d)}Y(b|0)|0;b=0;x[31785]=0;V(992,6429,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z()}fb=e+32|0;return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Qn(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;x[31785]=0;W(1005,a|0);e=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=x[a+24>>2];x[31785]=0;O(d|0,f+4|0,e|0);d=x[31785];x[31785]=0;if((d|0)==1){break i}d=x[f+4>>2];e=Qd(d,x[f+8>>2]);if(e>>>0<2147483647){break h}d=ac(8);x[31785]=0;b=P(1060,d|0,7449)|0;e=x[31785];x[31785]=0;if((e|0)==1){break g}x[31785]=0;S(100,b|0,125600,165);b=x[31785];x[31785]=0;if((b|0)!=1){break b}b=T(0)|0;break f}b=T(0)|0;break e}b=T(0)|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=xg(22485);break j}b=xg(Jb(Dd(d,b)))}Pd(f+4|0);break d}b=T(0)|0;jc(d)}Pd(f+4|0)}Y(b|0)|0;b=0;x[31785]=0;V(992,c|0,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Z()}fb=f+16|0;return b}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break a}T(0)|0;Rb()}p()}Q(a|0);p()}function qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=Mi(a,b,c,d);x[b+4260>>2]=0;x[b>>2]=45452;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Nb(d)+24|0;if((d|0)!=(c|0)){continue}break}v[b+5046|0]=1;w[b+5044>>1]=0;a=b+4208|0;f=wb(a,0),g=1063675494,x[f>>2]=g;f=wb(a,1),g=1065185444,x[f>>2]=g;f=wb(a,2),g=0,x[f>>2]=g;f=wb(a,3),g=1032805417,x[f>>2]=g;f=wb(a,4),g=1053079357,x[f>>2]=g;f=wb(a,5),g=1059859440,x[f>>2]=g;f=wb(a,6),g=1047457519,x[f>>2]=g;f=wb(a,7),g=1062836634,x[f>>2]=g;f=wb(a,8),g=1038174126,x[f>>2]=g;f=wb(a,9),g=1065353216,x[f>>2]=g;f=wb(a,10),g=1065353216,x[f>>2]=g;f=wb(a,11),g=1048525618,x[f>>2]=g;f=wb(a,12),g=1059760811,x[f>>2]=g;x[31785]=0;O(950,b+44|0,2);a=x[31785];x[31785]=0;if((a|0)==1){a=N()|0;while(1){c=sc(c-24|0);if((e|0)!=(c|0)){continue}break}Uf(b);Q(a|0);p()}return b|0}function T2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=Nb(a);a=0;a:{b:{c:{while(1){if((Dx(b,c,a)|0)==-1){break b}f=Dx(b,c,a);x[31785]=0;V(103,d+4|0,b|0,a|0,f-a|0);f=x[31785];x[31785]=0;if((f|0)!=1){x[31785]=0;O(104,e|0,d+4|0);f=x[31785];x[31785]=0;if((f|0)==1){break c}tb(d+4|0);a=Dx(b,c,a)+Wc(x[c+4>>2],y[c+11|0])|0;continue}break}a=N()|0;break a}a=N()|0;tb(d+4|0);break a}d:{e:{f:{g:{if(mc(x[e>>2],x[e+4>>2])){x[31785]=0;V(103,d+4|0,b|0,a|0,-1);c=x[31785];x[31785]=0;if((c|0)==1){break f}c=Wc(x[d+8>>2],y[d+15|0]);tb(d+4|0);if(!c){break g}}x[31785]=0;V(103,d+4|0,b|0,a|0,-1);a=x[31785];x[31785]=0;if((a|0)==1){break e}x[31785]=0;O(104,e|0,d+4|0);a=x[31785];x[31785]=0;if((a|0)==1){break d}tb(d+4|0)}fb=d+16|0;return}a=N()|0;break a}a=N()|0;break a}a=N()|0;tb(d+4|0)}Pd(e);Q(a|0);p()}function TJ(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=fb-32|0;fb=h;a:{b:{c:{if((b|0)!=(c|0)){j=x[31660];x[31660]=0;g=fb-16|0;fb=g;Kd();e=fb-16|0;fb=e;f=fb-16|0;fb=f;uy(f,b,h+28|0,2);k=x[f>>2];i=x[f+4>>2];b=x[f+12>>2];x[e+8>>2]=x[f+8>>2];x[e+12>>2]=b;x[e>>2]=k;x[e+4>>2]=i;fb=f+16|0;i=x[e>>2];f=x[e+4>>2];b=x[e+12>>2];x[g+8>>2]=x[e+8>>2];x[g+12>>2]=b;x[g>>2]=i;x[g+4>>2]=f;fb=e+16|0;f=x[g>>2];e=x[g+4>>2];b=x[g+12>>2];x[h+16>>2]=x[g+8>>2];x[h+20>>2]=b;x[h+8>>2]=f;x[h+12>>2]=e;fb=g+16|0;g=x[h+16>>2];i=x[h+20>>2];e=x[h+8>>2];f=x[h+12>>2];b=x[31660];if(!b){break c}if(x[h+28>>2]!=(c|0)){break b}l=e;m=f;n=g;o=i;if((b|0)!=68){break a}break b}x[d>>2]=4;break a}x[31660]=j;if(x[h+28>>2]==(c|0)){break a}}x[d>>2]=4;e=l;f=m;g=n;i=o}x[a>>2]=e;x[a+4>>2]=f;x[a+8>>2]=g;x[a+12>>2]=i;fb=h+32|0}function Eq(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;a:{g=x[a>>2];e=x[a+4>>2];if(mc(g,e)){break a}i=Od(g,e)-1|0;while(1){b:{c:{if(Od(g,e)-1>>>0<=f>>>0){f=i;break c}if(z[Nc(g,e,f)>>1]<(b|0)){break b}e=x[a+4>>2];g=x[a>>2]}i=z[Nc(g,e,f)>>1];g=0;x[h+12>>2]=0;d:{if((b|0)>=(i|0)){j=h,k=(y[Nc(x[a>>2],x[a+4>>2],f)+2|0]<<16>>>0)/(d>>>0)|0,x[j+12>>2]=k;break d}e=0;if(f){e=f-1|0;g=(y[Nc(x[a>>2],x[a+4>>2],e)+2|0]<<16>>>0)/(d>>>0)|0;x[h+12>>2]=g;e=z[Nc(x[a>>2],x[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=i>>>0){break d}a=((y[Nc(x[a>>2],x[a+4>>2],f)+2|0]<<16>>>0)/(d>>>0)|0)-g|0;d=a;f=a>>31;a=b-e|0;b=sua(d,f,a,a>>31);a=i-e|0;j=h,k=Fc(tua(b,hb,a,a>>31),hb)+g|0,x[j+12>>2]=k}Ee(h+12|0,0,65536);f=(D(x[h+12>>2],c)+32768|0)/65536|0;break a}f=f+1|0;e=x[a+4>>2];g=x[a>>2];continue}}fb=h+16|0;return f}function uma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+32>>2];l=x[a+28>>2];m=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;p=w[e+38390>>1];q=w[e+38388>>1];r=w[e+38386>>1];e=w[e+38384>>1];h=0;while(1){if((h|0)!=2){i=h+o|0;x[(h<<2)+b>>2]=(((D(v[i|0],r)+D(v[i-2|0],e)|0)+D(v[i+2|0],q)|0)+D(v[i+4|0],p)<<8)/16384;h=h+1|0;continue}break}g=g+l|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+k|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Qb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Qla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Qb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function cr(a,b){var c=0;c=fb-16|0;fb=c;a=Qr(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(Lb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:EA(c,2);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Yf(a,107);break a;case 3:EA(c,4);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b;Yf(a,4);break a;case 2:break b;case 0:break c}}Lb(a,88,1);break a}EA(c,b);b=x[c+12>>2];x[a+8>>2]=x[c+8>>2];x[a+12>>2]=b;b=x[c+4>>2];x[a>>2]=x[c>>2];x[a+4>>2]=b}fb=c+16|0}function qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((jk(x[a>>2],x[a+4>>2])|0)==2){if((jk(x[a+12>>2],x[a+16>>2])|0)==(b|0)){break b}}x[31785]=0;O(952,a|0,2);c=x[31785];x[31785]=0;c:{if((c|0)==1){break c}x[31785]=0;O(952,a+12|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}x[31785]=0;O(953,a+24|0,2);c=x[31785];x[31785]=0;if((c|0)==1){break c}x[31785]=0;O(953,a+36|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=Mr(x[c+12>>2],a);f=wb(x[c+36>>2],a),g=d,x[f>>2]=g;a=a+1|0;continue}}else{e=Mr(x[a>>2],d);f=wb(x[a+24>>2],d),g=e,x[f>>2]=g;d=d+1|0;continue}}b=T(125240)|0;if((gb|0)!=($(125240)|0)){break a}Y(b|0)|0;Xz(a);DQ(a);b=a+12|0;Xz(b);DQ(b);b=a+24|0;Gf(b);CQ(b);a=a+36|0;Gf(a);CQ(a);Z()}return}Q(b|0);p()}function epa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb+-64|0;fb=c;j=c,k=jf(a)>>>5|0,w[j+32>>1]=k;w[c+20>>1]=3999;i=b+480190|0;d=z[Mc(c+32|0,c+20|0)>>1];w[i>>1]=d;g=1;while(1){f=g&65535;if(f>>>0<=d>>>0){d=ri(b,f);e=c+32|0;ov(a,e);jd(d,0);h=c+8|0;Zj(h,2,e);e=c+20|0;Ec(e,h);zc(((f<<5)+b|0)+946304|0,e);tb(e);x[d+24>>2]=8287;j=c,k=Cb(y[c+60|0]|y[c+61|0]<<8),w[j+20>>1]=k;w[c+8>>1]=64;j=d,k=z[Mc(e,h)>>1]<<2,w[j+30>>1]=k;j=d,k=$b(y[c+52|0]|y[c+53|0]<<8|(y[c+54|0]<<16|y[c+55|0]<<24))&-2,x[j>>2]=k;e=Cb(y[c+62|0]|y[c+63|0]<<8);j=wb(d+68|0,0),k=e,x[j>>2]=k;e=Cb(y[c+56|0]|y[c+57|0]<<8);f=Cb(y[c+58|0]|y[c+59|0]<<8);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>A[d>>2]){break a}x[d+16>>2]=f;x[d+12>>2]=e<<1;w[d+34>>1]=z[d+34>>1]|8}g=g+1|0;d=z[i>>1];continue}break}fb=c- -64|0}function Hia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=fb-16|0;fb=f;k=Bf(a,c);Yd(f,x[a+36>>2]);l=a;a:{if(!k){Pc(f,a+32|0,5);c=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}e=fb-48|0;fb=e;i=x[a+36>>2];ll(i,e+40|0);g=x[e+44>>2];if(!g&A[e+40>>2]>=257|g){x[e+40>>2]=256;x[e+44>>2]=0}g=x[e+40>>2];m=x[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=g>>>0){break b}kg(i,e+38|0);h=Fb(e+24|0);x[31785]=0;P(502,i|0,h|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){x[31785]=0;S(500,e+12|0,d|0,h|0);a=x[31785];x[31785]=0;if((a|0)==1){break e}x[31785]=0;a=P(940,b|0,e+38|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break d}j=a;a=e+12|0;yb(j,a);tb(a);tb(h);c=c+1|0;continue}break}c=N()|0;break c}c=N()|0;break c}c=N()|0;tb(e+12|0)}tb(h);Q(c|0);p()}fb=e+48|0;c=k}cf(l,c);fb=f+16|0}function ud(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=x[a+112>>2];d=x[a+116>>2];i=!!(b|d);e=b;f=x[a+4>>2];h=x[a+44>>2];b=f-h|0;g=b;c=b+x[a+120>>2]|0;b=x[a+124>>2]+(b>>31)|0;a:{b=c>>>0<g>>>0?b+1|0:b;if(!(((b|0)>=(d|0)&c>>>0>=e>>>0|(b|0)>(d|0))&i)){i=Cy(a);if((i|0)>=0){break a}f=x[a+4>>2];h=x[a+44>>2]}x[a+112>>2]=-1;x[a+116>>2]=-1;x[a+104>>2]=f;g=c;c=h-f|0;d=g+c|0;b=(c>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=c>>>0>d>>>0?b+1|0:b;return-1}d=c+1|0;b=d?b:b+1|0;f=x[a+4>>2];h=x[a+8>>2];e=x[a+116>>2];g=e;c=x[a+112>>2];b:{if(!(e|c)){break b}e=c-d|0;c=g-(b+(c>>>0<d>>>0)|0)|0;j=h-f|0;g=j>>31;if((c|0)>=(g|0)&e>>>0>=j>>>0|(c|0)>(g|0)){break b}h=e+f|0}x[a+104>>2]=h;c=x[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;x[a+120>>2]=d;x[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){v[f-1|0]=i}return i}function Iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=E(0);c=fb-4112|0;fb=c;h=ib[x[x[a>>2]+120>>2]](a)|0;if(!h){ib[x[x[a>>2]+124>>2]](a)}x[c+12>>2]=0;f=fb-16|0;fb=f;while(1){d=x[a+44>>2];if(jk(d,x[a+48>>2])>>>0<=e>>>0){fb=f+16|0}else{x[f+12>>2]=0;d=Mr(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){B[d>>2]=B[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){x[c+8>>2]=b;vc(c+8|0,512);e=c+16|0;IA(e);d=x[c+8>>2];ib[x[x[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;B[c+4>>2]=F(B[g>>2]);i=c,j=B[Pz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;B[c+4>>2]=F(B[g+2048>>2]);i=c,j=B[Pz(c+12|0,c+4|0)>>2],B[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){ib[x[x[a>>2]+128>>2]](a)}fb=c+4112|0;return E(B[c+12>>2])}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=fb+-64|0;fb=e;x[e+60>>2]=c;a=oe(a,e+60|0);c=rc(a+4|0);g=rc(a+24|0);h=rc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31785]=0;O(1e3,a|0,d|0);f=x[31785];x[31785]=0;a:{b:{c:{d:{if((f|0)!=1){le(e+24|0,x[b>>2],x[b+4>>2]);kf(e+32|0,x[e+24>>2],x[e+28>>2]);b=Jd(e+16|0);x[31785]=0;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;ws(1004,e+40|0,x[e+32>>2],x[e+36>>2],e+8|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;S(1001,a|0,e+40|0,d|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}ub(e+40|0);x[31785]=0;W(1002,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+40|0)}Pd(j);mf(i);yl(h);sh(g);rh(c);Uc(a);Uc(e+60|0);Q(d|0);p()}Uc(e+60|0);fb=e- -64|0;return a|0}function gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-96|0;fb=d;x[31785]=0;f=x[b+12>>2];x[d+40>>2]=x[b+8>>2];x[d+44>>2]=f;f=x[b+4>>2];x[d+32>>2]=x[b>>2];x[d+36>>2]=f;f=R(1158,d+32|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){a:{b:{if(f){x[31785]=0;O(1159,d+72|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){b=d+80|0;f=d+72|0;xp(b,f);e=zf(d+88|0,b);g=zf(d- -64|0,c);h=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=h;e=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=e;yp(a,d+8|0,d);break b}break a}x[31785]=0;O(1160,d+72|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=d+80|0;f=d+72|0;xp(b,f);e=zf(d+56|0,b);g=zf(d+48|0,c);h=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=h;e=x[g+4>>2];x[d+16>>2]=x[g>>2];x[d+20>>2]=e;yp(a,d+24|0,d+16|0)}he(b);he(f);he(c);fb=d+96|0;return}}a=N()|0;he(c);Q(a|0);p()}function Rla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=fb-16|0;fb=e;g=x[a+40>>2];h=x[a+36>>2];j=x[a+16>>2];i=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=i;k=b+24|0;l=x[a+32>>2];m=x[a+28>>2];i=x[a+8>>2];n=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;h=h+m|0;x[c>>2]=x[c>>2]+D(b,h>>12);g=g+l|0;x[c+4>>2]=x[c+4>>2]+D(b,g>>12);Qb(e+8|0,i,n);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;x[a+40>>2]=g;x[a+20>>2]=h>>12;x[a+36>>2]=h;x[a+24>>2]=g>>12;fb=e+16|0}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;a=Ru(d+4|0,a,1);sz(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+16;hc(a);fb=d+16|0;return}h=fb-32|0;fb=h;d=Ab(a);c=xV(h+12|0,yV(a,Dk(x[a>>2],x[a+4>>2])+1|0),Dk(x[a>>2],x[a+4>>2]),d);sz(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+16;g=fb-16|0;fb=g;f=zb(g+12|0,x[a+4>>2]);d=zb(g+8|0,x[a>>2]);b=zb(g+4|0,x[c+4>>2]);f=x[f>>2];d=x[d>>2];e=fb-16|0;fb=e;x[e+8>>2]=x[b>>2];x[e+12>>2]=f;while(1){b=x[e+8>>2];if(Pg(f,d)){sz(RM(b),f-16|0);b=tz(e+12|0);tz(e+8|0);f=x[b>>2];continue}break}fb=e+16|0;x[c+4>>2]=b;wc(a,c+4|0);wc(a+4|0,c+8|0);wc(Ab(a),Ac(c));x[c>>2]=x[c+4>>2];fb=g+16|0;b=x[c+4>>2];while(1){a=x[c+8>>2];if((a|0)!=(b|0)){a=a-16|0;x[c+8>>2]=a;Hk(a);continue}break}a=x[c>>2];if(a){fs(c);Db(a)}fb=h+32|0}function Lca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=fb+-64|0;fb=f;x[f+60>>2]=d;a=oe(a,f+60|0);d=rc(a+4|0);g=rc(a+24|0);h=rc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31785]=0;O(1e3,a|0,e|0);k=x[31785];x[31785]=0;a:{b:{c:{d:{if((k|0)!=1){bc(f+24|0,b,c);kf(f+32|0,x[f+24>>2],x[f+28>>2]);b=Jd(f+16|0);x[31785]=0;c=x[b+4>>2];x[f+8>>2]=x[b>>2];x[f+12>>2]=c;ws(1004,f+40|0,x[f+32>>2],x[f+36>>2],f+8|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;S(1001,a|0,f+40|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}ub(f+40|0);x[31785]=0;W(1002,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(f+40|0)}Pd(j);mf(i);yl(h);sh(g);rh(d);Uc(a);Uc(f+60|0);Q(e|0);p()}Uc(f+60|0);fb=f- -64|0;return a|0}function Rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=E(0),o=E(0),p=0,q=0,r=0,s=0;h=fb-16|0;fb=h;if(wi(a+44|0)){g=x[a+44>>2];r=h,s=Hc(g,0),x[r+8>>2]=s;r=h,s=Hc(g,1),x[r+12>>2]=s;g=x[a+56>>2];l=Hc(g,0);x[h>>2]=l;m=Hc(g,1);x[h+4>>2]=m;p=y[a+4273|0];q=y[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=x[i>>2];x[i>>2]=e+4;f=E(B[e>>2]*B[a+4240>>2]);e=a+j|0;i=e+4228|0;f=E(f+E(B[i>>2]*B[a+4236>>2]));B[i>>2]=f;f=TP(E(f*E(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=B[e>>2];o=B[a+4264>>2];f=E(E(E(f*B[a+4260>>2])-E(B[a+4268>>2]*B[i>>2]))-E(n*o));B[e>>2]=f;B[i>>2]=n+E(f*o);e=h+j|0;j=x[e>>2];x[e>>2]=j+4;B[j>>2]=f*E(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{Li(a,b,c,l,m,d)}break}}fb=h+16|0}function yo(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[b+88>>2];d=c|2048;x[b+88>>2]=d;f=x[b+656>>2];if(!(!f|v[b+730|0]&1)){d=c|6144;x[b+88>>2]=d}a:{if(!x[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=x[b+104>>2];if(!c){break b}e=z[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;x[b+88>>2]=d;e=x[c>>2];x[b+76>>2]=e;g=x[c+4>>2];x[b+80>>2]=g;c=x[c+8>>2];x[b+84>>2]=c;if(c>>>0<e>>>0){x[b+76>>2]=c;h=c}else{h=e}e=x[b+4>>2];if(h>>>0>=e>>>0){break b}x[b>>2]=0;x[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;x[b+88>>2]=d;x[b+76>>2]=x[c>>2]}if(!f){break a}if(!(!(y[f+60|0]&2|x[a+480180>>2]&1064964)|!x[f>>2])){x[b+88>>2]=d|4096}if(y[f+65|0]==255|z[b+728>>1]!=65535){break a}i=b,j=dd(Eq(f+48|0,x[b+724>>2],256,64)),w[i+728>>1]=j;i=b,j=z[wb(x[f+48>>2],y[f+65|0])>>1],x[i+724>>2]=j}}function FQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;if(!(oc(x[a>>2],x[a+4>>2])>>>0>511|x[(x[x[b>>2]-12>>2]+b|0)+16>>2])){d=fb-16|0;fb=d;f=Dc(64);x[31785]=0;g=R(882,f|0)|0;h=x[31785];x[31785]=0;a:{b:{if((h|0)!=1){f=uf(d+8|0,g);g=x[f>>2];x[31785]=0;g=U(947,g|0,b|0,c|0)|0;h=x[31785];x[31785]=0;c:{d:{if((h|0)!=1){if((g|0)==1){break d}rc(d+12|0);break c}a=N()|0;Ig(f);break b}oe(d+12|0,f)}Ig(f);fb=d+16|0;d=x[d+12>>2];break a}a=N()|0;Db(f)}Q(a|0);p()}x[e+12>>2]=d;e:{f:{if(!xd(d)){x[31785]=0;b=P(945,b|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break f}x[e+8>>2]=b;b=e+8|0;cZ(e+12|0,ie(b));Ig(b);d=x[e+12>>2]}if(!xd(d)){break e}x[31785]=0;O(504,a|0,e+12|0);a=x[31785];x[31785]=0;i=d;if((a|0)!=1){break e}}a=N()|0;Ig(e+12|0);Q(a|0);p()}Ig(e+12|0)}fb=e+16|0;return i}function iq(a){var b=E(0),c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;e=(q(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=E(1);if(d>>>0<964689920){break a}b=Bi(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=E(-Bi(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=Ci(f+1.5707963267948966);break a}b=Ci(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Bi(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=Ci(-4.71238898038469-+a);break a}b=Ci(+a+-4.71238898038469);break a}b=E(a-a);if(d>>>0>=2139095040){break a}b:{switch(Qy(a,c+8|0)&3){case 0:b=Bi(C[c+8>>3]);break a;case 1:b=Ci(-C[c+8>>3]);break a;case 2:b=E(-Bi(C[c+8>>3]));break a;default:break b}}b=Ci(C[c+8>>3])}a=b;fb=c+16|0;return a}function EH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[31785]=0;W(1005,a|0);e=x[31785];x[31785]=0;a:{b:{c:{if((e|0)!=1){e=Fb(d+20|0);x[31785]=0;W(c|0,d+8|0);c=x[31785];x[31785]=0;d:{e:{if((c|0)!=1){h=d,i=vb(x[d+8>>2]),x[h+4>>2]=i;f=1;while(1){g=vb(x[d+12>>2]);c=x[d+4>>2];if(!Ib(c,g)){c=xg(Jb(e));Pd(d+8|0);tb(e);break b}if(!f){x[31785]=0;P(994,e|0,14763)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}c=x[d+4>>2]}x[31785]=0;P(845,e|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}Uq(d+4|0);f=0;continue}}c=T(0)|0;break d}c=T(0)|0;Pd(d+8|0)}tb(e);break c}c=T(0)|0}Y(c|0)|0;c=0;x[31785]=0;V(992,b|0,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z()}fb=d+32|0;return c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){T(0)|0;Rb();p()}Q(a|0);p()}function xM(a,b){var c=0,d=0,e=0;x[a+4>>2]=b;x[a>>2]=127184;x[a+8>>2]=b;e=(b|0)!=0;x[a+12>>2]=e;c=b&31;if((b&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}x[a+24>>2]=0;c=c&65536;x[a+28>>2]=c;d=c^65536;a:{if((c|0)==(d|0)|c>>>0>d>>>0){c=b;break a}c=b>>>e|0;x[a+8>>2]=c;e=b?2:1;x[a+12>>2]=e;d=c&31;if((c&63)>>>0>=32){d=-1<<d}else{d=(1<<d)-1&-1>>>32-d|-1<<d}x[a+24>>2]=0;x[a+28>>2]=d&65536}x[a+16>>2]=e-((b>>>0)%(e>>>0)|0);d=63-c|0;b=d&31;if((d&63)>>>0>=32){d=0;b=-1>>>b|0}else{d=-1>>>b|0;b=d|(1<<b)-1<<32-b}x[a+48>>2]=b;x[a+52>>2]=d;d=64-c|0;b=d&31;if((d&63)>>>0>=32){d=0;b=-1>>>b|0}else{d=-1>>>b|0;b=d|(1<<b)-1<<32-b}x[a+40>>2]=c?b:0;x[a+44>>2]=c?d:0;c=c+1|0;b=c&31;if((c&63)>>>0>=32){c=-1<<b}else{c=(1<<b)-1&-1>>>32-b|-1<<b}x[a+32>>2]=0;x[a+36>>2]=c&65536;return a}function $1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;x[c+28>>2]=0;if(Ad(y[Cm(c+27|0,a,0)|0])){$c(c+16|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31785]=0;e=R(1184,x[c+16>>2])|0;d=x[31785];x[31785]=0;a:{b:{if((d|0)!=1){d=hp(c+12|0,a);f=rc(c+8|0);g=x[x[a>>2]-12>>2];f=x[f>>2];d=x[d>>2];x[31785]=0;ja(1186,e|0,d|0,f|0,a+g|0,c+28|0,c+20|0);e=x[31785];x[31785]=0;if((e|0)!=1){break b}}b=T(0)|0;Zb(c+16|0);Y(b|0)|0;b=x[c+28>>2]|1;x[c+28>>2]=b;Am(x[x[a>>2]-12>>2]+a|0,b);c:{d:{if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31785]=0;X(87);a=x[31785];x[31785]=0;if((a|0)!=1){break c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break d}Q(a|0);p()}Z();break a}T(0)|0;Rb()}p()}Zb(c+16|0);x[b>>2]=x[c+20>>2]}$j(x[x[a>>2]-12>>2]+a|0,x[c+28>>2])}fb=c+32|0;return a|0}function dF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[31785]=0;f=P(21,e+8|0,a|0)|0;d=x[31785];x[31785]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!Ad(y[f|0])){break e}g=hp(e+4|0,a);d=x[x[a>>2]-12>>2]+a|0;h=x[d+4>>2];x[31785]=0;i=R(22,d|0)|0;j=x[31785];x[31785]=0;if((j|0)==1){break d}g=x[g>>2];x[31785]=0;c=b+c|0;b=ea(23,g|0,b|0,((h&176)==32?c:b)|0,c|0,d|0,i|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}if(b){break e}b=x[x[a>>2]-12>>2];x[31785]=0;O(24,a+b|0,5);b=x[31785];x[31785]=0;if((b|0)!=1){break e}break d}em(f);break b}b=T(0)|0;em(f);break c}b=T(0)|0}Y(b|0)|0;b=x[x[a>>2]-12>>2];x[31785]=0;W(25,a+b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}Z()}fb=e+16|0;return a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){T(0)|0;Rb();p()}Q(a|0);p()}function uP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=fb-48|0;fb=j;k=x[a+4>>2];l=x[a>>2];a=x[a+8>>2];x[j+32>>2]=b;x[j+44>>2]=a;x[j+36>>2]=l;x[j+40>>2]=k;x[31785]=0;a=P(985,(d?d:986)|0,e|0)|0;b=x[31785];x[31785]=0;a:{b:{c:{d:{if((b|0)!=1){x[j+24>>2]=a;a=x[oe(j+28|0,j+24|0)>>2];b=x[j+44>>2];x[j+16>>2]=x[j+40>>2];x[j+20>>2]=b;x[31785]=0;b=x[j+36>>2];x[j+8>>2]=x[j+32>>2];x[j+12>>2]=b;c=+pa(987,j+8|0,+c,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break d}Uc(j+24|0);break b}a=T(0)|0;break c}a=T(0)|0;Uc(j+24|0)}Y(a|0)|0;x[31785]=0;ga(988,15222,d|0,e|0,f|0,g|0,h|0,i|0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();c=0}fb=j+48|0;return+c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=OM(),x[j+12>>2]=k;g=a+24|0;c=d+12|0;MM(g,ie(c));sh(c);w[a+28>>1]=0;sP();f=fb-16|0;fb=f;e=Dc(144);x[31785]=0;h=P(1137,e|0,4)|0;i=x[31785];x[31785]=0;a:{if((i|0)!=1){e=x[uf(f+12|0,h)>>2];fb=f+16|0;break a}a=N()|0;Db(e);Q(a|0);p()}x[d+12>>2]=e;LM(a+32|0,ie(c));yl(c);j=d,k=NM(x[a>>2]),x[j+12>>2]=k;KM(a+4|0,ie(c));rh(c);no(x[g>>2],x[a+4>>2]);v[a+64|0]=1;x[a+60>>2]=0;x[a+48>>2]=1065353216;x[a+52>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;j=d,k=Yi(x[b>>2]),x[j+12>>2]=k;e=Jf(b);b:{while(1){b=x[d+12>>2];if(!Vg(b,e)){break b}c=qd(b);b=fg(d,c);x[31785]=0;V(1021,a|0,b|0,c+12|0,0);c=x[31785];x[31785]=0;if((c|0)!=1){tb(b);Yg(d+12|0);continue}break}a=N()|0;tb(b);Q(a|0);p()}fb=d+16|0}function _0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=fb-16|0;fb=g;bd(b,y[c+32|0]|y[c+33|0]<<8|(y[c+34|0]<<16|y[c+35|0]<<24));h=Nb(a);a=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);x[31785]=0;O(182,h|0,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24))>>>0<=a>>>0){break b}e=x[b+8>>2];f=x[b>>2];x[31785]=0;e=U(153,f|0,e|0,4)|0;f=x[31785];x[31785]=0;if((f|0)==1){break a}if(!e){break b}e=y[c+4|0]|y[c+5|0]<<8;x[31785]=0;e=P(183,b|0,e|0)|0;f=x[31785];x[31785]=0;c:{if((f|0)!=1){x[g+12>>2]=e;if(Qd(x[d>>2],x[d+4>>2])>>>0<=e>>>0){break c}x[31785]=0;O(184,h|0,g+12|0);e=x[31785];x[31785]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}fb=g+16|0;return}}a=N()|0;sc(h);Q(a|0);p()}function F3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;Tb(d+116|0,0,44);while(1){if((c|0)==7){a:{c=0;while(1){if((c|0)==12){break a}x[d+132>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14437,f|0,x[a>>2])|0;g=D(c,12)+a|0;id(g+172|0,e);fa(e|0,100,13354,f|0,x[a>>2])|0;id(g+316|0,e);c=c+1|0;continue}}}else{x[d+140>>2]=c;e=d+16|0;f=d+116|0;fa(e|0,100,14450,f|0,x[a>>2])|0;g=D(c,12)+a|0;id(g+4|0,e);fa(e|0,100,13518,f|0,x[a>>2])|0;id(g+88|0,e);c=c+1|0;continue}break}x[d+124>>2]=1;c=d+16|0;e=d+116|0;fa(c|0,100,9282,e|0,x[a>>2])|0;id(a+460|0,c);x[d+124>>2]=13;fa(c|0,100,9282,e|0,x[a>>2])|0;id(a+472|0,c);c=d+4|0;Cs(c,a,99,b);yb(a+484|0,c);tb(c);Cs(c,a,114,b);yb(a+496|0,c);tb(c);Cs(c,a,120,b);yb(a+508|0,c);tb(d+4|0);Cs(c,a,88,b);yb(a+520|0,c);tb(d+4|0);fb=d+160|0}function pQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=fb-16|0;fb=c;e=x[b+4220>>2];f=x[b+4224>>2];g=x[b+4228>>2];h=x[b+4232>>2];i=x[b+4240>>2];j=x[b+4236>>2];l=y[b+4244|0];k=b+4208|0;Uj(k,33);d=x[k>>2];v[d+32|0]=l;v[d+24|0]=j;v[d+25|0]=j>>>8;v[d+26|0]=j>>>16;v[d+27|0]=j>>>24;v[d+28|0]=i;v[d+29|0]=i>>>8;v[d+30|0]=i>>>16;v[d+31|0]=i>>>24;v[d+16|0]=g;v[d+17|0]=g>>>8;v[d+18|0]=g>>>16;v[d+19|0]=g>>>24;v[d+20|0]=h;v[d+21|0]=h>>>8;v[d+22|0]=h>>>16;v[d+23|0]=h>>>24;v[d+8|0]=e;v[d+9|0]=e>>>8;v[d+10|0]=e>>>16;v[d+11|0]=e>>>24;v[d+12|0]=f;v[d+13|0]=f>>>8;v[d+14|0]=f>>>16;v[d+15|0]=f>>>24;v[d|0]=76;v[d+1|0]=70;v[d+2|0]=79;v[d+3|0]=32;v[d+4|0]=0;v[d+5|0]=0;v[d+6|0]=0;v[d+7|0]=0;le(c+8|0,x[k>>2],x[b+4212>>2]);gc(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function WP(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;e=(q(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Ci(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=E(-Bi(d+1.5707963267948966));break a}a=Bi(d+-1.5707963267948966);break a}a=Ci(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=Bi(d+4.71238898038469);break a}a=E(-Bi(d+-4.71238898038469));break a}a=Ci(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=E(a-a);break a}b:{switch(Qy(a,b+8|0)&3){case 0:a=Ci(C[b+8>>3]);break a;case 1:a=Bi(C[b+8>>3]);break a;case 2:a=Ci(-C[b+8>>3]);break a;default:break b}}a=E(-Bi(C[b+8>>3]))}fb=b+16|0;return a}function JL(a){var b=E(0),c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=E(0),j=E(0),k=E(0),l=E(0),m=E(0),n=E(0),o=E(0);f=B[a>>2];i=B[a+24>>2];c=E(f-i);d=B[a+16>>2];b=B[a+32>>2];g=B[a+8>>2];e=E(d+E(b-g));B[a+16>>2]=c+e;j=E(c-E(e*E(.5)));c=B[a+4>>2];e=B[a+20>>2];h=B[a+28>>2];k=E(E(E(c-e)-h)*E(.8660253882408142));B[a+4>>2]=j+k;l=E(E(d-b)*E(.1736481785774231));f=E(f+E(i*E(.5)));i=E(E(g+b)*E(.7660444378852844));m=E(l+E(f-i));n=E(E(c+e)*E(.9848077297210693));b=E(B[a+12>>2]*E(.8660253882408142));c=E(E(c+h)*E(.6427876353263855));o=E(E(n-b)-c);B[a+12>>2]=m+o;B[a+20>>2]=m-o;B[a+28>>2]=j-k;d=E(E(g+d)*E(.9396926164627075));g=E(E(f+d)-l);e=E(E(e-h)*E(.3420201539993286));h=E(E(e-b)-n);B[a+32>>2]=g+h;d=E(E(f-d)+i);b=E(E(b+e)-c);B[a+24>>2]=d+b;B[a+8>>2]=d-b;B[a>>2]=g-h}function fqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;j=8;n=D(c,d)<<1;a:while(1){if((d|0)!=(k|0)){h=(k<<1)+b|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){w[e+10>>1]=0;WX(a,e+15|0,e+12|0,j,e+10|0);i=z[e+10>>1];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!xf(a,e+9|0)){break c}f=y[e+9|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&65535;e:{if(g>>>0<4){break e}f=15;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&65534)>>>1)+l|0;w[e+10>>1]=l;w[h>>1]=l;h=(d<<1)+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function Fna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-80|0;fb=c;a:{d=x[a+4>>2];b:{if(d>>>0<b>>>0){f=Jd(c+72|0);e=b-d|0;g=Pu(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){Mq(c+60|0,x[a>>2],d);gc(f,x[c+60>>2],x[c+64>>2]);x[a+4>>2]=x[a+4>>2]+e;break c}d=Mo(c+60|0);x[31785]=0;b=P(764,a|0,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break a}x[31785]=0;O(765,d|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}x[d+4>>2]=x[a+4>>2]+e;fn(c+44|0,x[a>>2]);Mq(c+32|0,x[a>>2],x[a+4>>2]);fn(c+24|0,x[d>>2]);b=x[c+48>>2];x[c+8>>2]=x[c+44>>2];x[c+12>>2]=b;TW(c+52|0,c+8|0,x[c+32>>2],x[c+36>>2],x[c+24>>2],x[c+28>>2]);gc(f,x[c+52>>2],x[c+56>>2]);YB(a,d);$e(d)}a=gc(c+16|0,x[f>>2],x[f+4>>2]);Gw(x[a>>2],x[a+4>>2],e,0);break b}x[a+4>>2]=b}fb=c+80|0;return}a=N()|0;$e(d);Q(a|0);p()}function hB(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{f=a+1074312|0;if(j=Pb(f,77),k=0,l=x[(D(c,872)+b|0)+704>>2]&134218752,l?j:k){break a}g=x[a+480180>>2]!=2?c:0;e=D(g,872);if(!d){x[(b+e|0)+1380>>2]=x[b+48>>2];return}h=(b+e|0)+1457|0;c=y[h|0];b:{if(c){c=c-1|0;v[h|0]=c;if(c&255){break b}if(!Pb(f,16)&x[a+480180>>2]!=2){break a}x[(D(g,872)+b|0)+1380>>2]=x[b+48>>2]+1;return}c:{if(Pb(f,17)|y[a+480180|0]&3){break c}c=b+616|0;i=e+c|0;e=0;a=z[a+480188>>1];while(1){if(a>>>0<=(e&65535)>>>0){break c}if(y[c+841|0]?(c|0)!=(i|0):0){break a}c=c+872|0;e=e+1|0;continue}}v[h|0]=d}a=x[(D(g,872)+b|0)+1380>>2];x[b+56>>2]=a;if((a|0)==-1){break a}d:{if(x[b+60>>2]==-1){break d}if(!Pb(f,68)){break d}x[b+60>>2]=a}x[b+64>>2]=a;if(!Pb(f,103)){break a}w[b+68>>1]=65535}}function ls(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;x[d+28>>2]=0;a:{b:{c:{if(Ad(y[Cm(d+27|0,a,0)|0])){$c(d+20|0,x[(x[x[a>>2]-12>>2]+a|0)+28>>2]);x[31785]=0;g=R(1184,x[d+20>>2])|0;e=x[31785];x[31785]=0;d:{e:{if((e|0)==1){break e}e=hp(d+16|0,a);f=rc(d+12|0);h=x[x[a>>2]-12>>2];f=x[f>>2];e=x[e>>2];x[31785]=0;ja(c|0,g|0,e|0,f|0,a+h|0,d+28|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break e}Zb(d+20|0);break d}b=T(0)|0;Zb(d+20|0);Y(b|0)|0;b=x[d+28>>2]|1;x[d+28>>2]=b;Am(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31785]=0;X(87);a=x[31785];x[31785]=0;if((a|0)!=1){break b}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break c}Q(a|0);p()}Z()}$j(x[x[a>>2]-12>>2]+a|0,x[d+28>>2])}fb=d+32|0;break a}T(0)|0;Rb()}p()}return a}function Zia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-32|0;fb=e;c=Nf(x[x[a+48>>2]+12>>2]);a:{if(!b){break a}c=D(b,c);b:{if(x[a+12>>2]!=(b|0)){break b}if((Jk(x[a>>2],x[a+4>>2])|0)!=(c|0)){break b}b=fb-16|0;fb=b;d=vb(x[a>>2]);a=vb(x[a+4>>2]);w[b+12>>1]=0;x[b+8>>2]=0;f=eu(a,d);c=fb-16|0;fb=c;x[c+12>>2]=d;while(1){if((f|0)>0){a=x[c+12>>2];d=y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24);v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;d=y[b+12|0]|y[b+13|0]<<8;v[a+4|0]=d;v[a+5|0]=d>>>8;f=f-1|0;ah(c+12|0);continue}break}fb=c+16|0;fb=b+16|0;break a}w[e+16>>1]=0;x[e+12>>2]=0;c=mZ(e+20|0,c,e+12|0);aR(a);x[a>>2]=x[c>>2];x[a+4>>2]=x[c+4>>2];f=Ab(c);g=Ab(a),h=x[f>>2],x[g>>2]=h;x[f>>2]=0;x[c>>2]=0;x[c+4>>2]=0;Nk(c);x[a+12>>2]=b}fb=e+32|0}function FX(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=v[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=D(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=v[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=y[e+45|0];if(y[e+44|0]|c>>>0>64){break a}b=Cb(y[e+42|0]|y[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=y[a+470|0];if(d>>>0>128){break a}b=y[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=zC(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Dt(y[a|0],y[c|0])?c:a;continue}}a=y[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function IE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;e=x[b>>2];d=Xc(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=fb-32|0;fb=i;d=c-d|0;f=x[Ab(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=fb-16|0;fb=f;e=vi(f+4|0,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){hc(e);fb=f+16|0}else{ip(d);d=d+2|0;x[e+4>>2]=d;continue}break}break b}f=Ab(b);e=hk(i+12|0,ik(b,Xc(x[b>>2],e)+d|0),Xc(x[b>>2],x[b+4>>2]),f);h=fb-16|0;fb=h;d=rp(h+4|0,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){ip(f);f=x[d>>2]+2|0;x[d>>2]=f;continue}break}ee(d);fb=h+16|0;Id(b,e);fj(e)}fb=i+32|0;break a}if(c>>>0<d>>>0){xn(b,e+(c<<1)|0)}}c=Mb(x[a>>2],x[a+8>>2],c<<1);if(c){d=x[b>>2];bc(g+8|0,d,Xc(d,x[b+4>>2])<<1);md(g,a,x[g+8>>2],x[g+12>>2])}fb=g+16|0;return c|0}function zo(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;if(e){x[e>>2]=0}a:{i=x[a+484344>>2];if(!Ge(i,x[a+484348>>2],b)){break a}g=Vb(i,b);k=x[g+48>>2];b=gd(x[g>>2],x[k+12>>2],c,d);f=y[b+5|0];b:{c:{d:{e:{j=y[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}x[h+12>>2]=1;i=0;if((j|0)!=17){break b}i=x[a+480180>>2]==4;break b}x[h+12>>2]=2;i=0}x[h+8>>2]=x[g+12>>2]+(c^-1);d=0;a=x[Gb(h+8|0,h+12|0)>>2];c=a;while(1){f:{if(c){b=D(Nf(x[k+12>>2]),6)+b|0;if(y[b+3|0]==34){break f}a=d}f=(j-37&255)>>>0<254?f:a?f:f<<8;if(!e){break a}x[e>>2]=a;break a}g=f<<8;f=y[b+5|0]|(i?f>>>0>31?f>>>0<256?g+-8192|0:g:g:g);d=d+1|0;c=c-1|0;continue}}fb=h+16|0;return f}function FB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=fb-16|0;fb=h;i=Nl(a,b);a:{if((i|0)==255){break a}if(Ak(x[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}g=c;f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=20-f|0;j=c&31;if((c&63)>>>0>=32){c=g<<j;g=0}else{c=(1<<j)-1&g>>>32-j;g=g<<j}g=g+24858e3|0;if(g>>>0<24858e3){c=c+1|0}c=Bc(uua(g,c,49716e3,0),hb)}if(e){w[h+14>>1]=(b&3)+c;w[h+12>>1]=1023;c=z[Mc(h+14|0,h+12|0)>>1]}g=Lu(i);e=a+8|0;k=xb(e,i),l=(f<<10|c)>>>8|(d?0:32),v[k|0]=l;wh(x[a>>2],x[a+4>>2],b,g|160,c&255);c=xb(e,i);wh(x[a>>2],x[a+4>>2],b,g|176,y[c|0]);v[a+534|0]=1}fb=h+16|0}function NZ(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=Fb(a);a=wd(b);x[e+12>>2]=a;f=yf(b);b=0;a:{while(1){b:{if(!Ib(a,f)){if(!b){break b}x[31785]=0;O(36,d|0,65533);a=x[31785];x[31785]=0;if((a|0)!=1){break b}break a}a=y[a|0];c:{d:{if(!b){if(a<<24>>24>=0){b=0;x[31785]=0;O(36,d|0,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break a}if((a&224)==192){c=a&31;b=1;break c}if((a&240)==224){c=a&15;b=2;break c}c=65533;if((a&248)!=240){break d}c=a&7;b=3;break c}if((a&192)!=128){c=0;x[31785]=0;O(36,d|0,65533);g=x[31785];x[31785]=0;b=0;if((g|0)==1){break a}}c=a&63|c<<6;b=b-1|0;if(b){break c}}b=0;x[31785]=0;O(36,d|0,c|0);a=x[31785];x[31785]=0;c=0;if((a|0)==1){break a}}a=x[je(e+12|0)>>2];continue}break}fb=e+16|0;return}a=N()|0;Sb(d);Q(a|0);p()}function zl(a,b,c){var d=0,e=0,f=0,g=0;e=fb-48|0;fb=e;d=x[a+24>>2];g=x[d+24620>>2];a:{if(!((g|0)!=(b|0)|x[d+24624>>2]!=(c|0))){if(y[a+29|0]){break a}CR(d,1);break a}f=e+8|0;yc(f,d+24604|0,40);x[e+28>>2]=c;x[e+24>>2]=b;c=x[e+44>>2];Kt(f,x[e+40>>2]);Ho(f,c);AA(d,f);if((b|0)==(g|0)){break a}c=x[a+24>>2]+906300|0;d=Dj(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];b:{if(!b){break b}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break b}ib[x[x[b>>2]+112>>2]](b,0);ib[x[x[b>>2]+100>>2]](b);ib[x[x[b>>2]+128>>2]](b)}c=c+160|0;continue}break}c=x[a+24>>2]+906300|0;d=Dj(c);while(1){if((c|0)!=(d|0)){b=x[c>>2];c:{if(!b){break c}if(ib[x[x[b>>2]+120>>2]](b)|0){break c}ib[x[x[b>>2]+112>>2]](b,1);ib[x[x[b>>2]+124>>2]](b)}c=c+160|0;continue}break}}v[a+29|0]=1;fb=e+48|0}function eqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=fb-16|0;fb=e;v[e+15|0]=0;w[e+12>>1]=0;n=D(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){v[e+11|0]=0;VX(a,e+15|0,e+12|0,e+11|0);i=y[e+11|0];f=z[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!xf(a,e+10|0)){break c}f=y[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}w[e+12>>1]=f;break b}k=k+1|0;continue a}w[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;v[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;v[e+11|0]=l;v[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}fb=e+16|0}function tk(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=fb-32|0;fb=b;a:{b:{while(1){f=(b+8|0)+(d<<2)|0;e=1<<d&2147483647;if(e|1){e=qK(d,e?a:22485)}else{e=x[d<<2>>2]}x[f>>2]=e;if((e|0)==-1){break b}d=d+1|0;if((d|0)!=6){continue}break}if(!pK(0)){c=121724;if(!Ob(b+8|0,121724,24)){break a}c=121748;if(!Ob(b+8|0,121748,24)){break a}d=0;if(!y[500384]){while(1){g=(d<<2)+500336|0,h=qK(d,22485),x[g>>2]=h;d=d+1|0;if((d|0)!=6){continue}break}v[500384]=1;x[125090]=x[125084]}c=500336;if(!Ob(b+8|0,500336,24)){break a}c=500360;if(!Ob(b+8|0,500360,24)){break a}c=Ed(24);if(!c){break b}}a=x[b+12>>2];x[c>>2]=x[b+8>>2];x[c+4>>2]=a;a=x[b+28>>2];x[c+16>>2]=x[b+24>>2];x[c+20>>2]=a;a=x[b+20>>2];x[c+8>>2]=x[b+16>>2];x[c+12>>2]=a;break a}c=0}fb=b+32|0;return c}function Sna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;e=x[b>>2];d=Hg(e,x[b+4>>2]);a:{if(d>>>0<c>>>0){i=fb-32|0;fb=i;d=c-d|0;f=x[Ab(b)>>2];e=x[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=fb-16|0;fb=f;e=ZB(f+4|0,b,d);d=x[e+4>>2];h=x[e+8>>2];while(1){if((d|0)==(h|0)){hc(e);fb=f+16|0}else{rV(d);d=d+32|0;x[e+4>>2]=d;continue}break}break b}f=Ab(b);e=Qu(i+12|0,Hq(b,Hg(x[b>>2],e)+d|0),Hg(x[b>>2],x[b+4>>2]),f);h=fb-16|0;fb=h;d=sV(h+4|0,e+8|0,d);f=x[d>>2];while(1){if(x[d+4>>2]!=(f|0)){rV(f);f=x[d>>2]+32|0;x[d>>2]=f;continue}break}ee(d);fb=h+16|0;Id(b,e);uV(e)}fb=i+32|0;break a}if(c>>>0<d>>>0){HX(b,e+(c<<5)|0)}}if(Mb(x[a>>2],x[a+8>>2],c<<5)){c=x[b>>2];bc(g+8|0,c,Hg(c,x[b+4>>2])<<5);md(g,a,x[g+8>>2],x[g+12>>2])}fb=g+16|0}function SR(a,b){var c=E(0),d=E(0),e=E(0);a:{b:{c:{switch(b|0){case 0:nq(a,E(1));wk(a,E(3.725290298461914e-9));mq(a,E(268435456));lq(a,0);break b;case 1:nq(a,E(32));wk(a,E(4.656612873077393e-10));mq(a,E(2147483648));lq(a,0);break b;case 2:nq(a,E(2));wk(a,E(7.450580596923828e-9));mq(a,E(134217728));lq(a,1);break b;default:nq(a,E(1));wk(a,E(7.450580596923828e-9));mq(a,E(134217728));lq(a,1);tA(a,0);sA(a,1);rA(a,1);d=E(256);c=E(128);e=E(128);b=0;break a;case 4:case 5:break c}}nq(a,E(.75));wk(a,E(7.450580596923828e-9));mq(a,E(134217728));lq(a,1);tA(a,0);b=(b|0)==4;sA(a,b?2:3);rA(a,1);d=E(256);c=b?E(256):E(192);e=c;b=1;break a}tA(a,1);sA(a,0);rA(a,0);d=E(128);e=E(100);c=E(256);b=4}B[a+16>>2]=c;B[a+20>>2]=e;B[a+24>>2]=d;x[a+28>>2]=b}function iL(a,b,c,d){a:{switch(b-9|0){case 0:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];return;case 6:b=x[c>>2];x[c>>2]=b+4;b=w[b>>1];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 7:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=z[b>>1];x[a+4>>2]=0;return;case 8:b=x[c>>2];x[c>>2]=b+4;b=v[b|0];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 9:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=y[b|0];x[a+4>>2]=0;return;case 16:b=x[c>>2]+7&-8;x[c>>2]=b+8;C[a>>3]=C[b>>3];return;case 17:ib[d|0](a,c);default:return;case 1:case 4:case 14:b=x[c>>2];x[c>>2]=b+4;b=x[b>>2];x[a>>2]=b;x[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=x[c>>2];x[c>>2]=b+4;x[a>>2]=x[b>>2];x[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=x[c>>2]+7&-8;x[c>>2]=b+8;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c}function NX(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=x[b>>2];while(1){if((i|0)==128){tg(b,c);c=x[a+8>>2];d=c+d|0;i=z[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(hh(x[a>>2])&-2)){break c}bd(a,c+(f<<10)|0);if(!EC(a,16,1)){break b}w[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((hh(x[a>>2])|0)!=(d+D(f,i)|0)){break a}}bd(a,c+D(f,z[e>>1])|0);h=EC(a,64,1)?h:k}bd(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(D(c,z[e>>1])<<8)|0)==(hh(x[a>>2])|0)){break d}}if(c>>>0>=255){DC(b,254,65534);DC(b,255,65535)}l=h}a=l&65535}else{j=z[_b(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function C2(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-176|0;fb=c;b=c+12|0;Uk(b,a);x[31785]=0;O(105,c+24|0,b|0);a=x[31785];x[31785]=0;a:{b:{c:{d:{if((a|0)!=1){x[31785]=0;a=P(106,c+36|0,c+24|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break d}tb(c+24|0);tb(c+12|0);b=x[x[a>>2]-12>>2];x[31785]=0;d=ca(107)|0;e=x[31785];x[31785]=0;if((e|0)==1){break b}x[31785]=0;S(108,c+8|0,a+b|0,d|0);b=x[31785];x[31785]=0;if((b|0)==1){break b}Zb(c+8|0);b=a+x[x[a>>2]-12>>2]|0;x[b+4>>2]=x[b+4>>2]&-75;x[b+4>>2]=x[b+4>>2]|8;x[31785]=0;b=P(109,a|0,c+24|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break b}a=pk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+24>>2];Af(b);fb=c+176|0;return(a?0:d)|0}b=N()|0;break c}b=N()|0;tb(c+24|0)}tb(c+12|0);break a}b=N()|0;Af(a)}Q(b|0);p()}function Xp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{if(!(((b|0)>0|(b|0)>=0)&b>>>0>1048575)){if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(b>>>0>2146435071){break a}f=1072693248;g=-1023;if((b|0)!=1072693248){f=b;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;f=b;g=-1077}b=f+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function xea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;f=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);g=Bb(x[c+4>>2],y[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(eq(i,g,y[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=zb(h+12|0,Ne(Ne(wd(b),e),1));d=zb(h+8|0,yf(b));Jr(b,x[c>>2],x[d>>2]);break c}if(!Wc(x[b+4>>2],y[b+11|0])){break c}f=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);g=Bb(x[c+4>>2],y[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=v[d|0];d=d+1|0;if(!mc(v[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Fb(a);break b}Yc(a,b)}fb=h+16|0}function PS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;i=-1;a:{if(!vA(a,b,2)){break a}f=x[b+656>>2];d=a+1074312|0;g=Pb(d,31);h=x[b+740>>2];if(h?0:g){break a}h=h-Pb(d,31)|0;g=x[a+480180>>2];d=(g|0)==4096;j=f+88|0;f=d?64:(g|0)==16384?192:512;d=Eq(j,h,f,d?255:64)-(f>>>1|0)|0;if(y[b+746|0]&16){i=wq(a,b,!(x[b+88>>2]&32768),d);break a}if(Oj(x[b+656>>2])){if((d|0)==w[b+772>>1]){break a}k=b,l=dd(d),w[k+772>>1]=l;v[b+851|0]=y[b+851|0]|64;break a}a=Ej(a);x[e+12>>2]=d;b:{if((d|0)<0){x[e+12>>2]=0-d;xi(e+12|0,255);a=(x[e+12>>2]<<2)+(a?36832:35808)|0;break b}xi(e+12|0,255);a=(x[e+12>>2]<<2)+(a?35808:36832)|0}a=x[a>>2];b=a;d=a>>31;a=x[c>>2];k=c,l=Fc(tua(sua(b,d,a,a>>31),hb,65536,0),hb),x[k>>2]=l}fb=e+16|0;return i}function u1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=fb-16|0;fb=h;f=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);g=Bb(x[c+4>>2],y[c+11|0]);d=d+f|0;e=-1;a:{while(1){if((d|0)==(f|0)){break a}d=d-1|0;if(lu(i,g,y[d|0])){continue}break}e=d-f|0}b:{c:{if((e|0)!=-1){c=zb(h+12|0,Ne(Ne(wd(b),e),1));d=zb(h+8|0,yf(b));Jr(b,x[c>>2],x[d>>2]);break c}if(!Wc(x[b+4>>2],y[b+11|0])){break c}f=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);g=Bb(x[c+4>>2],y[c+11|0]);if(!d|!g){c=-1}else{c=f;e=d+c|0;g=g+i|0;while(1){d:{d=i;e:{if((c|0)!=(e|0)){while(1){if((d|0)==(g|0)){break e}j=y[d|0];d=d+1|0;if(!mc(y[c|0],j)){continue}break}}else{c=e}break d}c=c+1|0;continue}break}c=(c|0)==(e|0)?-1:c-f|0}if(c){break c}Fb(a);break b}Yc(a,b)}fb=h+16|0}function ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-32|0;fb=g;h=a+8|0;c=x[a+8>>2];j=Ac(a);a:{if((c|0)!=x[j>>2]){break a}i=a+4|0;d=x[a+4>>2];e=x[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Ov(d,c,a+d|0);x[h>>2]=c;x[i>>2]=a+x[i>>2];break a}x[g+8>>2]=c-e>>1;x[g+28>>2]=1;d=g+8|0;c=x[_c(d,g+28|0)>>2];c=hg(d,c,c>>>2|0,x[a+16>>2]);e=zb(g+4|0,x[a+4>>2]);f=x[zb(g,x[a+8>>2])>>2];d=fb-16|0;fb=d;e=x[e>>2];x[d+12>>2]=e;e=An(d,c+8|0,wv(f,e));f=x[e>>2];while(1){if(x[e+4>>2]!=(f|0)){k=f;f=x[d+12>>2];Vo(k,z[f>>1]|z[f+2>>1]<<16);f=x[e>>2]+4|0;x[e>>2]=f;Pe(d+12|0);continue}break}ee(e);fb=d+16|0;wc(a,c);wc(i,c+4|0);wc(h,c+8|0);wc(j,Ac(c));gg(c);c=x[a+8>>2]}Vo(c,z[b>>1]|z[b+2>>1]<<16);x[h>>2]=x[h>>2]+4;fb=g+32|0}function wK(a,b,c,d,e,f){var g=0;g=fb-80|0;fb=g;a:{if((f|0)>=16384){Rd(g+32|0,b,c,d,e,0,0,0,2147352576);d=x[g+40>>2];e=x[g+44>>2];b=x[g+32>>2];c=x[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Rd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)>=49149?49149:f)-32766|0;d=x[g+24>>2];e=x[g+28>>2];b=x[g+16>>2];c=x[g+20>>2];break a}if((f|0)>-16383){break a}Rd(g- -64|0,b,c,d,e,0,0,0,7471104);d=x[g+72>>2];e=x[g+76>>2];b=x[g+64>>2];c=x[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Rd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)<=-48920?-48920:f)+32538|0;d=x[g+56>>2];e=x[g+60>>2];b=x[g+48>>2];c=x[g+52>>2]}Rd(g,b,c,d,e,0,0,0,f+16383<<16);b=x[g+12>>2];x[a+8>>2]=x[g+8>>2];x[a+12>>2]=b;b=x[g+4>>2];x[a>>2]=x[g>>2];x[a+4>>2]=b;fb=g+80|0}function Zna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;c=fb-16|0;fb=c;f=b;g=a;d=$d(a);a:{if(d){b=ec(g);while(1){a=d;d=a+13|0;if(Wu(f,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!Wu(d,f)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(g);b=a}x[c+12>>2]=a;d=b;b=x[b>>2];if(!b){f=fb-16|0;fb=f;a=ec(g);h=zh(c,Dc(20),Kg(f+8|0,a));b=x[h>>2];a=x[e+4>>2];a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);v[b+17|0]=0;v[b+13|0]=a;v[b+14|0]=a>>>8;v[b+15|0]=a>>>16;v[b+16|0]=a>>>24;i=ec(h),j=1,v[i+4|0]=j;fb=f+16|0;Xg(g,x[c+12>>2],d,x[c>>2]);b=ie(c);a=x[c>>2];x[c>>2]=0;if(a){ec(c);Db(a)}h=1}Wg(e+8|0,x[zb(c,b)>>2],h);fb=c+16|0;fb=e+16|0;return x[e+8>>2]+17|0}function Qy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=(q(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;C[b>>3]=d;g=d<-.7853981852531433;if(F(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;C[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){C[b>>3]=E(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;C[e+8>>3]=(l(2,i-(c<<23)|0),r());c=nL(e+8|0,e,c,1,0);d=C[e>>3];if((g|0)<0){C[b>>3]=-d;c=0-c|0;break a}C[b>>3]=d}fb=e+16|0;return c}function Jpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=fb-528|0;fb=b;d=-1;a:{if(!ih(a,1468)){break a}Wl(a,1464);c=b+524|0;SX(a,c);if(!me(c,25497)){d=0;if(!me(b+524|0,15746)){break a}}Wl(a,20);c=1;b:{while(1){if((c&65535)>>>0>31){break b}d=OX(a,b);if(!d){AX(b)}if(d){c=c+1|0;e=IC(b)+e|0;continue}break}d=-1;break a}d=0;if(e>>>0>40){break a}e=b+522|0;c=fb-16|0;fb=c;c:{if(!ih(a,2)){v[c|0]=0;eF(e,c);break c}sp(c+8|0,e);HC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;if(y[b+522|0]>128){break a}e=Ic(b+522|0);c=fb-16|0;fb=c;d:{if(!ih(a,512)){zX(b);break d}fE(c+8|0,b);HC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;c=0;d=1;a=y[e|0];while(1){if((c|0)==512){break a}e=b+c|0;c=c+1|0;if(a>>>0>=y[e|0]){continue}break}d=0}fb=b+528|0;return d|0}function Jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>18|0;p=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){i=(e<<1)+p|0;j=w[i>>1];x[(e<<2)+b>>2]=j+((D(w[i+4>>1]-j|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Qb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function wH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=fb-48|0;fb=f;x[f+44>>2]=c;a=oe(a,f+44|0);c=rc(a+4|0);h=rc(a+24|0);i=rc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31785]=0;O(1e3,a|0,d|0);g=x[31785];x[31785]=0;a:{b:{c:{d:{if((g|0)!=1){le(f+16|0,x[b>>2],x[b+4>>2]);b=Jd(f+8|0);x[31785]=0;g=x[b+4>>2];x[f>>2]=x[b>>2];x[f+4>>2]=g;ws(e,f+24|0,x[f+16>>2],x[f+20>>2],f);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;S(1001,a|0,f+24|0,d|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}ub(f+24|0);x[31785]=0;W(1002,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(f+24|0)}Pd(k);mf(j);yl(i);sh(h);rh(c);Uc(a);Uc(f+44|0);Q(d|0);p()}Uc(f+44|0);fb=f+48|0;return a}function fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;c=Bf(a,c);Yd(f,x[a+36>>2]);i=a;a:{if(!c){Pc(f,a+32|0,5);d=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}g=x[a+36>>2];a=fb-16|0;fb=a;x[a+12>>2]=0;VM(g,a+12|0,1);e=x[a+12>>2];d=e>>>2&3;v[a+11|0]=d;if(d){v[a+4|0]=3;d=y[Ub(a+4|0,a+11|0)|0];v[a+4|0]=0;v[a|0]=0;v[a+10|0]=0;b:{if(!d){break b}Hi(g,a+4|0);if((d|0)==1){break b}Hi(g,a);if(d>>>0<3){break b}Hi(g,a+10|0);h=y[a+10|0]<<24}e=e&255|(y[a+4|0]<<8|y[a|0]<<16|h)}d=e>>>4|0;x[a+4>>2]=d;x[a>>2]=1e6;UB(b,x[Gb(a+4|0,a)>>2]);e=0;while(1){h=Bb(x[b+4>>2],y[b+11|0]);if(h>>>0<=e>>>0){if((d|0)!=(h|0)){Km(g,d-h|0)}fb=a+16|0}else{zj(g,cc(b,e),1);e=e+1|0;continue}break}d=c}cf(i,d);fb=f+16|0}function rH(a,b,c,d,e,f){var g=0,h=0,i=E(0),j=0;g=fb-80|0;fb=g;zA(x[a+24>>2]);v[x[a+24>>2]+1298424|0]=x[a+52>>2]!=0;x[g+44>>2]=b;x[g+40>>2]=c;x[g+36>>2]=d;i=B[a+48>>2];j=x[a+32>>2];x[g+8>>2]=b;c=x[g+40>>2];x[g>>2]=x[g+36>>2];x[g+4>>2]=c;d=fb-16|0;fb=d;x[d+8>>2]=x[g+8>>2];c=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=c;c=uM(g+48|0);x[c+8>>2]=j;x[c+4>>2]=0;x[c>>2]=f;f=x[d+4>>2];x[c+12>>2]=x[d>>2];x[c+16>>2]=f;x[c+20>>2]=x[d+8>>2];C[c+24>>3]=i;x[c>>2]=e;fb=d+16|0;while(1){if(b){d=x[a+24>>2];x[g+24>>2]=b;x[g+28>>2]=0;x[g+16>>2]=134217727;x[g+20>>2]=0;d=vM(d,x[Hr(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(x[a+52>>2]!=1|h)){a=x[a+24>>2];x[a+480208>>2]=x[a+480208>>2]&-513}fb=g+80|0;return h}function BX(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],1024)){x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;a=64;while(1){if(a){d=y[c+20|0]|y[c+21|0]<<8|(y[c+22|0]<<16|y[c+23|0]<<24);e=y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24);v[b|0]=e;v[b+1|0]=e>>>8;v[b+2|0]=e>>>16;v[b+3|0]=e>>>24;v[b+4|0]=d;v[b+5|0]=d>>>8;v[b+6|0]=d>>>16;v[b+7|0]=d>>>24;d=y[c+28|0]|y[c+29|0]<<8|(y[c+30|0]<<16|y[c+31|0]<<24);e=y[c+24|0]|y[c+25|0]<<8|(y[c+26|0]<<16|y[c+27|0]<<24);v[b+8|0]=e;v[b+9|0]=e>>>8;v[b+10|0]=e>>>16;v[b+11|0]=e>>>24;v[b+12|0]=d;v[b+13|0]=d>>>8;v[b+14|0]=d>>>16;v[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}BC(c+8|0,b);md(c+16|0,a,x[c+8>>2],x[c+12>>2])}fb=c+32|0}function qx(a,b,c){var d=0,e=0,f=0,g=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31785]=0;O(117,d|0,Wc(e,a)|0);a=x[31785];x[31785]=0;if((a|0)!=1){a:{while(1){if(Wc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Sd(b,f)>>2];g=e&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|(e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}else{x[31785]=0;O(118,d|0,a<<24>>24);a=x[31785];x[31785]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31785]=0;O(118,d|0,a<<24>>24);a=x[31785];x[31785]=0;if((a|0)!=1){break b}break a}x[31785]=0;O(118,d|0,63);a=x[31785];x[31785]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function Haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb+-64|0;fb=d;a=x[a+4>>2];_w(d+16|0,b);x[31785]=0;b=P(1,d+4|0,18589)|0;e=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){x[31785]=0;S(2,d+28|0,d+16|0,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break h}x[31785]=0;S(493,d+40|0,d+28|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break g}x[31785]=0;O(1068,d+52|0,d+40|0);c=x[31785];x[31785]=0;if((c|0)==1){break f}c=x[x[a>>2]+8>>2];x[31785]=0;O(c|0,a|0,d+52|0);a=x[31785];x[31785]=0;if((a|0)==1){break e}tb(d+52|0);tb(d+40|0);tb(d+28|0);tb(b);tb(d+16|0);fb=d- -64|0;return}a=N()|0;break a}a=N()|0;break b}a=N()|0;break c}a=N()|0;break d}a=N()|0;tb(d+52|0)}tb(d+40|0)}tb(d+28|0)}tb(b)}tb(d+16|0);Q(a|0);p()}function Foa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=fb-32|0;fb=f;jd(c,2);v[f+20|0]=y[b+13|0];v[f+8|0]=64;d=f+20|0;e=f+8|0;i=c,j=y[Ub(d,e)|0]<<2,w[i+30>>1]=j;x[c+24>>2]=(y[b+14|0]|y[b+15|0]<<8)<<1;Lk(e,2,b+1|0);Ec(d,e);ye(c+43|0,d);tb(d);d=ad(a,8,1,0,2);a:{if((y[b|0]&3)!=1){break a}g=y[b+22|0]|y[b+23|0]<<8|(y[b+24|0]<<16|y[b+25|0]<<24);x[c>>2]=g;e=y[b+26|0]|y[b+27|0]<<8|(y[b+28|0]<<16|y[b+29|0]<<24);x[c+4>>2]=e;a=y[b+30|0]|y[b+31|0]<<8|(y[b+32|0]<<16|y[b+33|0]<<24);h=a-(a>>>0>e>>>0)|0;x[c+8>>2]=h;a=y[b|0];if(a&4){w[c+34>>1]=z[c+34>>1]|2;a=y[b|0]}if(a&8){w[c+34>>1]=z[c+34>>1]|4;a=y[b|0]}if(!(a&16)){break a}ed(d,16);ug(d,9);x[c+8>>2]=h>>>1;x[c+4>>2]=e>>>1;x[c>>2]=g>>>1}fb=f+32|0}function MZ(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=fb-176|0;fb=b;c=b+12|0;Of(c,a);x[31785]=0;O(127,b+24|0,c|0);a=x[31785];x[31785]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31785]=0;a=P(106,b+36|0,b+24|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break e}tb(b+24|0);tb(b+12|0);c=x[x[a>>2]-12>>2];x[31785]=0;d=ca(107)|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}x[31785]=0;S(108,b+8|0,a+c|0,d|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}Zb(b+8|0);x[31785]=0;x[b+24>>2]=0;x[b+28>>2]=0;c=P(413,a|0,b+24|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break c}a=pk(x[(c+x[x[c>>2]-12>>2]|0)+16>>2]);e=C[b+24>>3];Af(c);fb=b+176|0;e=a?0:e;break a}c=N()|0;break d}c=N()|0;tb(b+24|0)}tb(b+12|0);break b}c=N()|0;Af(a)}Q(c|0);p()}return+e}function Kma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];k=x[a+16>>2];h=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=h;l=x[a+32>>2];m=x[a+28>>2];h=x[a+8>>2];n=x[a+12>>2];while(1){if(d){e=x[b+8>>2];o=e>>>10&4194048;p=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){i=e+p|0;j=v[i|0];x[(e<<2)+b>>2]=((D(v[i+2|0]-j|0,o)|0)/16384|0)+(j<<8);e=e+1|0;continue}break}g=g+m|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Qb(b+8|0,h,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-48|0;fb=e;x[e+44>>2]=c;a=oe(a,e+44|0);f=rc(a+4|0);g=rc(a+24|0);h=rc(a+32|0);i=Nb(a+36|0);x[a+56>>2]=3;j=Nb(a+68|0);x[31785]=0;O(1e3,a|0,d|0);c=x[31785];x[31785]=0;a:{b:{c:{d:{if((c|0)!=1){c=Jd(e+16|0);x[31785]=0;k=x[c+4>>2];x[e+8>>2]=x[c>>2];x[e+12>>2]=k;S(1124,e+24|0,b|0,e+8|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;S(1001,a|0,e+24|0,d|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}ub(e+24|0);x[31785]=0;W(1002,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}d=N()|0;break b}d=N()|0;break b}d=N()|0;ub(e+24|0)}Pd(j);mf(i);yl(h);sh(g);rh(f);Uc(a);Uc(e+44|0);Q(d|0);p()}Uc(e+44|0);fb=e+48|0;return a|0}function Qm(a,b){var c=0,d=0,e=0,f=0;c=fb+-64|0;fb=c;d=x[x[a>>2]-12>>2]+a|0;e=x[d+16>>2]&-3;eg(d,e);a:{b:{if(Ad(y[Cm(c+63|0,a,1)|0])){d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31785]=0;f=x[b+12>>2];x[c+16>>2]=x[b+8>>2];x[c+20>>2]=f;f=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=f;S(946,c+40|0,d|0,c+8|0);b=x[31785];x[31785]=0;c:{if((b|0)!=1){b=ei(c+24|0,-1,-1);b=Un(x[c+48>>2],x[c+52>>2],x[b+8>>2],x[b+12>>2])?e|4:e;break c}Y(T(0)|0)|0;b=e|1;Am(x[x[a>>2]-12>>2]+a|0,b);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31785]=0;X(87);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}$j(x[x[a>>2]-12>>2]+a|0,b)}fb=c- -64|0;return}T(0)|0;Rb()}p()}function xma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=e>>>21&2040;n=w[e+38390>>1];o=w[e+38388>>1];p=w[e+38386>>1];e=w[e+38384>>1];f=0;while(1){if((f|0)!=2){g=(f<<1)+m|0;x[(f<<2)+b>>2]=(((D(w[g>>1],p)+D(w[g-4>>1],e)|0)+D(w[g+4>>1],o)|0)+D(w[g+8>>1],n)|0)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Qb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Nh(a,b){var c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=0;f=GP(a);h=a+4208|0;c=E(E(B[wb(h,4)>>2]*E(1.899999976158142))+E(.10000000149011612));g=B[a+4268>>2];d=Ce(E(10),E(E(E(E(E(x[((b<<2)+a|0)+4292>>2])/g)*E(-60))/E(E(B[wb(h,3)>>2]*E(19.899999618530273))+E(.10000000149011612)))/E(20)));c=E(E(Ce(d,E(E(2)-E(E(2)/c)))+E(-1))/E(E(1)-iq(c>E(1)?E(3.1415927410125732):E(f*E(E(6.2831854820251465)/g)))));a:{if(c==E(0)){break a}if(!Rm(c)){break a}g=E(c+c);f=E(E(-2)-g);c=E(E(f*f)+E(E(c*c)*E(-4)));if(c>E(0)){e=E(M(c))}c=E(E(e-f)/g);if(E(F(c))>E(1)){c=E(E(E(-f)-e)/g)}e=Wf(c)}b=(b<<3)+a|0;B[b+4404>>2]=e;B[b+4400>>2]=d;c=B[a+4272>>2];c=E(c*c);e=E(E(1)-c);d=E(d*d);return E(E(E(e*E(d/E(E(1)-E(c*d))))*e)+c)}function JH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=fb-48|0;fb=g;x[g+44>>2]=d;a=oe(a,g+44|0);d=rc(a+4|0);h=rc(a+24|0);i=rc(a+32|0);j=Nb(a+36|0);x[a+56>>2]=3;k=Nb(a+68|0);x[31785]=0;O(1e3,a|0,e|0);l=x[31785];x[31785]=0;a:{b:{c:{d:{if((l|0)!=1){bc(g+16|0,b,c);b=Jd(g+8|0);x[31785]=0;c=x[b+4>>2];x[g>>2]=x[b>>2];x[g+4>>2]=c;ws(f,g+24|0,x[g+16>>2],x[g+20>>2],g);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;S(1001,a|0,g+24|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}ub(g+24|0);x[31785]=0;W(1002,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}e=N()|0;break b}e=N()|0;break b}e=N()|0;ub(g+24|0)}Pd(k);mf(j);yl(i);sh(h);rh(d);Uc(a);Uc(g+44|0);Q(e|0);p()}Uc(g+44|0);fb=g+48|0;return a}function Kfa(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;c=Fb(b+20|0);x[31785]=0;W(993,b+8|0);a=x[31785];x[31785]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=vb(x[b+8>>2]),x[f+4>>2]=g;d=1;while(1){e=vb(x[b+12>>2]);a=x[b+4>>2];if(!Ib(a,e)){a=xg(Jb(c));Pd(b+8|0);tb(c);break b}if(!d){x[31785]=0;P(994,c|0,14763)|0;a=x[31785];x[31785]=0;if((a|0)==1){break d}a=x[b+4>>2]}x[31785]=0;P(845,c|0,a|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break d}Uq(b+4|0);d=0;continue}}a=T(0)|0;break c}a=T(0)|0;Pd(b+8|0)}tb(c);Y(a|0)|0;a=0;x[31785]=0;V(992,7060,0,0,0);c=x[31785];x[31785]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}b=N()|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){T(0)|0;Rb();p()}Q(b|0);p()}function JC(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;d=y[a|0];if(d&1){v[b+12|0]=y[b+12|0]|1;d=y[a|0]}if(d&2){v[b+12|0]=y[b+12|0]|4;d=y[a|0]}if(d&4){v[b+12|0]=y[b+12|0]|2;d=y[a|0]}if(d&16){v[b+12|0]=y[b+12|0]|16;d=y[a|0]}if(d&32){v[b+12|0]=y[b+12|0]|8}v[e+15|0]=y[a+1|0];v[e+14|0]=25;dh(b,y[Ub(e+15|0,e+14|0)|0]);v[b+15|0]=y[a+2|0];v[b+16|0]=y[a+3|0];v[b+13|0]=y[a+4|0];v[b+14|0]=y[a+5|0];g=x[b>>2];i=Od(g,x[b+4>>2]);b=0;while(1){if((b|0)!=(i|0)){h=wb(g,b);f=(b<<2)+a|0;d=y[f+6|0]|y[f+7|0]<<8;w[h>>1]=d;a:{if(!b){break a}j=d;d=z[wb(g,b-1|0)>>1];if(j>>>0>=d>>>0){break a}w[h>>1]=d+1}k=h,l=Xb((y[f+8|0]|y[f+9|0]<<8)<<16>>16>>c,0,64),v[k+2|0]=l;b=b+1|0;continue}break}fb=e+16|0}function qK(a,b){var c=0,d=0,e=0;a:{if(y[b|0]){break a}b=xy(13964);if(y[b|0]?b:0){break a}b=xy(D(a,12)+96016|0);if(y[b|0]?b:0){break a}b=xy(14253);if(y[b|0]?b:0){break a}b=14896}b:{while(1){d=y[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14896;c:{d:{c=y[b|0];e:{f:{if(!(y[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!y[e+1|0]){break e}}if(!li(e,14896)){break e}if(li(e,13626)){break d}}if(!a){c=96088;if(y[e+1|0]==46){break c}}return 0}c=x[125083];if(c){while(1){if(!li(e,c+8|0)){break c}c=x[c+32>>2];if(c){continue}break}}c=Ed(36);if(c){x[c+4>>2]=20;x[c>>2]=95984;b=c+8|0;yc(b,e,d);v[b+d|0]=0;x[c+32>>2]=x[125083];x[125083]=c}c=a|c?c:96088}return c}function Zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=ig(1,2);e=hb;l=e;Qb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=((((x[b+12>>2]&2147483647)<<1|i>>>31)&2147483646)<<1)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=w[(h<<1)+i>>1];h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Qb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Dg(a,j,l);fb=b+16|0}function M8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=x[b+44>>2];i=x[b+24>>2];if(h>>>0<i>>>0){x[b+44>>2]=i;h=i}m=-1;n=-1;o=f&24;a:{if(!o|(e|0)==1&(o|0)==24){break a}if(h){j=h-Jb(b+32|0)|0;k=j>>31}b:{c:{switch(e|0){case 1:if(f&8){g=x[b+12>>2]-x[b+8>>2]|0;l=g>>31;break b}g=i-x[b+20>>2]|0;l=g>>31;break b;case 0:break b;case 2:break c;default:break a}}g=j;l=k}d=d+l|0;c=c+g|0;d=g>>>0>c>>>0?d+1|0:d;if((d|0)<0|(c>>>0>j>>>0&(d|0)>=(k|0)|(d|0)>(k|0))){break a}e=f&8;d:{if(!(c|d)){break d}if(x[b+12>>2]?0:e){break a}if(!(f&16)){break d}if(!i){break a}}if(e){e=x[b+8>>2];_n(b,e,c+e|0,h)}if(f&16){Fy(b,x[b+20>>2],x[b+28>>2]);jt(b,c)}m=c;n=d}ei(a,m,n)}function Kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=fb-16|0;fb=i;d=x[zb(i+12|0,vb(x[a+4>>2]))>>2];h=fb-32|0;fb=h;e=d;d=x[a>>2];f=(dp(e,vb(d))<<1)+d|0;e=vB(b,c);a:{if((e|0)<=0){break a}d=x[Ab(a)>>2];g=x[a+4>>2];if((e|0)<=d-g>>1){k=g-f|0;j=k>>1;b:{if((e|0)<=(j|0)){d=c;break b}x[h+8>>2]=b;s$(h+8|0,j);d=x[h+8>>2];MB(a,d,c,e-j|0);if((k|0)<=0){break a}}DU(a,f,g,(e<<1)+f|0);Gk(b,d,f);break a}d=Ab(a);e=hk(h+8|0,ik(a,Xc(x[a>>2],g)+e|0),f-x[a>>2]>>1,d);g=fb-16|0;fb=g;c=rp(g+4|0,e+8|0,vB(b,c));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){dk(d,z[b>>1]);d=x[c>>2]+2|0;x[c>>2]=d;b=b+2|0;continue}break}ee(c);fb=g+16|0;f=ir(a,e,f);fj(e)}zb(h+28|0,f);fb=h+32|0;fb=i+16|0;return a|0}function iN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;a:{b:{c:{d:{e:{if((b|0)>=0){g=a;a=x[a+32>>2];if((Nf(a)|0)>(b|0)){break e}}a=ac(8);x[31785]=0;b=P(37,f+4|0,10745)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break b}c=N()|0;tb(b);break c}d=(a+(b<<5)|0)+480280|0;c=c?134218752:0;x[d>>2]=c|x[d>>2]&-134218753;d=(a+D(b,872)|0)+1075080|0;x[d>>2]=c|x[d>>2]&-134218753;a=z[a+480188>>1];d=a>>>0<=256?256:a;b=b+1|0;g=x[g+32>>2];while(1){if((a|0)==(d|0)){break a}e=g+D(a,872)|0;if((b|0)==z[e+1075778>>1]){e=e+1075080|0;x[e>>2]=c|x[e>>2]&-134218753}a=a+1|0;continue}}c=N()|0;jc(a)}Q(c|0)}p()}fb=f+16|0}function a2(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-176|0;fb=c;b=c+12|0;Of(b,a);x[31785]=0;O(127,c+24|0,b|0);a=x[31785];x[31785]=0;a:{b:{c:{d:{e:{if((a|0)!=1){x[31785]=0;a=P(106,c+36|0,c+24|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}tb(c+24|0);tb(c+12|0);b=x[x[a>>2]-12>>2];x[31785]=0;d=ca(107)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}x[31785]=0;S(108,c+8|0,a+b|0,d|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}Zb(c+8|0);x[31785]=0;x[c+24>>2]=0;b=P(128,a|0,c+24|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break c}a=pk(x[(b+x[x[b>>2]-12>>2]|0)+16>>2]);d=x[c+24>>2];Af(b);fb=c+176|0;a=a?0:d;break a}b=N()|0;break d}b=N()|0;tb(c+24|0)}tb(c+12|0);break b}b=N()|0;Af(a)}Q(b|0);p()}return a|0}function d0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;jd(b,0);x[b>>2]=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);c=zr(a+4|0,a);f=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+4>>2]=f;c=zr(a+8|0,a);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);x[b+8>>2]=c;v[e+15|0]=127;v[e+14|0]=y[a+15|0];g=b,h=(((y[Ub(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,w[g+30>>1]=h;d=y[a+12|0];if(d>>>0>=16){w[b+34>>1]=32;w[b+28>>1]=d&240}d=(y[a+13|0]|y[a+14|0]<<8)<<1;x[b+24>>2]=d;d=y[a+13|0]|y[a+14|0]<<8?d:16726;x[b+24>>2]=d;g=b,h=(D(iw(0,y[a+12|0]<<28>>24),d)>>>0)/8363|0,x[g+24>>2]=h;if(c>>>0>f>>>0){w[b+34>>1]=z[b+34>>1]|2}if(y[a+16|0]&132){w[b+34>>1]=z[b+34>>1]|1}fb=e+16|0}function $na(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(e+8|0,x[zb(e+4|0,a)>>2]);a:{if(b){x[31785]=0;O(743,a|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;d=f+4|0;x[d>>2]=a;c=x[a+4>>2];x[d+4>>2]=c;x[d+8>>2]=c+D(b,36);b=x[d+4>>2];g=x[d+8>>2];while(1){if((b|0)==(g|0)){hc(d);fb=f+16|0}else{c=Tb(b,0,36);x[c>>2]=0;x[c+4>>2]=0;w[c+22>>1]=0;w[c+24>>1]=0;w[c+26>>1]=0;w[c+28>>1]=0;v[c+21|0]=64;v[c+19|0]=64;v[c+20|0]=100;v[c+15|0]=0;v[c+16|0]=0;v[c+17|0]=0;v[c+18|0]=0;x[c+8>>2]=0;x[c+12>>2]=0;w[c+30>>1]=0;w[c+32>>1]=0;b=b+36|0;x[d+4>>2]=b;continue}break}}b=e+8|0;Md(b);MV(b);fb=e+16|0;return a|0}a=N()|0;MV(e+8|0);Q(a|0);p()}function Co(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){v[b+809|0]=c;break a}c=y[b+809|0]}e=x[a+480180>>2];d=e&202376205?c&240?c&-16:c:c;c=x[b+688>>2];b:{if(e&69206029){break b}g=d&255;f=d&15;if((f|0)==15){if(g>>>0>=16){Bo(a,b,(d&240)>>>4|0,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c-60|0;break b}if((g&240)!=240){break b}if(f){Ao(a,b,f,0);return}if(!(v[b+851|0]&1)){break b}c=y[a+480208|0]&2?c:c+60|0}c:{if(!(!(v[b+851|0]&1)|y[a+480208|0]&2)&(x[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&15;d:{if(a){if((d&255)>>>0>15?e&16777248:0){break c}c=c-(a<<2)|0;break d}c=((d&255)>>>2&60)+c|0}if((e|0)!=1){break c}x[b+88>>2]=x[b+88>>2]|2097152}h=b,i=Xb(c,0,256),x[h+688>>2]=i}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;x[31785]=0;f=R(1162,b|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){a:{b:{if(f){x[31785]=0;O(1163,d+56|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){b=d- -64|0;f=d+56|0;xp(b,f);e=zf(d+72|0,b);g=zf(d+48|0,c);h=x[e+4>>2];x[d+8>>2]=x[e>>2];x[d+12>>2]=h;e=x[g+4>>2];x[d>>2]=x[g>>2];x[d+4>>2]=e;yp(a,d+8|0,d);break b}break a}x[31785]=0;O(1164,d+56|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}b=d- -64|0;f=d+56|0;xp(b,f);e=zf(d+40|0,b);g=zf(d+32|0,c);h=x[e+4>>2];x[d+24>>2]=x[e>>2];x[d+28>>2]=h;e=x[g+4>>2];x[d+16>>2]=x[g>>2];x[d+20>>2]=e;yp(a,d+24|0,d+16|0)}he(b);he(f);he(c);fb=d+80|0;return}}a=N()|0;he(c);Q(a|0);p()}function js(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Lc(a)>>>0>=b>>>0){break a}k=d,l=Bb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Ah(x[_c(d+12|0,d+8|0)>>2]);if((Lc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Bb(x[a+4>>2],y[a+11|0]);b:{c:{h=Ok(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Lc(a)>>>0<b>>>0){ng(e+8|0,c);break e}x[31785]=0;O(119,e+8|0,c|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);g=Jb(a);c=Bb(x[a+4>>2],c)}b=yg(b,g,c+1|0);if(i){Db(g)}if(!h){nf(a,j);Vd(a,f);vd(a,b);break b}Ke(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}of();p()}function RT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<2147483632){a:{if(Lc(a)>>>0>=b>>>0){break a}k=d,l=Bb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=Ah(x[_c(d+12|0,d+8|0)>>2]);if((Lc(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;f=Bb(x[a+4>>2],y[a+11|0]);b:{c:{h=Ok(b);d:{if(h){i=1;j=b+1|0;g=x[a>>2];b=a;c=f;break d}c=b+1|0;e:{if(Lc(a)>>>0<b>>>0){ng(e+8|0,c);break e}x[31785]=0;O(53,e+8|0,c|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}}j=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);g=Jb(a);c=Bb(x[a+4>>2],c)}b=Tg(b,g,c+1|0);if(i){Db(g)}if(!h){nf(a,j);Vd(a,f);vd(a,b);break b}Ke(a,f);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}of();p()}function Mi(a,b,c,d){var e=0,f=0,g=0;x[a+20>>2]=d;x[a+16>>2]=c;x[a+12>>2]=b;x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=43016;c=a+24|0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;b=Nb(a+44|0);d=Nb(b+12|0);e=Nb(b+24|0);f=Nb(b+36|0);x[31785]=0;O(950,b|0,0);g=x[31785];x[31785]=0;if((g|0)==1){a=N()|0;sc(f);sc(e);Yt(d);Yt(b);Q(a|0);p()}w[a+4204>>1]=0;x[a+4196>>2]=1065353216;x[a+4200>>2]=0;d=x[a+16>>2];x[d+946300>>2]=x[d+946300>>2]+1;x[31785]=0;d=R(951,a+92|0)|0;e=x[31785];x[31785]=0;a:{if((e|0)!=1){b=a+4200|0;x[c>>2]=d;c=x[a+16>>2]+906300|0;d=y[a+4200|0];e=x[a+20>>2];while(1){if((rd(c,d)|0)==(e|0)|d>>>0>248){break a}d=d+1|0;v[b|0]=d;continue}}a=N()|0;lQ(b);Q(a|0);p()}return a}function bf(a,b,c){var d=0,e=0,f=0;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31785]=0;O(117,d|0,Wc(e,a)|0);a=x[31785];x[31785]=0;if((a|0)!=1){a:{while(1){if(Wc(x[b+4>>2],y[b+11|0])>>>0>f>>>0){e=x[Sd(b,f)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((e|0)==x[(a<<2)+c>>2]){x[31785]=0;O(118,d|0,a<<24>>24);a=x[31785];x[31785]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if((e|0)!=x[(a<<2)+c>>2]){a=a+1|0;continue}break}x[31785]=0;O(118,d|0,a<<24>>24);a=x[31785];x[31785]=0;if((a|0)!=1){break b}break a}x[31785]=0;O(118,d|0,63);a=x[31785];x[31785]=0;if((a|0)!=1){break b}break a}f=f+1|0;continue}break}return}}a=N()|0;tb(d);Q(a|0);p()}function WA(a,b,c){var d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;e=x[a>>2];f=x[e-4>>2];g=x[e-8>>2];x[d+28>>2]=0;x[d+32>>2]=0;x[d+36>>2]=0;x[d+40>>2]=0;x[d+44>>2]=0;x[d+48>>2]=0;x[d+52>>2]=0;x[d+56>>2]=0;e=0;v[d+59|0]=0;v[d+60|0]=0;v[d+61|0]=0;v[d+62|0]=0;x[d+20>>2]=0;x[d+24>>2]=0;x[d+16>>2]=b;x[d+12>>2]=a;x[d+8>>2]=c;a=a+g|0;a:{if(kh(f,c,0)){x[d+56>>2]=1;ib[x[x[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=x[d+32>>2]==1?a:0;break a}ib[x[x[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(x[d+44>>2]){case 0:e=x[d+48>>2]==1?x[d+36>>2]==1?x[d+40>>2]==1?x[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(x[d+32>>2]!=1){if(x[d+48>>2]|x[d+36>>2]!=1|x[d+40>>2]!=1){break a}}e=x[d+24>>2]}fb=d- -64|0;return e}function KQ(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=fb-48|0;fb=e;d=Fb(e+36|0);x[31785]=0;O(941,b|0,e+24|0);g=x[31785];x[31785]=0;if((g|0)!=1){b:{g=x[e+28>>2];f=x[e+24>>2];rf(d);x[31785]=0;g=!g&f>>>0>=255|g?255:f;O(47,d|0,g|0);f=x[31785];x[31785]=0;if((f|0)==1){break b}c:{while(1){if((g|0)==(h|0)){b=w$(Jb(d),Bb(x[d+4>>2],y[d+11|0]));if((b|0)==-1){break c}x[31785]=0;O(47,d|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break c}break b}f=cc(d,h);x[31785]=0;P(942,b|0,f|0)|0;f=x[31785];x[31785]=0;if((f|0)!=1){h=h+1|0;continue}break}break b}x[31785]=0;S(500,e+12|0,a|0,d|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}a=e+12|0;yb(c,a);tb(a);tb(d);fb=e+48|0;break a}}a=N()|0;tb(d);Q(a|0);p()}}function pna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;jd(b,4);w[b+30>>1]=y[a+12|0]<<2;Pf(b+30|0,256);e=y[a+15|0];w[b+34>>1]=32;w[b+28>>1]=e;v[b+37|0]=y[a+13|0];v[b+36|0]=y[a+16|0];f=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=f;c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+4>>2]=c;d=(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+c|0;x[b+8>>2]=d;e=y[a+14|0];if(e&16){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;f=f>>>1|0;x[b>>2]=f;e=y[a+14|0]}if(e&32){d=d>>>1|0;x[b+8>>2]=d;c=c>>>1|0;x[b+4>>2]=c;x[b>>2]=f>>>1;e=y[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){w[b+34>>1]=34;w[b+34>>1]=y[a+14|0]&2?38:34}a=Cc(g+4|0,22485);ye(b+43|0,a);tb(a);fb=g+16|0}function aka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=fb-16|0;fb=d;x[d+12>>2]=b;if(b>>>0<1073741808){a:{if(kn(a)>>>0>=b>>>0){break a}k=d,l=Bb(x[a+4>>2],y[a+11|0]),x[k+8>>2]=l;b=jn(x[_c(d+12|0,d+8|0)>>2]);if((kn(a)|0)==(b|0)){break a}e=fb-16|0;fb=e;i=1;f=b+1|0;c=kn(a);g=Bb(x[a+4>>2],y[a+11|0]);b:{c:{j=Nq(b);d:{if(j){h=x[a>>2];b=a;c=g;break d}e:{if(b>>>0>c>>>0){Rj(e+8|0,f);break e}x[31785]=0;O(55,e+8|0,f|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}}f=x[e+12>>2];b=x[e+8>>2];c=y[a+11|0];i=Cd(c);h=Jb(a);c=Bb(x[a+4>>2],c)}b=Wi(b,h,c+1|0);if(i){Db(h)}if(!j){nf(a,f);Vd(a,g);vd(a,b);break b}Ke(a,g);break b}Y(T(0)|0)|0;Z()}fb=e+16|0}fb=d+16|0;return}of();p()}function Ria(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);b:{c=Jk(x[b>>2],x[b+4>>2]);if(!c){break b}x[31785]=0;O(464,a|0,c|0);e=x[31785];x[31785]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[31785]=0;du(a,f,e,c);c=x[31785];x[31785]=0;if((c|0)!=1){break b}}a=N()|0;am(d+8|0);Q(a|0);p()}c=d+8|0;Md(c);am(c);fb=d+16|0;x[a+20>>2]=x[b+20>>2];d=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=d;x[31785]=0;d=P(928,a+24|0,b+24|0)|0;c=x[31785];x[31785]=0;c:{d:{if((c|0)!=1){x[31785]=0;P(73,a+36|0,b+36|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}x[a+48>>2]=x[b+48>>2];break a}b=N()|0;break c}b=N()|0;sc(d)}Nk(a);Q(b|0);p()}}function yma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=fb-16|0;fb=b;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;k=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=e>>>21&2040;n=w[e+38390>>1];o=w[e+38388>>1];p=w[e+38386>>1];e=w[e+38384>>1];f=0;while(1){if((f|0)!=2){g=f+m|0;x[(f<<2)+b>>2]=(((D(v[g|0],p)+D(v[g-2|0],e)|0)+D(v[g+2|0],o)|0)+D(v[g+4|0],n)<<8)/16384;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],i);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],h);Qb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function bh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb+-64|0;fb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=x[a>>2];e=x[a+4>>2];if(Ge(d,e,b)){break b}c:{d:{if(Sk(d,e)>>>0<=b>>>0){d=hA(f+12|0,a);x[31785]=0;S(202,a|0,b+1|0,d|0);e=x[31785];x[31785]=0;if((e|0)==1){break d}Dl(d);d=x[a>>2]}x[31785]=0;O(203,sg(d,b)|0,c|0);c=x[31785];x[31785]=0;e:{if((c|0)!=1){c=sg(x[a>>2],b);x[c+16>>2]=0;x[c+20>>2]=0;c=x[a>>2];x[31785]=0;W(204,sg(c,b)|0);c=x[31785];x[31785]=0;if((c|0)!=1){break e}}b=T(125240)|0;a=gb;break c}a=sg(x[a>>2],b);g=Ib(x[a>>2],x[a+4>>2]);break b}b=T(125240)|0;a=gb;Dl(d)}if(($(125240)|0)!=(a|0)){break a}Y(b|0)|0;Z()}fb=f- -64|0;return g|0}Q(b|0);p()}function fT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-112|0;fb=f;x[f+108>>2]=0;e=zo(a,e&65535,d,c,f+108|0);c=y[b+790|0];if(!x[f+108>>2]){d=(c|0)==15;h=d&!y[b+792|0];e=e<<8;a:{if(e){x[b+664>>2]=e;break a}e=0;if(d){break a}e=x[b+664>>2]}h=h?0:y[b+836|0]<<16}if((c|0)==15){c=y[b+792|0];b:{if(!c){c=x[b+76>>2];x[f+4>>2]=1;g=x[_c(f+4|0,f+108|0)>>2]<<3;e=sua(c,0,e,0);d=(256<<g>>>1|0)+e|0;c=hb;c=d>>>0<e>>>0?c+1|0:c;e=g+8|0;g=d;d=e&31;if((e&63)>>>0>=32){e=0;c=c>>>d|0}else{e=c>>>d|0;c=((1<<d)-1&c)<<32-d|g>>>d}e=Bc(c,e);break b}Kv(f+4|0);if(c>>>0>9){break b}c=x[b+104>>2];if(!c){break b}e=x[wb(c+68|0,y[b+792|0]-1|0)>>2]+e|0}x[b+664>>2]=e}Do(a,b,e+h|0);fb=f+112|0}function n9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;e=x[a+28>>2];x[d+16>>2]=e;f=x[a+20>>2];x[d+28>>2]=c;x[d+24>>2]=b;b=f-e|0;x[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Sy(Aa(x[a+60>>2],b|0,i|0,d+12|0)|0)){g=x[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];a=c;break a}h=x[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;x[e>>2]=h+x[e>>2];b=(j?12:4)+b|0;x[b>>2]=x[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a>>2]=x[a>>2]|32;a=0;if((i|0)==2){break a}a=c-x[b+4>>2]|0}fb=d+32|0;return a|0}function _ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=fb-16|0;fb=b;k=x[a+16>>2];j=ig(1,2);e=hb;l=e;Qb(a,j,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;m=x[a+32>>2];n=x[a+28>>2];e=x[a+8>>2];o=x[a+12>>2];while(1){if(d){d=d-1|0;i=x[b+8>>2];i=(((x[b+12>>2]&2147483647)<<1|i>>>31)&-2)+k|0;h=0;while(1){if((h|0)!=2){x[(h<<2)+b>>2]=v[h+i|0]<<8;h=h+1|0;continue}break}g=g+n|0;x[c>>2]=x[c>>2]+D(x[b>>2],g>>12);f=f+m|0;x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],f>>12);Qb(b+8|0,e,o);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Dg(a,j,l);fb=b+16|0}function Naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;h=g+4|0;e=fb-32|0;fb=e;d=pf(e+20|0,1,0);a:{b:{c:{while(1){c=Jb(d);j=Bb(x[d+4>>2],y[d+11|0])+c|0;i=x[b>>2];k=e+12|0;f=x[b+4>>2];if(!((f|0)>0|(f|0)>=0|(c|0)==(j|0))){v[c|0]=45;i=wN(i,f);f=hb;c=c+1|0}vN(k,c,j,i,f);if(!x[e+16>>2]){break c}c=ni(Bb(x[d+4>>2],y[d+11|0]));x[31785]=0;O(46,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)!=1){continue}break}break b}b=x[e+12>>2];c=Jb(d);x[31785]=0;O(47,d|0,b-c|0);b=x[31785];x[31785]=0;d:{if((b|0)!=1){x[31785]=0;O(306,h|0,d|0);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break b}break b}tb(d);fb=e+32|0;break a}a=N()|0;tb(d);Q(a|0);p()}Oh(a,h);tb(h);fb=g+16|0}function vfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;x[31785]=0;W(1005,a|0);e=x[31785];x[31785]=0;a:{b:{c:{if((e|0)==1){break c}x[31785]=0;W(1006,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break c}x[31785]=0;W(1006,c|0);f=x[31785];x[31785]=0;e=1;if((f|0)==1){break c}f=x[a+24>>2];b=pc(d+24|0,b);c=pc(d+16|0,c);g=x[c>>2];c=x[c+4>>2];x[31785]=0;h=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=h;xs(1027,f,d+8|0,g,c,1);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,5527,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();e=0}fb=d+32|0;return e|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Ula(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=(x[e+12>>2]<<1)+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=(((((D(w[f+4>>1],w[b+10>>1])+D(w[f+2>>1],w[b+8>>1])|0)+D(w[f+6>>1],w[b+12>>1])|0)+D(w[f+8>>1],w[b+14>>1])|0)/2|0)+((((D(w[f-4>>1],w[b+2>>1])+D(w[f-6>>1],w[b>>1])|0)+D(w[f-2>>1],w[b+4>>1])|0)+D(w[f>>1],w[b+6>>1])|0)/2|0)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Qb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function QQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=E(0),j=E(0),k=0,l=E(0);g=fb-16|0;fb=g;e=w[d>>1];f=w[d+2>>1];if(!(!z[b>>1]|(e|0)>(f|0)|(!(B[c>>2]>E(0))|(f-e|0)>32766))){w[a>>1]=3;f=a+4|0;Gf(f);w[a+28>>1]=65472;x[g+12>>2]=1065353216;UQ(f,g+12|0);x[a+32>>2]=0;w[a+30>>1]=0;Gf(a+16|0);h=w[d>>1];w[a+28>>1]=h;e=fb-16|0;fb=e;w[e+14>>1]=z[b>>1];w[e+12>>1]=32767;b=w[Mc(e+14|0,e+12|0)>>1];fb=e+16|0;w[a+30>>1]=b;i=E(F(B[c>>2]));B[a+32>>2]=i;i=Ce(i,E(E(1)/E(b|0)));vk(f,(w[d+2>>1]-h|0)+1|0);b=x[a+4>>2];c=w[a+28>>1];e=w[d+2>>1];d=w[d>>1];while(1){if((d|0)>(e|0)){kq(a)}else{j=Ce(i,E(d|0));k=wb(b,d-c|0),l=j,B[k>>2]=l;d=d+1|0;continue}break}h=1}fb=g+16|0;return h|0}function yO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=0;c=x[b+24>>2];c=Gu(x[c+484344>>2],x[c+484348>>2]);x[31785]=0;O(179,e|0,c|0);c=x[31785];x[31785]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=x[b+24>>2];f=x[c+484344>>2];if(Gu(f,x[c+484348>>2])>>>0<=a>>>0){break b}x[31785]=0;O(1075,d+8|0,Vb(f,a)|0);c=x[31785];x[31785]=0;if((c|0)!=1){c=x[b+24>>2];x[31785]=0;S(1062,d+20|0,c|0,d+8|0);c=x[31785];x[31785]=0;if((c|0)==1){break e}x[31785]=0;O(181,e|0,d+20|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}a=a+1|0;tb(d+20|0);tb(d+8|0);continue}break}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(d+20|0)}tb(d+8|0);break a}fb=d+32|0;return}a=N()|0}Pd(e);Q(a|0);p()}function eU(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=Ju(b);e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(e+8|0,x[zb(e+4|0,a)>>2]);x[31785]=0;O(805,a|0,2048);c=x[31785];x[31785]=0;a:{if((c|0)!=1){h=fb-16|0;fb=h;g=Tr(h+4|0,a,2048);c=x[g+4>>2];j=x[g+8>>2];while(1){if((c|0)==(j|0)){hc(g);fb=h+16|0}else{x[c>>2]=0;x[c+4>>2]=0;c=c+8|0;x[g+4>>2]=c;continue}break}c=e+8|0;Md(c);Iu(c);fb=e+16|0;break a}a=N()|0;Iu(e+8|0);Q(a|0);p()}while(1){b:{d=1;if((f|0)!=1024){if((f|0)==2048){break b}d=+(f-1024|0);k=Ju(M(d*d*-9.5367431640625e-7+1)*b);d=d*.0372006759294457;d=k*Ti(d)/(i*d)}l=Re(x[a>>2],f),m=d*.011841342921061943,C[l>>3]=m;f=f+1|0;continue}break}}function Jz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d>>2]=a;x[d+4>>2]=b;x[d+8>>2]=a;x[d+12>>2]=b;b=fb+-64|0;fb=b;a:{if(!x[d+4>>2]){break a}a=x[d>>2];h=x[d+4>>2];c=30864;while(1){if((c|0)==31288){c=31296;while(1){f=(c|0)!=31344;if((c|0)==31344){break a}x[b+40>>2]=a;x[b+44>>2]=h;e=pc(b+32|0,x[c+8>>2]);g=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=g;g=x[e+4>>2];x[b>>2]=x[e>>2];x[b+4>>2]=g;c=c+12|0;if(!sR(b+8|0,b)){continue}break}break a}x[b+56>>2]=a;x[b+60>>2]=h;f=pc(b+48|0,x[c+4>>2]);e=x[b+60>>2];x[b+24>>2]=x[b+56>>2];x[b+28>>2]=e;e=x[f+4>>2];x[b+16>>2]=x[f>>2];x[b+20>>2]=e;c=c+8|0;if(!sR(b+24|0,b+16|0)){continue}break}f=1}fb=b- -64|0;fb=d+16|0;return f}function _aa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{b:{c:{while(1){if((b|0)==(c|0)){break c}x[31785]=0;O(1133,d|0,b|0);f=x[31785];x[31785]=0;if((f|0)!=1){d=d+16|0;x[e+28>>2]=d;b=b+16|0;continue}break}Y(T(0)|0)|0;a=SM(e+12|0,a,e+24|0,e+28|0);b=fb-16|0;fb=b;d=zb(b+12|0,x[x[a+8>>2]>>2]);e=x[zb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(Pg(a,e)){Hk(RM(a));a=x[tz(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0;x[31785]=0;X(87);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}Q(a|0);p()}fb=e+32|0;return d|0}T(0)|0;Rb()}p()}function C9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=d;x[e+24>>2]=d;a:{b:{c:{while(1){if((b|0)==(c|0)){break c}x[31785]=0;O(1169,d|0,b|0);f=x[31785];x[31785]=0;if((f|0)!=1){d=d+12|0;x[e+28>>2]=d;b=b+12|0;continue}break}Y(T(0)|0)|0;a=SM(e+12|0,a,e+24|0,e+28|0);b=fb-16|0;fb=b;d=zb(b+12|0,x[x[a+8>>2]>>2]);e=x[zb(b+8|0,x[x[a+4>>2]>>2])>>2];c=fb-16|0;fb=c;a=x[d>>2];x[c+12>>2]=a;while(1){if(Pg(a,e)){Eb(mx(a));a=x[tm(c+12|0)>>2];continue}break}fb=c+16|0;fb=b+16|0;x[31785]=0;X(87);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}Q(a|0);p()}fb=e+32|0;return d|0}T(0)|0;Rb()}p()}function Uu(a,b){var c=0,d=0,e=0;e=fb-48|0;fb=e;d=e+28|0;HV(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);a=e+8|0;HV(a,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=x[d>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a>>2];b=Tu(c,y[b|0]|y[b+1|0]<<8);a:{if(!Pj(b)){break a}b=x[d+4>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+4>>2];b=Tu(c,y[b|0]|y[b+1|0]<<8);if(!Pj(b)){break a}b=x[d+8>>2];c=y[b|0]|y[b+1|0]<<8;b=x[a+8>>2];b=Tu(c,y[b|0]|y[b+1|0]<<8);if(!Pj(b)){break a}b=x[a+12>>2];b=y[b|0]|y[b+1|0]<<8;c=x[d+12>>2];c=ve((y[c|0]|y[c+1|0]<<8)<<16>>16);b=ve(b<<16>>16);b=(b|0)!=(c|0)?(c|0)<(b|0)?-1:1:0;if(!Pj(b)){break a}b=x[d+16>>2];a=x[a+16>>2];b=Tu(y[b|0]|y[b+1|0]<<8,y[a|0]|y[a+1|0]<<8)}a=Cd(b);fb=e+48|0;return a}function SK(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[31785]=0;c=P(1190,d+8|0,a|0)|0;b=x[31785];x[31785]=0;c:{if((b|0)!=1){d:{if(!Ad(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31785]=0;b=R(1191,b|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[31785]=0;W(1192,a+b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break d}}b=T(0)|0;RK(c);break c}RK(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31785]=0;W(25,a+c|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function PA(a,b,c,d){var e=0,f=0,g=0;a:{if(!d){break a}if(c){v[b+815|0]=c;break a}c=y[b+815|0]}e=x[a+480180>>2];d=e&1048580;c=d?c&240?c&-16:c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=x[a+480208>>2]&4096;if(!d){break h}if(!a){break b}c=0-(d>>>2|0)|0;break d}a=x[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(e&16777248)|!d){break c}break b}c=0-(d>>>2|0)|0;break d}if(y[a+480209|0]&16){break b}d=c&240;c=d?d>>>2|0:0-(c<<2&60)|0;if(!Pb(a+1074312|0,56)){break d}c=c>>2}if(!c){break b}}a=x[b+692>>2];w[b+784>>1]=0;f=b,g=Xb(a+c|0,0,256),x[f+692>>2]=g}}function d7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-416|0;fb=h;d=h+416|0;x[h+12>>2]=d;c=fb-144|0;fb=c;x[c+28>>2]=c+132;i=c+32|0;JJ(x[a+8>>2],i,c+28|0,e,f,g);x[c+16>>2]=0;x[c+20>>2]=0;x[c+12>>2]=i;e=h+16|0;f=oc(e,x[h+12>>2]);a=Di(e,c+12|0,f,c+16|0,x[a+8>>2]);if((a|0)==-1){Yn(12682);p()}x[h+12>>2]=e+(a<<2);fb=c+144|0;f=fb-16|0;fb=f;i=f+8|0;a=fb-32|0;fb=a;Sp(a+24|0,e,x[h+12>>2]);h=a+16|0;e=x[a+24>>2];g=x[a+28>>2];c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){if((e|0)!=(g|0)){OK(c+12|0,x[e>>2]);e=e+4|0;continue}break}Qj(h,g,c+12|0);fb=c+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Td(i,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=d;return x[f+12>>2]}function zoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-160|0;fb=d;b=-1;a:{if(!sm(a,80)){break a}b:{c:{if(!Wl(a,60)){break c}if(!DW(a,d+140|0)){break c}c=15;if(ev(d+140|0,15)){break b}}if(!sm(a,144)){break a}b=0;if(!Wl(a,124)){break a}if(!DW(a,d+140|0)){break a}c=31;if(!ev(d+140|0,31)){break a}}XD(a);b=0;d:{while(1){if((b&65535)>>>0>=c>>>0){break d}b=b+1|0;if(BW(a)>>>0<=131072){continue}break}b=0;break a}b=-1;if(!fd(a,D(c,30)|20)){break a}c=fb-16|0;fb=c;e=d+10|0;FC(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){wC(e)}if(!a){break a}b=CW(y[d+10|0])}fb=d+160|0;return b|0}function un(a){a=a|0;var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;a:{b:{if(!x[(x[x[a>>2]-12>>2]+a|0)+24>>2]){break b}x[31785]=0;c=P(21,d+8|0,a|0)|0;b=x[31785];x[31785]=0;c:{if((b|0)!=1){d:{if(!Ad(y[c|0])){break d}b=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31785]=0;b=R(31,b|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=x[x[a>>2]-12>>2];x[31785]=0;O(24,a+b|0,1);b=x[31785];x[31785]=0;if((b|0)!=1){break d}}b=T(0)|0;em(c);break c}em(c);break b}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31785]=0;W(25,a+c|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}Z()}fb=d+16|0;return a|0}a=N()|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Wn(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0,n=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;n=a&255;if((n|0)!=y[k+24|0]){m=45;if(y[k+25|0]!=(n|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Bb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;a=Ii(k,k+26|0,a)-k|0;if((a|0)>23){break c}d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(a|0)<22){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+111968|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+111968|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function Vla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;h=x[a+24>>2];i=x[a+20>>2];j=x[a+16>>2];g=x[a+4>>2];x[e+8>>2]=x[a>>2];x[e+12>>2]=g;k=b+24|0;g=x[a+8>>2];l=x[a+12>>2];while(1){if(d){b=x[e+8>>2];f=x[e+12>>2]+j|0;b=(((b>>>16|0)+4&131064)<<1)+k|0;b=((((D(v[f+2|0],w[b+10>>1])+D(v[f+1|0],w[b+8>>1])|0)+D(v[f+3|0],w[b+12>>1])|0)+D(v[f+4|0],w[b+14>>1])<<8>>1)+(((D(v[f-2|0],w[b+2>>1])+D(v[f-3|0],w[b>>1])|0)+D(v[f-1|0],w[b+4>>1])|0)+D(v[f|0],w[b+6>>1])<<8>>1)|0)/16384|0;x[c>>2]=x[c>>2]+D(b,i);x[c+4>>2]=x[c+4>>2]+D(b,h);Qb(e+8|0,g,l);c=c+8|0;d=d-1|0;continue}break}b=x[e+12>>2];x[a>>2]=x[e+8>>2];x[a+4>>2]=b;fb=e+16|0}function N8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;a:{b:{if(!mc(b,-1)){i=x[a+8>>2];j=x[a+12>>2];d=x[a+24>>2];if((d|0)==x[a+28>>2]){g=-1;if(!(y[a+48|0]&16)){break a}h=x[a+20>>2];k=x[a+44>>2];x[31785]=0;f=a+32|0;O(118,f|0,0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Lc(f);x[31785]=0;O(47,f|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=Jb(f);Fy(a,c,Bb(x[a+36>>2],y[a+43|0])+c|0);jt(a,d-h|0);x[a+44>>2]=x[a+20>>2]+(k-h|0);d=x[a+24>>2]}x[e+12>>2]=d+1;c=x[_c(e+12|0,a+44|0)>>2];x[a+44>>2]=c;if(y[a+48|0]&8){d=Jb(a+32|0);_n(a,d,d+(j-i|0)|0,c)}g=YK(a,b<<24>>24);break a}g=Ey(b);break a}Y(T(0)|0)|0;Z()}fb=e+16|0;return g|0}function Iqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;a=q$(d+4|0,a);UC(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;hc(a);fb=d+16|0;return}h=fb-32|0;fb=h;d=Ab(a);c=o$(h+12|0,p$(a,sr(x[a>>2],x[a+4>>2])+1|0),sr(x[a>>2],x[a+4>>2]),d);UC(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;f=zb(g+12|0,x[a+4>>2]);d=zb(g+8|0,x[a>>2]);b=zb(g+4|0,x[c+4>>2]);f=x[f>>2];d=x[d>>2];e=fb-16|0;fb=e;x[e+8>>2]=x[b>>2];x[e+12>>2]=f;while(1){b=x[e+8>>2];if(Pg(f,d)){UC(m$(b),qr(f));b=$v(e+12|0);$v(e+8|0);f=x[b>>2];continue}break}fb=e+16|0;x[c+4>>2]=b;wc(a,c+4|0);wc(a+4|0,c+8|0);wc(Ab(a),Ac(c));x[c>>2]=x[c+4>>2];fb=g+16|0;n$(c);fb=h+32|0}function _j(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;a=q$(d+4|0,a);YD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+28;hc(a);fb=d+16|0;return}h=fb-32|0;fb=h;d=Ab(a);c=o$(h+12|0,p$(a,sr(x[a>>2],x[a+4>>2])+1|0),sr(x[a>>2],x[a+4>>2]),d);YD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+28;g=fb-16|0;fb=g;f=zb(g+12|0,x[a+4>>2]);d=zb(g+8|0,x[a>>2]);b=zb(g+4|0,x[c+4>>2]);f=x[f>>2];d=x[d>>2];e=fb-16|0;fb=e;x[e+8>>2]=x[b>>2];x[e+12>>2]=f;while(1){b=x[e+8>>2];if(Pg(f,d)){YD(m$(b),qr(f));b=$v(e+12|0);$v(e+8|0);f=x[b>>2];continue}break}fb=e+16|0;x[c+4>>2]=b;wc(a,c+4|0);wc(a+4|0,c+8|0);wc(Ab(a),Ac(c));x[c>>2]=x[c+4>>2];fb=g+16|0;n$(c);fb=h+32|0}function Vn(a,b,c,d,e,f,g,h,i,j,k){var l=0,m=0;a:{b:{l=x[d>>2];if((l|0)!=(c|0)){break b}m=43;if(x[k+96>>2]!=(a|0)){m=45;if(x[k+100>>2]!=(a|0)){break b}}x[d>>2]=c+1;v[c|0]=m;break a}c:{if(!(!Bb(g,h)|(a|0)!=(f|0))){h=0;a=x[j>>2];if((a-i|0)>159){break c}b=x[e>>2];x[j>>2]=a+4;x[a>>2]=b;break a}h=-1;f=ky(k,k+104|0,a)-k|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(l|0)|(l-c|0)>2|y[l-1|0]!=48){break c}x[e>>2]=0;x[d>>2]=l+1;v[l|0]=y[a+111968|0];return 0}x[d>>2]=l+1;v[l|0]=y[a+111968|0];x[e>>2]=x[e>>2]+1;h=0}return h}x[e>>2]=0;return 0}function yka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Kf(d+52|0);x[31785]=0;g=P(842,b|0,e|0)|0;f=x[31785];x[31785]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31785]=0;R(843,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[31785]=0;S(188,d+12|0,b|0,g|0);f=x[31785];x[31785]=0;if((f|0)==1){break a}f=d+12|0;h=ic(d+32|0,f);hd(e+8|0,h);ub(h);ub(f);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}x[31785]=0;P(186,b|0,2-c|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break d}break a}Pk(a,e)}Fd(e);fb=d+80|0;return}a=N()|0;Fd(e);Q(a|0);p()}function vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[h>>1],w[e+38386>>1])+D(w[h-2>>1],w[e+38384>>1])|0)+D(w[h+2>>1],w[e+38388>>1])|0)+D(w[h+4>>1],w[e+38390>>1])|0)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function es(a){var b=0,c=0;b=fb-32|0;fb=b;c=b+8|0;Cc(c,15547);x[31785]=0;S(126,b+20|0,1,c|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)!=1){x[31785]=0;O(12,a|0,b+20|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}Sb(b+20|0);tb(b+8|0);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Sb(b+20|0)}tb(b+8|0);Q(a|0);p()}x[31785]=0;b=ca(120)|0;c=x[31785];x[31785]=0;d:{if((c|0)==1){break d}x[a+12>>2]=b;x[31785]=0;b=ca(121)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}v[a+16|0]=b;x[31785]=0;b=ca(122)|0;c=x[31785];x[31785]=0;if((c|0)==1){break d}v[a+18|0]=0;v[a+17|0]=b;x[31785]=0;W(123,a+20|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}return}b=N()|0;tb(a);Q(b|0);p()}function QS(a,b,c,d,e){var f=0,g=0,h=0,i=0;a:{b:{c:{if(v[b+851|0]&1){f=y[b+848|0];g=c&240;if(g){f=f&15|g;v[b+848|0]=f}c=c&15;if(c){f=c|f&-16;v[b+848|0]=f}v[b+849|0]=(f&240)>>>4;if(x[a+480180>>2]!=32768){break a}break c}if(x[a+480180>>2]==32768){break c}c=y[b+849|0]-1|0;v[b+849|0]=c;if(c&255){break a}f=y[b+848|0];break b}f=y[b+848|0];if((f&240)==16){break b}if(!(y[a+480209|0]&16)){break a}}v[b+849|0]=(f&240)>>>4;c=f&15;c=d?c:0-c|0;d=x[b+656>>2];d:{if(Oj(d)){x[b+852>>2]=x[b+852>>2]+D(c,x[x[d+44>>2]+36>>2]);break d}h=b,i=vh(a,ru(a,x[b+700>>2],w[b+772>>1],x[b+704>>2])+c|0,w[b+772>>1],x[b+704>>2]),x[h+700>>2]=i}if(!e){break a}x[b>>2]=0;x[b+4>>2]=0}}function Ora(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];d=mr(c,x[a+4>>2]);if(d>>>0<b>>>0){f=fb-32|0;fb=f;c=b-d|0;b=x[Ab(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=(b-e|0)/40>>>0){d=fb-16|0;fb=d;b=R_(d+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{JY(a);a=a+40|0;x[b+4>>2]=a;continue}break}break a}b=Ab(a);d=O_(f+12|0,P_(a,mr(x[a>>2],e)+c|0),mr(x[a>>2],x[a+4>>2]),b);e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=x[d+8>>2];g=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=D(c,40)+g;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){JY(c);c=x[b>>2]+40|0;x[b>>2]=c;continue}break}ee(b);fb=e+16|0;N_(a,d);M_(d)}fb=f+32|0;return}if(b>>>0<d>>>0){K_(a,c+D(b,40)|0)}}function NF(a){a=a|0;var b=0,c=0,d=0,e=0;b=LE(x[(x[x[a>>2]-12>>2]+a|0)+28>>2],10);d=fb-16|0;fb=d;x[31785]=0;c=P(21,d+8|0,a|0)|0;e=x[31785];x[31785]=0;a:{b:{c:{d:{if((e|0)!=1){e:{if(!Ad(y[c|0])){break e}e=hp(d+4|0,a);x[31785]=0;b=P(30,e|0,b|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){if(x[b>>2]){break e}b=x[x[a>>2]-12>>2];x[31785]=0;O(24,a+b|0,1);b=x[31785];x[31785]=0;if((b|0)!=1){break e}}b=T(0)|0;em(c);break d}em(c);break c}b=T(0)|0}Y(b|0)|0;c=x[x[a>>2]-12>>2];x[31785]=0;W(25,a+c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}Z()}fb=d+16|0;break a}a=N()|0;x[31785]=0;X(26);d=x[31785];x[31785]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}return un(a)|0}function Jra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=fb-48|0;fb=c;d=a;a:{if(Cv(x[d>>2],x[d+8>>2])){x[g>>2]=0;break a}OY(c+16|0,c+32|0);kc(c+24|0,x[d>>2],x[d+8>>2],x[c+16>>2],x[c+20>>2]);h=x[c+28>>2];i=y[c+32|0];f=i&127;x[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(D(h,7)+a|0)+D(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=y[(c+32|0)+e|0];f=i&127|f<<7;x[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}Yb(d,h);OY(c+8|0,c+32|0);kc(c+24|0,x[d>>2],x[d+8>>2],x[c+8>>2],x[c+12>>2]);h=x[c+28>>2];f=x[g>>2];e=0;a=b;continue}break}Yb(d,e);if(a>>>0<33){break a}x[g>>2]=-1}fb=c+48|0}function gra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;x[d+28>>2]=0;Ik(a,d+28|0);a:{b:{i=x[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Fb(d+16|0);x[31785]=0;w[d+14>>1]=0;e=U(499,a|0,g|0,255)|0;h=x[31785];x[31785]=0;if((h|0)==1){break b}if(!e){break d}x[31785]=0;O(488,a|0,d+14|0);e=x[31785];x[31785]=0;if((e|0)==1){break b}x[31785]=0;S(500,d|0,c|0,g|0);e=x[31785];x[31785]=0;if((e|0)!=1){x[31785]=0;e=P(501,b|0,d+14|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break e}yb(e,d);tb(d);tb(g);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(g)}fb=d+32|0;return}f=N()|0}tb(g);Q(f|0);p()}function IH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;x[31785]=0;W(1005,a|0);e=x[31785];x[31785]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}x[31785]=0;W(1006,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break f}g=x[a+24>>2];x[31785]=0;e=P(37,f+8|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break e}x[31785]=0;S(d|0,f+20|0,g|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}a=f+20|0;b=xg(Jb(a));tb(a);tb(e);break b}b=T(0)|0;break c}b=T(0)|0;break c}b=T(0)|0;tb(e)}Y(b|0)|0;b=0;x[31785]=0;V(992,c|0,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z()}fb=f+32|0;return b}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function wma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+8>>2];h=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[h|0],w[e+38386>>1])+D(v[h-1|0],w[e+38384>>1])|0)+D(v[h+1|0],w[e+38388>>1])|0)+D(v[h+2|0],w[e+38390>>1])<<8)/16384|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function A9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-32|0;fb=d;h=Fb(a);f=Fb(d+20|0);a=1;a:{b:{c:{while(1){e=a&65535;c=x[b+24>>2];if(e>>>0>z[c+480192>>1]){if(!(i&1)){break c}x[31785]=0;O(250,h|0,f|0);a=x[31785];x[31785]=0;if((a|0)!=1){break c}a=N()|0;break a}c=IR(c,e);x[31785]=0;c=P(37,d+8|0,c|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break b}e=yd(x[d+12>>2],y[d+19|0]);x[31785]=0;g=P(845,f|0,c|0)|0;j=x[31785];x[31785]=0;d:{if((j|0)==1){break d}x[31785]=0;P(994,g|0,22460)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}i=e^1|i;tb(c);a=a+1|0;continue}break}a=N()|0;tb(c);break a}tb(f);fb=d+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function fra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-32|0;fb=d;w[d+30>>1]=0;kg(a,d+30|0);a:{b:{i=z[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Fb(d+16|0);x[31785]=0;w[d+14>>1]=0;e=P(502,a|0,g|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break b}if(!e){break d}x[31785]=0;O(488,a|0,d+14|0);e=x[31785];x[31785]=0;if((e|0)==1){break b}x[31785]=0;S(500,d|0,c|0,g|0);e=x[31785];x[31785]=0;if((e|0)!=1){x[31785]=0;e=P(501,b|0,d+14|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break e}yb(e,d);tb(d);tb(g);f=f+1|0;continue}break}f=N()|0;break a}f=N()|0;tb(d);break a}tb(g)}fb=d+32|0;return}f=N()|0}tb(g);Q(f|0);p()}function Aka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-80|0;fb=d;e=Kf(d+52|0);x[31785]=0;c=P(838,b|0,e|0)|0;f=x[31785];x[31785]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31785]=0;R(839,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[31785]=0;c=$b(c);c=c?c:-1;S(188,d+12|0,b|0,c|0);f=x[31785];x[31785]=0;if((f|0)==1){break a}f=d+12|0;g=ic(d+32|0,f);hd(e+8|0,g);ub(g);ub(f);d:{c=c&1;if(!c){break d}x[31785]=0;P(186,b|0,2-c|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break d}break a}Pk(a,e)}Fd(e);fb=d+80|0;return}a=N()|0;Fd(e);Q(a|0);p()}function u0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;jd(b,0);e=c+16|0;f=pf(e,1,v[a+1|0]);ye(b+43|0,f);tb(f);x[b>>2]=y[a+6|0]|y[a+7|0]<<8|(y[a+8|0]<<16|y[a+9|0]<<24);x[b+24>>2]=y[a+10|0]|y[a+11|0]<<8;v[c+16|0]=y[a+12|0];v[c+12|0]=64;g=b,h=y[Ub(e,c+12|0)|0]<<2,w[g+30>>1]=h;x[b+4>>2]=y[a+13|0]|y[a+14|0]<<8|(y[a+15|0]<<16|y[a+16|0]<<24);e=y[a+19|0];f=y[a+17|0]|y[a+18|0]<<8;v[c+14|0]=0;v[c+18|0]=e;w[c+16>>1]=f;w[c+12>>1]=0;while(1){if((d|0)!=3){e=y[xb(c+16|0,d)|0];g=xb(c+12|0,d),h=e,v[g|0]=h;d=d+1|0;continue}break}d=_f(c+12|0);x[b+8>>2]=d;if(!(!y[a|0]|d>>>0<=x[b+4>>2]+2>>>0|d>>>0>A[b>>2])){w[b+34>>1]=z[b+34>>1]|2}fb=c+32|0}function a7(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=uJ(b);il(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;hl(a,b);yb(i,a);tb(a);hi(a,b);yb(h,a);tb(a);m=d,n=qj(b),v[m|0]=n;m=e,n=rj(b),v[m|0]=n;ph(a,b);yb(f,a);tb(k+4|0);ii(a,b);yb(g,a);tb(k+4|0);a=Kk(b);break a}a=k+4|0;b=tJ(b);il(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;hl(a,b);yb(i,a);tb(a);hi(a,b);yb(h,a);tb(a);m=d,n=qj(b),v[m|0]=n;m=e,n=rj(b),v[m|0]=n;ph(a,b);yb(f,a);tb(k+4|0);ii(a,b);yb(g,a);tb(k+4|0);a=Kk(b)}x[l>>2]=a;fb=k+16|0}function z9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-32|0;fb=c;h=Fb(a);f=Fb(c+20|0);a=1;a:{b:{c:{while(1){d=a&65535;e=x[b+24>>2];if(d>>>0>z[e+480190>>1]){if(!(i&1)){break c}x[31785]=0;O(250,h|0,f|0);a=x[31785];x[31785]=0;if((a|0)!=1){break c}a=N()|0;break a}x[31785]=0;e=P(37,c+8|0,JR(e,d)|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break b}d=yd(x[c+12>>2],y[c+19|0]);x[31785]=0;g=P(845,f|0,e|0)|0;j=x[31785];x[31785]=0;d:{if((j|0)==1){break d}x[31785]=0;P(994,g|0,22460)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}i=d^1|i;tb(e);a=a+1|0;continue}break}a=N()|0;tb(e);break a}tb(f);fb=c+32|0;return}a=N()|0}tb(f);tb(h);Q(a|0);p()}function vka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);j=Bb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(eq(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=zb(g+12|0,wd(b));d=zb(g+8|0,Ne(wd(b),f));Jr(b,x[c>>2],x[d>>2]);break c}f=Wc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Jb(b);i=Bb(x[b+4>>2],y[b+11|0]);j=Jb(c);d=-1;h=Bb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!eq(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}Yc(a,b)}fb=g+16|0}function oC(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;h=x[a>>2];a:{if(Sc(h,x[a+4>>2])>>>0<=b>>>0){break a}b:{c:{switch(c|0){case 0:if((d|0)>=0){i=xb(h,b),j=d^128,v[i|0]=j}c=g+8|0;Kb(c,x[a+24>>2],b);Df(c,0);break b;case 2:i=xb(h,b),j=128,v[i|0]=j;c=g+8|0;Kb(c,x[a+24>>2],b);Df(c,1);break b;case 4:break c;default:break b}}i=xb(h,b),j=128,v[i|0]=j;c=g+8|0;Kb(c,x[a+24>>2],b);Df(c,0)}if(y[e|0]){break a}c=x[f+4>>2];if(mc(x[f>>2],c)){break a}c=YW(c);if(y[xb(x[c>>2],b)|0]==y[xb(x[a>>2],b)|0]){Kb(g+8|0,x[c+24>>2],b);c=Hb(x[x[g+8>>2]>>2],x[g+12>>2]);Kb(g,x[a+24>>2],b);if((Hb(x[x[g>>2]>>2],x[g+4>>2])|0)==(c|0)){break a}}v[e|0]=1}fb=g+16|0}function V6(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-16|0;fb=k;l=j;a:{if(a){a=k+4|0;b=qJ(b);il(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;hl(a,b);mh(i,a);Sb(a);hi(a,b);mh(h,a);Sb(a);m=d,n=qj(b),x[m>>2]=n;m=e,n=rj(b),x[m>>2]=n;ph(a,b);yb(f,a);tb(a);ii(a,b);mh(g,a);Sb(k+4|0);a=Kk(b);break a}a=k+4|0;b=pJ(b);il(a,b);j=x[k+4>>2];v[c|0]=j;v[c+1|0]=j>>>8;v[c+2|0]=j>>>16;v[c+3|0]=j>>>24;hl(a,b);mh(i,a);Sb(a);hi(a,b);mh(h,a);Sb(a);m=d,n=qj(b),x[m>>2]=n;m=e,n=rj(b),x[m>>2]=n;ph(a,b);yb(f,a);tb(a);ii(a,b);mh(g,a);Sb(k+4|0);a=Kk(b)}x[l>>2]=a;fb=k+16|0}function M1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=Jb(b);d=Bb(x[b+4>>2],y[b+11|0]);i=Jb(c);j=Bb(x[c+4>>2],y[c+11|0]);f=-1;a:{if(!d){break a}h=d+e|0;d=e;while(1){if((d|0)==(h|0)){break a}if(lu(i,j,y[d|0])){d=d+1|0;continue}break}f=d-e|0}b:{c:{if((f|0)!=-1){c=zb(g+12|0,wd(b));d=zb(g+8|0,Ne(wd(b),f));Jr(b,x[c>>2],x[d>>2]);break c}f=Wc(x[b+4>>2],y[b+11|0]);if(!f){break c}e=Jb(b);i=Bb(x[b+4>>2],y[b+11|0]);j=Jb(c);d=-1;h=Bb(x[c+4>>2],y[c+11|0]);if(h){c=e+i|0;d:{while(1){if((c|0)==(e|0)){break d}c=c-1|0;if(!lu(j,h,y[c|0])){continue}break}d=c-e|0}}if((f-1|0)!=(d|0)){break c}Fb(a);break b}Yc(a,b)}fb=g+16|0}function dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Kf(d+52|0);x[31785]=0;g=P(918,b|0,e|0)|0;f=x[31785];x[31785]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31785]=0;R(919,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break b}}break a}g=x[e+4>>2];x[31785]=0;S(188,d+12|0,b|0,g|0);f=x[31785];x[31785]=0;if((f|0)==1){break a}f=d+12|0;h=ic(d+32|0,f);hd(e+8|0,h);ub(h);ub(f);d:{if(!(g&1)|c>>>0<2){break d}x[31785]=0;P(186,b|0,1)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break d}break a}Pk(a,e)}Fd(e);fb=d+80|0;return}a=N()|0;Fd(e);Q(a|0);p()}function N2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(kh(a,x[b+8>>2],f)){Ix(b,c,d,e);return}g=y[b+53|0];j=x[a+12>>2];v[b+53|0]=0;h=y[b+52|0];v[b+52|0]=0;m=a+16|0;Ex(x[m>>2],x[a+20>>2],b,c,d,e,f);k=y[b+53|0];g=g|k;l=y[b+52|0];h=h|l;i=a+24|0;j=(j<<3)+m|0;a:{if(i>>>0>=j>>>0){break a}while(1){h=h&1;g=g&1;if(y[b+54|0]){break a}b:{if(l){if(x[b+24>>2]==1){break a}if(y[a+8|0]&2){break b}break a}if(!k){break b}if(!(v[a+8|0]&1)){break a}}w[b+52>>1]=0;Ex(x[i>>2],x[i+4>>2],b,c,d,e,f);k=y[b+53|0];g=k|g;l=y[b+52|0];h=l|h;i=i+8|0;if(j>>>0>i>>>0){continue}break}}v[b+53|0]=(g&255)!=0;v[b+52|0]=(h&255)!=0}function Cka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-80|0;fb=d;e=Kf(d+52|0);x[31785]=0;c=P(834,b|0,e|0)|0;f=x[31785];x[31785]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31785]=0;R(835,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break b}}break a}c=x[e+4>>2];x[31785]=0;c=$b(c);S(188,d+12|0,b|0,c|0);f=x[31785];x[31785]=0;if((f|0)==1){break a}f=d+12|0;g=ic(d+32|0,f);hd(e+8|0,g);ub(g);ub(f);d:{c=c&1;if(!c){break d}x[31785]=0;P(186,b|0,2-c|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break d}break a}Pk(a,e)}Fd(e);fb=d+80|0;return}a=N()|0;Fd(e);Q(a|0);p()}function DA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;c=x[a>>2];if(!mc(c,x[a+4>>2])){d=vb(c);x[e+12>>2]=d;c=vb(x[a+4>>2]);while(1){if(Ib(d,c)){vp(d,4194304,67108864);f=x[d>>2];g=f+g|0;b=g>>>0<f>>>0?b+1|0:b;d=x[Pe(e+12|0)>>2];continue}else{f=x[a>>2];c=oc(f,x[a+4>>2]);k=e,l=vb(f),x[k+8>>2]=l;d=c<<24;g=uua(g,b,c,0);c=g;h=((hb&1)<<31|c>>>1)&2147483647;i=vb(x[a+4>>2]);while(1){b=x[e+8>>2];if(Ib(b,i)){f=b;c=x[b>>2];b=c>>>8|0;c=h+(c<<24)|0;b=b+j|0;b=Bc(uua(c,c>>>0<h>>>0?b+1|0:b,g,j),hb);x[f>>2]=b;d=d-b|0;Pe(e+8|0);continue}else{b=x[a>>2];if(!oc(b,x[a+4>>2])){tw();p()}x[b>>2]=x[b>>2]+d}break}}break}}fb=e+16|0}
function aqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Gb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Gb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k<<1)+i|0;f=oi(E(Ld(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(32768)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=dd(g),w[m>>1]=n;a=a+1|0;continue}}}_(17559,9003,27,9530);p()}_(17509,9003,28,9530);p()}fb=c+16|0}function Qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb+-64|0;fb=f;d=f+16|0;h=fb-16|0;fb=h;i=aP(h+8|0);l=f+4|0;while(1){if((j|0)==12){fb=h+16|0}else{g=fb+-64|0;fb=g;c=x[i+4>>2];e=x[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=wM(xM(g+8|0,32));break a}e=G(c);e=xM(g+8|0,(c<<e&2147483647?32:31)-e|0);while(1){k=wM(e);if(c>>>0<=k>>>0){continue}break}c=x[i>>2]+k|0}fb=g- -64|0;m=wb(d,j),n=c,x[m>>2]=n;j=j+1|0;continue}break}d=jP(l,d,oP(d));fP(a,d);Tm(d);fb=f- -64|0;d=pz(a+120|0,a,b);v[d+20|0]=1;x[31785]=0;O(1147,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){a=N()|0;mo(d);Q(a|0);p()}return a|0}function q3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{c:{if(li(b,14426)){d=Bs(c+28|0,b);e=x[d>>2];if(!xd(e)){x[31785]=0;b=P(37,c+4|0,b|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}x[31785]=0;S(1020,c+16|0,17998,b|0);a=x[31785];x[31785]=0;d:{e:{if((a|0)!=1){x[31785]=0;W(1348,c+16|0);a=x[31785];x[31785]=0;if((a|0)==1){break e}p()}a=N()|0;break d}a=N()|0;tb(c+16|0)}tb(b);break a}Qp(e);if(!As(a+8|0,16978,x[d>>2])){v[a+8|0]=v[a+8|0]}if(!As(a+9|0,22485,x[d>>2])){v[a+9|0]=v[a+9|0]}x[31785]=0;O(275,a+12|0,22485);a=x[31785];x[31785]=0;if((a|0)==1){break b}gl(d)}fb=c+32|0;return}a=N()|0;break a}a=N()|0}gl(d);Q(a|0);p()}function GO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;f=Nb(a);a=b;b=z[x[b+24>>2]+480192>>1];x[31785]=0;O(179,f|0,b|0);c=x[31785];x[31785]=0;b=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=b&65535;c=x[a+24>>2];if(d>>>0>z[c+480192>>1]){break b}c=IR(c,d);x[31785]=0;c=P(37,e+8|0,c|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){d=x[a+24>>2];x[31785]=0;S(1062,e+20|0,d|0,c|0);d=x[31785];x[31785]=0;if((d|0)==1){break e}x[31785]=0;O(181,f|0,e+20|0);d=x[31785];x[31785]=0;if((d|0)==1){break d}tb(e+20|0);tb(c);b=b+1|0;continue}break}b=N()|0;break a}b=N()|0;break c}b=N()|0;tb(e+20|0)}tb(c);break a}fb=e+32|0;return}b=N()|0}Pd(f);Q(b|0);p()}function cG(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];d=gh(c,x[a+4>>2]);if(d>>>0<b>>>0){f=fb-32|0;fb=f;c=b-d|0;b=x[Ab(a)>>2];e=x[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=fb-16|0;fb=d;b=Tr(d+4|0,a,c);a=x[b+4>>2];c=x[b+8>>2];while(1){if((a|0)==(c|0)){hc(b);fb=d+16|0}else{bl(a);a=a+8|0;x[b+4>>2]=a;continue}break}break a}b=Ab(a);d=Vr(f+12|0,Wr(a,gh(x[a>>2],e)+c|0),gh(x[a>>2],x[a+4>>2]),b);e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=x[d+8>>2];g=x[d+8>>2];x[b+8>>2]=d+8;x[b+4>>2]=(c<<3)+g;c=x[b>>2];while(1){if(x[b+4>>2]!=(c|0)){bl(c);c=x[b>>2]+8|0;x[b>>2]=c;continue}break}ee(b);fb=e+16|0;Id(a,d);Ur(d)}fb=f+32|0;return}if(b>>>0<d>>>0){aG(a,c+(b<<3)|0)}}function kN(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Nf(a)|0)>(b|0)){break d}}a=ac(8);x[31785]=0;d=P(37,d+4|0,10745)|0;b=x[31785];x[31785]=0;if((b|0)==1){break c}nc(a,d);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}if(c<0|c>1){a=ac(8);x[31785]=0;d=P(37,d+4|0,11773)|0;b=x[31785];x[31785]=0;if((b|0)!=1){nc(a,d);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}b=N()|0;tb(d);break b}b=N()|0;jc(a);break b}e=(a+D(b,872)|0)+1075740|0,f=Xi(c*64),x[e>>2]=f;fb=d+16|0;return}b=N()|0;jc(a)}Q(b|0)}p()}function $pa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=E(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=fb-16|0;fb=c;a:{b:{d=x[b+8>>2];if((d|0)==x[a+8>>2]){e=x[b+4>>2];if((e|0)!=x[a+4>>2]){break b}x[c+12>>2]=d;x[c+8>>2]=d;d=x[Gb(c+12|0,c+8|0)>>2];x[c+12>>2]=e;x[c+8>>2]=e;h=x[Gb(c+12|0,c+8|0)>>2];i=x[a>>2];j=x[b>>2];b=0;c:while(1){if((b|0)==(d|0)){break a}k=D(b,e);a=0;while(1)if((a|0)==(h|0)){b=b+1|0;continue c}else{l=(a+k|0)+i|0;f=oi(E(Ld(B[x[(a<<2)+j>>2]+(b<<2)>>2],E(-1))*E(128)));d:{if(E(F(f))<E(2147483648)){g=~~f;break d}g=-2147483648}m=l,n=UX(g),v[m|0]=n;a=a+1|0;continue}}}_(17559,9003,27,9530);p()}_(17509,9003,28,9530);p()}fb=c+16|0}function uO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-32|0;fb=e;f=Nb(a);a=b;b=z[x[b+24>>2]+480190>>1];x[31785]=0;O(179,f|0,b|0);d=x[31785];x[31785]=0;b=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=b&65535;d=x[a+24>>2];if(c>>>0>z[d+480190>>1]){break b}x[31785]=0;d=P(37,e+8|0,JR(d,c)|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){c=x[a+24>>2];x[31785]=0;S(1062,e+20|0,c|0,d|0);c=x[31785];x[31785]=0;if((c|0)==1){break e}x[31785]=0;O(181,f|0,e+20|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}tb(e+20|0);tb(d);b=b+1|0;continue}break}b=N()|0;break a}b=N()|0;break c}b=N()|0;tb(e+20|0)}tb(d);break a}fb=e+32|0;return}b=N()|0}Pd(f);Q(b|0);p()}function Iw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=fb-16|0;fb=f;v[f+15|0]=d;v[b+12|0]=y[b+12|0]&240|y[a|0]&15;i=a+1|0;e=f+15|0;dh(b,y[Ub(i,e)|0]);g=y[Ub(a+2|0,e)|0];v[b+13|0]=g;k=b,l=Hd(y[a+3|0],g,d),v[k+14|0]=l;e=y[Ub(a+4|0,e)|0];v[b+15|0]=e;k=b,l=Hd(y[a+5|0],e,d),v[k+16|0]=l;g=x[b>>2];b=0;while(1){v[f+14|0]=25;if(b>>>0<y[Ub(f+14|0,i)|0]){e=D(b,3)+a|0;h=Xb(y[e+6|0]+c<<24>>24,0,64);d=wb(g,b);v[d+2|0]=h;e=y[e+7|0]|y[e+8|0]<<8;w[d>>1]=e;a:{if(!b){break a}h=wb(g,b-1|0);j=z[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;w[d>>1]=e;if(z[h>>1]<=(e&65535)>>>0){break a}w[d>>1]=e+256}b=b+1|0;continue}break}fb=f+16|0}function OF(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Ob(a,3878,4)){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(b>>>0<36){break a}c=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);if(c>>>0<36){break a}d=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);if(d>>>0<36){break a}e=y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24);if(D(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function Hfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;c=fb-16|0;fb=c;g=a;d=$d(a);a:{if(d){f=ec(g);while(1){a=d;d=a+16|0;if(Bu(b,d)){f=a;d=x[a>>2];if(d){continue}break a}if(!Bu(d,b)){break a}f=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(g);f=a}x[c+12>>2]=a;b=x[f>>2];if(!b){a=fb-16|0;fb=a;b=ec(g);b=zh(c,Dc(40),Kg(a+8|0,b));Fb(Yc(x[b>>2]+16|0,x[e+4>>2])+12|0);i=ec(b),j=1,v[i+4|0]=j;fb=a+16|0;Xg(g,x[c+12>>2],f,x[c>>2]);b=ie(c);a=x[c>>2];x[c>>2]=0;if(a){if(y[ec(c)+4|0]){Ym(a+16|0)}Db(a)}h=1}Wg(e+8|0,x[zb(c,b)>>2],h);fb=c+16|0;a=qd(x[e+8>>2]);fb=e+16|0;return a+12|0}function sY(a){var b=0,c=0,d=0,e=0,f=0;b=fb-32|0;fb=b;e=b,f=$b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788|0,x[e>>2]=f;x[b+4>>2]=0;e=b,f=$b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24)),x[e+8>>2]=f;x[b+12>>2]=0;c=$b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24));x[b+16>>2]=c?c:52;x[b+20>>2]=0;e=b,f=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+80|0,x[e+24>>2]=f;x[b+28>>2]=0;a=b;d=Re(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=Cw(x[a>>2],x[a+4>>2],x[c>>2],x[c+4>>2])?c:a;continue}}fb=b+32|0;c=x[a>>2];b=c-52|0;hb=x[a+4>>2]-(c>>>0<52)|0;return b}function lL(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-208|0;fb=f;x[f+204>>2]=c;c=f+160|0;Tb(c,0,40);x[f+200>>2]=x[f+204>>2];a:{if((kL(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=x[a+76>>2]>=0;g=x[a>>2];if(x[a+72>>2]<=0){x[a>>2]=g&-33}b:{c:{d:{if(!x[a+48>>2]){x[a+48>>2]=80;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;h=x[a+44>>2];x[a+44>>2]=f;break d}if(x[a+16>>2]){break c}}c=-1;if(a0(a)){break b}}c=kL(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){ib[x[a+36>>2]](a,0,0)|0;x[a+48>>2]=0;x[a+44>>2]=h;x[a+28>>2]=0;b=x[a+20>>2];x[a+16>>2]=0;x[a+20>>2]=0;c=b?c:-1}b=a;a=x[a>>2];x[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}fb=f+208|0;return e}function _oa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;a:{c=x[a+12>>2];b:{if((c|0)==(b|0)){break b}f=b>>>0>c>>>0;c=D(Nf(x[x[a+48>>2]+12>>2]),f?b-c|0:c-b|0);d=vb(x[a+4>>2]);c:{if(f){d=zb(e+28|0,d);w[e+24>>1]=0;x[e+20>>2]=0;d=x[d>>2];x[31785]=0;V(666,a|0,d|0,c|0,e+20|0);c=x[31785];x[31785]=0;if((c|0)!=1){break c}a=T(125240)|0;if((gb|0)!=($(125240)|0)){break a}Y(a|0)|0;Z();break b}c=zb(e+16|0,xD(d,c));d=x[zb(e+12|0,vb(x[a+4>>2]))>>2];f=fb-16|0;fb=f;g=x[c>>2];c=x[a>>2];c=D(eu(g,vb(c)),6)+c|0;if(Ib(g,d)){cD(a,bR(c+D(eu(d,g),6)|0,x[a+4>>2],c))}zb(f+12|0,c);fb=f+16|0}x[a+12>>2]=b}fb=e+32|0;return}Q(a|0);p()}function kQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=fb-16|0;fb=e;lh(e+8|0,b);f=fb-16|0;fb=f;kf(f+8|0,x[e+8>>2],x[e+12>>2]);g=x[f+8>>2];b=x[f+12>>2];h=fb-16|0;fb=h;k=h,l=vb(a),x[k+12>>2]=l;a=b;b=fb-16|0;fb=b;j=x[h+12>>2];c=j;d=x[c+8>>2];c=x[c+12>>2];i=c;a:{if((c|0)<0){break a}c=x[j+4>>2];if(!i&c>>>0<d>>>0|i){break a}x[b+8>>2]=c-d;x[b+12>>2]=0-(i+(d>>>0>c>>>0)|0);x[b>>2]=a;x[b+4>>2]=0;c=R$(b+8|0,b);if((Au(x[c>>2],x[c+4>>2])|0)!=(a|0)){break a}Qi(g,a+g|0,d+x[j>>2]|0);d=x[h+12>>2];g=d;c=x[d+8>>2];d=x[d+12>>2];i=a;a=a+c|0;d=i>>>0>a>>>0?d+1|0:d;x[g+8>>2]=a;x[g+12>>2]=d}fb=b+16|0;fb=h+16|0;fb=f+16|0;fb=e+16|0}function T4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a|0)!=(b|0)){e=fb-16|0;fb=e;d=x[b>>2];b=x[b+4>>2];f=Od(d,b);a:{if(f>>>0<=Rg(a)>>>0){h=b;i=x[a>>2];c=oc(i,x[a+4>>2]);j=c>>>0>=f>>>0;if(!j){x[e+12>>2]=d;OC(e+12|0,c);h=x[e+12>>2]}g=fb-16|0;fb=g;c=fb-32|0;fb=c;Sp(c+24|0,d,h);Fk(c+16|0,x[c+24>>2],x[c+28>>2],i);d=x[c+16>>2];x[c+12>>2]=x[c+20>>2];Td(g+8|0,d,c+12|0);fb=c+32|0;c=x[g+12>>2];fb=g+16|0;if(!j){so(a,h,b,f-oc(x[a>>2],x[a+4>>2])|0);break a}Yh(a,c);break a}if(x[a>>2]){Gf(a);Xx(Js(a),x[a>>2],Rg(a));k=Ab(a),l=0,x[k>>2]=l;x[a>>2]=0;x[a+4>>2]=0}dJ(a,Tf(a,f));so(a,d,b,f)}fb=e+16|0}return a|0}function kna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;a:{if(!(c&1024)){break a}i=g,j=wd(b),x[i+12>>2]=j;c=Wc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[cc(b,0)|0]!=43){if(y[cc(b,0)|0]!=45){break b}}d=d+1|0;UU(g+12|0)}if(c>>>0>=d>>>0){break a}e=x[zb(g+8|0,x[g+12>>2])>>2];c=d-Wc(x[b+4>>2],y[b+11|0])|0;c:{e=zk(e,wd(b));d=Bb(x[b+4>>2],y[b+11|0]);if(e>>>0<=d>>>0){if(c){f=Lc(b);d:{if(c>>>0<=f-d>>>0){f=Jb(b);if((d|0)==(e|0)){break d}h=e+f|0;Ri(c+h|0,h,d-e|0);break d}DB(b,f,(c+d|0)-f|0,d,e,c);f=x[b>>2]}$l(e+f|0,c,48);c=c+d|0;jg(b,c);ed(c+f|0,0)}break c}Pl();p()}wd(b)}Yc(a,b);fb=g+16|0}function kua(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-208|0;fb=d;T$(c,a);S$(c,d+16|0,D(y[a+4|0],3));a:{if(y[a+4|0]<2){break a}c=fb-16|0;fb=c;x[c+12>>2]=64;x[c+8>>2]=255;e=y[Gb(c+12|0,c+8|0)|0];fb=c+16|0;v[d+12|0]=e;dh(b,y[Ub(a+4|0,d+12|0)|0]);v[b+13|0]=y[a+2|0];v[b+14|0]=y[a+3|0];a=y[a+1|0];v[b+15|0]=a;v[b+16|0]=a;e=x[b>>2];f=Od(e,x[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=y[d+18|0];c=wb(e,0);break b}g=z[wb(e,a-1|0)>>1];x[d+12>>2]=1;b=(d+16|0)+D(a,3)|0;x[d+8>>2]=(v[b+1|0]&1)<<8|y[b|0];h=We(d+12|0,d+8|0);c=wb(e,a);w[c>>1]=z[h>>1]+g;b=y[b+2|0]}v[c+2|0]=b;a=a+1|0;continue}}fb=d+208|0}function QU(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}v[a+798|0]=0;return}v[a+798|0]=1;return}v[a+798|0]=2;return}v[a+798|0]=3;return}v[a+730|0]=y[a+730|0]&254;return}v[a+730|0]=y[a+730|0]|1;return}v[a+738|0]=y[a+738|0]&254;return}v[a+738|0]=y[a+738|0]|1;return}v[a+746|0]=y[a+746|0]&254;return}v[a+746|0]=y[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=y[a+746|0];v[c+746|0]=(b|0)==13?a&238|1:a|17}}function Joa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;jd(b,0);f=d+8|0;ui(f,1,a);c=d+20|0;Ec(c,f);ye(b+43|0,c);tb(c);x[b>>2]=y[a+48|0]|y[a+49|0]<<8|(y[a+50|0]<<16|y[a+51|0]<<24);x[b+4>>2]=y[a+52|0]|y[a+53|0]<<8|(y[a+54|0]<<16|y[a+55|0]<<24);x[b+8>>2]=y[a+56|0]|y[a+57|0]<<8|(y[a+58|0]<<16|y[a+59|0]<<24);x[b+24>>2]=y[a+62|0]|y[a+63|0]<<8;_l(b,+((y[a+60|0]^8)-120|0)/192);v[d+20|0]=y[a+61|0];v[d+8|0]=64;g=b,h=y[Ub(c,f)|0]<<2,w[g+30>>1]=h;w[b+34>>1]=0;c=y[a+47|0];if(c&4){w[b+34>>1]=1;x[b>>2]=x[b>>2]>>>1;e=1;c=y[a+47|0]}if(c&32){e=e|4;w[b+34>>1]=e;c=y[a+47|0]}if(c<<24>>24<0){w[b+34>>1]=e|2}fb=d+32|0}function nD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=fb-16|0;fb=e;d=(c<<3)+a|0;f=y[d+356|0];v[b+12|0]=y[b+12|0]&248|f&1|f<<1&4|f>>>1&2;dh(b,Hd(y[d+352|0],2,16));v[b+13|0]=y[d+354|0];v[b+14|0]=y[d+355|0];d=y[d+353|0];v[b+15|0]=d;v[b+16|0]=d;d=0;w[e+14>>1]=0;f=((c|0)!=0)<<1;h=x[b>>2];j=Od(h,x[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){mD(b,32);fb=e+16|0}else{a=k+(d<<2)|0;w[e+12>>1]=y[a+160|0]|y[a+161|0]<<8;g=se(e+14|0,e+12|0);i=wb(h,d);g=z[g>>1];w[i>>1]=g;w[e+14>>1]=g+1;v[e+11|0]=(c^y[a+162|0])>>>f;v[e+10|0]=64;l=i,m=y[Ub(e+11|0,e+10|0)|0],v[l+2|0]=m;d=d+1|0;continue}break}}function uS(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;a:{if(x[a+480180>>2]!=1){break a}c=y[b+846|0];if(!c){break a}e=x[b+104>>2];if(!e){break a}if(!ge(x[e>>2],x[e+20>>2])){break a}f=z[e+34>>1];if(!(f&10)){break a}c=y[b+847|0]+y[(c&15)+31904|0]|0;v[b+847|0]=c;if(c<<24>>24>=0){break a}v[b+847|0]=0;h=f&2;c=x[(h?4:12)+e>>2];g=b;b=x[b+760>>2]+1|0;b=b>>>0<x[(h?8:16)+e>>2]-c>>>0?b:0;x[g+760>>2]=b;g=x[e+20>>2];c=b+c|0;b=$k(f);bc(d+8|0,g+D(c,b)|0,b);i=d,j=vb(x[d+8>>2]),x[i+4>>2]=j;f=Tk(x[d+8>>2],x[d+12>>2]);while(1){b=x[d+4>>2];if(Ib(b,f)){v[b|0]=y[b|0]^-1;je(d+4|0);continue}else{Mj(e,a)}break}}fb=d+16|0}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=fb-16|0;fb=h;f=c;e=fb-16|0;fb=e;g=b;d=$d(b);a:{if(d){c=ec(g);while(1){b=d;d=b+16|0;if(pR(f,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!pR(d,f)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=ec(g);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=ec(g);d=zh(e,Dc(28),Kg(b+8|0,d));i=x[d>>2];x[31785]=0;O(896,i+16|0,f|0);f=x[31785];x[31785]=0;b:{if((f|0)!=1){j=ec(d),k=1,v[j+4|0]=k;fb=b+16|0;break b}a=N()|0;oR(d);Q(a|0);p()}Xg(g,x[e+12>>2],c,x[e>>2]);b=ie(e);oR(e);i=1}c=h+8|0;Wg(c,x[zb(e,b)>>2],i);fb=e+16|0;OU(a,c);fb=h+16|0}function ita(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-32|0;fb=f;e=b;b=x[a>>2];b=zk(e,vb(b))+b|0;e=KD(c,d);a:{if((e|0)<=0){break a}g=x[Ab(a)>>2];h=x[a+4>>2];if((e|0)<=(g-h|0)){x[f+8>>2]=d;g=h-b|0;if((g|0)<(e|0)){x[f+8>>2]=c;y_(f+8|0,g);JD(a,x[f+8>>2],d,e-g|0);if((g|0)<=0){break a}}x_(a,b,h,b+e|0);Qv(c,x[f+8>>2],b);break a}g=Ab(a);h=gn(f+8|0,Ul(a,Sc(x[a>>2],h)+e|0),b-x[a>>2]|0,g);e=fb-16|0;fb=e;x[e+12>>2]=c;c=gC(e,h+8|0,KD(c,d));d=x[c>>2];while(1){if(x[c+4>>2]!=(d|0)){ul(d,y[x[e+12>>2]]);d=x[c>>2]+1|0;x[c>>2]=d;je(e+12|0);continue}break}ee(c);fb=e+16|0;b=ir(a,h,b);en(h)}zb(f+28|0,b);fb=f+32|0}function fR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=fb-16|0;fb=h;v[h+15|0]=b;v[h+14|0]=10;dh(g,y[Ub(h+15|0,h+14|0)|0]);v[g+15|0]=c;v[g+16|0]=c;v[g+14|0]=e;v[g+13|0]=d;j=x[g>>2];k=Od(j,x[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=y[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=wb(j,b);l=D(b,3)+f|0;i=(y[l|0]|y[l+1|0]<<8)>>>4|0;w[m>>1]=i;c:{if(b){n=z[wb(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=wb(j,b),p=i,w[o>>1]=p}o=m,p=Hd(y[l+2|0],0,64),v[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}v[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;fb=h+16|0}function Zja(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){ku(a+484344|0);rf(a+1298308|0);rf(a+1298320|0);rf(a+1298332|0);Wv(a+1298412|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){b=a+906300|0;c=Dj(b);while(1){if((b|0)==(c|0)){break a}D$(b);b=b+160|0;continue}}d=x[b>>2];if(d){Db(xv(d))}x[b>>2]=0;b=b+4|0;continue}}}else{hn(c);c=c+104|0;continue}break}x[a+480180>>2]=0;x[a+480184>>2]=0;a=a+480186|0;w[a>>1]=0;w[a+2>>1]=0;w[a+4>>1]=0;w[a+6>>1]=0}else{x[b+104>>2]=0;x[b+656>>2]=0;x[b+76>>2]=0;x[b+16>>2]=0;b=b+872|0;continue}break}}function gt(a,b,c,d){var e=0,f=0,g=0,h=0;g=d?d:500324;d=x[g>>2];a:{b:{c:{if(!b){if(d){break c}return 0}e=-2;if(!c){break b}d:{if(d){e=c;break d}d=y[b|0];f=d<<24>>24;if((f|0)>=0){if(a){x[a>>2]=d}return(f|0)!=0}if(!x[x[124291]>>2]){e=1;if(!a){break b}x[a>>2]=f&57343;return 1}d=d-194|0;if(d>>>0>50){break c}d=x[(d<<2)+111760>>2];e=c-1|0;if(!e){break a}b=b+1|0}f=y[b|0];h=f>>>3|0;if((h-16|(d>>26)+h)>>>0>7){break c}while(1){e=e-1|0;d=f-128|d<<6;if((d|0)>=0){x[g>>2]=0;if(a){x[a>>2]=d}return c-e|0}if(!e){break a}b=b+1|0;f=y[b|0];if((f&192)==128){continue}break}}x[g>>2]=0;x[31660]=25;e=-1}return e}x[g>>2]=d;return-2}function bsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-80|0;fb=d;e=Kf(d+52|0);x[31785]=0;c=P(414,b|0,e|0)|0;f=x[31785];x[31785]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31785]=0;R(415,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break a}}break c}c=fb-16|0;fb=c;g=c,h=$b(x[e+4>>2]),x[g+12>>2]=h;x[c+8>>2]=8;f=x[_c(c+12|0,c+8|0)>>2];fb=c+16|0;x[31785]=0;S(188,d+12|0,b|0,f-8|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}a=N()|0;Fd(e);Q(a|0);p()}b=d+12|0;c=ic(d+32|0,b);hd(e+8|0,c);ub(c);ub(b);Pk(a,e)}Fd(e);fb=d+80|0}function Ei(a,b,c,d){var e=0,f=0,g=0;e=fb-48|0;fb=e;f=x[x[a>>2]-12>>2]+a|0;g=x[f+16>>2]&-3;eg(f,g);a:{b:{if(Ad(y[Cm(e+47|0,a,1)|0])){f=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31785]=0;xs(89,e+24|0,f,b,c,d);b=x[31785];x[31785]=0;c:{if((b|0)!=1){b=ei(e+8|0,-1,-1);d=Un(x[e+32>>2],x[e+36>>2],x[b+8>>2],x[b+12>>2])?g|4:g;break c}Y(T(0)|0)|0;d=g|1;Am(x[x[a>>2]-12>>2]+a|0,d);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31785]=0;X(87);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}$j(x[x[a>>2]-12>>2]+a|0,d)}fb=e+48|0;return a}T(0)|0;Rb()}p()}function xqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;f=z[b>>1];d=fb-16|0;fb=d;g=a;c=$d(a);a:{if(c){b=ec(g);while(1){a=c;c=z[a+14>>1];if(To(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!To(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=ec(g);f=zh(d,Dc(20),Kg(a+8|0,c));c=x[f>>2];h=z[x[e+4>>2]>>1];w[c+16>>1]=0;w[c+14>>1]=h;i=ec(f),j=1,v[i+4|0]=j;fb=a+16|0;Xg(g,x[d+12>>2],b,x[d>>2]);a=ie(d);Xl(d);h=1}Wg(e+8|0,x[zb(d,a)>>2],h);fb=d+16|0;a=Xo(x[e+8>>2]);fb=e+16|0;return a+2|0}function Tfa(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=fb-80|0;fb=d;x[d+76>>2]=c;c=x[a>>2];e=x[a+4>>2];f=x[a+12>>2];x[d+48>>2]=x[a+8>>2];x[d+52>>2]=f;x[d+40>>2]=c;x[d+44>>2]=e;a=Jd(d+32|0);c=x[d+52>>2];x[d+16>>2]=x[d+48>>2];x[d+20>>2]=c;x[31785]=0;c=x[d+44>>2];x[d+8>>2]=x[d+40>>2];x[d+12>>2]=c;c=x[a+4>>2];x[d>>2]=x[a>>2];x[d+4>>2]=c;S(989,d+56|0,d+8|0,d|0);a=x[31785];x[31785]=0;a:{b:{if((a|0)!=1){a=x[oe(d+28|0,d+76|0)>>2];x[31785]=0;b=+pa(990,d+56|0,+b,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}ub(d+56|0);Uc(d+76|0);fb=d+80|0;return+b}a=N()|0;break a}a=N()|0;ub(d+56|0)}Uc(d+76|0);Q(a|0);p()}function KZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;f=x[b>>2];d=fb-16|0;fb=d;g=a;c=$d(a);a:{if(c){b=ec(g);while(1){a=c;c=x[a+16>>2];if(_D(f,c)){b=a;c=x[a>>2];if(c){continue}break a}if(!_D(c,f)){break a}b=a+4|0;c=x[a+4>>2];if(c){continue}break}break a}a=ec(g);b=a}x[d+12>>2]=a;a=x[b>>2];if(!a){a=fb-16|0;fb=a;c=ec(g);f=zh(d,Dc(24),Kg(a+8|0,c));c=x[f>>2];h=x[x[e+4>>2]>>2];x[c+20>>2]=0;x[c+16>>2]=h;i=ec(f),j=1,v[i+4|0]=j;fb=a+16|0;Xg(g,x[d+12>>2],b,x[d>>2]);a=ie(d);Xl(d);h=1}Wg(e+8|0,x[zb(d,a)>>2],h);fb=d+16|0;a=qd(x[e+8>>2]);fb=e+16|0;return a+4|0}function yt(a,b,c){var d=0,e=0;d=a,e=xj(E(E(B[c+1792>>2]*E(75038))+E(E(E(B[c+2048>>2]-B[c+1536>>2])*E(37489))+E(E(E(B[c+1280>>2]+B[c+2304>>2])*E(6574))+E(E(E(B[c+2560>>2]-B[c+1024>>2])*E(5153))+E(E(E(B[c+768>>2]+B[c+2816>>2])*E(2037))+E(E(E(B[c+3072>>2]-B[c+512>>2])*E(459))+E(E(E(B[c+256>>2]+B[c+3328>>2])*E(213))+E(E(B[c+3584>>2]-B[c>>2])*E(29)))))))))),w[d>>1]=e;d=(b<<5)+a|0,e=xj(E(E(B[c+8>>2]*E(-5))+E(E(B[c+520>>2]*E(146))+E(E(B[c+1032>>2]*E(-45))+E(E(B[c+1544>>2]*E(-9975))+E(E(B[c+2056>>2]*E(64019))+E(E(B[c+2568>>2]*E(9727))+E(E(B[c+3080>>2]*E(1567))+E(B[c+3592>>2]*E(104)))))))))),w[d>>1]=e}function A7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}$c(f+16|0,x[c+28>>2]);x[31785]=0;a=R(1221,x[f+16>>2])|0;b=x[31785];x[31785]=0;b:{if((b|0)!=1){Zb(f+16|0);c:{if(e){ii(f+16|0,a);break c}hi(f+16|0,a)}g=f,h=wd(f+16|0),x[g+12>>2]=h;while(1){a=kl(f+16|0);b=x[f+12>>2];if(!Ib(b,a)){c=x[f+28>>2];Sb(f+16|0);break a}a=x[b>>2];x[31785]=0;P(1235,f+28|0,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){Pe(f+12|0);continue}break}c=N()|0;Sb(f+16|0);break b}c=N()|0;Zb(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function UW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;Gc(a+8|0,0);d=x[b+4>>2];if(d){Ir(a,d);fn(c+8|0,x[b>>2]);Mq(c,x[b>>2],x[b+4>>2]);b=fb-32|0;fb=b;d=x[c+8>>2];j=x[c>>2];e=x[a+4>>2];g=x[c+12>>2];k=x[c+4>>2];f=e+SW(d,g,j,k)|0;x[a+4>>2]=f;a:{b:{if(!e){h=f-1|0;break b}h=f-1|0;if((h^e-1)>>>0>31){break b}x[b+24>>2]=d;x[b+28>>2]=g;i=x[a>>2];break a}i=x[a>>2];x[i+((f>>>0>=33?h>>>5|0:0)<<2)>>2]=0;x[b+24>>2]=d;x[b+28>>2]=g}op(b+16|0,i,e);d=x[b+28>>2];x[b>>2]=x[b+24>>2];x[b+4>>2]=d;TW(b+8|0,b,j,k,x[b+16>>2],x[b+20>>2]);fb=b+32|0}fb=c+16|0;return a|0}function K7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+28>>2]=b;a:{if(!(v[c+4|0]&1)){c=ib[x[x[a>>2]+24>>2]](a,b,c,d,e)|0;break a}$c(f+16|0,x[c+28>>2]);x[31785]=0;a=R(1204,x[f+16>>2])|0;b=x[31785];x[31785]=0;b:{if((b|0)!=1){Zb(f+16|0);c:{if(e){ii(f+16|0,a);break c}hi(f+16|0,a)}g=f,h=wd(f+16|0),x[g+12>>2]=h;while(1){a=yf(f+16|0);b=x[f+12>>2];if(!Ib(b,a)){c=x[f+28>>2];tb(f+16|0);break a}a=v[b|0];x[31785]=0;P(30,f+28|0,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){je(f+12|0);continue}break}c=N()|0;tb(f+16|0);break b}c=N()|0;Zb(f+16|0)}Q(c|0);p()}fb=f+32|0;return c|0}function D2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;k=fb-32|0;fb=k;n=x[c>>2];l=x[c+8>>2];m=x[c+4>>2];c=k;x[c+8>>2]=m;x[c+12>>2]=l;x[c+24>>2]=m;x[c+28>>2]=l;x[c+20>>2]=n;x[c+16>>2]=d;x[31785]=0;d=x[c+20>>2];x[c>>2]=x[c+16>>2];x[c+4>>2]=d;a=Ia(1103,a|0,b|0,c|0)|0;b=x[31785];x[31785]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31785]=0;ga(988,10425,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}Z();a=-255}fb=k+32|0;break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}return a|0}function Nma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>18|0;n=((((x[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+k|0;e=0;while(1){if((e|0)!=2){g=(e<<1)+n|0;h=w[g>>1];x[(e<<2)+b>>2]=h+((D(w[g+4>>1]-h|0,m)|0)/16384|0);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Qb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function _G(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;e=g+4|0;v[e+8|0]=1;x[e+4>>2]=c;x[e>>2]=a;h=y[e+8|0];a=x[e>>2];i=x[e+4>>2];j=Jb(b);b=Bb(x[b+4>>2],y[b+11|0]);d=fb-16|0;fb=d;x[d+8>>2]=b;x[d+12>>2]=i;b=a;e=x[Gb(d+12|0,d+8|0)>>2];f=e;while(1){a:{if(!f){f=0;break a}c=y[j|0];v[b|0]=c;if(!c){break a}j=j+1|0;b=b+1|0;f=f-1|0;continue}break}b:{if((h-1&255)>>>0<=1){v[d+7|0]=0;Mm(b,((b+i|0)-e|0)+f|0,d+7|0);break b}if((h-3&255)>>>0>1){break b}v[d+6|0]=32;Mm(b,((b+i|0)-e|0)+f|0,d+6|0)}c:{switch(h-1|0){case 0:case 3:v[(x[d+12>>2]+a|0)-1|0]=0;break;default:break c}}fb=d+16|0;fb=g+16|0}function jy(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;$c(f+12|0,b);x[31785]=0;b=R(1220,x[f+12>>2])|0;g=x[31785];x[31785]=0;a:{if((g|0)==1){break a}x[31785]=0;V(1231,b|0,111968,112e3,c|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}x[31785]=0;b=R(1221,x[f+12>>2])|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;c=R(1232,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break a}x[d>>2]=c;x[31785]=0;c=R(1229,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}x[e>>2]=c;x[31785]=0;O(1230,a|0,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Zb(f+12|0);fb=f+16|0;return}a=N()|0;Zb(f+12|0);Q(a|0);p()}function Xg(a,b,c,d){var e=0,f=0;x[d+8>>2]=b;x[d>>2]=0;x[d+4>>2]=0;x[c>>2]=d;b=x[x[a>>2]>>2];if(b){x[a>>2]=b;d=x[c>>2]}f=x[ec(a)>>2];v[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=x[d+8>>2];if(y[c+12|0]){break a}b:{if(Qh(c)){b=x[c+8>>2];e=x[b+4>>2];if(!(!e|y[e+12|0])){break b}if(!Qh(d)){$q(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;_q(b);break a}b=x[c+8>>2];e=x[b>>2];if(!(!e|y[e+12|0])){break b}if(Qh(d)){_q(c);c=x[c+8>>2]}v[c+12|0]=1;b=x[c+8>>2];v[b+12|0]=0;$q(b);break a}v[c+12|0]=1;d=b;v[d+12|0]=(d|0)==(f|0);v[e+12|0]=1;continue}break}a=Ab(a);x[a>>2]=x[a>>2]+1}function Uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb+-64|0;fb=c;f=bU(a,1<<b-1);x[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=x[10133];d=c+32|0;x[d+8>>2]=x[10132];x[d+12>>2]=e;e=x[10131];x[d>>2]=x[10130];x[d+4>>2]=e;BB(d,h*+(b>>>0));YT(c+48|0,C[c+32>>3],C[c+40>>3]);d=Ud(x[f>>2],a);e=x[c+60>>2];x[d+8>>2]=x[c+56>>2];x[d+12>>2]=e;e=x[c+52>>2];x[d>>2]=x[c+48>>2];x[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=Ml(c+16|0,1,0);b=x[a+12>>2];x[c+8>>2]=x[a+8>>2];x[c+12>>2]=b;b=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=b;nA(f,0,g,c);fb=c- -64|0;return f|0}function _m(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function dh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=fb-16|0;fb=c;b=th(c+4|0,a,b);a=x[b+4>>2];d=x[b+8>>2];while(1){if((a|0)==(d|0)){hc(b);fb=c+16|0}else{Hw(a);a=a+4|0;x[b+4>>2]=a;continue}break}break a}c=Ab(a);c=hg(e+12|0,Tf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=An(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Hw(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}ee(b);fb=f+16|0;Id(a,c);gg(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Yh(a,d+(b<<2)|0)}}function r3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{b:{if(li(b,14426)){d=Bs(c+28|0,b);e=x[d>>2];if(!xd(e)){x[31785]=0;b=P(37,c+4|0,b|0)|0;a=x[31785];x[31785]=0;c:{d:{e:{if((a|0)!=1){x[31785]=0;S(1020,c+16|0,17931,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break e}x[31785]=0;W(1348,c+16|0);a=x[31785];x[31785]=0;if((a|0)==1){break d}p()}a=N()|0;break a}a=N()|0;break c}a=N()|0;tb(c+16|0)}tb(b);break a}Qp(e);Np(a+8|0,16978,x[d>>2]);Np(a+12|0,22485,x[d>>2]);x[31785]=0;O(275,a+16|0,22485);a=x[31785];x[31785]=0;if((a|0)==1){break b}gl(d)}fb=c+32|0;return}a=N()|0}gl(d);Q(a|0);p()}function oy(a,b,c,d,e){var f=0,g=0;f=fb-16|0;fb=f;$c(f+12|0,b);x[31785]=0;b=R(28,x[f+12>>2])|0;g=x[31785];x[31785]=0;a:{if((g|0)==1){break a}x[31785]=0;V(1218,b|0,111968,112e3,c|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}x[31785]=0;b=R(1204,x[f+12>>2])|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;c=R(1219,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break a}v[d|0]=c;x[31785]=0;c=R(1216,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}v[e|0]=c;x[31785]=0;O(1217,a|0,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Zb(f+12|0);fb=f+16|0;return}a=N()|0;Zb(f+12|0);Q(a|0);p()}function FL(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(df(a)){fc(a,31);return 0}g=a,h=df(a),v[g+1375|0]=h;d=wj(a);b=wj(a);wj(a);g=a,h=wj(a),x[g+1112>>2]=h;wj(a);c=df(a);x[a+1116>>2]=c;if(!Zy(a,a+1120|0,c)){fc(a,10);return 0}x[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=x[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(y[(b+a|0)+1120|0]==255){continue}break}x[a+1408>>2]=d;x[a+1404>>2]=b}if(y[a+1377|0]){b=0;e=x[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=y[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}x[a- -64>>2]=d;x[a+60>>2]=(x[a+56>>2]+(c+e|0)|0)+27}x[a+1380>>2]=0;return 1}function dl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;f=a+36|0;c=x[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=x[a+20>>2];if(d>>>0>=A[a+24>>2]){lo(e,f,hG(f));md(e+8|0,a,x[e>>2],x[e+4>>2]);c=x[e+12>>2];x[a+24>>2]=c;x[a+20>>2]=0;if(!c){break c}d=0;c=x[a+32>>2]}x[a+20>>2]=d+1;g=y[(a+d|0)+36|0];d=c+8|0;x[a+32>>2]=d;x[a+28>>2]=x[a+28>>2]|g<<c;c=d;continue}break}a=ac(8);x[31785]=0;b=R(164,a|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}x[a+32>>2]=c-b;d=a;a=x[a+28>>2];x[d+28>>2]=a>>>b;fb=e+16|0;return a&(-1<<b^-1)}da(b|0,29088,165);p()}function Afa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;x[31785]=0;W(1005,a|0);d=x[31785];x[31785]=0;a:{b:{c:{if((d|0)==1){break c}x[31785]=0;W(1006,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break c}d=x[a+24>>2];b=pc(c+12|0,b);x[31785]=0;e=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=e;V(1018,c+20|0,d|0,c|0,1);b=x[31785];x[31785]=0;if((b|0)==1){break c}a=c+20|0;b=xg(Jb(a));tb(a);break b}Y(T(0)|0)|0;b=0;x[31785]=0;V(992,5555,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z()}fb=c+32|0;return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Oma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;i=x[a+24>>2];j=x[a+20>>2];k=x[a+16>>2];f=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=f;f=x[a+8>>2];l=x[a+12>>2];while(1){if(d){e=x[b+8>>2];m=e>>>10&4194048;n=(((x[b+12>>2]&2147483647)<<1|e>>>31)&-2)+k|0;e=0;while(1){if((e|0)!=2){g=e+n|0;h=v[g|0];x[(e<<2)+b>>2]=((D(v[g+2|0]-h|0,m)|0)/16384|0)+(h<<8);e=e+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],j);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],i);Qb(b+8|0,f,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Cm(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;v[a|0]=0;a:{d=x[x[b>>2]-12>>2]+b|0;b:{if(!x[d+16>>2]){d=x[d+72>>2];if(d){un(d)}c:{if(c){break c}c=x[x[b>>2]-12>>2]+b|0;if(!(y[c+5|0]&16)){break c}$c(e+12|0,x[c+28>>2]);x[31785]=0;f=R(28,x[e+12>>2])|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}Zb(e+12|0);c=hp(e+8|0,b);d=rc(e+4|0);while(1){d:{if(qh(c,d)){break d}g=rl(x[c>>2]);if(!Ef(x[f+8>>2],1,g)){break d}Bm(c);continue}break}if(!qh(c,d)){break c}$j(x[x[b>>2]-12>>2]+b|0,6)}v[a|0]=!x[(x[x[b>>2]-12>>2]+b|0)+16>>2];break b}$j(d,4)}fb=e+16|0;return a}a=N()|0;Zb(e+12|0);Q(a|0);p()}function uta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{b:{if(b){x[31785]=0;O(324,a|0,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break b}e=fb-16|0;fb=e;d=nr(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){hc(d);fb=e+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+4|0]=6;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=8;v[b+3|0]=4;b=b+6|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Md(b);am(b);fb=c+16|0;break a}a=N()|0;am(c+8|0);Q(a|0);p()}v[a+16|0]=6;x[a+12>>2]=2015363072;return a|0}function m4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=fb+-64|0;fb=g;Tn(g+16|0,c);x[31785]=0;c=g+28|0;O(94,c|0,d|0);d=x[31785];x[31785]=0;b:{c:{d:{if((d|0)==1){break d}x[31785]=0;c=g+40|0;O(94,c|0,e|0);d=x[31785];x[31785]=0;if((d|0)==1){break d}x[31785]=0;c=g+52|0;O(94,c|0,f|0);d=x[31785];x[31785]=0;if((d|0)==1){break d}Tx(g+8|0,g+16|0);x[31785]=0;V(95,a|0,b|0,x[g+8>>2],x[g+12>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}mI(g+16|0);fb=g- -64|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=N()|0;mI(g+16|0)}Q(a|0);p()}}function Yd(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a=ei(a,-1,-1);a:{b:{if(Ad(y[Cm(c+31|0,b,1)|0])){d=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31785]=0;xs(89,c+8|0,d,0,0,1);d=x[31785];x[31785]=0;c:{if((d|0)!=1){d=x[c+12>>2];x[a>>2]=x[c+8>>2];x[a+4>>2]=d;d=x[c+20>>2];x[a+8>>2]=x[c+16>>2];x[a+12>>2]=d;break c}Y(T(0)|0)|0;e=1;Am(x[x[b>>2]-12>>2]+b|0,1);if(x[(x[x[b>>2]-12>>2]+b|0)+20>>2]&1){x[31785]=0;X(87);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}$j(x[x[b>>2]-12>>2]+b|0,e)}fb=c+32|0;return}T(0)|0;Rb()}p()}function X_(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=y[e|0];if(!i){break a}j=2240>>>d&d>>>0<12;g=D(c,-6);k=(d-2&255)>>>0>2;while(1){if(!b){break a}c=a;a=c+g|0;f=y[a+3|0];b:{c:{if(!((f-2&255)>>>0>2|k)){f=1;if(y[(c+g|0)+5|0]<224){break c}break a}f=!(1<<f&2240)|(!j|f>>>0>11)?(d|0)==(f|0):1;if(k){break b}}h=c+g|0;if((y[h+2|0]-11&255)>>>0>2){break b}if(y[h+4|0]){break a}}d:{if(!j){break d}h=c+g|0;if((y[h+2|0]-3&255)>>>0>3){break d}if(y[h+4|0]){break a}}b=b-1|0;if(!f){continue}c=y[(c+g|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}v[e|0]=0}}function MM(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a>>2];x[a>>2]=b;if(c){x[31785]=0;W(860,c|0);a=x[31785];x[31785]=0;a:{if((a|0)!=1){d=x[c+4>>2];if(d){e=fb-16|0;fb=e;f=zb(e+12|0,d);a=x[f>>2];if(x[a>>2]){g=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(g|0)){b=b-4|0;Ig(b);continue}break}x[a+4>>2]=g;a=x[f>>2];b=x[a>>2];Rg(a);Db(b)}fb=e+16|0;Db(d)}x[c+4>>2]=0;fS(c+1298412|0);LA(c+1298344|0);tb(c+1298332|0);tb(c+1298320|0);tb(c+1298308|0);KA(c+1298304|0);JA(c+1298300|0);xu(c+1298264|0);ZA(c+1074376|0);eS(c+906300|0);OB(c+484360|0);YR(c+484344|0);sc(c+480248|0);break a}T(0)|0;Rb();p()}Db(c)}}function Lsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;c=65535;e=x[a>>2];a:{if(Xc(e,x[a+4>>2])>>>0<=b>>>0){break a}e=z[_b(e,b)>>1];b:{if(!$i(a,b)){break b}c=x[a+24>>2];d=vb(x[c+484360>>2]);x[g+12>>2]=d;h=vb(x[c+484364>>2]);while(1){if(!Ib(d,h)){break b}f=0;i=dm(x[d>>2],x[d+4>>2]);while(1){if((f|0)!=(i|0)){c:{if(!((a|0)!=(d|0)|(b|0)!=(f|0))|(e|0)!=z[_b(x[d>>2],f)>>1]){break c}c=tX(x[a+24>>2]+484344|0,e);if((c|0)==65535){break c}j=_b(x[a>>2],b),k=c,w[j>>1]=k;break a}f=f+1|0;continue}break}d=x[av(g+12|0)>>2];continue}}c=e}fb=g+16|0;return c&65535}function A2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=fb-16|0;fb=c;x[31785]=0;W(1005,a|0);e=x[31785];x[31785]=0;a:{b:{c:{d:{if((e|0)==1){break d}x[31785]=0;W(1006,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break d}e=x[a+24>>2];b=pc(c+8|0,b);x[31785]=0;g=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=g;xs(1026,e,c,f,d,1);d=x[31785];x[31785]=0;b=1;if((d|0)!=1){break c}}Y(T(0)|0)|0;x[31785]=0;V(992,8662,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break b}Z();b=0}fb=c+16|0;break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}return b|0}function MF(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=D(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),5)+(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24));x[b+8>>2]=(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))+((y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24))<<3);x[b+12>>2]=(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))+((y[a+28|0]|y[a+29|0]<<8|(y[a+30|0]<<16|y[a+31|0]<<24))<<2);a=b+4|0;d=wb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Qq(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;return x[a>>2]-36|0}function ov(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;yE(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;v[b+31|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function tL(a,b){var c=0,d=0,e=0,f=0,g=0;if(!y[497056]){f=497057,g=Qa()|0,v[f|0]=g;v[497056]=1}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!y[497057]){break c}d=+Ga();break a}x[31660]=28;return-1}d=+Xa()}c=d/1e3;e:{if(F(c)<0x8000000000000000){e=~~c>>>0;a=F(c)>=1?~~(c>0?H(J(c*2.3283064365386963e-10),4294967295):K((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break e}a=-2147483648}x[b>>2]=e;x[b+4>>2]=a;c=(d-(+(sua(e,a,1e3,0)>>>0)+ +(hb|0)*4294967296))*1e3*1e3;f:{if(F(c)<2147483648){a=~~c;break f}a=-2147483648}x[b+8>>2]=a;return 0}function bna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=ig(1,2);e=hb;j=e;Qb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=((((x[b+12>>2]&2147483647)<<1|g>>>31)&2147483646)<<1)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=w[(f<<1)+g>>1];f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Qb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Dg(a,h,j);fb=b+16|0}function Mma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;h=v[e|0];e=((D(v[e+1|0]-h|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(h<<8)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function ms(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=fb-16|0;fb=h;g=zb(h+12|0,x[a+4>>2]);e=zb(h+8|0,x[a>>2]);j=zb(h+4|0,x[b+4>>2]);k=fb-16|0;fb=k;f=fb-16|0;fb=f;l=fb-16|0;fb=l;m=fb-16|0;fb=m;i=x[g>>2];g=x[e>>2];e=i-g|0;i=D((e|0)/(d|0)|0,c);d=x[j>>2];j=i+d|0;i=ai(j,g,e);e=D((e|0)/(c|0)|0,c);x[m+12>>2]=i+e;Td(l+8|0,e+g|0,m+12|0);fb=m+16|0;Td(f+8|0,g,zb(l+4|0,d+D((j-d|0)/(c|0)|0,c)|0));fb=l+16|0;c=x[f+8>>2];x[f+4>>2]=x[f+12>>2];Td(k+8|0,c,f+4|0);fb=f+16|0;fb=k+16|0;x[b+4>>2]=x[k+12>>2];wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),Ac(b));x[b>>2]=x[b+4>>2];fb=h+16|0}function V5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=x[a>>2];d=oc(c,x[a+4>>2]);if(d>>>0<b>>>0){h=fb-32|0;fb=h;e=b-d|0;b=x[Ab(a)>>2];c=x[a+4>>2];a:{if(e>>>0<=b-c>>2>>>0){Ou(a,e);break a}f=Js(a);d=Tf(a,oc(x[a>>2],c)+e|0);g=oc(x[a>>2],x[a+4>>2]);c=fb-16|0;fb=c;b=h+12|0;Gg(b+12|0,f);b:{if(!d){f=0;d=0;break b}NI(c+8|0,x[b+16>>2],d);f=x[c+12>>2];d=x[c+8>>2]}x[b>>2]=d;g=d+(g<<2)|0;x[b+8>>2]=g;x[b+4>>2]=g;i=Ac(b),j=d+(f<<2)|0,x[i>>2]=j;fb=c+16|0;RQ(b,e);Id(a,b);JP(b);a=x[b>>2];if(a){Xx(x[b+16>>2],a,Kz(b))}}fb=h+32|0;return}if(b>>>0<d>>>0){Yh(a,c+(b<<2)|0)}}function xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[31785]=0;W(1005,a|0);e=x[31785];x[31785]=0;a:{b:{c:{if((e|0)==1){break c}x[31785]=0;W(1006,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break c}e=x[a+24>>2];b=pc(d+8|0,b);x[31785]=0;f=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=f;V(1023,e|0,d|0,(c|0)!=0|0,1);c=x[31785];x[31785]=0;b=1;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,10015,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function sn(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;v[g+14|0]=d;v[g+15|0]=c;v[g+13|0]=e;v[g+12|0]=f;d=0;a:{b:{while(1){c=d&255;if(c>>>0>3){break b}e=y[g+15|0];wr(g+10|0,e,y[g+14|0],c>>>0>1);if(!(y[g+10|0]|!e)){d=d+1|0;og(g+15|0,g+13|0);og(g+14|0,g+12|0);continue}break}c=z[g+10>>1];v[b+2|0]=c;v[b+4|0]=c>>>8;c=y[g+13|0];v[b+5|0]=y[g+12|0];v[b+3|0]=c;v[g+9|0]=0;ae(a,0,g+9|0);break a}d=y[g+15|0];e=Uh(d);c=y[g+13|0];if(e>>>0>Uh(c)>>>0){og(g+15|0,g+13|0);og(g+14|0,g+12|0);d=y[g+15|0];c=y[g+13|0]}v[b+4|0]=0;v[b+2|0]=0;v[b+5|0]=y[g+12|0];v[b+3|0]=c;ae(a,d,g+14|0)}fb=g+16|0}function Sia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+12>>2]=b;a:{if(ju(a)>>>0>=b>>>0){e=x[a>>2];g=Sk(e,x[a+4>>2]);x[f+8>>2]=g;d=x[Gb(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=$Q(e,c)+52|0;continue}break}if(b>>>0>g>>>0){gA(a,b-g|0,c);break a}ZQ(a,x[a>>2]+D(b,52)|0);break a}if(x[a>>2]){ku(a);d=x[a>>2];ju(a);Db(d);h=Ab(a),i=0,x[h>>2]=i;x[a>>2]=0;x[a+4>>2]=0}e=YQ(a,b);d=fb-16|0;fb=d;if(Hh(82595524)>>>0<e>>>0){cd();p()}XQ(d+8|0,e);e=x[d+8>>2];x[a+4>>2]=e;x[a>>2]=e;h=Ab(a),i=e+D(x[d+12>>2],52)|0,x[h>>2]=i;fb=d+16|0;gA(a,b,c)}fb=f+16|0}function Nfa(a){a=a|0;var b=0;b=8036;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=22485;break a}b=8069;break a}b=18374;break a;case 0:b=5031;break a;case 9:b=8092;break a;case 10:b=8106;break a;case 11:b=5408;break a;case 12:b=5428;break a;case 19:b=8118;break a;case 20:b=8050;break a;case 21:b=12919;break a;case 22:b=12242;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=6039;break a}b=8003}return xg(b)|0}function dQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=Mi(a,b,c,d);v[a+4260|0]=e;x[a>>2]=44988;c=Nb(a+4264|0);d=Nb(a+4276|0);x[a+4328>>2]=0;b=a+4320|0;x[b>>2]=0;x[b+4>>2]=0;x[a+4312>>2]=0;x[a+4316>>2]=0;b=a+4208|0;f=wb(b,0),g=1056964608,x[f>>2]=g;f=wb(b,1),g=1036831949,x[f>>2]=g;f=wb(b,2),g=1038174126,x[f>>2]=g;f=wb(b,3),g=1065353216,x[f>>2]=g;f=wb(b,4),g=1061158912,x[f>>2]=g;f=wb(b,5),g=1059082943,x[f>>2]=g;f=wb(b,6),g=1061997773,x[f>>2]=g;x[31785]=0;O(950,a+44|0,2);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;sc(d);sc(c);Uf(a);Q(b|0);p()}function Lma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;f=x[a+40>>2];g=x[a+36>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+32>>2];k=x[a+28>>2];l=x[a+8>>2];m=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;h=w[e>>1];e=h+((D(w[e+2>>1]-h|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;x[c>>2]=x[c>>2]+D(e,g>>12);f=f+j|0;x[c+4>>2]=x[c+4>>2]+D(e,f>>12);Qb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;fb=b+16|0}function l8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=y[a+52|0];a:{if(mc(b,-1)){if(d){break a}b=x[a+48>>2];e=a,f=mc(b,-1)^1,v[e+52|0]=f;break a}b:{if(!d){break b}v[c+19|0]=x[a+48>>2]<<24>>24;c:{d:{e:{d=c+20|0;switch(Wq(x[a+36>>2],x[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((ht(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}fb=c+32|0;return b|0}function B2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;a:{b:{c:{d:{if((c|0)==1){break d}x[31785]=0;W(1006,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}c=x[a+24>>2];b=pc(d+8|0,b);x[31785]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=PH(c,d,1);e=x[31785];x[31785]=0;c=hb;if((e|0)!=1){break c}}Y(T(0)|0)|0;x[31785]=0;V(992,8693,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break b}Z();b=0;c=0}fb=d+16|0;a=c;break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}gb=a;return b|0}function Oq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=pf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);ds(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=ni(Bb(x[c+4>>2],y[c+11|0]));x[31785]=0;O(46,c|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31785]=0;O(47,c|0,b-d|0);b=x[31785];x[31785]=0;d:{if((b|0)!=1){x[31785]=0;O(306,g|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Oh(a,g);tb(g);fb=f+16|0}function Oaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=pf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);ds(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=ni(Bb(x[c+4>>2],y[c+11|0]));x[31785]=0;O(46,c|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31785]=0;O(47,c|0,b-d|0);b=x[31785];x[31785]=0;d:{if((b|0)!=1){x[31785]=0;O(306,g|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Oh(a,g);tb(g);fb=f+16|0}function q_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=pf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);mw(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=ni(Bb(x[c+4>>2],y[c+11|0]));x[31785]=0;O(46,c|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31785]=0;O(47,c|0,b-d|0);b=x[31785];x[31785]=0;d:{if((b|0)!=1){x[31785]=0;O(48,g|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Oh(a,g);tb(g);fb=f+16|0}function p8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(mc(b,-1)){break c}v[c+23|0]=b<<24>>24;if(y[a+44|0]){d=-1;if((Mk(c+23|0,1,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Wq(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Mk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Mk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=Ey(b);break a}d=-1}fb=c+32|0;return d|0}function hha(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2];b=Fc(tua(sua(b,b>>31,3840,0),hb,1e3,0),hb);x[a+4316>>2]=b;x[31785]=0;x[c+12>>2]=0;S(956,a+4264|0,b|0,c+12|0);b=x[31785];x[31785]=0;a:{b:{c:{if((b|0)!=1){d:{if(!y[a+4260|0]){break d}b=x[a+4316>>2];x[31785]=0;x[c+12>>2]=0;S(956,a+4276|0,b|0,c+12|0);b=x[31785];x[31785]=0;if((b|0)!=1){break d}b=T(125240)|0;break c}x[c+12>>2]=0;b=c+12|0;$P(a+4288|0,b);x[c+12>>2]=0;$P(a+4300|0,b);break b}b=T(125240)|0}if((gb|0)!=($(125240)|0)){break a}Y(b|0)|0;x[a+4316>>2]=0;Z()}fb=c+16|0;return}Q(b|0);p()}function Fv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=pf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);mw(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,z[b>>1]);if(!x[e+16>>2]){break c}d=ni(Bb(x[c+4>>2],y[c+11|0]));x[31785]=0;O(46,c|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31785]=0;O(47,c|0,b-d|0);b=x[31785];x[31785]=0;d:{if((b|0)!=1){x[31785]=0;O(48,g|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Oh(a,g);tb(g);fb=f+16|0}function Cp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=pf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);ds(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,x[b>>2]);if(!x[e+16>>2]){break c}d=ni(Bb(x[c+4>>2],y[c+11|0]));x[31785]=0;O(46,c|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31785]=0;O(47,c|0,b-d|0);b=x[31785];x[31785]=0;d:{if((b|0)!=1){x[31785]=0;O(48,g|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Oh(a,g);tb(g);fb=f+16|0}function pz(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(e+8|0,x[zb(e+4|0,a)>>2]);a:{b:{if(c){x[31785]=0;O(1144,a|0,c|0);d=x[31785];x[31785]=0;if((d|0)==1){break b}f=fb-16|0;fb=f;d=th(f+4|0,a,c);c=x[d+4>>2];g=x[d+8>>2];while(1){if((c|0)==(g|0)){hc(d);fb=f+16|0}else{x[c>>2]=0;rc(c);c=c+4|0;x[d+4>>2]=c;continue}break}}c=e+8|0;Md(c);_g(c);fb=e+16|0;break a}a=N()|0;_g(e+8|0);Q(a|0);p()}e=a;a=0;c=0;d=fb-16|0;fb=d;f=d+12|0;while(1){if(a>>>0<32){a=a+48|0;c=VR(b);continue}break}x[f>>2]=c;wo(f);fb=d+16|0;x[e+12>>2]=x[f>>2];return e}function jK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{if(a>>>0>131071){break a}f=a&255;c=(f>>>0)/3|0;g=x[((D(c,-3)+a&255)<<2)+99288>>2];e=c;c=a>>>8|0;d=x[(((D(g,y[(e+D(y[c+100672|0],86)|0)+100672|0])>>>11>>>0)%6|0)+y[c+103344|0]<<2)+99312>>2];c=d>>8;d=d&255;if(d>>>0<=1){return(c&0-(b^d))+a|0}d=c&255;if(!d){break a}c=c>>>8|0;while(1){h=d>>>1|0;e=h+c|0;i=y[(e<<1)+100272|0];if((i|0)==(f|0)){c=x[(y[(e<<1)+100273|0]<<2)+99312>>2];d=c&255;if(d>>>0<=1){return(0-(b^d)&c>>8)+a|0}return(b?-1:1)+a|0}g=e;e=f>>>0<i>>>0;c=e?c:g;d=e?h:d-h|0;if(d){continue}break}}return a}function as(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a=Fb(a);a:{b:{c:{switch(b|0){case 0:x[31785]=0;b=P(1,d+4|0,16068)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}yb(a,b);tb(b);break b;case 1:x[31785]=0;b=P(1,d+4|0,16093)|0;c=x[31785];x[31785]=0;if((c|0)!=1){yb(a,b);tb(b);break b}break a;case 2:x[31785]=0;b=P(1,d+4|0,16041)|0;c=x[31785];x[31785]=0;if((c|0)!=1){yb(a,b);tb(b);break b}break a;case 3:break c;default:break b}}x[31785]=0;b=P(1,d+4|0,16015)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}yb(a,b);tb(b)}fb=d+16|0;return}b=N()|0;tb(a);Q(b|0);p()}function wfa(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=fb-16|0;fb=e;x[31785]=0;W(1005,a|0);d=x[31785];x[31785]=0;a:{b:{c:{if((d|0)==1){break c}x[31785]=0;W(1006,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break c}d=x[a+24>>2];b=pc(e+8|0,b);x[31785]=0;f=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=f;Za(1025,d|0,e|0,+c,1);d=x[31785];x[31785]=0;b=1;if((d|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,5946,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=0}fb=e+16|0;return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function cna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=fb-16|0;fb=b;i=x[a+16>>2];h=ig(1,2);e=hb;j=e;Qb(a,h,e);k=x[a+24>>2];l=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];m=x[a+12>>2];while(1){if(d){d=d-1|0;g=x[b+8>>2];g=(((x[b+12>>2]&2147483647)<<1|g>>>31)&-2)+i|0;f=0;while(1){if((f|0)!=2){x[(f<<2)+b>>2]=v[f+g|0]<<8;f=f+1|0;continue}break}x[c>>2]=x[c>>2]+D(x[b>>2],l);x[c+4>>2]=x[c+4>>2]+D(x[b+4>>2],k);Qb(b+8|0,e,m);c=c+8|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Dg(a,h,j);fb=b+16|0}function PU(a,b){var c=0,d=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+14|0]=5;w[a+12>>1]=0;x[a+8>>2]=128;x[a>>2]=256;x[a+4>>2]=64;x[a+28>>2]=0;v[a+27|0]=60;x[a+40>>2]=0;x[a+44>>2]=0;v[a+33|0]=2;v[a+34|0]=0;v[a+35|0]=0;v[a+36|0]=2;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=255;v[a+26|0]=0;v[a+32|0]=0;SB(a+48|0);SB(a+68|0);SB(a+88|0);Mu(a+492|0);Mu(a+524|0);gk(a,0,0);fk(a,0,0);x[a+40>>2]=0;x[a+44>>2]=0;yv(a,b);b=a+108|0;d=zC(b);c=1;while(1){if((b|0)!=(d|0)){v[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function w8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{if(bo(b)){break c}x[c+20>>2]=b;if(y[a+44|0]){d=-1;if((Mk(c+20|0,4,1,x[a+32>>2])|0)==1){break c}break a}f=c+24|0;x[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Wq(x[a+36>>2],x[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(x[c+12>>2]==(d|0)){break b}if((e|0)==3){if((Mk(d,1,1,x[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=x[c+16>>2]-g|0;if((Mk(g,1,d,x[a+32>>2])|0)!=(d|0)){break b}d=x[c+12>>2];if((e|0)==1){continue}break}}d=bo(b)?0:b;break a}d=-1}fb=c+32|0;return d|0}function Sqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=fb-48|0;fb=e;c=x[a+8>>2];d=x[a>>2];x[31785]=0;c=U(153,d|0,c|0,1)|0;d=x[31785];x[31785]=0;a:{if((d|0)==1){break a}b:{if(!c){break b}x[31785]=0;W(520,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;c=R(200,a|0)|0;d=x[31785];x[31785]=0;c:{if((d|0)!=1){while(1){if(!(c&255)){break b}x[31785]=0;d=P(521,a|0,e+15|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break c}f=y[e+15|0];if(d&f>>>0<64){yc(DY(x[b>>2],f),e+15|0,33)}c=c-1|0;continue}}break a}break a}ub(a);fb=e+48|0;return}b=N()|0;ub(a);Q(b|0);p()}function T5(a){a=a|0;if(y[500752]){return x[125187]}if(!y[501856]){v[501856]=1}sd(501568,120732);sd(501580,120764);sd(501592,120800);sd(501604,120824);sd(501616,120848);sd(501628,120864);sd(501640,120884);sd(501652,120904);sd(501664,120932);sd(501676,120972);sd(501688,121004);sd(501700,121040);sd(501712,121076);sd(501724,121092);sd(501736,121108);sd(501748,121124);sd(501760,120848);sd(501772,121140);sd(501784,121156);sd(501796,121172);sd(501808,121188);sd(501820,121204);sd(501832,121220);sd(501844,121236);v[500752]=1;x[125187]=501568;return 501568}function s8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-32|0;fb=c;d=y[a+52|0];a:{if(bo(b)){if(d){break a}b=x[a+48>>2];e=a,f=bo(b)^1,v[e+52|0]=f;break a}b:{if(!d){break b}x[c+16>>2]=x[a+48>>2];c:{d:{e:{d=c+20|0;switch(Wq(x[a+36>>2],x[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=x[a+48>>2];x[c+20>>2]=c+25;v[c+24|0]=d}while(1){d=x[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;x[c+20>>2]=d;if((ht(v[d|0],x[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}v[a+52|0]=1;x[a+48>>2]=b}fb=c+32|0;return b|0}function oX(a){var b=0,c=0,d=0;a:{if((y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))!=1196314451){break a}c=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(y[c|0]|y[c+1|0]<<8){break a}b=a+1096|0;if((y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24))-5>>>0<4294967292){break a}if(!lv(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|y[a+32|0]>15|y[a+33|0]>64){break a}b=lv(a);a=a+34|0;if(b){continue}break}}return d}function moa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31785]=0;O(714,a|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}f=fb-16|0;fb=f;c=f+4|0;x[c>>2]=a;e=x[a+4>>2];x[c+4>>2]=e;x[c+8>>2]=e+D(b,9);b=x[c+4>>2];e=x[c+8>>2];while(1){if((b|0)==(e|0)){hc(c);fb=f+16|0}else{v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;b=b+9|0;x[c+4>>2]=b;continue}break}}b=d+8|0;Md(b);hW(b);fb=d+16|0;return a|0}a=N()|0;hW(d+8|0);Q(a|0);p()}function yja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-48|0;fb=d;c=d+28|0;Yj(c,b,1819307379);hd(a+40|0,c);ub(c);Yj(c,b,1953721961);hd(a+60|0,c);ub(c);Yj(c,b,543520099);hd(a+120|0,c);ub(c);Yj(c,b,1414744396);x[31785]=0;c=P(416,c|0,13868)|0;e=x[31785];x[31785]=0;a:{if((e|0)!=1){b:{if(c){x[31785]=0;S(814,d+8|0,d+28|0,2);c=x[31785];x[31785]=0;if((c|0)==1){break b}c=d+8|0;jv(a+140|0,c);fe(c)}x[31785]=0;S(815,d+8|0,b|0,1634890872);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}}a=N()|0;ub(d+28|0);Q(a|0);p()}b=a+80|0;a=d+8|0;hd(b,a);ub(a);ub(d+28|0);fb=d+48|0}function ns(a,b,c,d){var e=0,f=0;e=fb-80|0;fb=e;f=x[c>>2];UG(e+52|0,c,73);x[31785]=0;S(d|0,e+4|0,b|0,(f&2?16:10)|0);b=x[31785];x[31785]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;gV(b,e+4|0,x[e+52>>2]);x[31785]=0;V(302,e+28|0,b|0,x[e+52>>2],x[e+56>>2]);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;S(303,e+40|0,e+28|0,e+52|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}b=a;a=e+40|0;Oh(b,a);tb(a);tb(e+28|0);tb(e+16|0);tb(e+4|0);Dh(e+52|0);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Dh(e+52|0);Q(c|0);p()}function gD(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=y[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!y[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=y[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=D(c>>>3|0,b);b=((d|0)==10)<<4}c=b+D(Xq(y[a+1|0]),c)|0}return c}function Eia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;h=Bf(a,c);Yd(e,x[a+36>>2]);a:{b:{if(!h){Pc(e,a+32|0,5);c=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}c=x[h+16>>2]}f=x[a+36>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){d=fb-16|0;fb=d;x[d+12>>2]=0;jq(f,d+12|0);B[b>>2]=B[d+12>>2];break c}d=fb-16|0;fb=d;x[d+12>>2]=c;x[d+8>>2]=4;c=x[Gb(d+12|0,d+8|0)>>2];g=fb-16|0;fb=g;mz(g+8|0,f);f=x[g+12>>2];if(Pp(-1,2147483647,c,0)^1){i=Pp(c,0,0,-2147483648)^1}else{i=0}if(i){Ei(f,c,0,1)}fb=g+16|0;x[b>>2]=0}fb=d+16|0;d=h}cf(a,d);fb=e+16|0}function nw(a,b){var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;g=f+4|0;e=fb-32|0;fb=e;c=pf(e+20|0,1,0);a:{b:{c:{while(1){d=Jb(c);mw(e+12|0,d,Bb(x[c+4>>2],y[c+11|0])+d|0,y[b|0]);if(!x[e+16>>2]){break c}d=ni(Bb(x[c+4>>2],y[c+11|0]));x[31785]=0;O(46,c|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){continue}break}break b}b=x[e+12>>2];d=Jb(c);x[31785]=0;O(47,c|0,b-d|0);b=x[31785];x[31785]=0;d:{if((b|0)!=1){x[31785]=0;O(48,g|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break d}break b}break b}tb(c);fb=e+32|0;break a}a=N()|0;tb(c);Q(a|0);p()}Oh(a,g);tb(g);fb=f+16|0}function Bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[31785]=0;W(1005,a|0);d=x[31785];x[31785]=0;a:{b:{c:{if((d|0)==1){break c}x[31785]=0;W(1006,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break c}d=x[a+24>>2];b=pc(c+8|0,b);x[31785]=0;f=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=f;e=+oa(1016,d|0,c|0,1);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,5983,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();e=0}fb=c+16|0;return+e}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function $ma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=ig(1,2);e=hb;k=e;Qb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=w[(x[b+12>>2]<<1)+j>>1];g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Qb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Dg(a,h,k);fb=b+16|0}function nla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=fb-16|0;fb=g;h=z[c>>1];i=c;e=fb-16|0;fb=e;f=b;d=$d(b);a:{if(d){c=ec(f);while(1){b=d;d=z[b+14>>1];if(_k(h,d)){c=b;d=x[b>>2];if(d){continue}break a}if(!_k(d,h)){break a}c=b+4|0;d=x[b+4>>2];if(d){continue}break}break a}b=ec(f);c=b}x[e+12>>2]=b;b=x[c>>2];if(!b){b=fb-16|0;fb=b;d=ec(f);d=zh(e,Dc(16),Kg(b+8|0,d));dk(x[d>>2]+14|0,z[i>>1]);k=ec(d),l=1,v[k+4|0]=l;fb=b+16|0;Xg(f,x[e+12>>2],c,x[e>>2]);b=ie(e);Xl(e);j=1}c=g+8|0;Wg(c,x[zb(e,b)>>2],j);fb=e+16|0;OU(a,c);fb=g+16|0}function Jp(a,b,c,d){var e=0,f=0;e=fb-80|0;fb=e;f=x[c>>2];UG(e+52|0,c,3);x[31785]=0;S(d|0,e+4|0,b|0,(f&2?16:10)|0);b=x[31785];x[31785]=0;a:{b:{c:{d:{if((b|0)!=1){b=e+16|0;gV(b,e+4|0,x[e+52>>2]);x[31785]=0;V(19,e+28|0,b|0,x[e+52>>2],x[e+56>>2]);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;S(20,e+40|0,e+28|0,e+52|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}b=a;a=e+40|0;Oh(b,a);tb(a);tb(e+28|0);tb(e+16|0);tb(e+4|0);Dh(e+52|0);fb=e+80|0;return}c=N()|0;break a}c=N()|0;break b}c=N()|0;tb(e+28|0)}tb(e+16|0);tb(e+4|0)}Dh(e+52|0);Q(c|0);p()}function Cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;a:{b:{c:{if((c|0)==1){break c}x[31785]=0;W(1006,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break c}c=x[a+24>>2];b=pc(d+8|0,b);x[31785]=0;e=x[b+4>>2];x[d>>2]=x[b>>2];x[d+4>>2]=e;b=U(1012,c|0,d|0,1)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,10046,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=0}fb=d+16|0;return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function ZE(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=fb-16|0;fb=f;x[f+8>>2]=e;x[f+12>>2]=d;rf(a);js(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;x[f+4>>2]=i;g=x[Gb(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=is(ot(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){x[f+4>>2]=i-g;e=h+1|0;d=x[Gb(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=v[cc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=cc(j,e),n=32,v[m|0]=n}e=e+1|0;continue}}break}fb=f+16|0}function ana(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=fb-16|0;fb=b;j=x[a+16>>2];h=ig(1,2);e=hb;k=e;Qb(a,h,e);f=x[a+40>>2];g=x[a+36>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;l=x[a+32>>2];m=x[a+28>>2];e=x[a+8>>2];n=x[a+12>>2];while(1){if(d){i=v[x[b+12>>2]+j|0]<<8;g=g+m|0;x[c>>2]=x[c>>2]+D(i,g>>12);f=f+l|0;x[c+4>>2]=x[c+4>>2]+D(f>>12,i);Qb(b+8|0,e,n);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;x[a+40>>2]=f;x[a+20>>2]=g>>12;x[a+36>>2]=g;x[a+24>>2]=f>>12;Dg(a,h,k);fb=b+16|0}function tt(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=fb-240|0;fb=h;x[h+236>>2]=d;x[h+232>>2]=c;x[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-x[(e<<2)+g>>2]|0;if((fo(i,a,b)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=x[((e<<2)+g|0)-8>>2];l=j-4|0;if((fo(l,i,b)|0)>=0){break e}if((fo(l-f|0,i,b)|0)>=0){break e}}x[(k<<2)+h>>2]=i;c=rL(c,d);ut(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=x[h+236>>2];c=x[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}qL(h,k);Uy(i,b,e,g)}fb=h+240|0}function Wja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-208|0;fb=e;w[a+480212>>1]=0;x[a+480240>>2]=65536;x[a+480244>>2]=65536;$R(a+946304|0);f=a+906300|0;g=Dj(f);d=e+48|0;Tb(d,0,160);d=bS(d);x[31785]=0;S(867,f|0,g|0,d|0);f=x[31785];x[31785]=0;a:{if((f|0)!=1){HA(d);d=Fe(e+28|0,b);x[31785]=0;f=x[d+12>>2];x[e+16>>2]=x[d+8>>2];x[e+20>>2]=f;x[e+24>>2]=x[d+16>>2];f=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=f;a=U(868,a|0,e+8|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){a=N()|0;break a}ub(b);fb=e+208|0;return a|0}a=N()|0;HA(d)}ub(b);Q(a|0);p()}function az(a,b,c){var d=0,e=0,f=E(0),g=E(0),h=E(0),i=E(0),j=0,k=E(0),l=E(0),m=E(0);e=fb-32|0;fb=e;g=B[a+24>>2];f=B[a+12>>2];h=B[a+48>>2];i=B[a+36>>2];IL(E(-B[a>>2]),E(g+f),E(h+i),e+20|0);IL(B[a+60>>2],E(h-i),E(g-f),e+8|0);B[e+12>>2]=-B[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=B[j>>2];f=B[d+(e+20|0)>>2];h=B[d+87920>>2];i=B[d+87932>>2];k=B[d+(e+8|0)>>2];B[j>>2]=E(f*h)-E(i*k);j=b+d|0;l=B[(0-a<<2)+87928>>2];d=5-a<<2;m=B[d+87920>>2];f=E(E(f*i)+E(k*h));B[j>>2]=E(g*l)-E(m*f);B[b+d>>2]=E(g*m)+E(f*l);a=a+1|0;continue}break}fb=e+32|0}function ax(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;f=x[b>>2];g=ib[x[x[f>>2]+36>>2]](f,c,d)|0;a:{if(!g){_h(a);break a}mm(e+32|0,x[b>>2],x[b+4>>2]);b=x[e+36>>2];x[e+16>>2]=x[e+32>>2];x[e+20>>2]=b;b=fb-16|0;fb=b;d=e+16|0;f=mm(b+8|0,x[d>>2],x[d+4>>2]);x[31785]=0;h=x[f+4>>2];x[b>>2]=x[f>>2];x[b+4>>2]=h;V(169,e+40|0,b|0,c|0,g|0);c=x[31785];x[31785]=0;b:{if((c|0)!=1){he(d);fb=b+16|0;break b}a=N()|0;he(d);Q(a|0);p()}b=Jd(e+24|0);c=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=c;c=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=c;yp(a,e+8|0,e)}fb=e+48|0}function TB(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=x[a>>2];a:{if(!mc(c,x[a+4>>2])){w[c>>1]=0;If(c+2|0,b);f=d,g=Ek(vb(x[a>>2]),1),x[f+12>>2]=g;while(1){e=vb(x[a+4>>2]);c=x[d+12>>2];if(Ib(c,e)){f=c,g=z[se(c,Ek(c,-1))>>1],w[f>>1]=g;If(c+2|0,b);YV(d+12|0);continue}else{If(a+14|0,Od(x[a>>2],x[a+4>>2])-1&255);If(a+13|0,y[a+14|0]);If(a+16|0,Od(x[a>>2],x[a+4>>2])-1&255);If(a+15|0,y[a+16|0]);if(y[a+17|0]==255){break a}If(a+17|0,Od(x[a>>2],x[a+4>>2])-1&255);break a}}}v[a+17|0]=255;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0}fb=d+16|0}function to(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Kb(e+8|0,a+1074312|0,3);if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break c}if(!(v[(D(b,872)+a|0)+1075843|0]&1)){break a}c=D(d&15,c>>31|(c|0)!=0);c=d>>>0>239?c<<2:c;break b}if(v[(D(b,872)+a|0)+1075843|0]&1){Kb(e+8|0,a+1074312|0,3);if(!Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=D(b,872)+a|0;d=x[f+1075648>>2];a=qq(a,x[f+1075080>>2],d);if(!a){break a}ib[x[x[a>>2]+84>>2]](a,c,(d?y[d+33|0]:13)<<24>>24,b)}fb=e+16|0}function zma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=(x[b+12>>2]<<1)+i|0;e=e>>>21&2040;e=(((D(w[f>>1],w[e+38386>>1])+D(w[f-2>>1],w[e+38384>>1])|0)+D(w[f+2>>1],w[e+38388>>1])|0)+D(w[f+4>>1],w[e+38390>>1])|0)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function pja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=fb-32|0;fb=f;a=Nb(a);b:{c:{d:{e:{while(1){e=x[b+8>>2];g=x[b>>2];x[31785]=0;e=U(153,g|0,e|0,8)|0;g=x[31785];x[31785]=0;if((g|0)==1){break c}if(e){x[31785]=0;S(916,f+4|0,b|0,c|0);e=x[31785];x[31785]=0;if((e|0)==1){break e}x[31785]=0;O(917,a|0,f+4|0);e=x[31785];x[31785]=0;if((e|0)==1){break d}e=f+4|0;Fd(e);g=e;e=qr(x[a+4>>2]);ti(g,x[e>>2],x[e+4>>2]);if(x[f+4>>2]!=(d|0)){continue}}break}fb=f+32|0;break a}b=N()|0;break b}b=N()|0;Fd(f+4|0);break b}b=N()|0}fe(a);Q(b|0);p()}}function Ara(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=x[a>>2];d=Jk(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;d=b-d|0;b=x[Ab(a)>>2];f=x[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){dD(a,d,c);break a}b=Ab(a);b=VY(e+12|0,_C(a,Jk(x[a>>2],f)+d|0),Jk(x[a>>2],x[a+4>>2]),b);UY(b,d,c);c=fb-16|0;fb=c;d=zb(c+12|0,x[a+4>>2]);f=zb(c+8|0,x[a>>2]);g=zb(c+4|0,x[b+4>>2]);h=b,i=RY(x[d>>2],x[f>>2],x[g>>2]),x[h+4>>2]=i;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),Ac(b));x[b>>2]=x[b+4>>2];fb=c+16|0;TY(b)}fb=e+32|0;return}if(b>>>0<d>>>0){cD(a,e+D(b,6)|0)}}function zj(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;x[a+4>>2]=0;d=4;a:{b:{c:{if(!Ad(y[Cm(e+15|0,a,1)|0])){break c}d=x[(x[x[a>>2]-12>>2]+a|0)+24>>2];x[31785]=0;b=U(88,d|0,b|0,c|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){x[a+4>>2]=b;d=(b|0)!=(c|0)?6:0;break c}Y(T(0)|0)|0;d=1;Am(x[x[a>>2]-12>>2]+a|0,1);if(x[(x[x[a>>2]-12>>2]+a|0)+20>>2]&1){x[31785]=0;X(87);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)==1){break b}Q(a|0);p()}Z()}$j(x[x[a>>2]-12>>2]+a|0,d);fb=e+16|0;return a}T(0)|0;Rb()}p()}function s0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;jd(b,0);f=e+8|0;ui(f,1,a+33|0);d=e+20|0;Ec(d,f);ye(b+43|0,d);tb(d);g=y[a+50|0]|y[a+51|0]<<8|(y[a+52|0]<<16|y[a+53|0]<<24);x[b>>2]=g;x[b+24>>2]=y[a+54|0]|y[a+55|0]<<8;v[e+20|0]=y[a+56|0];v[e+8|0]=64;h=b,i=y[Ub(d,f)|0]<<2,w[h+30>>1]=i;d=y[a+57|0]|y[a+58|0]<<8|(y[a+59|0]<<16|y[a+60|0]<<24);x[b+4>>2]=d;f=y[a+61|0]|y[a+62|0]<<8|(y[a+63|0]<<16|y[a+64|0]<<24);c=c?d?g:f:f;x[b+8>>2]=c;if(!(!y[a|0]|c>>>0<=d+2>>>0|c>>>0>g>>>0)){w[b+34>>1]=z[b+34>>1]|2}fb=e+32|0}function QR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=16777216;h=e+12|0;d=x[a>>2];c=oc(d,x[a+4>>2]);a:{if(c>>>0<b>>>0){f=fb-32|0;fb=f;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){HE(a,b,h);break b}c=Ab(a);c=hg(f+12|0,Tf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);g=fb-16|0;fb=g;b=An(g+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){po(d,x[h>>2]);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}ee(b);fb=g+16|0;Id(a,c);gg(c)}fb=f+32|0;break a}if(b>>>0<c>>>0){Yh(a,d+(b<<2)|0)}}DA(a);fb=e+16|0}function qQ(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=0;Rz(a);c=Ld(c,E(0));a:{switch(b|0){case 0:B[a+4220>>2]=c;return;case 1:B[a+4224>>2]=c;return;case 2:B[a+4228>>2]=c;_t(a);return;case 3:v[a+4240|0]=c>=E(.5);_t(a);return;case 4:b=fb-16|0;fb=b;e=b,f=Il(E(c*E(32))),x[e+12>>2]=f;x[b+8>>2]=0;x[b+4>>2]=5;d=x[bk(b+12|0,b+8|0,b+4|0)>>2];fb=b+16|0;x[a+4232>>2]=d;return;case 5:v[a+4241|0]=c>=E(.5);return;case 6:v[a+4242|0]=c>=E(.5);return;case 7:v[a+4244|0]=c>=E(.5);return;case 8:if(c==E(0)){Qz(a)}C[a+4256>>3]=c;break;default:break a}}}function ipa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;e=Kf(d+52|0);x[31785]=0;c=P(653,b|0,e|0)|0;f=x[31785];x[31785]=0;a:{b:{c:{d:{if((f|0)!=1){if(c){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31785]=0;R(654,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break a}}break c}c=x[e+4>>2];x[31785]=0;S(188,d+12|0,b|0,(c>>>0>=9?c-8|0:0)|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}a=N()|0;Fd(e);Q(a|0);p()}b=d+12|0;c=ic(d+32|0,b);hd(e+8|0,c);ub(c);ub(b);Pk(a,e)}Fd(e);fb=d+80|0}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=bj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Sh(c);if((c|0)!=10){break b}}c=fb-16|0;fb=c;e:{if((d|0)!=2147483631){f=Jb(a);g=c+4|0;if(d>>>0<=1073741798){x[c+12>>2]=d<<1;x[c+4>>2]=d+1;e=Ah(x[_c(c+4|0,c+12|0)>>2])+1|0}else{e=2147483631}ng(g,e);e=x[c+4>>2];if(d){yg(e,f,d)}if((d|0)!=10){Db(f)}vd(a,e);nf(a,x[c+8>>2]);fb=c+16|0;break e}of();p()}c=d}d=x[a>>2];Vd(a,c+1|0);break a}Ke(a,c+1|0);d=a}a=c+d|0;ed(a,b);ed(a+1|0,0)}function wsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=fb-32|0;fb=d;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[31785]=0;c=U(153,e|0,c|0,8)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}if(c){x[31785]=0;O(411,d+4|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break e}x[31785]=0;O(412,a|0,d+4|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}c=d+4|0;Fd(c);e=c;c=qr(x[a+4>>2]);ti(e,x[c>>2],x[c+4>>2]);if(($b(x[d+4>>2])|0)!=1162757187){continue}}break}fb=d+32|0;break a}b=N()|0;break b}b=N()|0;Fd(d+4|0);break b}b=N()|0}fe(a);Q(b|0);p()}}function R0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=16384;d=x[Gb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=17;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=dl(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Lr(c+4|0,dl(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}Lr(c+4|0,d-e|0);break b}wF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}wF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function Dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(x[a+4>>2]!=x[Ab(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+7;tT(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+7;hc(c);fb=d+16|0;return}f=fb-32|0;fb=f;g=Ab(a);h=f+12|0;e=tB(x[a>>2],x[a+4>>2])+1|0;c=fb-16|0;fb=c;x[c+12>>2]=e;a:{d=Hh(613566756);if(e>>>0<=d>>>0){e=uB(a);if(e>>>0<d>>>1>>>0){x[c+8>>2]=e<<1;d=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;break a}cd();p()}c=wT(h,d,tB(x[a>>2],x[a+4>>2]),g);tT(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+7;vT(a,c);uT(c);fb=f+32|0}function Jqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=Kf(d+52|0);x[31785]=0;e=P(525,b|0,c|0)|0;f=x[31785];x[31785]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31785]=0;R(526,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break a}}break c}e=z[c+2>>1]|z[c+4>>1]<<16;x[31785]=0;S(188,d+12|0,b|0,e|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}a=N()|0;Fd(c);Q(a|0);p()}b=d+12|0;e=ic(d+32|0,b);hd(c+8|0,e);ub(e);ub(b);uY(a,c)}Fd(c);fb=d+80|0}function Ama(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+8>>2];f=x[b+12>>2]+i|0;e=e>>>21&2040;e=(((D(v[f|0],w[e+38386>>1])+D(v[f-1|0],w[e+38384>>1])|0)+D(v[f+1|0],w[e+38388>>1])|0)+D(v[f+2|0],w[e+38390>>1])<<8)/16384|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function Q0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=x[x[a+1060>>2]>>2]-x[a+1064>>2];x[c+8>>2]=32768;d=x[Gb(c+12|0,c+8|0)>>2];x[a+1072>>2]=d;x[c+4>>2]=9;while(1){a:{if(!d){break a}e=x[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=dl(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Lr(c+4|0,dl(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}Lr(c+4|0,d-e|0);break b}vF(a,d,f,b);break b}e=d&(f^-1);if(d&f){x[c+4>>2]=e+1;break b}vF(a,e,0,b)}d=x[a+1072>>2];continue}break}fb=c+16|0}function gN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];e=gq(a);d:{if(!e){if(fq(a)>>>0<=b>>>0){break d}a=ri(a,b+1&65535);w[a+34>>1]=z[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ac(8);x[31785]=0;b=P(37,d+4|0,6020)|0;c=x[31785];x[31785]=0;e:{if((c|0)!=1){nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;jc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];if(!a){break b}v[a+15|0]=y[a+15|0]&253|(c?2:0)}fb=d+16|0;return}p()}function sta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;jd(b,0);g=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);x[b>>2]=g;e=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);x[b+12>>2]=e;f=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);x[b+16>>2]=f;c=y[a+12|0]|y[a+13|0]<<8;w[b+32>>1]=64;x[b+24>>2]=c;c=y[a+14|0];w[b+30>>1]=c?c+1|0:256;d=z[b+34>>1]&32767|!y[a+14|0]<<15;w[b+34>>1]=d;c=y[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;w[b+34>>1]=d;c=y[a+15|0]}if(c&2){x[b+16>>2]=f>>>1;x[b+12>>2]=e>>>1;x[b>>2]=g>>>1;w[b+34>>1]=d|1}}function ij(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?G(c):G(d)+32|0;Vf(f,d,e,0,0,c+49|0);i=x[f>>2];h=x[f+4>>2];e=15372-c<<16;c=x[f+8>>2];d=e|x[f+12>>2]^65536}x[a>>2]=i;x[a+4>>2]=h;x[a+8>>2]=c;x[a+12>>2]=g&-2147483648|d;fb=f+16|0}function Tc(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=d+4|0;x[b+4>>2]=1214;x[b>>2]=a;x[b+8>>2]=0;c=fb-16|0;fb=c;if(x[a>>2]!=-1){a:{b=zb(c+8|0,uf(c+12|0,b));while(1){if(x[a>>2]==1){continue}break}b:{if(!x[a>>2]){vd(a,1);b=x[x[b>>2]>>2];x[31785]=0;W(1215,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break b}x[a>>2]=-1}break a}Y(T(0)|0)|0;vd(a,0);x[31785]=0;X(87);a=x[31785];x[31785]=0;c:{if((a|0)==1){a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){break c}T(0)|0;Rb()}p()}Q(a|0);p()}}fb=c+16|0;fb=d+16|0;return x[a+4>>2]-1|0}function VO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;e=Nb(a);a=b;b=0;a:{b:{c:{d:{e:{while(1){d=x[a+24>>2];if(z[d+480188>>1]<=b>>>0){break a}x[31785]=0;O(1061,c+8|0,(d+(b<<5)|0)+480289|0);d=x[31785];x[31785]=0;if((d|0)!=1){d=x[a+24>>2];x[31785]=0;S(1062,c+20|0,d|0,c+8|0);d=x[31785];x[31785]=0;if((d|0)==1){break e}x[31785]=0;O(181,e|0,c+20|0);d=x[31785];x[31785]=0;if((d|0)==1){break d}b=b+1|0;tb(c+20|0);tb(c+8|0);continue}break}b=N()|0;break b}b=N()|0;break c}b=N()|0;tb(c+20|0)}tb(c+8|0)}Pd(e);Q(b|0);p()}fb=c+32|0}function tW(a,b,c,d,e,f){b=y[(b&15)+25632|0];v[a+3|0]=b;a:{b:{switch(b-11|0){case 0:b=y[a+5|0];c=b&15;if(c){v[a+5|0]=c;return}v[a+5|0]=b&240;return;case 3:b=y[a+5|0];b=D(b&240,10)|b&15;v[a+5|0]=b;d=b&255;b=z[e>>1];if(!(d|(b|0)==65535)){v[a+5|0]=b;v[a+3|0]=12;w[e>>1]=65535}vc(f,c);return;case 1:w[e>>1]=y[a+5|0];x[f>>2]=63;v[a+3|0]=0;return;case 5:b=y[a+5|0];if(d>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|D(c,-10)+b;v[a+5|0]=b}if(b&255){break a}v[a+3|0]=0;return;case 7:break a;default:break b}}if(y[a+5|0]){break a}v[a+3|0]=0}}function kla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);b:{d=Xc(x[b>>2],x[b+4>>2]);if(!d){break b}x[31785]=0;O(644,a|0,d|0);e=x[31785];x[31785]=0;if((e|0)!=1){e=x[b+4>>2];f=x[b>>2];x[31785]=0;MB(a,f,e,d);d=x[31785];x[31785]=0;if((d|0)!=1){break b}}a=N()|0;Wj(c+8|0);Q(a|0);p()}d=c+8|0;Md(d);Wj(d);fb=c+16|0;x[31785]=0;P(3,a+12|0,b+12|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){x[a+24>>2]=x[b+24>>2];w[a+28>>1]=z[b+28>>1];break a}b=N()|0;kd(a);Q(b|0);p()}}function Woa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=fb-32|0;fb=d;a=Nb(a);b:{c:{d:{e:{while(1){c=x[b+8>>2];e=x[b>>2];x[31785]=0;c=U(153,e|0,c|0,8)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}if(c){x[31785]=0;O(684,d+4|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break e}x[31785]=0;O(685,a|0,d+4|0);c=x[31785];x[31785]=0;if((c|0)==1){break d}c=d+4|0;Fd(c);e=c;c=qr(x[a+4>>2]);ti(e,x[c>>2],x[c+4>>2]);if(x[d+4>>2]!=1413891155){continue}}break}fb=d+32|0;break a}b=N()|0;break b}b=N()|0;Fd(d+4|0);break b}b=N()|0}fe(a);Q(b|0);p()}}function Lpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=fb-608|0;fb=f;b=fb-16|0;fb=b;d=f+8|0;EX(b+8|0,d);c=x[b+12>>2];nd(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(c|0)){fd(a,x[b+12>>2])}fb=b+16|0;c=(c|0)==(e|0);if(!c){CX(d)}b=-1;a:{if(!c){break a}b=0;if(!FX(f+8|0)){break a}b=-1;if(!ih(a,1024)){break a}b=0;d=fb-1024|0;fb=d;c=fb-16|0;fb=c;BC(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((e|0)==(g|0)){fd(a,x[c+12>>2])}fb=c+16|0;if((e|0)==(g|0)){b=CC(d,0)>>>0<17}fb=d+1024|0}fb=f+608|0;return b|0}function Ev(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=0;x[g+8>>2]=a;i=fb-16|0;fb=i;b=gc(i+8|0,x[g+8>>2],x[g+12>>2]);e=fb-16|0;fb=e;d=121;x[e+12>>2]=121;c=x[b+4>>2];a:{if(!c){c=x[b>>2];break a}f=32-c|0;x[e+8>>2]=f;d=x[b>>2];j=x[d>>2];h=f;f=x[Gb(e+8|0,e+12|0)>>2];x[d>>2]=(-1<<c&-1>>>h-f^-1)&j;j=x[e+12>>2];c=d+4|0;x[b>>2]=c;d=j-f|0}h=c;c=d>>>5|0;rF(h,c);f=d&31;x[e+12>>2]=f;if((d&-32)!=(d|0)){h=b;b=x[b>>2]+(c<<2)|0;x[h>>2]=b;x[b>>2]=x[b>>2]&(-1>>>32-f^-1)}fb=e+16|0;fb=i+16|0;fb=g+16|0;return a}function QA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;g=vu(a,a+1074376|0,b,c);a:{if(!g){break a}h=a+1074312|0;Kb(d+8|0,h,117);if(Hb(x[x[d+8>>2]>>2],x[d+12>>2])){break a}e=D(b,872)+a|0;i=e+1075648|0;c=x[i>>2];if(!c|!y[c+33|0]){break a}f=a;a=e+1074992|0;e=qq(f,x[a+88>>2],c);if(!e){break a}Kb(d+8|0,h,34);f=!Hb(x[x[d+8>>2]>>2],x[d+12>>2]);c=Zg(y[a+797|0]-w[a+770>>1]|0);b:{if(f|c-1<<24>>24<0){break b}a=x[a+656>>2];if(!a){break b}c=y[xb(a+108|0,c-1|0)|0]}ib[x[x[e>>2]+88>>2]](e,g,c&255,v[x[i>>2]+33|0],b)}fb=d+16|0}function Vfa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a+4202|0]=1;c=Bk(E(E(A[x[a+16>>2]+24620>>2])*E(.04500000178813934)));d=Bk(E(E(c>>>0)*E(1.1892070770263672)));e=Bk(E(E(d>>>0)*E(1.1892070770263672)));h=Bk(E(E(e>>>0)*E(1.1892070770263672)));f=Bk(E(E(c+e>>>0)*E(.11546666920185089)));g=Bk(E(E(d+h>>>0)*E(.11546666920185089)));b=a+4272|0;i=wb(b,0),j=c-f|0,x[i>>2]=j;i=wb(b,1),j=e-f|0,x[i>>2]=j;i=wb(b,2),j=d-g|0,x[i>>2]=j;i=wb(b,3),j=h-g|0,x[i>>2]=j;i=wb(b,4),j=f,x[i>>2]=j;i=wb(b,5),j=g,x[i>>2]=j;DP(a);CP(a)}function HO(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=fb-16|0;fb=b;a:{f=a+36|0;c=x[f>>2];d=x[a+40>>2];b:{if(Ib(c,d)){rc(b+12|0);break b}oo(b,a);x[31785]=0;c=R(1065,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}x[b+12>>2]=c;mf(b);d=x[a+40>>2];c=x[a+36>>2]}c=(g=f,h=x[b+12>>2],i=Ib(c,d),i?g:h);a=x[a+8>>2];c:{if((a|0)==-1){g=b,h=vb(x[c>>2]),x[g>>2]=h;a=vb(x[c+4>>2]);while(1){c=x[b>>2];if(!Ib(c,a)){break c}e=e+C[c>>3];Zz(b);continue}}e=C[tf(x[c>>2],a)>>3]}vl(b+12|0);fb=b+16|0;return+e}a=N()|0;mf(b);Q(a|0);p()}function pB(a,b){var c=0;if(b>>>0<=999999){if(b>>>0<=9999){if(b>>>0<=99){if(b>>>0<=9){return vq(a,b)}return Gl(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Gl(vq(c,a),D(a,-100)+b|0)}return kB(a,b)}if(b>>>0<=99999){c=a;a=(b>>>0)/1e4|0;return kB(vq(c,a),D(a,-1e4)+b|0)}return iB(a,b)}if(b>>>0<=99999999){if(b>>>0<=9999999){c=a;a=(b>>>0)/1e6|0;return iB(vq(c,a),D(a,-1e6)+b|0)}return yu(a,b)}if(b>>>0<=999999999){c=a;a=(b>>>0)/1e8|0;return yu(vq(c,a),D(a,-1e8)+b|0)}c=a;a=(b>>>0)/1e8|0;return yu(Gl(c,a),D(a,-1e8)+b|0)}function mta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;jd(b,0);e=c+8|0;ui(e,1,a);d=c+20|0;Ec(d,e);ye(b+43|0,d);tb(d);x[b+24>>2]=y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24);w[b+34>>1]=z[b+34>>1]&65533|(y[a+13|0]|y[a+14|0]<<8)<<1&2;x[b>>2]=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);x[b+4>>2]=y[a+20|0]|y[a+21|0]<<8|(y[a+22|0]<<16|y[a+23|0]<<24);x[b+8>>2]=y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24);v[c+20|0]=y[a+15|0];v[c+8|0]=64;f=b,g=y[Ub(d,e)|0]<<2,w[f+30>>1]=g;fb=c+32|0}function Moa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-80|0;fb=c;d=Kf(c+52|0);x[31785]=0;e=P(691,b|0,d|0)|0;f=x[31785];x[31785]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31785]=0;R(692,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break a}}break c}e=x[d+4>>2];x[31785]=0;S(188,c+12|0,b|0,e|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}a=N()|0;Fd(d);Q(a|0);p()}b=c+12|0;e=ic(c+32|0,b);hd(d+8|0,e);ub(e);ub(b);Pk(a,d)}Fd(d);fb=c+80|0}function qS(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{if(b){v[c|0]=b;break a}b=y[c|0]}e=x[a+480180>>2];c=e&1048580?b&240?b&-16:b:b;b=c&255;c=c&15;b:{c:{d:{if(!((c|0)!=15|b>>>0<16)){if(!(y[a+480209|0]&16)){break b}b=b>>>3&30;break d}f=x[a+480208>>2]&4096;g=b&240;if(!(!c|(g|0)!=240)){if(!f){break b}b=0-(c<<1)|0;break c}if(f){break b}if(g){if(c?e&59314208:0){break b}b=b>>>3&30;break d}b=0-(c<<1)|0}if(!b){break b}}a=a+1074456|0;x[d+12>>2]=x[a>>2]+(b<<!(e&59314208));Ee(d+12|0,0,256);x[a>>2]=x[d+12>>2]}fb=d+16|0}function Vra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=pf(e+20|0,1,0);a:{b:{while(1){f=Jb(d);VB(e+12|0,f,Bb(x[d+4>>2],y[d+11|0])+f|0,z[b>>1],c);if(!x[e+16>>2]){break b}f=ni(Bb(x[d+4>>2],y[d+11|0]));x[31785]=0;O(46,d|0,f|0);f=x[31785];x[31785]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Jb(d);x[31785]=0;O(47,d|0,b-c|0);b=x[31785];x[31785]=0;c:{if((b|0)!=1){x[31785]=0;O(48,a|0,d|0);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-32|0;fb=e;d=pf(e+20|0,1,0);a:{b:{while(1){f=Jb(d);pN(e+12|0,f,Bb(x[d+4>>2],y[d+11|0])+f|0,y[b|0],c);if(!x[e+16>>2]){break b}f=ni(Bb(x[d+4>>2],y[d+11|0]));x[31785]=0;O(46,d|0,f|0);f=x[31785];x[31785]=0;if((f|0)!=1){continue}break}break a}b=x[e+12>>2];c=Jb(d);x[31785]=0;O(47,d|0,b-c|0);b=x[31785];x[31785]=0;c:{if((b|0)!=1){x[31785]=0;O(306,a|0,d|0);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break a}break a}tb(d);fb=e+32|0;return}a=N()|0;tb(d);Q(a|0);p()}function F5(a){a=a|0;if(y[500744]){return x[125185]}if(!y[501552]){v[501552]=1}id(501264,5054);id(501276,5045);id(501288,10885);id(501300,10629);id(501312,5281);id(501324,11673);id(501336,5138);id(501348,5629);id(501360,8906);id(501372,8889);id(501384,8897);id(501396,8916);id(501408,10083);id(501420,13335);id(501432,8979);id(501444,7734);id(501456,5281);id(501468,9772);id(501480,10488);id(501492,10897);id(501504,9269);id(501516,6483);id(501528,5512);id(501540,13253);v[500744]=1;x[125185]=501264;return 501264}function B0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;c=-1;a:{if(!RE(a,b+12|0)){break a}b:{if(QE(b+12|0)){if(fd(a,32)){break b}break a}c=0;if(!PE(b+12|0)){break a}}e=b+7|0;d=OE(y[b+15|0]);c=fb-32|0;fb=c;x[c+28>>2]=d;x[c+8>>2]=5;d=x[Gb(c+28|0,c+8|0)>>2];if(!ih(a,d)){d=(ib[x[x[a>>2]+24>>2]](a)|0)-x[a+12>>2]|0}f=c+8|0;ck(f,e);g=gc(c+16|0,x[c+8>>2],d);nd(c,a,x[g>>2],x[g+4>>2]);ck(f,e);Tb(x[c+8>>2]+d|0,0,5-d|0);fd(a,x[c+28>>2]);fb=c+32|0;if(!d){c=-1;break a}c=NE(b+7|0,y[b+15|0])}fb=b+16|0;return c|0}function bF(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if(Ob(a,11167,2)){if(Ob(a,13877,2)){break a}if(y[a+110|0]<=64){break b}break a}if(y[a+110|0]>64){break a}}if(v[a+112|0]<0|y[a+111|0]>128){break a}c=a+110|0;b=a+2|0;while(1){if((b|0)==(c|0)){while(1){b=(e|0)==128;if(b){break a}c=a+e|0;d=v[c+113|0];if((d|0)<-2){break a}f=y[c+241|0];if(!f&(d|0)>=0|f>>>0>15){break a}e=e+1|0;if(y[c+369|0]<64){continue}break a}}c:{if((y[b|0]-1&255)>>>0>30){break c}d=d+1|0;if((d&255)>>>0<=40){break c}return 0}b=b+1|0;continue}}return b}function Vja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;x[a>>2]=x[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){e=fb-16|0;fb=e;f=x[c+4>>2];h=x[c+8>>2];g=Tj(f,h);a:{if(g>>>0<=Qo(d)>>>0){i=h;j=x[d>>2];k=Sc(j,x[d+4>>2]);l=k>>>0>=g>>>0;if(!l){x[e+12>>2]=f;x[e+12>>2]=k+x[e+12>>2];i=x[e+12>>2]}f=Qi(f,i,j);if(!l){fv(d,i,h,g-Sc(x[d>>2],x[d+4>>2])|0);break a}Tq(d,f);break a}Pv(d);Yk(d,Ul(d,g));fv(d,f,h,g)}fb=e+16|0}yc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function U2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(kh(a,x[b+8>>2],e)){Hx(b,c,d);return}a:{if(kh(a,x[b>>2],e)){if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+32>>2]=d;b:{if(x[b+44>>2]==4){break b}w[b+52>>1]=0;a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,c,1,e);if(y[b+53|0]){x[b+44>>2]=3;if(!y[b+52|0]){break b}break a}x[b+44>>2]=4}x[b+20>>2]=c;x[b+40>>2]=x[b+40>>2]+1;if(x[b+36>>2]!=1|x[b+24>>2]!=2){break a}v[b+54|0]=1;return}a=x[a+8>>2];ib[x[x[a>>2]+24>>2]](a,b,c,d,e)}}function JU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=y[a+16|0];k=c?-1:1;l=c?1:-1;e=x[a+8>>2]-1|0;m=c?e-(y[a+17|0]!=0&(e|0)!=0)|0:0;f=x[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=x[a>>2]+D(f,62)|0;d=b?1:-1;p=D(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=D(c,f);q=x[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{w[(b<<1)+h>>1]=z[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function wpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,26);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+16|0]=0;v[b+17|0]=0;v[b+18|0]=0;v[b+19|0]=0;v[b+20|0]=0;v[b+21|0]=0;v[b+22|0]=0;v[b+23|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0;v[b+15|0]=0}}function ZG(a,b,c,d){var e=0,f=0,g=0;e=fb-80|0;fb=e;f=Kf(e+52|0);x[31785]=0;d=P(d|0,b|0,f|0)|0;g=x[31785];x[31785]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[31785]=0;R(c|0,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break a}}break c}c=x[f+4>>2];x[31785]=0;S(188,e+12|0,b|0,$b(c)|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}a=N()|0;Fd(f);Q(a|0);p()}b=e+12|0;c=ic(e+32|0,b);hd(f+8|0,c);ub(c);ub(b);Pk(a,f)}Fd(f);fb=e+80|0}function cK(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{g=x[31660];x[31660]=0;Kd();a=bK(a,e+12|0,d);d=hb;d:{f=x[31660];if(f){if(x[e+12>>2]!=(b|0)){break c}if((f|0)!=68){break d}x[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}break b}x[31660]=g;if(x[e+12>>2]==(b|0)){break d}break c}if((d|0)<0&a>>>0<=2147483647|(d|0)<-1){x[c>>2]=4;break b}if((d|0)>=0&a>>>0>=2147483648|(d|0)>0){x[c>>2]=4;b=2147483647;break a}b=a;break a}}x[c>>2]=4;b=0;break a}b=-2147483648}fb=e+16|0;return b}function Xm(a,b,c,d){var e=0;a:{e=a+1074312|0;if(Pb(e,84)){break a}b:{if(y[a+480209|0]&64){break b}if((d|0)!=8){if(!Pb(e,10)){break b}}x[b+88>>2]=x[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0>=64?64:c)<<2;break d;default:break e}}if(!(x[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}x[b+88>>2]=x[b+88>>2]|256;c=128}x[b+692>>2]=c}w[b+784>>1]=0;x[b+88>>2]=x[b+88>>2]|2097152;if(!Pb(e,10)){break a}v[b+831|0]=0;w[b+778>>1]=0}}function bra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=px(c+4|0,a);d=x[a+4>>2];x[31785]=0;O(505,d|0,b|0);b=x[31785];x[31785]=0;a:{if((b|0)!=1){x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;break a}b=N()|0;hc(a);Q(b|0);p()}return}d=fb-32|0;fb=d;c=Ab(a);c=um(d+12|0,Dp(a,Qd(x[a>>2],x[a+4>>2])+1|0),Qd(x[a>>2],x[a+4>>2]),c);e=x[c+8>>2];x[31785]=0;O(505,e|0,b|0);b=x[31785];x[31785]=0;b:{if((b|0)!=1){x[c+8>>2]=x[c+8>>2]+12;ox(a,c);gs(c);fb=d+32|0;break b}a=N()|0;gs(c);Q(a|0);p()}}function aea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=E(0);x[31785]=0;W(1005,a|0);d=x[31785];x[31785]=0;a:{if((d|0)==1){break a}x[31785]=0;W(1077,c|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}d=x[a+24>>2];e=B[d+48>>2];d=x[d+24>>2];x[31785]=0;b=Ya(1078,d|0,E(e),b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}x[c>>2]=b;return 1}Y(T(0)|0)|0;x[31785]=0;V(992,10363,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function T3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{c:{if(b){if(et(a)){break c}}if(m){if(dt(a)){break c}}if(l){if(ct(a)){break c}}if(k){if(bt(a)){break c}}if(j){if(at(a)){break c}}if(i){if($s(a)){break c}}if(h){if(Kh(a)){break c}}if(g){if(_s(a)){break c}}if(f){if(Zs(a)){break c}}if(!e){break b}if(!Ys(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function hT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=-1;a:{if(!(y[b+851|0]&2)){break a}d=x[a+480208>>2]&8192;b:{c:{f=x[b+656>>2];if(f){c=y[f+22|0];if(Cd(c)){g=b,h=Sh(c),v[g+838|0]=h;c=1}else{c=!d}d=y[f+21|0];if(Cd(d)){g=b,h=Sh(d),v[g+837|0]=h;break c}if(c){break c}break b}c=!d;x[b+776>>2]=0;x[b+780>>2]=0;break b}c=1;d=y[f+25|0];if((d|0)==255){break b}v[b+845|0]=d}d:{if(y[b+837|0]>=127){if(Pb(a+1074312|0,36)&c){break d}break a}if(!c){break a}}e=wq(a,b,1,256);if((e|0)<0){break a}e=y[b+837|0]>>>1|0}return e}function MH(a,b,c,d,e){var f=0,g=0,h=0;g=fb-16|0;fb=g;h=Fb(a);a=0;a:{b:{c:{d:{while(1){f=x[b>>2];if(Qd(f,x[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){f=Dd(f,0);break e}x[31785]=0;P(d|0,h|0,c|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break b}f=Dd(x[b>>2],a)}x[31785]=0;O(e|0,g+4|0,f|0);f=x[31785];x[31785]=0;if((f|0)!=1){x[31785]=0;P(d|0,h|0,g+4|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break d}a=a+1|0;tb(g+4|0);continue}break}a=N()|0;break a}a=N()|0;tb(g+4|0);break a}fb=g+16|0;return}a=N()|0}tb(h);Q(a|0);p()}function Qoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=fb-32|0;fb=e;jd(b,0);d=e+8|0;yD(d,a+1|0);c=e+20|0;Ec(c,d);ye(b+43|0,c);tb(c);x[b+24>>2]=y[a+73|0]|y[a+74|0]<<8|(y[a+75|0]<<16|y[a+76|0]<<24);c=y[a+54|0]|y[a+55|0]<<8|(y[a+56|0]<<16|y[a+57|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);d=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);if(d){x[b+8>>2]=d+1}w[b+30>>1]=(y[a+68|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;vc(b+8|0,c);vc(b+4|0,x[b+8>>2]);fb=e+32|0}function Vm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function Vk(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(y[a+35|0]&2)){break a}np(a)}d=z[a+34>>1]&-513|d;w[a+34>>1]=d;if(b){x[a>>2]=4;w[a+34>>1]=d&65470;Bh(a);b=y[c+8|0]|y[c+9|0]<<8|(y[c+10|0]<<16|y[c+11|0]<<24);v[a+76|0]=b;v[a+77|0]=b>>>8;v[a+78|0]=b>>>16;v[a+79|0]=b>>>24;b=y[c+4|0]|y[c+5|0]<<8|(y[c+6|0]<<16|y[c+7|0]<<24);c=y[c|0]|y[c+1|0]<<8|(y[c+2|0]<<16|y[c+3|0]<<24);v[a+68|0]=c;v[a+69|0]=c>>>8;v[a+70|0]=c>>>16;v[a+71|0]=c>>>24;v[a+72|0]=b;v[a+73|0]=b>>>8;v[a+74|0]=b>>>16;v[a+75|0]=b>>>24}}function Mfa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{b:{if(!a){a=xg(22485);break b}x[31785]=0;c=P(37,b+8|0,a|0)|0;a=x[31785];x[31785]=0;c:{d:{if((a|0)!=1){x[31785]=0;O(991,b+20|0,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break d}d=b+20|0;a=xg(Jb(d));tb(d);tb(c);break b}a=T(0)|0;break c}a=T(0)|0;tb(c)}Y(a|0)|0;a=0;x[31785]=0;V(992,11025,0,0,0);c=x[31785];x[31785]=0;if((c|0)==1){break a}Z()}fb=b+32|0;return a|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function TG(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=pf(f+20|0,1,0);a:{b:{while(1){g=Jb(e);VB(f+12|0,g,Bb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=ni(Bb(x[e+4>>2],y[e+11|0]));x[31785]=0;O(46,e|0,g|0);g=x[31785];x[31785]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31785]=0;O(47,e|0,b-c|0);b=x[31785];x[31785]=0;c:{if((b|0)!=1){x[31785]=0;O(d|0,a|0,e|0);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function JG(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=pf(f+20|0,1,0);a:{b:{while(1){g=Jb(e);pN(f+12|0,g,Bb(x[e+4>>2],y[e+11|0])+g|0,x[b>>2],c);if(!x[f+16>>2]){break b}g=ni(Bb(x[e+4>>2],y[e+11|0]));x[31785]=0;O(46,e|0,g|0);g=x[31785];x[31785]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31785]=0;O(47,e|0,b-c|0);b=x[31785];x[31785]=0;c:{if((b|0)!=1){x[31785]=0;O(d|0,a|0,e|0);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function ts(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;a=XN(a);x[a+8>>2]=0;x[a>>2]=47932;x[31785]=0;i=R(859,104)|0;h=x[31785];x[31785]=0;a:{b:{c:{d:{if((h|0)!=1){x[31785]=0;d=R(1108,d|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break d}x[g+8>>2]=d;d=x[oe(g+12|0,g+8|0)>>2];x[31785]=0;b=ha(f|0,i|0,b|0,c|0,d|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}x[a+8>>2]=b;Uc(g+8|0);b=x[a+8>>2];Vd(a,b?b+8|0:0);fb=g+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Uc(g+8|0)}Db(i)}Lm(a);Q(b|0);p()}function bH(a,b,c,d){var e=0,f=0,g=0;f=fb-32|0;fb=f;e=pf(f+20|0,1,0);a:{b:{while(1){g=Jb(e);VB(f+12|0,g,Bb(x[e+4>>2],y[e+11|0])+g|0,y[b|0],c);if(!x[f+16>>2]){break b}g=ni(Bb(x[e+4>>2],y[e+11|0]));x[31785]=0;O(46,e|0,g|0);g=x[31785];x[31785]=0;if((g|0)!=1){continue}break}break a}b=x[f+12>>2];c=Jb(e);x[31785]=0;O(47,e|0,b-c|0);b=x[31785];x[31785]=0;c:{if((b|0)!=1){x[31785]=0;O(d|0,a|0,e|0);a=x[31785];x[31785]=0;if((a|0)!=1){break c}break a}break a}tb(e);fb=f+32|0;return}a=N()|0;tb(e);Q(a|0);p()}function fN(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;a:{b:{c:{a=x[a+32>>2];c=gq(a);d:{if(!c){if(fq(a)>>>0<=b>>>0){break d}c=(y[ri(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ac(8);x[31785]=0;b=P(37,d+4|0,6020)|0;c=x[31785];x[31785]=0;e:{if((c|0)!=1){nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break e}c=N()|0;jc(a)}Q(c|0);p()}a=x[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(y[a+15|0]&2)>>>1|0}fb=d+16|0;return c|0}p()}function Mna(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=fb-48|0;fb=f;rr(f+12|0,c);x[31785]=0;c=f+24|0;O(600,c|0,d|0);d=x[31785];x[31785]=0;b:{c:{d:{if((d|0)==1){break d}x[31785]=0;c=f+36|0;O(600,c|0,e|0);d=x[31785];x[31785]=0;if((d|0)==1){break d}hx(f+4|0,f+12|0);x[31785]=0;V(304,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}Nn(f+12|0);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;Nn(f+12|0)}Q(a|0);p()}}function U1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=fb-48|0;fb=f;Cp(f+12|0,c);x[31785]=0;c=f+24|0;O(136,c|0,d|0);d=x[31785];x[31785]=0;b:{c:{d:{if((d|0)==1){break d}x[31785]=0;c=f+36|0;O(136,c|0,e|0);d=x[31785];x[31785]=0;if((d|0)==1){break d}hx(f+4|0,f+12|0);x[31785]=0;V(95,a|0,b|0,x[f+4>>2],x[f+8>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}Nn(f+12|0);fb=f+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(f+12|0)){continue}break}break b}a=N()|0;Nn(f+12|0)}Q(a|0);p()}}function Io(a){var b=0,c=0,d=0,e=0;d=z[x[a+4>>2]+28>>1]>>>(!y[a+77|0]<<1)|0;b=((d&3)<<4)+26432|0;x[a+40>>2]=b;e=z[a+24>>1];d=d>>>2|0;c=e+d|0;w[a+36>>1]=c>>>0<12?1:1<<c-12;c=12-c|0;c=c>>>0<=12?c:0;w[a+32>>1]=c;w[a+34>>1]=-1<<c^-1;if((e|0)==15){w[a+36>>1]=4095}x[a+52>>2]=b;x[a+64>>2]=b;b=d+z[a+26>>1]|0;w[a+48>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;c=b>>>0<=12?b:0;w[a+44>>1]=c;b=d+z[a+30>>1]|0;w[a+60>>1]=b>>>0<12?1:1<<b-12;b=12-b|0;b=b>>>0<=12?b:0;w[a+56>>1]=b;w[a+46>>1]=-1<<c^-1;w[a+58>>1]=-1<<b^-1}function _1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-32|0;fb=c;a:{b:{c:{d:{if(f=yd(x[b+4>>2],y[b+11|0]),g=1,h=x[b+12>>2],h?f:g){Fb(a);break d}d=Bb(x[b+4>>2],y[b+11|0]);e=Or(14453);$l(Tg(Tg(Jb(yz(c+20|0,d+e|0)),Jb(b),d)+d|0,14453,e)+e|0,1,0);x[31785]=0;O(129,c+8|0,b+12|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}x[31785]=0;S(2,a|0,c+20|0,c+8|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}tb(c+8|0);tb(c+20|0)}fb=c+32|0;return}b=N()|0;break a}b=N()|0;tb(c+8|0)}tb(c+20|0);Q(b|0);p()}function UO(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;e=Nb(a);de(c+24|0);a=0;b=x[c+28>>2];d=x[c+24>>2];x[31785]=0;O(179,e|0,RL(d,b)|0);b=x[31785];x[31785]=0;a:{if((b|0)!=1){b:{while(1){b=x[c+24>>2];if((RL(b,x[c+28>>2])|0)<=(a|0)){fb=c+32|0;return}b=x[b+(a<<3)>>2];x[31785]=0;b=P(37,c+12|0,b|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){x[31785]=0;O(181,e|0,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break b}tb(b);a=a+1|0;continue}break}a=N()|0;break a}a=N()|0;tb(b);break a}a=N()|0}Pd(e);Q(a|0);p()}function KU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=x[a+8>>2]-1|0;e=x[a+12>>2];f=x[a>>2]+D(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=D(e,g);i=x[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!y[a+16|0]){d=1;c=0;break c}d=-1;c=c-(y[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=y[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{v[b+f|0]=y[x[a+4>>2]+(D(c,e)+b|0)|0];b=b+1|0;e=x[a+12>>2];continue}}break}}function ss(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;a=XN(a);x[a+8>>2]=0;x[a>>2]=47932;x[31785]=0;h=R(859,104)|0;g=x[31785];x[31785]=0;a:{b:{c:{d:{if((g|0)!=1){x[31785]=0;c=R(1108,c|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break d}x[f+8>>2]=c;c=x[oe(f+12|0,f+8|0)>>2];x[31785]=0;b=ba(e|0,h|0,b|0,c|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}x[a+8>>2]=b;Uc(f+8|0);b=x[a+8>>2];Vd(a,b?b+8|0:0);fb=f+16|0;return a}b=N()|0;break a}b=N()|0;break b}b=N()|0;Uc(f+8|0)}Db(h)}Lm(a);Q(b|0);p()}function sra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-32|0;fb=c;e=c+12|0;f=Nb(e+8|0);x[31785]=0;d=R(205,b|0)|0;g=x[31785];x[31785]=0;a:{b:{if((g|0)==1){break b}x[31785]=0;S(172,e|0,b|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break b}d=x[e>>2];x[31785]=0;P(186,b|0,d|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break a}}a=N()|0;dc(f);Q(a|0);p()}Fn(c+4|0,e);x[31785]=0;S(479,a|0,x[c+4>>2],x[c+8>>2]);a=x[31785];x[31785]=0;if((a|0)!=1){Jc(c+12|0);fb=c+32|0;return}a=N()|0;Jc(c+12|0);Q(a|0);p()}function U3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b&512;f=b&256;g=b&128;h=b&64;i=b&32;j=b&16;k=b&8;l=b&4;m=b&2;b=b&1;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];b:{if(b){if(et(a)){break b}}if(m){if(dt(a)){break b}}if(l){if(ct(a)){break b}}if(k){if(bt(a)){break b}}if(j){if(at(a)){break b}}if(i){if($s(a)){break b}}if(h){if(Kh(a)){break b}}if(g){if(_s(a)){break b}}if(f){if(Zs(a)){break b}}if(e){if(Ys(a)){break b}}c=c+4|0;continue}break}d=c}return d|0}function Gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=E(0);e=fb-16|0;fb=e;f=Bf(a,c);Yd(e,x[a+36>>2]);h=a;a:{if(!f){Pc(e,a+32|0,5);c=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}c=0;d=fb-16|0;fb=d;g=x[a+36>>2];ll(g,d+8|0);i=d,j=Bc(x[d+8>>2],x[d+12>>2]),x[i+4>>2]=j;x[d>>2]=256;vk(b,x[Gb(d+4|0,d)>>2]);a=x[b>>2];while(1){if(oc(a,x[b+4>>2])>>>0<=c>>>0){fb=d+16|0}else{x[d+4>>2]=0;jq(g,d+4|0);a=x[b>>2];i=wb(a,c),k=B[d+4>>2],B[i>>2]=k;c=c+1|0;continue}break}c=f}cf(h,c);fb=e+16|0}function Qs(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}h=x[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((cp(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=gy(i+4|0,b,f);h=Jb(f);x[31785]=0;h=U(1238,a|0,h|0,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break a}Sb(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((cp(a,c,b)|0)!=(b|0)){break b}}XD(e);j=a}fb=i+16|0;return j|0}a=N()|0;Sb(f);Q(a|0);p()}function $M(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-32|0;fb=d;C[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31785]=0;d=P(37,d+8|0,10745)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,d);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}a=x[a+32>>2];x[d+8>>2]=0;x[d+12>>2]=-1074790400;x[d>>2]=0;x[d+4>>2]=1072693248;e=(a+D(b,872)|0)+1075684|0,f=Xi(C[Ug(d+24|0,d+8|0,d)>>3]*128+128),x[e>>2]=f;fb=d+32|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function GR(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;a:{f=b-1&65535;if(f>>>0>3998){break a}c=D(b,104)+a|0;e=c+484380|0;if(!ge(x[e>>2],x[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){hn(e);x[e>>2]=0;a=(D(b,104)+a|0)+484414|0;w[a>>1]=z[a>>1]&65470;x[d+24>>2]=0;x[d+8>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d>>2]=0;x[d+4>>2]=0;Vk(e,0,d);break a}if(x[c+104>>2]==(e|0)){x[c+76>>2]=0;x[c>>2]=0;x[c+4>>2]=0;x[c+16>>2]=0}c=c+872|0;continue}}fb=d+32|0;return f>>>0<3999}function wM(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=x[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(A[a+12>>2]<=d>>>0)){while(1){f=GA(x[a>>2]);e=hb;c=x[a+36>>2];if((e|0)==(c|0)&A[a+32>>2]<=f>>>0|e>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){f=GA(x[a>>2]);d=hb;c=x[a+28>>2];if((d|0)==(c|0)&A[a+24>>2]<=f>>>0|d>>>0>c>>>0){continue}break}c=b;b=x[a+8>>2];b=(f&x[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function S6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Bb(x[a+4>>2],y[a+11|0]);d=kn(a);f=Od(b,c);a:{if(!f){break a}b:{if(!oJ(a,b)){if(d-e>>>0<f>>>0){ay(a,d,(e+f|0)-d|0,e,e,0)}d=Jb(a)+(e<<2)|0;while(1){if((b|0)==(c|0)){break b}vd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=Xn(g+4|0,b,c);c=Jb(b);e=y[b+11|0];d=x[b+4>>2];x[31785]=0;U(1256,a|0,c|0,Bb(d,e)|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){Sb(b);break a}a=N()|0;Sb(b);Q(a|0);p()}vd(d,0);jg(a,e+f|0)}fb=g+16|0;return a|0}function kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;f=e+8|0;_i(f,2,a+2|0);d=e+20|0;Ec(d,f);zc(b+492|0,d);f=b+236|0;g=c+1|0;tb(d);c=0;while(1){if((c|0)==120){x[b>>2]=(y[a+223|0]|y[a+224|0]<<8)<<5;a=a+158|0;fR(y[a|0]&15,y[a+1|0]&15,y[a+2|0]&15,y[a+3|0]&15,y[a+4|0]&15,a+5|0,b+48|0);fR(y[a|0]>>>4|0,y[a+1|0]>>>4|0,y[a+2|0]>>>4|0,y[a+3|0]>>>4|0,y[a+4|0]>>>4|0,a+35|0,b+68|0);fb=e+32|0}else{d=y[(a+c|0)+31|0];h=_b(f,c),i=d+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function Y6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;g=fb-16|0;fb=g;e=Bb(x[a+4>>2],y[a+11|0]);d=Lc(a);f=Tj(b,c);a:{if(!f){break a}b:{if(!Dz(a,b)){if(d-e>>>0<f>>>0){Nm(a,d,(e+f|0)-d|0,e,e,0,0)}d=Jb(a)+e|0;while(1){if((b|0)==(c|0)){break b}ed(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=pi(g+4|0,b,c);c=Jb(b);e=y[b+11|0];d=x[b+4>>2];x[31785]=0;U(1249,a|0,c|0,Bb(d,e)|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}ed(d,0);jg(a,e+f|0)}fb=g+16|0;return a|0}function v0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-32|0;fb=d;jd(b,0);e=d+8|0;ui(e,1,a+33|0);c=d+20|0;Ec(c,e);ye(b+43|0,c);tb(c);f=y[a+50|0]|y[a+51|0]<<8;x[b>>2]=f;x[b+24>>2]=y[a+52|0]|y[a+53|0]<<8;v[d+20|0]=y[a+54|0];v[d+8|0]=64;g=b,h=y[Ub(c,e)|0]<<2,w[g+30>>1]=h;e=y[a+55|0]|y[a+56|0]<<8;x[b+4>>2]=e;c=y[a+57|0]|y[a+58|0]<<8;x[b+8>>2]=c;a:{if((c|0)==65535){x[b+4>>2]=0;x[b+8>>2]=0;break a}if(!y[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0){break a}w[b+34>>1]=z[b+34>>1]|2}fb=d+32|0}function sW(a){var b=0,c=0;a:{if(Ob(a+60|0,13923,4)){break a}b=y[a+28|0]|y[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=y[a+42|0];if(b>>>0>64&(b|0)!=88|(y[a+48|0]|y[a+49|0]<<8)>>>0>64|(y[a+50|0]|y[a+51|0]<<8)>>>0>96){break a}b=y[a+52|0]|y[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(y[a+30|0]|y[a+31|0]<<8)|(y[a+38|0]|y[a+39|0]<<8|(y[a+40|0]<<16|y[a+41|0]<<24)|(y[a+44|0]|y[a+45|0]<<8|(y[a+46|0]<<16|y[a+47|0]<<24))!=1)){break a}c=vW(a+20|0)}return c}function fx(a){var b=0,c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){b=fb-16|0;fb=b;a=ZF(b+4|0,a);c=x[a+4>>2];x[31785]=0;W(167,c|0);c=x[31785];x[31785]=0;a:{if((c|0)!=1){x[a+4>>2]=x[a+4>>2]+36;hc(a);fb=b+16|0;break a}b=N()|0;hc(a);Q(b|0);p()}return}c=fb-32|0;fb=c;b=Ab(a);b=XF(c+12|0,YF(a,Sr(x[a>>2],x[a+4>>2])+1|0),Sr(x[a>>2],x[a+4>>2]),b);d=x[b+8>>2];x[31785]=0;W(167,d|0);d=x[31785];x[31785]=0;b:{if((d|0)!=1){x[b+8>>2]=x[b+8>>2]+36;WF(a,b);Uw(b);fb=c+32|0;break b}a=N()|0;Uw(b);Q(a|0);p()}}function Vf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e}function Yo(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=fb-16|0;fb=g;f=(y[xb(b,0)|0]&15)<<8|y[xb(b,1)|0];d=0;a:{if(!f){break a}d=0;if((f|0)==4095){break a}while(1){d=108;if((e|0)==84){break a}b:{d=z[(e<<1)+31344>>1];if(f>>>0>=d>>>0){if(!e|(f|0)==(d|0)|(z[(e<<1)+31342>>1]-f|0)>=(f-d|0)){break b}d=e+24|0;break a}e=e+1|0;continue}break}d=e+25|0}v[c|0]=d;e=y[xb(b,2)|0];d=y[xb(b,0)|0];v[c+3|0]=0;v[c+1|0]=d&16|e>>>4;c=y[xb(b,2)|0];h=g,i=y[xb(b,3)|0],v[h+15|0]=i;ae(a,c&15,g+15|0);fb=g+16|0}function UR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=x[a+104>>2];d=(g<<3)+a|0;b=((g+7>>>0)%12<<3)+a|0;f=x[b>>2];e=x[b+4>>2];b=x[a+100>>2];j=b;h=x[a+96>>2];a:{if(!(b|h)){c=x[d+4>>2];b=x[d>>2];i=(c|0)==(e|0)&b>>>0>f>>>0|e>>>0<c>>>0;break a}c=x[d+4>>2];b=x[d>>2];i=!(e|f)|((c|0)==(e|0)&b>>>0>=f>>>0|e>>>0<c>>>0)}c=c+j|0;b=b+h|0;c=b>>>0<h>>>0?c+1|0:c;x[d>>2]=f-b;x[d+4>>2]=e-(c+(b>>>0>f>>>0)|0)&65535;x[a+104>>2]=(g+1>>>0)%12;x[a+96>>2]=i;x[a+100>>2]=0;hb=x[d+4>>2];return x[d>>2]}function xia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-48|0;fb=f;d=x[a+36>>2];eg(x[x[d>>2]-12>>2]+d|0,0);e=x[b>>2];d=x[e+8>>2];e=x[e+12>>2];g=e;if(d|e){h=x[a+36>>2];g=x[a+20>>2]+g|0;e=x[a+16>>2];d=d+e|0;e=ei(f+32|0,d,d>>>0<e>>>0?g+1|0:g);d=x[e+12>>2];x[f+8>>2]=x[e+8>>2];x[f+12>>2]=d;d=x[e+4>>2];x[f>>2]=x[e>>2];x[f+4>>2]=d;Qm(h,f)}d=f+16|0;Yd(d,x[a+36>>2]);IB(x[a+36>>2],c,x[x[b>>2]+16>>2]);c=x[b>>2];b=ol(d,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);cf(a,c);Eb(b);fb=f+48|0}function nA(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-48|0;fb=e;a:{if(!c){b=Ud(x[a>>2],b);a=x[d+12>>2];x[b+8>>2]=x[d+8>>2];x[b+12>>2]=a;a=x[d+4>>2];x[b>>2]=x[d>>2];x[b+4>>2]=a;break a}f=x[d+12>>2];x[e+24>>2]=x[d+8>>2];x[e+28>>2]=f;f=x[d+4>>2];x[e+16>>2]=x[d>>2];x[e+20>>2]=f;f=c>>>1|0;nA(a,b,f,e+16|0);g=C[d>>3];h=C[d+8>>3];d=Ud(x[a>>2],c);Oi(e+32|0,g,h,C[d>>3],C[d+8>>3]);d=x[e+44>>2];x[e+8>>2]=x[e+40>>2];x[e+12>>2]=d;d=x[e+36>>2];x[e>>2]=x[e+32>>2];x[e+4>>2]=d;nA(a,b|c,f,e)}fb=e+48|0}function $qa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=$d(a);a:{if(d){b=ec(f);while(1){a=d;d=z[a+16>>1];if(To(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!To(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){aZ(c,f,e+4|0);Xg(f,x[c+12>>2],b,x[c>>2]);a=ie(c);$Y(c);h=1}Wg(e+8|0,x[zb(c,a)>>2],h);fb=c+16|0;a=qd(x[e+8>>2]);fb=e+16|0;return a+4|0}function PQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;i=e,j=Vj(b),x[i+4>>2]=j;g=z[b>>1];c=fb-16|0;fb=c;f=a;d=$d(a);a:{if(d){b=ec(f);while(1){a=d;d=z[a+16>>1];if(Jq(g,d)){b=a;d=x[a>>2];if(d){continue}break a}if(!Jq(d,g)){break a}b=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(f);b=a}x[c+12>>2]=a;a=x[b>>2];if(!a){aZ(c,f,e+4|0);Xg(f,x[c+12>>2],b,x[c>>2]);a=ie(c);$Y(c);h=1}Wg(e+8|0,x[zb(c,a)>>2],h);fb=c+16|0;a=qd(x[e+8>>2]);fb=e+16|0;return a+4|0}function EF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;g=x[b+16>>2];x[a+4>>2]=0;x[a>>2]=g;a:{if(!g){break a}e=b+80|0;c=x[b+84>>2];if(c>>>0<=15){d=x[e>>2]}else{x[f+12>>2]=c-16;d=x[_c(e,f+12|0)>>2]}x[a+8>>2]=d;c=x[b+88>>2];if(!(c&2)){break a}d=c;c=x[b+104>>2];b:{if(!(!CF(d,c)|x[e>>2]!=x[c+12>>2])){e=1;d=x[b+84>>2];if((d|0)==x[c+16>>2]){break b}}e=0;d=x[b+84>>2];if((d|0)!=x[c+8>>2]){break a}}h=a,i=D((x[c>>2]-d|0)+(e?112:48)|0,$k(z[c+34>>1]))+g|0,x[h+4>>2]=i}fb=f+16|0}function Opa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=fb+-64|0;fb=d;b=-1;a:{if(!sm(a,1084)){break a}Wl(a,1080);c=d+60|0;SX(a,c);f=RX(d+40|0);b=0;if(!QX(c,f)){break a}Wl(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=A[f+4>>2]>=h>>>0}else{c=y[f+16|0];e=fb-16|0;fb=e;b:{g=d+10|0;if(!OX(a,g)|!c){break b}rv(e+8|0,g);c=0;while(1){if(c>>>0>=30){break b}i=x[e+8>>2];og(xb(i,c),xb(i,c|1));c=c+2|0;continue}}fb=e+16|0;b=b+1|0;h=IC(g)+h|0;continue}break}}fb=d- -64|0;return b|0}function saa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Xi(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=D(g,h);e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e+m<<2)+k|0;f=x[i>>2];f=tua(sua(f,f>>31,d,j),hb,65536,0);n=i,o=Fc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;nM(a,c);fb=c+16|0}function Baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=fb-16|0;fb=c;a:{d=Xi(C[a+24>>3]*65536);if((d|0)==65536){break a}j=d>>31;k=x[b>>2];h=x[b+4>>2];l=x[b+8>>2];b:while(1){if((g|0)==(l|0)){break a}m=D(g,h);e=0;while(1)if((e|0)==(h|0)){g=g+1|0;continue b}else{i=(e+m<<2)+k|0;f=x[i>>2];f=tua(sua(f,f>>31,d,j),hb,65536,0);n=i,o=Fc(f,hb),x[n>>2]=o;e=e+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;tM(a,c);fb=c+16|0}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];eg(x[x[e>>2]-12>>2]+e|0,0);f=x[b>>2];e=x[f+8>>2];f=x[f+12>>2];h=f;if(e|f){i=x[a+36>>2];h=x[a+20>>2]+h|0;f=x[a+16>>2];e=e+f|0;f=ei(g+32|0,e,e>>>0<f>>>0?h+1|0:h);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;Qm(i,g)}e=g+16|0;Yd(e,x[a+36>>2]);KQ(d,x[a+36>>2],c);c=x[b>>2];b=ol(e,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);cf(a,c);Eb(b);fb=g+48|0}function wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=fb-48|0;fb=g;e=x[a+36>>2];eg(x[x[e>>2]-12>>2]+e|0,0);f=x[b>>2];e=x[f+8>>2];f=x[f+12>>2];h=f;if(e|f){i=x[a+36>>2];h=x[a+20>>2]+h|0;f=x[a+16>>2];e=e+f|0;f=ei(g+32|0,e,e>>>0<f>>>0?h+1|0:h);e=x[f+12>>2];x[g+8>>2]=x[f+8>>2];x[g+12>>2]=e;e=x[f+4>>2];x[g>>2]=x[f>>2];x[g+4>>2]=e;Qm(i,g)}e=g+16|0;Yd(e,x[a+36>>2]);FQ(c,x[a+36>>2],d);c=x[b>>2];b=ol(e,xb(x[a+40>>2],x[c>>2]),z[c+20>>1]);cf(a,c);Eb(b);fb=g+48|0}function xm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;a:{b:{c:{d=kn(a);e=Od(b,c);if(d>>>0<e>>>0){if(oJ(a,b)){break c}g=d;h=e-d|0;d=Bb(x[a+4>>2],y[a+11|0]);ay(a,g,h,d,0,d)}d=Jb(a);while(1){if((b|0)==(c|0)){break b}vd(d,x[b>>2]);b=b+4|0;d=d+4|0;continue}}b=Xn(f+4|0,b,c);c=Jb(b);d=y[b+11|0];e=x[b+4>>2];x[31785]=0;S(1361,a|0,c|0,Bb(e,d)|0);c=x[31785];x[31785]=0;if((c|0)!=1){Sb(b);break a}a=N()|0;Sb(b);Q(a|0);p()}vd(d,0);jg(a,e)}fb=f+16|0;return a|0}function vN(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=c-b|0;a:{if((f|0)<=19){i=D(64-Mt(d|1,e)|0,1233)>>>12|0;j=(i<<3)+124272|0;g=f;f=x[j+4>>2];h=61;if((g|0)<(((e|0)==(f|0)&d>>>0>=A[j>>2]|e>>>0>f>>>0)+i|0)){break a}}b:{if(!e){c=pB(b,d);break b}if((e|0)==2&d>>>0>=1410065408|e>>>0>2){c=uua(d,e,1410065408,2);f=sua(c,hb,-1410065408,-3);e=e+hb|0;g=d;d=d+f|0;e=g>>>0>d>>>0?e+1|0:e;b=pB(b,c)}c=uua(d,e,1e8,0);e=hb;b=Gl(b,c);c=sua(c,e,-1e8,0)+d|0;c=yu(b,c)}h=0}x[a+4>>2]=h;x[a>>2]=c}function fw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Cd(y[a+11|0])){c=y[b+11|0];if(!Cd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Jb(b);b=Bb(x[b+4>>2],c);a:{if(b>>>0<=10){Ke(a,b);ed(yg(a,d,b)+b|0,0);break a}e=a;a=Sh(y[a+11|0]);Mp(e,10,b-10|0,a,0,a,b,d)}return}d=Jb(b);b=Bb(x[b+4>>2],y[b+11|0]);c=bj(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Vd(a,b);ed(yg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];Mp(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function bs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((a|0)!=(b|0)){if(!Cd(y[a+11|0])){c=y[b+11|0];if(!Cd(c)){d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];return}d=Jb(b);b=Bb(x[b+4>>2],c);a:{if(b>>>0<=10){Ke(a,b);ed(Tg(a,d,b)+b|0,0);break a}e=a;a=Sh(y[a+11|0]);Dq(e,10,b-10|0,a,0,a,b,d)}return}d=Jb(b);b=Bb(x[b+4>>2],y[b+11|0]);c=bj(x[a+8>>2]);b:{if(b>>>0<c>>>0){c=x[a>>2];Vd(a,b);ed(Tg(c,d,b)+b|0,0);break b}e=a;a=x[a+4>>2];Dq(e,c-1|0,(b-c|0)+1|0,a,0,a,b,d)}}}function XO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;a:{b:{c:{d=Lc(a);e=Tj(b,c);if(d>>>0<e>>>0){if(Dz(a,b)){break c}g=d;h=e-d|0;d=Bb(x[a+4>>2],y[a+11|0]);Nm(a,g,h,d,0,d,0)}d=Jb(a);while(1){if((b|0)==(c|0)){break b}ed(d,y[b|0]);b=b+1|0;d=d+1|0;continue}}b=pi(f+4|0,b,c);c=Jb(b);d=y[b+11|0];e=x[b+4>>2];x[31785]=0;S(75,a|0,c|0,Bb(e,d)|0);c=x[31785];x[31785]=0;if((c|0)!=1){tb(b);break a}a=N()|0;tb(b);Q(a|0);p()}ed(d,0);jg(a,e)}fb=f+16|0;return a|0}function VX(a,b,c,d){var e=0,f=0;f=fb-16|0;fb=f;e=z[c>>1];while(1){a:{e=e<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!xf(a,f+15|0)){break a}e=y[f+15|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;w[c>>1]=y[c|0]}v[d|0]=y[b|0]+(y[d|0]<<1);e=z[c>>1]<<1;w[c>>1]=e;v[b|0]=(e&65534)>>>0>255;e=y[c|0];w[c>>1]=e;if(!e){if(!xf(a,f+14|0)){break a}e=y[f+14|0];w[c>>1]=e<<1|1;v[b|0]=e>>>7;e=y[c|0];w[c>>1]=e;if(y[b|0]){continue}break a}if(y[b|0]){continue}}break}fb=f+16|0}function GH(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;x[31785]=0;W(1005,a|0);j=x[31785];x[31785]=0;a:{b:{if((j|0)!=1){c:{j=x[a+24>>2];x[31785]=0;ga(h|0,i+4|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}a=i+4|0;b=xg(Jb(a));tb(a);break b}}Y(T(0)|0)|0;b=0;x[31785]=0;V(992,g|0,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z()}fb=i+16|0;return b}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function e7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;c=fb-128|0;fb=c;x[c+12>>2]=c+116;d=c+16|0;JJ(x[a+8>>2],d,c+12|0,e,f,g);f=fb-16|0;fb=f;h=f+8|0;a=fb-32|0;fb=a;Sp(a+24|0,d,x[c+12>>2]);i=a+16|0;e=x[a+24>>2];g=x[a+28>>2];d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if((e|0)!=(g|0)){VK(d+12|0,v[e|0]);e=e+1|0;continue}break}Qj(i,g,d+12|0);fb=d+16|0;b=x[a+16>>2];x[a+12>>2]=x[a+20>>2];Td(h,b,a+12|0);fb=a+32|0;fb=f+16|0;fb=c+128|0;return x[f+12>>2]}function dw(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=fb-16|0;fb=i;a:{b:{if(!a){break b}g=x[e+12>>2];h=c-b|0;if((h|0)>0){if((cp(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=pf(i+4|0,b,f);g=Jb(f);x[31785]=0;g=U(32,a|0,g|0,b|0)|0;h=x[31785];x[31785]=0;if((h|0)==1){break a}tb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((cp(a,c,b)|0)!=(b|0)){break b}}XD(e);j=a}fb=i+16|0;return j|0}a=N()|0;tb(f);Q(a|0);p()}function PG(a,b,c,d,e,f){var g=0;a:{g=fb-48|0;fb=g;Tn(g+12|0,c);x[31785]=0;c=g+24|0;O(f|0,c|0,d|0);d=x[31785];x[31785]=0;b:{c:{d:{if((d|0)==1){break d}x[31785]=0;c=g+36|0;O(94,c|0,e|0);d=x[31785];x[31785]=0;if((d|0)==1){break d}hx(g+4|0,g+12|0);x[31785]=0;V(95,a|0,b|0,x[g+4>>2],x[g+8>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}Nn(g+12|0);fb=g+48|0;break a}a=N()|0;while(1){c=tb(c-12|0);if((c|0)!=(g+12|0)){continue}break}break b}a=N()|0;Nn(g+12|0)}Q(a|0);p()}}function Fta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=fg(d+4|0,c+16|0);f=Wc(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[cc(b,0)|0]==43){break c}if(y[cc(b,0)|0]==45){break c}}x[31785]=0;U(307,b|0,f-c|0,e|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}Yc(a,b);fb=d+16|0}function $J(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31660];x[31660]=0;Kd();a=py(a,e+12|0,d);d=hb;g=x[31660];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}x[31660]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d&a>>>0<65536){break b}}x[c>>2]=4;a=65535;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a&65535}function gna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;a:{g=x[c+12>>2];if(!g){break a}e=nm(d+4|0,c+16|0);f=Wc(x[b+4>>2],y[b+11|0]);h=f-1|0;c=0;while(1){if((c|0)==(f|0)){tb(e);break a}b:{c:{if(!c|(c>>>0)%(g>>>0)){break c}if((c|0)==(h|0)){if(y[cc(b,0)|0]==43){break c}if(y[cc(b,0)|0]==45){break c}}x[31785]=0;U(49,b|0,f-c|0,e|0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break b}}c=c+1|0;continue}break}a=N()|0;tb(e);Q(a|0);p()}Yc(a,b);fb=d+16|0}function bia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a>>2]=42780;b=Nb(a+4208|0);x[a+4236>>2]=-1;x[a+4240>>2]=0;x[a+4228>>2]=1049926264;x[a+4232>>2]=0;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;v[a+4244|0]=0;Tb(a+4248|0,0,48);x[31785]=0;X(857);c=x[31785];x[31785]=0;a:{if((c|0)==1){break a}e=a,f=aS(),x[e+4296>>2]=f;_t(a);Zt(a);x[31785]=0;O(950,a+44|0,2);c=x[31785];x[31785]=0;if((c|0)==1){break a}return a|0}c=N()|0;dc(b);Uf(a);Q(c|0);p()}function FH(a,b,c,d,e,f,g){var h=0,i=0;h=fb-16|0;fb=h;x[31785]=0;W(1005,a|0);i=x[31785];x[31785]=0;a:{b:{if((i|0)!=1){c:{i=x[x[a+24>>2]+24>>2];x[31785]=0;ja(g|0,h+4|0,i|0,b|0,c|0,d|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}a=h+4|0;b=xg(Jb(a));tb(a);break b}}Y(T(0)|0)|0;b=0;x[31785]=0;V(992,f|0,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z()}fb=h+16|0;return b}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function WS(a,b){var c=0,d=0,e=0,f=0,g=0;a:{if(y[b+791|0]!=27){a=v[b+831|0];break a}e=a+1074312|0;c=Pb(e,21);d=a;a=y[b+821|0];a=xA(d,y[b+828|0],c?a:a+16>>>2|0);b:{if(!(!Pb(e,45)|y[b+828|0]!=3)){c=y[b+821|0];c:{if(!(!c|c>>>0>=y[b+829|0])){a=y[b+832|0];d=c+1|0;break c}v[b+832|0]=a;d=1}v[b+821|0]=d;a=a<<24>>24;break b}v[b+821|0]=y[b+821|0]+y[b+829|0]}if(!Pb(e,47)){break a}v[b+831|0]=a}if(a){f=b,g=Xb(x[b+684>>2]+((D(y[b+830|0],a)+2|0)/8|0)|0,0,256),x[f+684>>2]=g}}function UQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<=127){f=fb-32|0;fb=f;c=128-c|0;e=x[Ab(a)>>2];d=x[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){fA(a,c,b);break a}e=Ab(a);d=hg(f+12|0,Tf(a,oc(x[a>>2],d)+c|0),oc(x[a>>2],x[a+4>>2]),e);g=fb-16|0;fb=g;c=An(g+4|0,d+8|0,c);e=x[c>>2];while(1){if(x[c+4>>2]!=(e|0)){wk(e,B[b>>2]);e=x[c>>2]+4|0;x[c>>2]=e;continue}break}ee(c);fb=g+16|0;Id(a,d);gg(d)}fb=f+32|0;return}if((c|0)!=128){Yh(a,d+512|0)}}function Pt(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==y[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}if(!(y[a|0]==(b&255)|c>>>0<4)){d=D(b&255,16843009);while(1){e=d^x[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}b=b&255;while(1){if((b|0)==y[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;e=d+4|0;c=fb-32|0;fb=c;f=c+8|0;Of(f,b);x[31785]=0;S(11,c+20|0,0,f|0);b=x[31785];x[31785]=0;a:{b:{c:{if((b|0)!=1){x[31785]=0;O(971,e|0,c+20|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}Sb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Sb(c+20|0)}tb(c+8|0);Q(a|0);p()}x[31785]=0;P(969,a|0,e|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){tb(d+4|0);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function vR(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{if((c|0)<2){break a}i=c-2>>>1|0;e=d-a|0;if((i|0)<e>>1){break a}g=e+1|0;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Bl(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(Bl(b,z[f>>1],z[d>>1])){break a}j=z[d>>1];while(1){b:{e=d;d=f;w[e>>1]=z[f>>1];if((g|0)>(i|0)){break b}e=g<<1;g=e|1;f=(g<<1)+a|0;e=e+2|0;if((e|0)<(c|0)){h=e;e=Bl(b,z[f>>1],z[f+2>>1]);g=e?h:g;f=e?f+2|0:f}if(!Bl(b,z[f>>1],j)){continue}}break}w[d>>1]=j}}function ioa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;bn(c+52|0,b);le(c+24|0,x[c+52>>2],x[c+56>>2]);b=Jd(c+16|0);x[31785]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=dg(163,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31785];x[31785]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31785]=0;S(736,b|0,d|0,Sc(e,a)>>>5|0);a=x[31785];x[31785]=0;if((a|0)==1){a=N()|0;Ui(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function foa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;bn(c+52|0,b);le(c+24|0,x[c+52>>2],x[c+56>>2]);b=Jd(c+16|0);x[31785]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=dg(163,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31785];x[31785]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31785]=0;S(737,b|0,d|0,Sc(e,a)>>>2|0);a=x[31785];x[31785]=0;if((a|0)==1){a=N()|0;sc(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function eoa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;bn(c+52|0,b);le(c+24|0,x[c+52>>2],x[c+56>>2]);b=Jd(c+16|0);x[31785]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=dg(163,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31785];x[31785]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31785]=0;S(738,b|0,d|0,Sc(e,a)>>>8|0);a=x[31785];x[31785]=0;if((a|0)==1){a=N()|0;cv(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function doa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb+-64|0;fb=c;bn(c+52|0,b);le(c+24|0,x[c+52>>2],x[c+56>>2]);b=Jd(c+16|0);x[31785]=0;d=x[b+4>>2];x[c+8>>2]=x[b>>2];x[c+12>>2]=d;b=dg(163,c+32|0,x[c+24>>2],x[c+28>>2],c+8|0);d=x[31785];x[31785]=0;a:{if((d|0)!=1){d=Nb(a);a=x[c+56>>2];e=x[c+52>>2];x[31785]=0;S(739,b|0,d|0,Sc(e,a)>>>4|0);a=x[31785];x[31785]=0;if((a|0)==1){a=N()|0;cn(d);ub(b);break a}ub(b);dc(c+52|0);fb=c- -64|0;return}a=N()|0}dc(c+52|0);Q(a|0);p()}function RK(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(gL()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31785]=0;b=R(1191,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[31785]=0;W(1192,a+b|0);a=x[31785];x[31785]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break a}}return}T(0)|0;Rb();p()}function Poa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-32|0;fb=d;jd(b,0);e=d+8|0;yD(e,a+1|0);c=d+20|0;Ec(c,e);ye(b+43|0,c);tb(c);x[b+24>>2]=y[a+78|0]|y[a+79|0]<<8;c=y[a+58|0]|y[a+59|0]<<8|(y[a+60|0]<<16|y[a+61|0]<<24);x[b>>2]=c;x[b+4>>2]=y[a+62|0]|y[a+63|0]<<8|(y[a+64|0]<<16|y[a+65|0]<<24);x[b+8>>2]=y[a+66|0]|y[a+67|0]<<8|(y[a+68|0]<<16|y[a+69|0]<<24);w[b+30>>1]=(y[a+73|0]<<1)+2;w[b+34>>1]=z[b+34>>1]&65533|y[a|0]>>>6&2;vc(b+8|0,c);vc(b+4|0,x[b+8>>2]);fb=d+32|0}function D0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;c=e+12|0;f=fb-16|0;fb=f;h=Dc(168);x[31785]=0;g=P(37,f+4|0,22485)|0;d=x[31785];x[31785]=0;a:{b:{c:{if((d|0)!=1){x[31785]=0;d=U(38,h|0,g|0,0)|0;i=x[31785];x[31785]=0;if((i|0)==1){break c}tb(g);x[c>>2]=d;cl(d);fb=f+16|0;break a}a=N()|0;break b}a=N()|0;tb(g)}Db(h);Q(a|0);p()}x[31785]=0;S(27,a|0,c|0,b|0);a=x[31785];x[31785]=0;if((a|0)!=1){Zb(c);fb=e+16|0;return}a=N()|0;Zb(c);Q(a|0);p()}function em(a){var b=0,c=0;a:{b=x[a+4>>2];b=x[x[b>>2]-12>>2]+b|0;b:{if(!x[b+24>>2]|x[b+16>>2]|!(y[b+5|0]&32)){break b}if(gL()){break b}b=x[a+4>>2];b=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];x[31785]=0;b=R(31,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=x[a+4>>2];b=x[x[a>>2]-12>>2];x[31785]=0;O(24,a+b|0,1);a=x[31785];x[31785]=0;if((a|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break a}}return}T(0)|0;Rb();p()}function aI(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(1073741806-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=536870886){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=jn(x[_c(i+4|0,i+12|0)>>2])+1|0}else{c=1073741807}Rj(j,c);c=x[i+4>>2];if(e){Wi(c,k,e)}if(g){Wi(c+(e<<2)|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){d=e<<2;Wi((d+c|0)+(g<<2)|0,(d+k|0)+(f<<2)|0,h)}if((b|0)!=1){Db(k)}vd(a,c);nf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Vd(b,a);vd(c+(a<<2)|0,0);fb=i+16|0;return}of();p()}function Uqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=vb(x[b>>2]);h=vb(x[b+4>>2]);g=fb-16|0;fb=g;x[g+12>>2]=d;while(1){a:{if(!Ib(d,h)){break a}e=fb-16|0;fb=e;f=y[d|0]|y[d+1|0]<<8|(y[d+2|0]<<16|y[d+3|0]<<24);v[e+10|0]=f;v[e+11|0]=f>>>8;v[e+12|0]=f>>>16;v[e+13|0]=f>>>24;f=y[d+4|0]|y[d+5|0]<<8;v[e+14|0]=f;v[e+15|0]=f>>>8;fb=e+16|0;if(z[e+10>>1]==(c|0)){break a}d=x[rn(g+12|0)>>2];continue}break}fb=g+16|0;if(mc(d,vb(x[b+4>>2]))){_h(a);return}ep(a,d)}function lT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=fb-16|0;fb=d;j=d,k=Vj(b),x[j+4>>2]=k;c=fb-16|0;fb=c;g=UA(a,c+12|0,y[b|0],x[b+4>>2]);b=x[g>>2];if(!b){e=fb-16|0;fb=e;b=ec(a);h=zh(c,Dc(28),Kg(e+8|0,b));b=x[h>>2];f=x[d+4>>2];i=x[f>>2];f=x[f+4>>2];x[b+24>>2]=0;x[b+16>>2]=i;x[b+20>>2]=f;j=ec(h),k=1,v[j+4|0]=k;fb=e+16|0;Xg(a,x[c+12>>2],g,x[c>>2]);b=ie(c);Xl(c);e=1}Wg(d+8|0,x[zb(c,b)>>2],e);fb=c+16|0;a=qd(x[d+8>>2]);fb=d+16|0;return a+8|0}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=z[a+30>>1];if(d){b=aA(b<<16>>16,d<<16>>16)}w[e+14>>1]=b;a=a+52|0;a:{if(!yd(x[c+4>>2],y[c+11|0])){bs(PQ(a,e+14|0),c);break a}b=bA(a,e+14|0);if(!Vg(b,Jf(a))){break a}c=fb-16|0;fb=c;b=x[zb(c+8|0,b)>>2];d=fb-16|0;fb=d;f=Yg(zb(d+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[f>>2]}g=Ab(a);x[g>>2]=x[g>>2]-1;NU(x[ec(a)>>2],b);a=x[f>>2];fb=d+16|0;Hk(qd(b));Db(b);zb(c+12|0,a);fb=c+16|0}fb=e+16|0}function qua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a:{b:{if(!ih(a,7)){break b}c=0;if(!xE(a,18647)){break a}if(!ih(a,1)){break b}c=-1;if(!fd(a,vr(a))){break a}c=fb-16|0;fb=c;f=d+9|0;ur(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){lE(f)}c=-1;if(!e){break a}c=0;if(!X$(y[d+9|0],y[d+10|0])){break a}c=xe(a,b,W$(d+9|0),hb);break a}c=-1}fb=d+16|0;return c|0}function i9(){var a=0,b=0,c=0,d=0,e=0,f=0;c=fb-48|0;fb=c;if(tL(1,c+24|0)){qt(x[31660],12800);p()}b=te(c+16|0,x[c+24>>2],x[c+28>>2]);f=MA(c+8|0,x[c+32>>2]);d=fb-16|0;fb=d;e=fb-16|0;fb=e;a=te(e+8|0,sua(x[b>>2],x[b+4>>2],1e9,0),hb);b=x[a>>2];a=x[a+4>>2];fb=e+16|0;x[d>>2]=b;x[d+4>>2]=a;a=x[d>>2];e=a+x[f>>2]|0;f=x[f+4>>2]+x[d+4>>2]|0;b=te(d+8|0,e,a>>>0>e>>>0?f+1|0:f);a=x[b>>2];fb=d+16|0;b=te(c+40|0,a,x[b+4>>2]);a=x[b>>2];fb=c+48|0;hb=x[b+4>>2];return a|0}function XJ(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){b:{c:{f=y[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=x[31660];x[31660]=0;Kd();a=py(a,e+12|0,d);d=hb;d:{g=x[31660];if(g){if(x[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}x[c>>2]=4;b=-1;a=-1;break a}x[31660]=h;if(x[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}x[c>>2]=4;b=0;a=0}fb=e+16|0;hb=a;return b}function jaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;d=fb-32|0;fb=d;Vl(d+24|0,a,b);h=d+16|0;e=x[d+24>>2];g=x[d+28>>2];b=fb-16|0;fb=b;x[b+12>>2]=c;a:{while(1){if((e|0)==(g|0)){break a}c=Cc(b,x[e>>2]);x[31785]=0;P(1154,b+12|0,c|0)|0;i=x[31785];x[31785]=0;if((i|0)!=1){tb(c);e=e+4|0;continue}break}a=N()|0;tb(c);Q(a|0);p()}Qj(h,g,b+12|0);fb=b+16|0;b=x[d+16>>2];x[d+12>>2]=x[d+20>>2];Td(f+8|0,cA(a,b),d+12|0);fb=d+32|0;fb=f+16|0}function Qma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=x[b+12>>2]+i|0;f=v[e|0];e=((D(v[e+1|0]-f|0,x[b+8>>2]>>>10&4194048)|0)/16384|0)+(f<<8)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function JE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Xc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){AE(a,b);break a}c=Ab(a);c=hk(e+12|0,ik(a,Xc(x[a>>2],d)+b|0),Xc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=rp(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){Kw(d);d=x[b>>2]+2|0;x[b>>2]=d;continue}break}ee(b);fb=f+16|0;Id(a,c);fj(c)}fb=e+32|0;return}if(b>>>0<c>>>0){xn(a,d+(b<<1)|0)}}function dta(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);x[31785]=0;W(347,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){e=fb-16|0;fb=e;b=e+4|0;x[b>>2]=a;c=x[a+4>>2];x[b+4>>2]=c;x[b+8>>2]=c+32768;c=x[b+4>>2];f=x[b+8>>2];while(1){if((c|0)==(f|0)){hc(b);fb=e+16|0}else{w[c>>1]=0;w[c+2>>1]=0;c=c+4|0;x[b+4>>2]=c;continue}break}b=d+8|0;Md(b);_g(b);fb=d+16|0;return a|0}a=N()|0;_g(d+8|0);Q(a|0);p()}function AD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;d=zb(e+12|0,x[a+4>>2]);c=zb(e+8|0,x[a>>2]);f=zb(e+4|0,x[b+4>>2]);g=x[d>>2];h=x[c>>2];d=fb-16|0;fb=d;x[d+8>>2]=x[f>>2];x[d+12>>2]=g;while(1){f=x[d+8>>2];if(Pg(g,h)){c=fb-16|0;fb=c;x[c+12>>2]=f;x[c+12>>2]=x[c+12>>2]-20;fb=c+16|0;DD(x[c+12>>2],g-20|0);c=p_(d+12|0);p_(d+8|0);g=x[c>>2];continue}break}fb=d+16|0;x[b+4>>2]=f;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),Ac(b));x[b>>2]=x[b+4>>2];fb=e+16|0}function yU(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;d=zb(e+12|0,x[a+4>>2]);c=zb(e+8|0,x[a>>2]);f=zb(e+4|0,x[b+4>>2]);g=x[d>>2];h=x[c>>2];d=fb-16|0;fb=d;x[d+8>>2]=x[f>>2];x[d+12>>2]=g;while(1){f=x[d+8>>2];if(Pg(g,h)){c=fb-16|0;fb=c;x[c+12>>2]=f;x[c+12>>2]=x[c+12>>2]-32;fb=c+16|0;JB(x[c+12>>2],KB(g));c=xU(d+12|0);xU(d+8|0);g=x[c>>2];continue}break}fb=d+16|0;x[b+4>>2]=f;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),Ac(b));x[b>>2]=x[b+4>>2];fb=e+16|0}function h9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+16>>2]=b;d=x[a+48>>2];x[e+20>>2]=c-((d|0)!=0);f=x[a+44>>2];x[e+28>>2]=d;x[e+24>>2]=f;a:{b:{if(Sy(cb(x[a+60>>2],e+16|0,2,e+12|0)|0)){b=32}else{d=x[e+12>>2];if((d|0)>0){break b}b=d?32:16}x[a>>2]=b|x[a>>2];break a}g=d;f=x[e+20>>2];if(f>>>0>=d>>>0){break a}d=x[a+44>>2];x[a+4>>2]=d;x[a+8>>2]=d+(g-f|0);if(x[a+48>>2]){x[a+4>>2]=d+1;v[(b+c|0)-1|0]=y[d|0]}g=c}fb=e+32|0;return g|0}function WF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;d=zb(e+12|0,x[a+4>>2]);c=zb(e+8|0,x[a>>2]);f=zb(e+4|0,x[b+4>>2]);g=x[d>>2];h=x[c>>2];d=fb-16|0;fb=d;x[d+8>>2]=x[f>>2];x[d+12>>2]=g;while(1){f=x[d+8>>2];if(Pg(g,h)){c=fb-16|0;fb=c;x[c+12>>2]=f;x[c+12>>2]=x[c+12>>2]-36;fb=c+16|0;Sw(x[c+12>>2],hj(g));c=VF(d+12|0);VF(d+8|0);g=x[c>>2];continue}break}fb=d+16|0;x[b+4>>2]=f;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),Ac(b));x[b>>2]=x[b+4>>2];fb=e+16|0}function Pma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=fb-16|0;fb=b;g=x[a+24>>2];h=x[a+20>>2];i=x[a+16>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;j=x[a+8>>2];k=x[a+12>>2];while(1){if(d){e=(x[b+12>>2]<<1)+i|0;f=w[e>>1];e=f+((D(w[e+2>>1]-f|0,x[b+8>>2]>>>18|0)|0)/16384|0)|0;x[c>>2]=x[c>>2]+D(e,h);x[c+4>>2]=x[c+4>>2]+D(e,g);Qb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;fb=b+16|0}function HG(a,b,c,d,e){var f=0,g=0,h=0;a:{f=fb-32|0;fb=f;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[31785]=0;a=U(153,g|0,a|0,8)|0;g=x[31785];x[31785]=0;if((g|0)==1){break c}if(!a){break d}x[31785]=0;S(e|0,f+4|0,b|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){x[31785]=0;O(d|0,h|0,f+4|0);a=x[31785];x[31785]=0;if((a|0)==1){break e}Fd(f+4|0);continue}break}a=N()|0;break b}a=N()|0;Fd(f+4|0);break b}fb=f+32|0;break a}a=N()|0}fe(h);Q(a|0);p()}}function Y1(a,b){a=a|0;b=b|0;var c=0;a=Fb(a);a:{if(y[b+16|0]){x[31785]=0;P(130,a|0,4965)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}}if(y[b+17|0]){x[31785]=0;P(130,a|0,12629)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}}if(yd(x[a+4>>2],y[a+11|0])){x[31785]=0;P(130,a|0,10077)|0;c=x[31785];x[31785]=0;if((c|0)==1){break a}}if(y[b+18|0]){x[31785]=0;P(130,a|0,11142)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}}return}b=N()|0;tb(a);Q(b|0);p()}function Uj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=x[a>>2];c=Sc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>>0){eX(a,b);break a}c=Ab(a);c=gn(e+12|0,Ul(a,Sc(x[a>>2],d)+b|0),Sc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=gC(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){FW(d);d=x[b>>2]+1|0;x[b>>2]=d;continue}break}ee(b);fb=f+16|0;Id(a,c);en(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Tq(a,b+d|0)}}function St(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(x[31654]){b=St(x[31654])}if(!x[31580]){break a}c=b|c;a=x[31580];continue}break}d=x[a+76>>2]>=0;b:{c:{if(x[a+20>>2]==x[a+28>>2]){break c}ib[x[a+36>>2]](a,0,0)|0;if(x[a+20>>2]){break c}b=-1;if(d){break b}break a}b=x[a+8>>2];e=x[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;ib[x[a+40>>2]](a,b,b>>31,1)|0}b=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;if(!d){break a}}}return b|c}function Ip(a,b,c,d,e){var f=0,g=0,h=0;a:{f=fb-32|0;fb=f;h=Nb(a);b:{c:{d:{e:{while(1){a=x[b+8>>2];g=x[b>>2];x[31785]=0;a=U(153,g|0,a|0,e|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break c}if(!a){break d}x[31785]=0;O(d|0,f+4|0,b|0);a=x[31785];x[31785]=0;if((a|0)!=1){x[31785]=0;O(c|0,h|0,f+4|0);a=x[31785];x[31785]=0;if((a|0)==1){break e}Fd(f+4|0);continue}break}a=N()|0;break b}a=N()|0;Fd(f+4|0);break b}fb=f+32|0;break a}a=N()|0}fe(h);Q(a|0);p()}}function qc(a,b){var c=0,d=0,e=0;c=x[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return qc(a,24)+(qc(a,b-24|0)<<24)|0}if(!c){x[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=xt(a);d=0;if((e|0)==-1){break a}d=x[a+1396>>2];c=d+8|0;x[a+1396>>2]=c;x[a+1392>>2]=x[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){_(10087,13279,1632,6885);p()}d=x[a+1392>>2];x[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}x[a+1396>>2]=c}return d}function goa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-4096|0;fb=c;bn(a,b);a:while(1){if(Sc(x[a>>2],x[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){h=f|2048;b=0;while(1){g=x[a>>2];if((b|0)!=2048){d=y[xb(g,b+h|0)|0]+d|0;i=xb(c,b<<1),j=d,v[i|0]=j;b=b+1|0;continue}break}$u(c,fC(c),Ne(vb(g),f));e=e+1|0;continue a}else{d=y[xb(x[a>>2],b+f|0)|0]+d|0;i=xb(c,b<<1|1),j=d,v[i|0]=j;b=b+1|0;continue}}break}fb=c+4096|0}function Csa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31785]=0;O(378,a|0,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break a}f=fb-16|0;fb=f;e=vi(f+4|0,a,b);b=x[e+4>>2];g=x[e+8>>2];while(1){if((b|0)==(g|0)){hc(e);fb=f+16|0}else{dj(b,y[c|0]|y[c+1|0]<<8);b=b+2|0;x[e+4>>2]=b;continue}break}}b=d+8|0;Md(b);Wj(b);fb=d+16|0;return a|0}a=N()|0;Wj(d+8|0);Q(a|0);p()}function ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=c;c=x[oe(e+24|0,e+28|0)>>2];x[31785]=0;f=x[b+12>>2];x[e+16>>2]=x[b+8>>2];x[e+20>>2]=f;f=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=f;ba(999,a+8|0,e+8|0,c|0,d|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){a=xz(a);b=wz(a+88|0);c=vz(a+92|0);d=uz(a+96|0);x[a>>2]=48012;x[b>>2]=48128;x[c>>2]=48208;x[d>>2]=48248;Uc(e+28|0);fb=e+32|0;return a|0}a=N()|0;Uc(e+28|0);Q(a|0);p()}function kR(a,b,c,d,e,f,g,h){var i=0,j=0;i=fb-16|0;fb=i;x[i+12>>2]=d;a:{if(!(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))){break a}x[i+8>>2]=y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24);j=b;b=x[Gb(i+8|0,i+12|0)>>2];x[j>>2]=b;b=Hd(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24),b,d);x[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=z[e>>1]|f;w[e>>1]=b;if((y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))!=1){break a}w[e>>1]=b|g}fb=i+16|0}function sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;b=fb-16|0;fb=b;a:{b:{d=x[a+20>>2];c=x[d+4>>2];if((Sc(c,x[d+8>>2])|0)!=7){break b}if(Ob(c,9576,4)){break b}d=vb(c);g=vb(x[x[a+20>>2]+8>>2]);ur(b+8|0,a+4228|0);f=vb(x[b+8>>2]);e=fb-16|0;fb=e;c=fb-32|0;fb=c;Vl(c+24|0,d,g);Fk(c+16|0,x[c+24>>2],x[c+28>>2],f);d=ID(d,x[c+16>>2]);h=c,i=HD(f,x[c+20>>2]),x[h+12>>2]=i;Td(e+8|0,d,c+12|0);fb=c+32|0;fb=e+16|0;break a}Uz(a,a)}Wt(a);fb=b+16|0}function Py(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!x[x[124291]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){v[a+1|0]=b&63|128;v[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){v[a+2|0]=b&63|128;v[a|0]=b>>>12|224;v[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){v[a+3|0]=b&63|128;v[a|0]=b>>>18|240;v[a+2|0]=b>>>6&63|128;v[a+1|0]=b>>>12&63|128;return 4}}x[31660]=25;a=-1}else{a=1}return a}v[a|0]=b;return 1}function Tna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=ad(c+12|0,16,1,1,0);x[c+8>>2]=0;jd(a,0);xc(b);a:{b:{if(Ar(b,13860)){bd(b,12);if(!fp(b)){mp(d,2)}bd(b,24);break b}if(ek(b,13732)){xc(b);x[c+8>>2]=4;e=1;break a}ed(d,8)}e=0}f=a,g=(jf(b)>>>0)/(D(y[d|0],Xq(y[d+1|0]))>>>3>>>0)|0,x[f>>2]=g;b=qg(d,a,b);if(!(!b|!e)){d=x[a+20>>2];f=c,g=Rk(x[a>>2],z[a+34>>1]),x[f+4>>2]=g;Tb(d,0,x[Gb(c+8|0,c+4|0)>>2])}fb=c+16|0;return(b|0)!=0|0}function IY(a,b){var c=0,d=0,e=0,f=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];d=x[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){WC(a,b);break a}c=Ab(a);c=hg(e+12|0,Tf(a,oc(x[a>>2],d)+b|0),oc(x[a>>2],x[a+4>>2]),c);f=fb-16|0;fb=f;b=An(f+4|0,c+8|0,b);d=x[b>>2];while(1){if(x[b+4>>2]!=(d|0)){vn(d);d=x[b>>2]+4|0;x[b>>2]=d;continue}break}ee(b);fb=f+16|0;Id(a,c);gg(c)}fb=e+32|0;return}if(b>>>0<c>>>0){Yh(a,d+(b<<2)|0)}}function DT(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;j=e,k=Vj(b),x[j+4>>2]=k;c=fb-16|0;fb=c;f=yB(a,c+12|0,z[b>>1],x[b+4>>2]);b=x[f>>2];if(!b){b=fb-16|0;fb=b;d=ec(a);g=zh(c,Dc(36),Kg(b+8|0,d));d=x[g>>2]+16|0;h=x[e+4>>2];i=x[h+4>>2];x[d>>2]=x[h>>2];x[d+4>>2]=i;Nb(d+8|0);j=ec(g),k=1,v[j+4|0]=k;fb=b+16|0;Xg(a,x[c+12>>2],f,x[c>>2]);b=ie(c);IT(c);d=1}Wg(e+8|0,x[zb(c,b)>>2],d);fb=c+16|0;a=qd(x[e+8>>2]);fb=e+16|0;return a+8|0}function ffa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;x[31785]=0;W(1030,a|0);f=x[31785];x[31785]=0;a:{b:{if((f|0)!=1){f=x[a+28>>2];g=x[x[f>>2]+72>>2];x[31785]=0;b=Ta(g|0,f|0,b|0,c|0,+d,+e)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11319,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function f2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;fw(c,b);x[a+44>>2]=0;b=x[a+48>>2];if(b&8){b=Jb(c)+Bb(x[a+36>>2],y[a+43|0])|0;x[a+44>>2]=b;d=Jb(c);_n(a,d,d,b);b=x[a+48>>2]}a:{if(!(b&16)){break a}b=Bb(x[a+36>>2],y[a+43|0]);e=a,f=b+Jb(c)|0,x[e+44>>2]=f;UB(c,Lc(c));c=Jb(c);Fy(a,c,Bb(x[a+36>>2],y[a+43|0])+c|0);if(!(y[a+48|0]&3)){break a}while(1){if((b|0)<0){jt(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}jt(a,b)}}function eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;h=e,i=Dc(56),x[h+8>>2]=i;c=pm(x[e+8>>2]);x[c>>2]=77712;g=Ac(c);c=fb-16|0;fb=c;d=x[b+12>>2];x[c+8>>2]=x[b+8>>2];x[c+12>>2]=d;d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;d=gM(g);x[d>>2]=77876;b=x[c+4>>2];x[d+24>>2]=x[c>>2];x[d+28>>2]=b;b=x[c+12>>2];x[d+32>>2]=x[c+8>>2];x[d+36>>2]=b;v[d+40|0]=0;fb=c+16|0;b=a;a=Kn(e);Jn(b,Ac(a),a);qm(e);fb=f+16|0}function ll(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=fb-16|0;fb=e;x[b>>2]=0;x[b+4>>2]=0;v[e+15|0]=0;ki(a,e+15|0);c=y[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){x[b>>2]=f;x[b+4>>2]=d;if(!h&(g|0)==(i|0)){fb=e+16|0}else{v[e+15|0]=0;ki(a,e+15|0);d=x[b>>2];j=x[b+4>>2];f=y[e+15|0];c=h;g=g+1|0;h=g?c:c+1|0;k=d;c=(g<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=f<<d;d=0}else{c=(1<<d)-1&f>>>32-d;d=f<<d}f=k|d;d=c|j;continue}break}}function gsa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;a:{if(z[a+480192>>1]<b>>>0){break a}b=x[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+4|0;OZ(h,b);j=g,k=vb(x[g+4>>2]),x[j>>2]=k;h=mg(h);i=z[a+480190>>1];while(1){b=x[g>>2];if(!Ib(b,h)){Hv(g+4|0);break a}b=z[Xo(b)>>1];if(b>>>0<=i>>>0){b=D(b,104)+a|0;v[b+484421|0]=f;v[b+484418|0]=c;v[b+484420|0]=e;v[b+484419|0]=d}Yg(g);continue}}fb=g+16|0}function jla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Hg(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;a:{b:{d=b-d|0;b=x[Ab(a)>>2];f=x[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){NB(a,d,c);break c}b=Ab(a);b=Qu(e+12|0,Hq(a,Hg(x[a>>2],f)+d|0),Hg(x[a>>2],x[a+4>>2]),b);x[31785]=0;S(791,b|0,d|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}yU(a,b);LB(b)}fb=e+32|0;break a}a=N()|0;LB(b);Q(a|0);p()}return}if(b>>>0<d>>>0){zU(a,e+(b<<5)|0)}}function Eu(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;i=AB(x[a+24>>2],y[a+32|0]);g=Lj(i);j=65535;a:{while(1){if((d|0)==(g|0)){d=g;a=-1;break a}b:{c:{if(!$i(i,d&65535)){break c}e=x[a>>2];if(Qd(e,x[a+4>>2])>>>0<=d>>>0){break b}f=0;h=Dd(e,d);while(1){d:{e=x[h+4>>2];if(e>>>0>f>>>0){if(!mC(x[h>>2],f)){break d}e=x[h+4>>2]}if((f|0)==(e|0)){break b}break c}f=f+1|0;continue}}d=d+1|0;continue}break}j=d;a=0}w[b>>1]=j;x[c>>2]=a;return d>>>0<g>>>0}function Az(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=fb-48|0;fb=b;x[b+40>>2]=e;x[b+44>>2]=f;c=gc(b+32|0,c,d);d=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=d;a:{a=hu(a,b+8|0,b+40|0);if(a+1>>>0>=3){a=ac(8);x[31785]=0;b=P(37,b+20|0,8077)|0;c=x[31785];x[31785]=0;b:{if((c|0)!=1){nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0);p()}fb=b+48|0;return a|0}p()}function oU(a,b,c,d,e){var f=0,g=0,h=0;h=-1;g=d&2147483647;f=(g|0)==2147418112;a:{if(f&!c?a|b:f&(c|0)!=0|g>>>0>2147418112){break a}f=e&2147483647;if(((f|0)==2147418112&0|f>>>0>2147418112)&(f|0)!=2147418112){break a}if(!(a|c|(f|g|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(((c|0)!=0|(d|0)!=(e|0))&(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function Mp(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Ah(x[_c(i+4|0,i+12|0)>>2])+1|0}else{c=2147483631}ng(j,c);c=x[i+4>>2];if(e){yg(c,k,e)}if(g){yg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){yg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}vd(a,c);nf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Vd(b,a);ed(a+c|0,0);fb=i+16|0;return}of();p()}function Hf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;i=sua(b,c,h,i);h=hb;e=sua(d,e,f,g);i=e+i|0;d=hb+h|0;h=e>>>0>i>>>0?d+1|0:d;j=g;e=0;k=c;d=0;c=sua(g,e,c,d);g=c+i|0;i=hb+h|0;l=g;c=c>>>0>g>>>0?i+1|0:i;g=sua(f,0,b,0);h=hb;i=0;d=sua(f,i,k,d);h=h+d|0;f=hb+i|0;f=d>>>0>h>>>0?f+1|0:f;i=f+l|0;d=c;f=f>>>0>i>>>0?d+1|0:d;c=sua(b,m,j,e)+h|0;e=hb;e=c>>>0<h>>>0?e+1|0:e;h=e+i|0;i=f;x[a+8>>2]=h;x[a+12>>2]=e>>>0>h>>>0?i+1|0:i;x[a>>2]=g;x[a+4>>2]=c}function Dq(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=fb-16|0;fb=i;if(2147483630-b>>>0>=c>>>0){k=Jb(a);j=i+4|0;if(b>>>0<=1073741798){x[i+12>>2]=b<<1;x[i+4>>2]=b+c;c=Ah(x[_c(i+4|0,i+12|0)>>2])+1|0}else{c=2147483631}ng(j,c);c=x[i+4>>2];if(e){Tg(c,k,e)}if(g){Tg(c+e|0,h,g)}j=e+f|0;h=d-j|0;if((d|0)!=(j|0)){Tg((c+e|0)+g|0,(e+k|0)+f|0,h)}if((b|0)!=10){Db(k)}vd(a,c);nf(a,x[i+8>>2]);b=a;a=h+(e+g|0)|0;Vd(b,a);ed(a+c|0,0);fb=i+16|0;return}of();p()}function dna(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=ig(1,2);e=hb;i=e;Qb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=w[(x[b+12>>2]<<1)+h>>1];x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Qb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Dg(a,f,i);fb=b+16|0}function I_(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=x[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(D(b,6)+a|0)+1072|0,g=dl(a,7),v[f|0]=g;d=dl(a,1);e=dl(a,1);c=x[a+1060>>2];if((c|0)>255){break a}b=x[a+1064>>2]+1|0;x[a+1060>>2]=b;x[a+1064>>2]=b;b:{if(d){w[(D(c,6)+a|0)+1068>>1]=b;I_(a);b=x[a+1064>>2];break b}w[(D(c,6)+a|0)+1068>>1]=65535}x[a+1060>>2]=b;if(e){w[(D(c,6)+a|0)+1070>>1]=b;continue}break}w[(D(c,6)+a|0)+1070>>1]=65535}}function ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31785]=0;W(1030,a|0);e=x[31785];x[31785]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+12>>2];x[31785]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11464,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Rt(a,b){var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=$d(a);d=ec(a);f=fb-16|0;fb=f;while(1){if(c){g=Bu(c+16|0,b);d=g?d:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[zb(f+12|0,d)>>2];fb=f+16|0;a:{if(Ib(c,mg(a))){if(!Bu(b,qd(c))){break a}}c=mg(a)}if(!mc(c,mg(a))){b=x[zb(e+12|0,c)>>2];c=fb-16|0;fb=c;d=Yg(zb(c+12|0,b));if((b|0)==x[a>>2]){x[a>>2]=x[d>>2]}d=Ab(a);x[d>>2]=x[d>>2]-1;NU(x[ec(a)>>2],b);fb=c+16|0;Ym(qd(b));Db(b)}fb=e+16|0}function hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;x[31785]=0;W(1030,a|0);e=x[31785];x[31785]=0;a:{b:{if((e|0)!=1){e=x[a+28>>2];f=x[x[e>>2]+8>>2];x[31785]=0;b=ba(f|0,e|0,b|0,c|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11500,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function ZJ(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=y[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=x[31660];x[31660]=0;Kd();a=py(a,e+12|0,d);d=hb;g=x[31660];e:{if(g){if(x[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}x[31660]=h;if(x[e+12>>2]!=(b|0)){break c}if(!d){break b}}x[c>>2]=4;a=-1;break a}}x[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}fb=e+16|0;return a}function mH(a,b,c,d,e,f){var g=0,h=0;g=fb-256|0;fb=g;x[g+248>>2]=37;x[g+252>>2]=0;h=g+248|0;Ss(h|1,10626,f,x[b+4>>2]);f=Kd();x[g>>2]=d;x[g+4>>2]=e;d=g+224|0;e=nh(d,24,f,h,g)+d|0;f=pj(d,e,x[b+4>>2]);h=g+20|0;$c(h,x[b+28>>2]);x[31785]=0;ga(1236,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[31785];x[31785]=0;a:{if((d|0)!=1){Zb(g+20|0);a=Qs(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);fb=g+256|0;break a}a=N()|0;Zb(g+20|0);Q(a|0);p()}return a}function jc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{c=At(a);a=c;if(a>>>0<502960&a>>>0>=502448){b=c-4|0;e=x[125610];d=e;while(1){a=d;if(!(!a|(a|0)==502960)){if((YH(a)|0)==(b|0)){w[a+2>>1]=z[c-2>>1]+z[a+2>>1];break a}if((YH(b)|0)==(a|0)){d=c-2|0;w[d>>1]=z[a+2>>1]+z[d>>1];if(!f){x[125610]=b;w[b>>1]=z[a>>1];break a}g=f,h=Jx(b),w[g>>1]=h;break a}else{d=Kx(z[a>>1]);f=a;continue}}break}g=b,h=Jx(e),w[g>>1]=h;x[125610]=b;break a}Db(c)}}function ena(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=fb-16|0;fb=b;h=x[a+16>>2];f=ig(1,2);e=hb;i=e;Qb(a,f,e);j=x[a+24>>2];k=x[a+20>>2];e=x[a+4>>2];x[b+8>>2]=x[a>>2];x[b+12>>2]=e;e=x[a+8>>2];l=x[a+12>>2];while(1){if(d){g=v[x[b+12>>2]+h|0]<<8;x[c>>2]=x[c>>2]+D(g,k);x[c+4>>2]=x[c+4>>2]+D(j,g);Qb(b+8|0,e,l);c=c+8|0;d=d-1|0;continue}break}c=x[b+12>>2];x[a>>2]=x[b+8>>2];x[a+4>>2]=c;Dg(a,f,i);fb=b+16|0}function rW(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+4>>2]=((y[a+48|0]|y[a+49|0]<<8)<<1)+((y[a+32|0]|y[a+33|0]<<8)<<4);x[b+8>>2]=((y[a+50|0]|y[a+51|0]<<8)<<1)+((y[a+34|0]|y[a+35|0]<<8)<<4);x[b+12>>2]=(D(y[a+52|0]|y[a+53|0]<<8,5)+((y[a+36|0]|y[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=wb(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=Iq(x[a>>2],x[c>>2])?c:a;continue}}fb=b+16|0;a=x[a>>2];hb=a>>31;return a}function oH(a,b,c,d,e,f){var g=0,h=0;g=fb-112|0;fb=g;x[g+104>>2]=37;x[g+108>>2]=0;h=g+104|0;Ss(h|1,10626,f,x[b+4>>2]);f=Kd();x[g>>2]=d;x[g+4>>2]=e;d=g+80|0;e=nh(d,24,f,h,g)+d|0;f=pj(d,e,x[b+4>>2]);h=g+20|0;$c(h,x[b+28>>2]);x[31785]=0;ga(1233,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=x[31785];x[31785]=0;a:{if((d|0)!=1){Zb(g+20|0);a=dw(a,g+32|0,x[g+28>>2],x[g+24>>2],b,c);fb=g+112|0;break a}a=N()|0;Zb(g+20|0);Q(a|0);p()}return a}function k0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[d+12>>2]=-1;if(ch(a,d+11|0)){x[d+4>>2]=y[d+11|0];f=x[Gb(d+4|0,d+12|0)>>2];c=fb+-64|0;fb=c;e=c+44|0;Zf(e,a,f);g=x[c+44>>2];a=c+20|0;rg(a,3,Se(e),g);x[31785]=0;O(221,c+32|0,a|0);a=x[31785];x[31785]=0;a:{if((a|0)!=1){a=c+12|0;gc(a,b,11);b=a;a=c+32|0;jm(b,a);tb(a);Jc(c+44|0);fb=c- -64|0;e=!f|(g|0)!=0;break a}a=N()|0;Jc(c+44|0);Q(a|0);p()}}fb=d+16|0;return e|0}function dfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31785]=0;W(1030,a|0);d=x[31785];x[31785]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+64>>2];x[31785]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,6715,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function bfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;x[31785]=0;W(1030,a|0);d=x[31785];x[31785]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+56>>2];x[31785]=0;S(f|0,d|0,b|0,(c|0)!=0|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,6769,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function X9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=pm(a);x[e>>2]=77212;d=Ac(e);a=fb-16|0;fb=a;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;b=fb-16|0;fb=b;c=x[a+12>>2];x[b+8>>2]=x[a+8>>2];x[b+12>>2]=c;c=x[a+4>>2];x[b>>2]=x[a>>2];x[b+4>>2]=c;d=$L(d,aM(b));x[d>>2]=77376;c=x[a+4>>2];x[d+24>>2]=x[a>>2];x[d+28>>2]=c;c=x[a+12>>2];x[d+32>>2]=x[a+8>>2];x[d+36>>2]=c;fb=b+16|0;fb=a+16|0;return e|0}function Pqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=Lf(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;a:{b:{c=b-c|0;b=x[Ab(a)>>2];e=x[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){GE(a,c);break c}b=Ab(a);b=BD(d+12|0,CD(a,Lf(x[a>>2],e)+c|0),Lf(x[a>>2],x[a+4>>2]),b);x[31785]=0;O(524,b|0,c|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}AD(a,b);Mv(b)}fb=d+32|0;break a}a=N()|0;Mv(b);Q(a|0);p()}return}if(b>>>0<c>>>0){CE(a,d+D(b,20)|0)}}function Ar(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=gc(c+8|0,c+24|0,7);kc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(Ob(c+24|0,b,7)){break b}Yb(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17688,9099,601,13243);p()}_(17667,9099,599,13243);p()}return d|0}function tg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;w[d+12>>1]=65535;w[d+14>>1]=b;f=d+12|0;b=z[Mc(41660,d+14|0)>>1];e=x[a>>2];c=Xc(e,x[a+4>>2]);a:{if(b>>>0>c>>>0){e=fb-32|0;fb=e;b=b-c|0;c=x[Ab(a)>>2];g=x[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){jp(a,b,f);break b}c=Ab(a);c=hk(e+12|0,ik(a,Xc(x[a>>2],g)+b|0),Xc(x[a>>2],x[a+4>>2]),c);cF(c,b,f);Id(a,c);fj(c)}fb=e+32|0;break a}if(b>>>0<c>>>0){xn(a,e+(b<<1)|0)}}fb=d+16|0}function xe(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;f=hh(a);a:{b:{if(!b){i=e,j=hh(a),x[i+8>>2]=j;x[e+12>>2]=0;break b}g=x[b>>2];b=x[b+4>>2];h=b;x[e+8>>2]=g;x[e+12>>2]=b;a=x[a+12>>2];x[e>>2]=2048;x[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Hr(e+8|0,e);c=x[a>>2];a=x[a+4>>2];if(!a&c>>>0>f>>>0|a){a=-1;if(!d&b>>>0<=f>>>0){break b}break a}a=0;if((d|0)==(h|0)&b>>>0>g>>>0|d>>>0>h>>>0){break a}}a=1}fb=e+16|0;return a}function o3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-32|0;fb=f;g=Xn(f+20|0,b,c);x[31785]=0;e=U(1367,f+8|0,d|0,e|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){a=Jb(g);d=Jb(e);b=x[d>>2];c=x[a>>2];a:{if(!b|!c|(b|0)!=(c|0)){break a}while(1){b=x[d+4>>2];c=x[a+4>>2];if(!b|!c){break a}d=d+4|0;a=a+4|0;if((b|0)==(c|0)){continue}break}}Sb(e);Sb(g);fb=f+32|0;a=c-b|0;return((a|0)<0?-1:(a|0)!=0)|0}a=N()|0;Sb(g);Q(a|0);p()}function F2(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;x[31785]=0;m=a;a=0;a=OH(1102,m|a,b,c,d,a|e,f);b=x[31785];x[31785]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31785]=0;ga(988,8863,g|0,h|0,i|0,j|0,k|0,l|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}return a|0}function $t(a){var b=0,c=0,d=0;b=y[a+4266|0];B[a+4236>>2]=E(b>>>0)*E(.00390625);B[a+4240>>2]=E(256-b|0)*E(.00390625);c=y[a+4267|0];b=y[a+4265|0];B[a+4244>>2]=E(D(c,b)|0)*E(152587890625e-16);d=c|-256;B[a+4256>>2]=E(D(d,b|-256)|0)*E(152587890625e-16);B[a+4252>>2]=E(D(b,d)|0)*E(152587890625e-16);B[a+4248>>2]=E(D(256-b|0,c)|0)*E(152587890625e-16);b=a;c=x[a+4232>>2];a=y[a+4264|0];x[b+4228>>2]=(D(c,(a?a:-89)&255)+250>>>0)/500}function pO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ac(8);x[31785]=0;b=P(37,h+4|0,8220)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}zl(a,b,4);c=lz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;jc(a)}Q(d|0)}p()}function maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;c=fb-16|0;fb=c;h=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;jM(a,c);a:{f=C[a+24>>3];if(f==1){break a}i=E(f);d=x[b+4>>2];j=x[b+8>>2];b:while(1){if((e|0)==(j|0)){break a}k=D(x[a+16>>2],e+h|0);l=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{g=(b+k<<2)+l|0;B[g>>2]=B[g>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function hO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=fb-16|0;fb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ac(8);x[31785]=0;b=P(37,h+4|0,8220)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}d=N()|0;tb(b);break b}zl(a,b,4);c=nz(a,c,d,e,f,g);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=h+16|0;return c|0}d=N()|0;jc(a)}Q(d|0)}p()}function BL(a){var b=0,c=E(0),d=E(0),e=E(0),f=E(0),g=E(0),h=E(0),i=0,j=0,k=0,l=E(0),m=E(0),n=E(0),o=E(0),p=0;c=B[a>>2];i=a-16|0;d=B[i>>2];e=E(c+d);b=a-8|0;f=B[b>>2];j=a-24|0;g=B[j>>2];h=E(f+g);B[a>>2]=e+h;B[b>>2]=e-h;b=a-12|0;h=B[b>>2];k=a-28|0;l=B[k>>2];e=E(h+l);p=b;b=a-4|0;m=B[b>>2];a=a-20|0;n=B[a>>2];o=E(m+n);B[p>>2]=o-e;f=E(f-g);g=E(m-n);B[k>>2]=f+g;c=E(c-d);d=E(h-l);B[i>>2]=c+d;B[j>>2]=c-d;B[b>>2]=e+o;B[a>>2]=g-f}function Y2(a){a=a|0;var b=0,c=0,d=0,e=0;c=fb-32|0;fb=c;b=uc(c+8|0,16978);x[31785]=0;S(101,c+20|0,a|0,b|0);a=x[31785];x[31785]=0;a:{if((a|0)!=1){tb(b);a=0;b=0;while(1){d=x[c+20>>2];if(!(b>>>0<=3&Qd(d,x[c+24>>2])>>>0>b>>>0)){Pd(c+20|0);fb=c+32|0;return a|0}x[31785]=0;d=R(102,Dd(d,b)|0)|0;e=x[31785];x[31785]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=N()|0;Pd(c+20|0);break a}a=N()|0;tb(b)}Q(a|0);p()}function V8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+12>>2];f=x[a+16>>2];b:{if(d>>>0<f>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=f-d>>2;x[e+4>>2]=c-g;f=d;d=x[pd(e+12|0,pd(e+8|0,e+4|0))>>2];b=Wi(b,f,d);f=d<<2;x[a+12>>2]=f+x[a+12>>2];b=b+f|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}x[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}fb=e+16|0;return g|0}function Qt(a,b,c,d,e){var f=0,g=0;a:{if(!zt(b)){break a}f=x[a+484344>>2];if(!Ge(f,x[a+484348>>2],b&65535)){break a}b=Vb(f,b);if(x[b+12>>2]<=(c|0)|e>>>0>5|z[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=gd(x[b>>2],x[x[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=y[b|0]}return g}function _ea(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31785]=0;W(1030,a|0);d=x[31785];x[31785]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+48>>2];x[31785]=0;ra(f|0,d|0,b|0,+c);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11699,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Qea(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31785]=0;W(1030,a|0);d=x[31785];x[31785]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+96>>2];x[31785]=0;ra(f|0,d|0,b|0,+c);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11637,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Oea(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;x[31785]=0;W(1030,a|0);d=x[31785];x[31785]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+28>>2];f=x[x[d>>2]+88>>2];x[31785]=0;ra(f|0,d|0,b|0,+c);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11076,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=E(0),j=0,k=0,l=0;c=fb-16|0;fb=c;h=x[a+4>>2];x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;pM(a,c);a:{f=C[a+24>>3];if(f==1){break a}i=E(f);d=x[b+4>>2];j=x[b+8>>2];b:while(1){if((e|0)==(j|0)){break a}k=e+h|0;l=x[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{g=x[(b<<2)+l>>2]+(k<<2)|0;B[g>>2]=B[g>>2]*i;b=b+1|0;continue}}}fb=c+16|0}function D$(a){a=a|0;var b=0,c=0,d=0;b=x[a>>2];if(b){hQ(x[b+12>>2],b);b=x[a>>2];ib[x[x[b>>2]+8>>2]](b);x[a>>2]=0}a=a+4|0;So(a);b=fb-32|0;fb=b;a:{b:{d=Qo(a);c=Sc(x[a>>2],x[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}x[31785]=0;c=ba(959,b+12|0,c|0,c|0,Ab(a)|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){Id(a,c);en(c);break c}Y(T(0)|0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break b}}fb=b+32|0;break a}T(0)|0;Rb();p()}}function r7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=fb-208|0;fb=a;f=Kd();x[a>>2]=e;g=a+176|0;i=nh(g,20,f,9282,a);e=i+g|0;g=pj(g,e,x[c+4>>2]);$c(a+12|0,x[c+28>>2]);x[31785]=0;f=R(1220,x[a+12>>2])|0;h=x[31785];x[31785]=0;if((h|0)!=1){Zb(a+12|0);h=f;f=a+16|0;RJ(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=Qs(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);fb=a+208|0;return b|0}b=N()|0;Zb(a+12|0);Q(b|0);p()}function g9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+16>>2];d=x[a+12>>2];b:{if(g>>>0>d>>>0){x[e+12>>2]=2147483647;x[e+8>>2]=g-d;x[e+4>>2]=c-f;g=d;d=x[pd(e+12|0,pd(e+8|0,e+4|0))>>2];b=yg(b,g,d);x[a+12>>2]=x[a+12>>2]+d;b=b+d|0;break b}d=ib[x[x[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b|0]=d<<24>>24;d=1;b=b+1|0}f=d+f|0;continue}break}fb=e+16|0;return f|0}function gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=fb-32|0;fb=f;d=f+8|0;Te(d,2,a+6|0);e=f+20|0;Ec(e,d);zc(b+492|0,e);d=b+236|0;g=c+1|0;tb(e);c=0;while(1){if((c|0)==128){x[b>>2]=(y[a+226|0]|y[a+227|0]<<8)<<5;jA(a+180|0,b+48|0,0);jA(a+228|0,b+88|0,2);jA(a+276|0,b+68|0,1);if(!(y[a+324|0]|y[a+325|0]<<8)){Tb(d,0,256)}fb=f+32|0}else{e=y[(a+c|0)+38|0];h=_b(d,c),i=e+g|0,w[h>>1]=i;c=c+1|0;continue}break}}function xA(a,b,c){if(Pb(a+1074312|0,21)){c=c&255;a:{switch((b&3)-1|0){default:return v[c+32112|0];case 0:return 64-(c+1>>>1|0)|0;case 1:return(c>>>0<128)<<6;case 2:break a}}return xR(xo(a))+-64|0}if(z[a+480182>>1]&1032){return v[(c>>>1&31)+30768|0]}a=c&63;b:{switch((b&3)-1|0){default:return v[a+31984|0];case 0:return(a>>>0>=32?255:0)-(a<<2)|0;case 1:return a>>>0<32?127:-127;case 2:break b}}return v[a+32048|0]}function v1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=fb-16|0;fb=g;f=g+4|0;x[f+4>>2]=1;j=f,k=Dc(32),x[j+8>>2]=k;e=pm(x[f+8>>2]);x[e>>2]=41672;h=Ac(e);e=fb-16|0;fb=e;b=mm(e+8|0,x[b>>2],x[b+4>>2]);d=x[d>>2];c=x[c>>2];i=x[b+4>>2];x[e>>2]=x[b>>2];x[e+4>>2]=i;b=In(h);x[b>>2]=41808;mm(b+4|0,x[e>>2],x[e+4>>2]);x[b+16>>2]=d;x[b+12>>2]=c;he(e);fb=e+16|0;b=a;a=Kn(f);Jn(b,Ac(a),a);qm(f);fb=g+16|0}function nH(a,b,c,d,e){var f=0,g=0,h=0;f=fb-144|0;fb=f;x[f+136>>2]=37;x[f+140>>2]=0;g=f+136|0;Ss(g|1,10793,e,x[b+4>>2]);e=Kd();x[f>>2]=d;d=f+123|0;e=nh(d,13,e,g,f)+d|0;g=pj(d,e,x[b+4>>2]);h=f+4|0;$c(h,x[b+28>>2]);x[31785]=0;ga(1236,d|0,g|0,e|0,f+16|0,f+12|0,f+8|0,h|0);d=x[31785];x[31785]=0;a:{if((d|0)!=1){Zb(f+4|0);a=Qs(a,f+16|0,x[f+12>>2],x[f+8>>2],b,c);fb=f+144|0;break a}a=N()|0;Zb(f+4|0);Q(a|0);p()}return a}function jF(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Ob(a,11170,2)|(y[a+514|0]-16&255)>>>0<241|y[a+515|0]>128){break a}d=a+514|0;c=a+2|0;while(1){if((c|0)!=(d|0)){f=Ab(c);b=c;while(1){if((b|0)!=(f|0)){g=y[b|0];b=b+1|0;if(g>>>0>31){continue}break a}break}c=c+8|0;continue}break}d=a+772|0;b=a+516|0;c=-1;while(1){e=(b|0)==(d|0);if(e){break a}a=c;c=y[b|0]|y[b+1|0]<<8;a=(a|0)<(c|0);b=b+2|0;if(a){continue}break}}return e}function cha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a>>2]=43860;c=Nb(a+4256|0);b=a+4208|0;e=wb(b,0),f=1056964608,x[e>>2]=f;e=wb(b,1),f=1017370378,x[e>>2]=f;e=wb(b,2),f=1028670828,x[e>>2]=f;e=wb(b,3),f=1059760811,x[e>>2]=f;e=wb(b,4),f=1017370378,x[e>>2]=f;e=wb(b,5),f=1065353216,x[e>>2]=f;x[31785]=0;O(950,a+44|0,2);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;sc(c);Uf(a);Q(b|0);p()}function OT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-32|0;fb=d;x[a+4>>2]=0;a:{if(b){b:{if(Pu(a)>>>0>=b>>>0){x[a+4>>2]=b;break b}e=Mo(d+20|0);x[31785]=0;f=P(764,a|0,b|0)|0;g=x[31785];x[31785]=0;if((g|0)==1){break a}x[31785]=0;O(765,e|0,f|0);f=x[31785];x[31785]=0;if((f|0)==1){break a}x[e+4>>2]=b;YB(a,e);$e(e)}fn(d+12|0,x[a>>2]);Gw(x[d+12>>2],x[d+16>>2],b,y[c|0])}fb=d+32|0;return}a=N()|0;$e(e);Q(a|0);p()}function AL(a,b){var c=0,d=0,e=0;if(!y[b+21|0]){fc(a,21);return-1}if(x[a+1396>>2]<=9){tl(a)}d=x[a+1392>>2];c=w[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=y[d+x[b+8>>2]|0];x[a+1392>>2]=e>>>c;c=x[a+1396>>2]-c|0;x[a+1396>>2]=(c|0)>0?c:0;c=(c|0)<0?-1:d;break a}c=Em(a,b)}if(!((c|0)>=x[b+2092>>2]?y[b+23|0]:0)){if(!(!(x[a+1384>>2]?y[a+1376|0]:1)|(c|0)>=0)){fc(a,21)}return c}_(7586,13279,1793,5770);p()}function _y(a){var b=0,c=0,d=0;a:{b:{if(!x[a+1384>>2]){b=x[a+1380>>2];if((b|0)==-1){x[a+1388>>2]=x[a+1116>>2]-1;if(!wt(a)){x[a+1384>>2]=1;return 0}if(!(v[a+1375|0]&1)){break b}b=x[a+1380>>2]}d=b+1|0;x[a+1380>>2]=d;c=y[(a+b|0)+1120|0];if((c|0)!=255){x[a+1388>>2]=b;x[a+1384>>2]=1}if(x[a+1116>>2]<=(d|0)){x[a+1380>>2]=-1}if(y[a+1376|0]){break a}v[a+1376|0]=c}return c}fc(a,32);return 0}_(15963,13279,1564,6056);p()}function eD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=fb-16|0;fb=c;if(Mb(x[a>>2],x[a+8>>2],b)){while(1){if((d|0)==4){Hm(c+4|0,x[c+12>>2]);d=x[c+4>>2]}else{v[c+11|0]=0;b:{if(b>>>0>d>>>0){ch(a,c+11|0);e=v[c+11|0];g=e>>>31|0;break b}e=0-g|0}v[(c+12|0)+d|0]=e;d=d+1|0;continue}break}}fb=c+16|0;c=d;break a}c=Mg(a);Yb(a,b-4|0)}v[f|0]=c}function pH(a,b,c,d,e){var f=0,g=0,h=0;f=fb+-64|0;fb=f;x[f+56>>2]=37;x[f+60>>2]=0;g=f+56|0;Ss(g|1,10793,e,x[b+4>>2]);e=Kd();x[f>>2]=d;d=f+43|0;e=nh(d,13,e,g,f)+d|0;g=pj(d,e,x[b+4>>2]);h=f+4|0;$c(h,x[b+28>>2]);x[31785]=0;ga(1233,d|0,g|0,e|0,f+16|0,f+12|0,f+8|0,h|0);d=x[31785];x[31785]=0;a:{if((d|0)!=1){Zb(f+4|0);a=dw(a,f+16|0,x[f+12>>2],x[f+8>>2],b,c);fb=f- -64|0;break a}a=N()|0;Zb(f+4|0);Q(a|0);p()}return a}function Uoa(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;v[b+15|0]=128;a=Vv(a,127,b+15|0);x[31785]=0;v[b+14|0]=64;d=U(603,a+12|0,127,b+14|0)|0;c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){x[31785]=0;v[b+13|0]=0;P(683,a+24|0,b+13|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break b}x[a+36>>2]=-1;x[a+40>>2]=108855296;x[a+44>>2]=0;x[a+48>>2]=0;w[a+52>>1]=0;fb=b+16|0;return a|0}b=N()|0;break a}b=N()|0;dc(d)}dc(a);Q(b|0);p()}function Rsa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;h=fb-16|0;fb=h;x[h+12>>2]=d;g=Bb(x[a+4>>2],y[a+11|0]);f=Lc(a);a:{if(f-g>>>0>=b>>>0){f=Jb(a);if((c|0)==(g|0)){break a}i=c+f|0;Ri(i+b|0,i,g-c|0);break a}Nm(a,f,(b+g|0)-f|0,g,c,0,b);f=x[a>>2]}b=b+g|0;jg(a,b);ed(b+f|0,0);b=c+f|0;while(1){if(Ib(d,e)){ed(b,y[d|0]);b=b+1|0;d=x[je(h+12|0)>>2];continue}break}a=Ne(wd(a),c);fb=h+16|0;return a|0}function gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+76>>2];x[31785]=0;O(e|0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11329,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Sea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+16>>2];x[31785]=0;O(e|0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,12868,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+84>>2];x[31785]=0;O(e|0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,12351,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+80>>2];x[31785]=0;O(e|0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11173,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Lea(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+104>>2];x[31785]=0;la(e|0,c|0,+b);c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,15302,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31785]=0;X(26);d=x[31785];x[31785]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function B7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=fb-96|0;fb=a;f=Kd();x[a>>2]=e;g=a- -64|0;i=nh(g,20,f,9282,a);e=i+g|0;g=pj(g,e,x[c+4>>2]);$c(a+12|0,x[c+28>>2]);x[31785]=0;f=R(28,x[a+12>>2])|0;h=x[31785];x[31785]=0;if((h|0)!=1){Zb(a+12|0);h=f;f=a+16|0;VJ(h,a- -64|0,e,f);h=b;b=f+i|0;b=dw(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);fb=a+96|0;return b|0}b=N()|0;Zb(a+12|0);Q(b|0);p()}function jda(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0;d=fb-48|0;fb=d;x[d+44>>2]=c;c=Jd(d+16|0);x[31785]=0;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;S(1124,d+24|0,a|0,d|0);a=x[31785];x[31785]=0;a:{b:{if((a|0)!=1){a=x[oe(d+12|0,d+44|0)>>2];x[31785]=0;b=+pa(990,d+24|0,+b,a|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}ub(d+24|0);Uc(d+44|0);fb=d+48|0;return+b}c=N()|0;break a}c=N()|0;ub(d+24|0)}Uc(d+44|0);Q(c|0);p()}function Yea(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+40>>2];x[31785]=0;la(e|0,c|0,+b);c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11737,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31785]=0;X(26);d=x[31785];x[31785]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Tea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+20>>2];x[31785]=0;O(e|0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,9332,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Rea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+100>>2];x[31785]=0;d=+qa(e|0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11655,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function bU(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{if(b){x[31785]=0;O(807,a|0,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}e=fb-16|0;fb=e;d=Ru(e+4|0,a,b);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){hc(d);fb=e+16|0}else{Ml(b,0,0);b=b+16|0;x[d+4>>2]=b;continue}break}}b=c+8|0;Md(b);ST(b);fb=c+16|0;return a}a=N()|0;ST(c+8|0);Q(a|0);p()}function Wea(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+32>>2];x[31785]=0;la(e|0,c|0,+b);c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,7797,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31785]=0;X(26);d=x[31785];x[31785]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Uea(a,b){a=a|0;b=+b;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+24>>2];x[31785]=0;la(e|0,c|0,+b);c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,7745,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31785]=0;X(26);d=x[31785];x[31785]=0;if((d|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Pea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+92>>2];x[31785]=0;d=+qa(e|0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11096,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Dx(a,b,c){var d=0,e=0,f=0,g=0;e=Jb(a);a=Bb(x[a+4>>2],y[a+11|0]);d=Jb(b);b=Bb(x[b+4>>2],y[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}c=c+e|0;a=a+e|0;b=b+d|0;b:{if((b|0)==(d|0)){break b}c:{b=b-d|0;if((b|0)>(a-c|0)){break c}g=y[d|0];while(1){f=a-c|0;if((f|0)<(b|0)){break c}c=lu(c,(f-b|0)+1|0,g);if(!c){break c}if(!lx(c,d,b)){break b}c=c+1|0;continue}}c=a}c=(a|0)==(c|0)?-1:c-e|0}else{c=-1}}return c}function $ea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];e=x[x[c>>2]+52>>2];x[31785]=0;d=+qa(e|0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11718,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return+d}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function efa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+68>>2];x[31785]=0;b=P(d|0,c|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,6742,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function cfa(a,b){a=a|0;b=b|0;var c=0,d=0;x[31785]=0;W(1030,a|0);c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){c=x[a+28>>2];d=x[x[c>>2]+60>>2];x[31785]=0;b=P(d|0,c|0,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,6793,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=-1}return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function $A(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}xk(a,b,b+700|0,0-(c<<2)|0,0);if(x[b+700>>2]<65536){break b}if(Pb(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function e9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=x[a+28>>2];d=x[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=vf(v[b|0]),h=x[x[a>>2]+52>>2],ib[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{x[e+12>>2]=g-d;x[e+8>>2]=c-f;g=d;d=x[pd(e+12|0,e+8|0)>>2];yg(g,b,d);x[a+24>>2]=d+x[a+24>>2];f=f+d|0;b=b+d|0}continue}break}fb=e+16|0;return f|0}function T9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-32|0;fb=e;a:{if(y[b+8|0]){f=x[b+12>>2];h=e,i=Sc(f,x[b+16>>2])-c|0,x[h+28>>2]=i;x[e+24>>2]=x[d+4>>2];g=x[Gb(e+28|0,e+24|0)>>2];f=Ne(vb(f),c);c=Ne(Ne(vb(x[b+12>>2]),c),g);b=x[d>>2];Qv(f,c,b);bc(a,b,g);break a}g=x[d+4>>2];d=x[d>>2];x[e+16>>2]=d;x[e+20>>2]=g;f=x[x[b>>2]+40>>2];x[e+8>>2]=d;x[e+12>>2]=g;ib[f|0](a,b,c,e+8|0)}fb=e+32|0}function ff(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Kp(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(VH(a,b)&3){case 0:c=Kp(C[b>>3],C[b+8>>3]);break a;case 1:c=-Lp(C[b>>3],C[b+8>>3],1);break a;case 2:c=-Kp(C[b>>3],C[b+8>>3]);break a;default:break b}}c=Lp(C[b>>3],C[b+8>>3],1)}a=c;fb=b+16|0;return a}function Wk(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c)){break a}vc(f+12|0,65535);tg(a,z[f+12>>1]);c=vb(x[a>>2]);x[f+4>>2]=c;h=vb(x[a+4>>2]);while(1){if(!Ib(c,h)){break a}a=f+11|0;if(!ch(b,a)){Wh(a)}a=y[f+11|0];w[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}w[c>>1]=g}c=x[Wd(f+4|0)>>2];continue}}fb=f+16|0}function qna(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=XB(c+4|0,a);Hm(x[a+4>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=hg(d+12|0,Tf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);Hm(x[c+8>>2],y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24));x[c+8>>2]=x[c+8>>2]+4;Id(a,c);gg(c);fb=d+32|0}function $N(a,b){var c=0;a:{b:{if((a^b)&3){c=y[b|0];break b}if(b&3){while(1){c=y[b|0];v[a|0]=c;if(!c){break a}a=a+1|0;b=b+1|0;if(b&3){continue}break}}c=x[b>>2];if((c^-1)&c-16843009&-2139062144){break b}while(1){x[a>>2]=c;c=x[b+4>>2];a=a+4|0;b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}v[a|0]=c;if(!(c&255)){break a}while(1){c=y[b+1|0];v[a+1|0]=c;a=a+1|0;b=b+1|0;if(c){continue}break}}}function Ku(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[b+40>>2]=0;x[b+44>>2]=0;f=b- -64|0;x[f>>2]=0;x[f+4>>2]=0;x[b+56>>2]=0;x[b+60>>2]=0;x[b+48>>2]=0;x[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=vb(x[c>>2]);x[e+12>>2]=d;f=vb(x[c+4>>2]);while(1){if(!Ib(d,f)){break a}g=d,h=UT(b,C[d>>3]),C[g>>3]=h;d=x[Hu(e+12|0)>>2];continue}}}else{UT(b,C[Re(x[c>>2],0)>>3]);d=d+1|0;continue}break}Tl(a,c);fb=e+16|0}function pra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;c=Bf(a,c);Yd(e,x[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);d=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}d=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(d+1|0){case 0:case 2:d=fb-32|0;fb=d;v[d+31|0]=0;yj(d+8|0,d+31|0);Im(d+20|0,f,x[d+8>>2],x[d+12>>2]);v[b|0]=y[d+31|0];fb=d+32|0;break c;default:break d}}ZY(f,b,d)}f=c}cf(a,f);fb=e+16|0}function oO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=ac(8);x[31785]=0;b=P(37,f+4|0,8220)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}zl(a,b,2);c=lz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;jc(a)}Q(e|0)}p()}function gO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!(e?d:0)){a=ac(8);x[31785]=0;b=P(37,f+4|0,8220)|0;c=x[31785];x[31785]=0;if((c|0)==1){break c}nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}e=N()|0;tb(b);break b}zl(a,b,2);c=nz(a,c,d,e,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c|0}e=N()|0;jc(a)}Q(e|0)}p()}function dba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Ko(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31785]=0;O(113,a|0,uh(e,d)|0);d=x[31785];x[31785]=0;if((d|0)!=1){a:{while(1){if(uh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[cc(c+4|0,b)|0];x[31785]=0;O(114,a|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function _R(a,b){var c=0,d=0,e=0,f=0;c=x[a>>2];x[a>>2]=b;if(c){b=fb-16|0;fb=b;d=vb(x[c>>2]);x[b+12>>2]=d;f=vb(x[c+4>>2]);while(1){a:{b:{if(Ib(d,f)){while(1){a=x[d>>2];e=x[a>>2];if(!e){break b}hQ(a,e);a=x[x[e>>2]+8>>2];x[31785]=0;W(a|0,e|0);a=x[31785];x[31785]=0;if((a|0)!=1){continue}break}T(0)|0;Rb();p()}a=sc(c);fb=b+16|0;break a}Eb(a+20|0);Eb(a+8|0);Db(a);d=x[Pe(b+12|0)>>2];continue}break}Db(a)}}function _A(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&240|c&15;break a}c=d&15;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}xk(a,b,b+700|0,0-c|0,0);if(x[b+700>>2]<65536){break b}if(Pb(a+1074312|0,7)|(x[a+480180>>2]!=4?y[a+480208|0]&16:0)){break b}x[b+700>>2]=65535}}function FA(a,b){a=a|0;b=b|0;var c=E(0),d=0,e=0,f=0;v[a+1074368|0]=b;SR(a+1074332|0,b);a=a+906300|0;f=Dj(a);while(1){if((a|0)!=(f|0)){b=x[a>>2];if(b){c=E(1);d=x[b+20>>2];if(d){c=E(E(y[d+26|0])*E(.10000000149011612))}c=c<E(.10000000149011612)?E(1):c;if(ib[x[x[b>>2]+140>>2]](b)|0){d=x[b+16>>2];e=d+1074332|0;c=E(E(c/B[e+8>>2])*E(E(A[d+480232>>2])/B[e+20>>2]))}B[b+4196>>2]=c}a=a+160|0;continue}break}}function BH(a,b,c,d,e,f,g,h,i){var j=0;x[31785]=0;W(1005,a|0);j=x[31785];x[31785]=0;a:{b:{if((j|0)!=1){j=x[a+24>>2];x[31785]=0;b=sa(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,h|0,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function tx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Uk(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31785]=0;O(113,a|0,uh(e,d)|0);d=x[31785];x[31785]=0;if((d|0)!=1){a:{while(1){if(uh(x[c+8>>2],y[c+15|0])>>>0>b>>>0){d=v[cc(c+4|0,b)|0];x[31785]=0;O(114,a|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}b=b+1|0;continue}break}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function io(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Uk(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31785]=0;O(113,a|0,uh(e,d)|0);d=x[31785];x[31785]=0;if((d|0)!=1){a:{b:{while(1){if(uh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=v[cc(c+4|0,b)|0];x[31785]=0;O(114,a|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function Fda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31785]=0;W(1005,a|0);d=x[31785];x[31785]=0;e=1;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31785]=0;S(1101,d|0,b|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,10331,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();e=0}return e|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function hpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;b=-1;a:{if(!ih(a,8)){break a}b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;d=gc(b+8|0,b+24|0,8);nd(b+16|0,a,x[d>>2],x[d+4>>2]);b:{if(x[b+20>>2]!=8){break b}if(Ob(b+24|0,14244,8)){break b}fd(a,8);e=1}fb=b+32|0;b=0;if(!e){break a}b=-1;if(!kk(a,c+8|0)){break a}b=0;if(!$b(x[c+12>>2])){break a}b=!($b(x[c+8>>2])&-2139062144)}fb=c+16|0;return b|0}function LH(a,b,c){a=Fb(a);x[31785]=0;O(c|0,a|0,4);c=x[31785];x[31785]=0;a:{b:{if((c|0)==1){break b}x[31785]=0;O(b|0,a|0,32);c=x[31785];x[31785]=0;if((c|0)==1){break b}x[31785]=0;O(b|0,a|0,10);c=x[31785];x[31785]=0;if((c|0)==1){break b}x[31785]=0;O(b|0,a|0,13);c=x[31785];x[31785]=0;if((c|0)==1){break b}x[31785]=0;O(b|0,a|0,9);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}b=N()|0;tb(a);Q(b|0);p()}}function xE(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+7|0]){while(1){if((d|0)==7){d=0;v[c+27|0]=0;v[c+28|0]=0;v[c+29|0]=0;v[c+30|0]=0;x[c+24>>2]=0;e=gc(c+8|0,c+24|0,7);nd(c+16|0,a,x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=7){break b}if(Ob(c+24|0,b,7)){break b}fd(a,7);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17688,9099,601,13243);p()}_(17667,9099,599,13243);p()}return d}function QM(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Of(c+4|0,b);b=0;a=Fb(a);d=y[c+15|0];e=x[c+8>>2];x[31785]=0;O(96,a|0,uh(e,d)|0);d=x[31785];x[31785]=0;if((d|0)!=1){a:{b:{while(1){if(uh(x[c+8>>2],y[c+15|0])>>>0<=b>>>0){break b}d=y[cc(c+4|0,b)|0];x[31785]=0;O(98,a|0,d|0);d=x[31785];x[31785]=0;if((d|0)!=1){b=b+1|0;continue}break}break a}tb(c+4|0);fb=c+16|0;return}}b=N()|0;tb(a);tb(c+4|0);Q(b|0);p()}function iX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+8|0]){while(1){if((d|0)==8){x[c+24>>2]=0;x[c+28>>2]=0;d=gc(c+8|0,c+24|0,8);e=x[d>>2];kc(c+16|0,x[a>>2],x[a+8>>2],e,x[d+4>>2]);d=0;b:{if(x[c+20>>2]!=8){break b}if(Ob(c+24|0,b,8)){break b}Yb(a,8);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17688,9099,601,13243);p()}_(17667,9099,599,13243);p()}return d|0}function hN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Nf(a)|0)>(b|0)){break d}}b=ac(8);x[31785]=0;c=P(37,c+4|0,10745)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return(x[(a+D(b,872)|0)+1075080>>2]&134218752)!=0|0}a=N()|0;jc(b)}Q(a|0)}p()}function Hda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;x[31785]=0;W(1005,a|0);d=x[31785];x[31785]=0;a:{b:{if((d|0)!=1){d=x[a+24>>2];x[31785]=0;e=+oa(1097,d|0,b|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,5370,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();e=0}return+e}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function yna(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[b+12>>1]=0;w[b+14>>1]=1;Pf(b+14|0,z[x[x[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=fb-16|0;fb=d;c=z[b+14>>1];x[d+12>>2]=c;a:{if(Bn(a)>>>0>=c>>>0){g=x[a>>2];f=Xc(g,x[a+4>>2]);x[d+8>>2]=f;uv(g,x[Gb(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){jp(a,c-f|0,e);break a}xn(a,x[a>>2]+(c<<1)|0);break a}HU(a);tC(a,ik(a,c));jp(a,c,e)}fb=d+16|0;fb=b+16|0}
function Zea(a){a=a|0;var b=0,c=0,d=0;x[31785]=0;W(1030,a|0);b=x[31785];x[31785]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+44>>2];x[31785]=0;c=+ia(d|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,11755,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function E2(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;x[31785]=0;a=Ha(1104,a|0,b|0,c|0,d|0)|0;b=x[31785];x[31785]=0;a:{b:{if((b|0)==1){Y(T(0)|0)|0;x[31785]=0;ga(988,11213,e|0,f|0,g|0,h|0,i|0,j|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}Z();a=-255}break a}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}return a|0}function tY(a){var b=0;a:{if(Ob(a,14408,3)|(y[a+3|0]-52&255)>>>0<252){break a}if($b(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))+788>>>0<840){break a}if($b(y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24))>>>0<52){break a}if($b(y[a+24|0]|y[a+25|0]<<8|(y[a+26|0]<<16|y[a+27|0]<<24))-1>>>0<51){break a}b=$b(y[a+32|0]|y[a+33|0]<<8|(y[a+34|0]<<16|y[a+35|0]<<24))>>>0<4294967216}return b}function Xea(a){a=a|0;var b=0,c=0,d=0;x[31785]=0;W(1030,a|0);b=x[31785];x[31785]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+36>>2];x[31785]=0;c=+ia(d|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,7814,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Vea(a){a=a|0;var b=0,c=0,d=0;x[31785]=0;W(1030,a|0);b=x[31785];x[31785]=0;a:{b:{if((b|0)!=1){b=x[a+28>>2];d=x[x[b>>2]+28>>2];x[31785]=0;c=+ia(d|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,7762,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Lka(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);x[31785]=0;W(812,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){e=fb-16|0;fb=e;d=vi(e+4|0,a,2304);b=x[d+4>>2];f=x[d+8>>2];while(1){if((b|0)==(f|0)){hc(d);fb=e+16|0}else{Kw(b);b=b+2|0;x[d+4>>2]=b;continue}break}b=c+8|0;Md(b);Wj(b);fb=c+16|0;return a|0}a=N()|0;Wj(c+8|0);Q(a|0);p()}function Ti(a){var b=0,c=0;b=fb-16|0;fb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Lp(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(VH(a,b)&3){case 0:a=Lp(C[b>>3],C[b+8>>3],1);break a;case 1:a=Kp(C[b>>3],C[b+8>>3]);break a;case 2:a=-Lp(C[b>>3],C[b+8>>3],1);break a;default:break b}}a=-Kp(C[b>>3],C[b+8>>3])}fb=b+16|0;return a}function b1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;if(!Mb(x[b>>2],x[b+8>>2],c)){c=jf(b)}x[a>>2]=c;c=x[b>>2];a:{if(ib[x[x[c>>2]+16>>2]](c)|0){c=a;a=x[b>>2];e=c,f=(ib[x[x[a>>2]+20>>2]](a)|0)+x[b+8>>2]|0,x[e+4>>2]=f;break a}Uj(a+8|0,x[a>>2]);c=x[a+8>>2];a=x[a+12>>2];if(mc(c,a)){break a}le(d+8|0,c,a);kc(d,x[b>>2],x[b+8>>2],x[d+8>>2],x[d+12>>2])}fb=d+16|0}function jN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{d:{if((b|0)>=0){a=x[a+32>>2];if((Nf(a)|0)>(b|0)){break d}}b=ac(8);x[31785]=0;c=P(37,c+4|0,10745)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+x[(a+D(b,872)|0)+1075740>>2]*.015625)}a=N()|0;jc(b)}Q(a|0)}p()}function hz(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;a:{if(y[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=x[a+16>>2];if(b>>>0<=c>>>0){break a}b=cM(b,4096);bM(a,b-c|0);c=x[a+16>>2];b=gc(d+16|0,xb(x[a+4>>2],c),b-c|0);c=x[x[a>>2]+44>>2];e=x[b+4>>2];x[d+8>>2]=x[b>>2];x[d+12>>2]=e;ib[c|0](d+24|0,a,d+8|0);x[a+16>>2]=x[a+16>>2]+x[d+28>>2];if(!(ib[x[x[a>>2]+40>>2]](a)|0)){break a}v[a+20|0]=1}fb=d+32|0}function jta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{e=be(a);b:{if(e>>>0>1){break b}c:{if(e){x[31785]=0;S(337,d+4|0,a|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=d+4|0;pn(b,a);dc(a);break c}a=T(29088)|0;if((gb|0)!=($(29088)|0)){break a}Y(a|0)|0;Z();break b}if(!Mb(x[a>>2],x[a+8>>2],c)){break b}jw(a,b,c)}f=Sc(x[b>>2],x[b+4>>2])>>>0>=c>>>0}fb=d+16|0;return f|0}Q(a|0);p()}function bE(a,b,c){var d=0,e=0,f=0;d=x[c+16>>2];a:{if(!d){if(a0(c)){break a}d=x[c+16>>2]}f=x[c+20>>2];if(d-f>>>0<b>>>0){return ib[x[c+36>>2]](c,a,b)|0}b:{if(x[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(y[e+a|0]!=10){continue}break}e=ib[x[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=x[c+20>>2]}yc(f,a,b);x[c+20>>2]=x[c+20>>2]+b;e=b+d|0}return e}function aba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{d=Dk(x[b+4>>2],x[b+8>>2]);if(!d){break a}x[31785]=0;O(1130,a|0,d|0);e=x[31785];x[31785]=0;if((e|0)!=1){e=x[b+8>>2];b=x[b+4>>2];x[31785]=0;V(1131,a|0,b|0,e|0,d|0);a=x[31785];x[31785]=0;if((a|0)!=1){break a}}a=N()|0;UM(c+8|0);Q(a|0);p()}a=c+8|0;Md(a);UM(a);fb=c+16|0}function Ala(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Jb(c);c=Bb(x[c+4>>2],y[c+11|0]);a:{d=Bb(x[a+4>>2],y[a+11|0]);if(d>>>0>=b>>>0){e=Lc(a);if(c>>>0<=e-d>>>0){if(!c){break a}e=Jb(a);h=e+b|0;if((b|0)!=(d|0)){g=b+e|0;Ri(c+g|0,g,d-b|0);f=(f>>>0>=g>>>0?d+e>>>0>f>>>0?c:0:0)+f|0}Ri(h,f,c);b=c+d|0;jg(a,b);ed(b+e|0,0);break a}Dq(a,e,(c+d|0)-e|0,d,b,0,c,f);break a}Pl();p()}return a|0}function AH(a,b,c,d,e,f,g){var h=0;x[31785]=0;W(1005,a|0);h=x[31785];x[31785]=0;a:{b:{if((h|0)!=1){h=x[a+24>>2];x[31785]=0;b=ha(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,f|0,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function rV(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+30|0]=0;v[a+31|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function hra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);b:{f=b+c|0;c=Tj(b,f);if(c){x[31785]=0;O(348,a|0,c|0);e=x[31785];x[31785]=0;if((e|0)==1){break b}e=fb-16|0;fb=e;a=Sl(e+4|0,a,c);g=a,h=YY(b,f,x[a+4>>2]),x[g+4>>2]=h;hc(a);fb=e+16|0}a=d+8|0;Md(a);aj(a);fb=d+16|0;break a}a=N()|0;aj(d+8|0);Q(a|0);p()}}function Wsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,15);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0;v[b+14|0]=0}}function WJ(a,b,c){var d=0,e=0,f=E(0),g=0,h=E(0);e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31660];x[31660]=0;Kd();d=fb-16|0;fb=d;uy(d,a,e+12|0,0);f=uG(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31660];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31660]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function Kda(a,b){a=a|0;b=b|0;var c=0,d=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;d=1;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31785]=0;O(1096,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,10910,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();d=0}return d|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function AX(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+27|0]=0;v[a+28|0]=0;v[a+29|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function qO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=ac(8);x[31785]=0;c=P(37,e+4|0,8220)|0;b=x[31785];x[31785]=0;if((b|0)==1){break c}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}zl(a,b,1);c=lz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;jc(a)}Q(b|0)}p()}function iO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a:{b:{c:{if(!d){a=ac(8);x[31785]=0;c=P(37,e+4|0,8220)|0;b=x[31785];x[31785]=0;if((b|0)==1){break c}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}zl(a,b,1);c=nz(a,c,d,0,0,0);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=e+16|0;return c|0}b=N()|0;jc(a)}Q(b|0)}p()}function Rqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,14);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0;v[b+12|0]=0;v[b+13|0]=0}}function Gv(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{b:{switch(a|0){case 0:a=b>>31<<6|b>>>26;b=b<<6;a=Fc(tua(b- -8192|0,a-((b>>>0<4294959104)-1|0)|0,16384,0),hb);break a;case 1:a=b>>31<<6|b>>>26;b=(b<<6)+2048|0;a=b>>>0<2048?a+1|0:a;a=Fc(tua(b,a,4096,0),hb);break a;default:break b}}x[c+8>>2]=1;a=Xi(dK(8192/+x[We(c+12|0,c+8|0)>>2])*24+8)}fb=c+16|0;a=(a|0)>=64?64:a;return(a|0)>0?a:0}function x3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=v[e|0];f=4;if(!Ef(x[d+8>>2],64,e)){break b}f=4;g=jl(d,e);while(1){c:{e=x[a>>2]+1|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=v[e|0];if(!Ef(x[d+8>>2],64,e)){break a}f=f-1|0;g=jl(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}function nj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(qh(a,f+12|0)){break b}h=rl(x[a>>2]);g=4;if(!Ef(x[d+8>>2],64,h)){break b}b=jl(d,h);while(1){c:{b=b-48|0;h=Bm(a);if(qh(h,f+12|0)|(e|0)<2){break c}g=rl(x[h>>2]);if(!Ef(x[d+8>>2],64,g)){break a}e=e-1|0;b=jl(d,g)+D(b,10)|0;continue}break}g=2;if(!qh(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function mia(a){a=a|0;var b=0,c=0;b=x[a+20>>2];x[b+148>>2]=-1;x[31785]=0;O(290,b+4|0,8);b=x[31785];x[31785]=0;if((b|0)!=1){b=x[a+4264>>2];c=x[x[a+20>>2]+4>>2];a=x[a+4260>>2];v[c|0]=a;v[c+1|0]=a>>>8;v[c+2|0]=a>>>16;v[c+3|0]=a>>>24;v[c+4|0]=b;v[c+5|0]=b>>>8;v[c+6|0]=b>>>16;v[c+7|0]=b>>>24;return}b=T(125240)|0;if((gb|0)==($(125240)|0)){Y(b|0)|0;So(x[a+20>>2]+4|0);Z();return}Q(b|0);p()}function lfa(a){a=a|0;var b=0;x[31785]=0;W(1030,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){x[a+24>>2]=0;b=x[a+28>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+28>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31785]=0;V(992,5071,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function ZM(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31785]=0;d=P(37,d+4|0,10745)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,d);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(d);break b}e=(x[a+32>>2]+D(b,872)|0)+1075766|0,f=dC(c*32768),w[e>>1]=f;fb=d+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Ska(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{d=gh(x[b>>2],x[b+4>>2]);if(!d){break a}x[31785]=0;O(805,a|0,d|0);e=x[31785];x[31785]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31785]=0;VT(a,b,e,d);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}a=N()|0;Iu(c+8|0);Q(a|0);p()}b=c+8|0;Md(b);Iu(b);fb=c+16|0;return a|0}function Qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{d=oc(x[b>>2],x[b+4>>2]);if(!d){break a}x[31785]=0;O(228,a|0,d|0);e=x[31785];x[31785]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31785]=0;so(a,b,e,d);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}a=N()|0;_g(c+8|0);Q(a|0);p()}b=c+8|0;Md(b);_g(b);fb=c+16|0;return a|0}function Ooa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=kC(a,b);x[31785]=0;c=P(687,a+12|0,b+12|0)|0;d=x[31785];x[31785]=0;b:{c:{if((d|0)!=1){x[31785]=0;P(688,a+24|0,b+24|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break c}c=x[b+40>>2];x[a+36>>2]=x[b+36>>2];x[a+40>>2]=c;w[a+52>>1]=z[b+52>>1];c=x[b+48>>2];x[a+44>>2]=x[b+44>>2];x[a+48>>2]=c;break a}b=N()|0;break b}b=N()|0;dc(c)}dc(a);Q(b|0);p()}}function Oga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Mi(a,b,c,d);x[a>>2]=44480;b=Nb(a+4208|0);x[a+4240>>2]=0;x[a+4244>>2]=0;c=x[c+24620>>2];x[a+4260>>2]=0;x[a+4256>>2]=c;x[a+4236>>2]=0;c=a+4228|0;x[c>>2]=1048550822;x[c+4>>2]=1048550822;x[a+4220>>2]=1056964608;x[a+4224>>2]=1056964608;x[31785]=0;O(950,a+44|0,2);c=x[31785];x[31785]=0;if((c|0)!=1){return a|0}c=N()|0;sc(b);Uf(a);Q(c|0);p()}function kC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{d=Sc(x[b>>2],x[b+4>>2]);if(!d){break a}x[31785]=0;O(325,a|0,d|0);e=x[31785];x[31785]=0;if((e|0)!=1){e=x[b+4>>2];b=x[b>>2];x[31785]=0;fv(a,b,e,d);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}a=N()|0;aj(c+8|0);Q(a|0);p()}b=c+8|0;Md(b);aj(b);fb=c+16|0;return a|0}function aO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=fb-32|0;fb=b;c=gc(b+24|0,c,d);d=x[c+4>>2];x[b>>2]=x[c>>2];x[b+4>>2]=d;a:{a=hu(a,b,0);if(a+1>>>0>=3){a=ac(8);x[31785]=0;b=P(37,b+12|0,8077)|0;c=x[31785];x[31785]=0;b:{if((c|0)!=1){nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0);p()}fb=b+32|0;return a|0}p()}function Pn(a,b,c,d,e,f){var g=0;x[31785]=0;W(1005,a|0);g=x[31785];x[31785]=0;a:{b:{if((g|0)!=1){g=x[a+24>>2];x[31785]=0;b=ba(f|0,g|0,b|0,c|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,e|0,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=0}return b}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;oM(a,c);fb=c+16|0}function t_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=vb(x[b>>2]);x[d+28>>2]=a;b=vb(x[b+4>>2]);a:{while(1){if(Ib(a,b)){ti(d+8|0,x[a>>2],x[a+4>>2]);if(($b(x[d+8>>2])|0)==(c|0)){f=d+8|0;ep(f,a);x[31785]=0;O(363,e|0,f|0);a=x[31785];x[31785]=0;if((a|0)==1){break a}ub(d+8|0)}a=x[rn(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Qc(e);Q(a|0);p()}function raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;mM(a,c);fb=c+16|0}function o0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=-1;a:{if(!ih(a,7)){break a}c=0;if(!xE(a,11795)){break a}c=fb-16|0;fb=c;f=d+5|0;ww(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){uE(f)}c=-1;if(!e){break a}c=0;if(!wE(y[d+6|0])){break a}c=xe(a,b,vE(d+5|0),hb)}fb=d+16|0;return c|0}function laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;iM(a,c);fb=c+16|0}function UJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{c:{if((a|0)!=(b|0)){g=x[31660];x[31660]=0;Kd();d=fb-16|0;fb=d;uy(d,a,e+12|0,1);f=kx(x[d>>2],x[d+4>>2],x[d+8>>2],x[d+12>>2]);fb=d+16|0;a=x[31660];if(!a){break c}if(x[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}x[c>>2]=4;break a}x[31660]=g;if(x[e+12>>2]==(b|0)){break a}}x[c>>2]=4;f=h}fb=e+16|0;return f}function Aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=fb-16|0;fb=c;a:{if(C[a+24>>3]==1){break a}h=x[b>>2];f=x[b+4>>2];i=x[b+8>>2];b:while(1){if((e|0)==(i|0)){break a}j=D(e,f);d=0;while(1)if((d|0)==(f|0)){e=e+1|0;continue b}else{g=(d+j<<3)+h|0;C[g>>3]=C[a+24>>3]*C[g>>3];d=d+1|0;continue}}}x[c+8>>2]=x[b+8>>2];d=x[b+4>>2];x[c>>2]=x[b>>2];x[c+4>>2]=d;sM(a,c);fb=c+16|0}function $ia(a){a=a|0;var b=0,c=0,d=0,e=0;e=fb-16|0;fb=e;b=Dc(2500);c=fb-2496|0;fb=c;jQ(a,c,c+2496|0);a=0;while(1){if((a|0)==624){x[b+2496>>2]=0;a:{if(x[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!x[b+d>>2]){continue}break a}break}x[b>>2]=-2147483648}fb=c+2496|0}else{d=a<<2;x[d+b>>2]=x[c+d>>2];a=a+1|0;continue}break}a=x[uf(e+12|0,b)>>2];fb=e+16|0;return a|0}function ek(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+4|0]){while(1){if((d|0)==4){d=0;x[c+28>>2]=0;e=gc(c+8|0,c+28|0,4);kc(c+20|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+24>>2]!=4){break b}if(Ob(c+28|0,b,4)){break b}Yb(a,4);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17688,9099,601,13243);p()}_(17667,9099,599,13243);p()}return d|0}function T8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=x[a+24>>2];e=x[a+28>>2];if(d>>>0>=e>>>0){if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{x[f+12>>2]=e-d>>2;x[f+8>>2]=c-g;e=d;d=x[pd(f+12|0,f+8|0)>>2];Wi(e,b,d);e=d<<2;x[a+24>>2]=e+x[a+24>>2];g=g+d|0;b=b+e|0}continue}break}fb=f+16|0;return g|0}function ox(a,b){var c=0,d=0,e=0,f=0,g=0;f=fb-16|0;fb=f;d=zb(f+12|0,x[a+4>>2]);g=zb(f+8|0,x[a>>2]);e=zb(f+4|0,x[b+4>>2]);d=x[d>>2];g=x[g>>2];c=fb-16|0;fb=c;x[c+8>>2]=x[e>>2];x[c+12>>2]=d;while(1){e=x[c+8>>2];if(Pg(d,g)){hs(mx(e),On(d));e=tm(c+12|0);tm(c+8|0);d=x[e>>2];continue}break}fb=c+16|0;x[b+4>>2]=e;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),Ac(b));x[b>>2]=x[b+4>>2];fb=f+16|0}function jna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;d=-1;a:{if(!ih(a,1)){break a}if((vr(a)|0)==3){while(1){if((e|0)==127){d=1;break a}c=fb-16|0;fb=c;Br(c+8|0,b);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;c=(f|0)==(g|0);if(!c){or(b)}if(!c){break a}e=e+1|0;if(cV(b)){continue}break}}d=0}fb=b+16|0;return d|0}function JK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=Cc(d+8|0,c);x[31785]=0;S(1194,d+20|0,b|0,e|0);c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){x[31785]=0;a=P(1195,a|0,d+20|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break b}tb(d+20|0);tb(e);x[a>>2]=124512;c=x[b+4>>2];x[a+8>>2]=x[b>>2];x[a+12>>2]=c;fb=d+32|0;return a|0}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(e);Q(c|0);p()}function Gda(a,b){a=a|0;b=+b;var c=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){c=x[a+24>>2];x[31785]=0;b=+Wa(1098,c|0,+b);c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,7626,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=0}return+b}a=N()|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;if((c|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function LX(a,b){var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(!y[b+5|0]){while(1){if((d|0)==5){d=0;v[c+28|0]=0;x[c+24>>2]=0;e=gc(c+8|0,c+24|0,5);kc(c+16|0,x[a>>2],x[a+8>>2],x[e>>2],x[e+4>>2]);b:{if(x[c+20>>2]!=5){break b}if(Ob(c+24|0,b,5)){break b}Yb(a,5);d=1}fb=c+32|0;break a}e=b+d|0;d=d+1|0;if(y[e|0]){continue}break}_(17688,9099,601,13243);p()}_(17667,9099,599,13243);p()}return d}function zx(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47892;h=Dc(80);x[31785]=0;d=R(1108,d|0)|0;i=x[31785];x[31785]=0;a:{b:{if((i|0)!=1){x[g+8>>2]=d;d=x[oe(g+12|0,g+8|0)>>2];x[31785]=0;b=ha(f|0,h|0,b|0,c-b|0,d|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break b}x[a+4>>2]=b;Uc(g+8|0);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Uc(g+8|0)}Db(h);Q(a|0);p()}function Zha(a,b){a=a|0;b=b|0;var c=E(0);a:{switch(b|0){case 0:return E(B[a+4220>>2]);case 1:return E(B[a+4224>>2]);case 2:return E(B[a+4228>>2]);case 3:return E(y[a+4240|0]?E(1):E(0));case 4:return E(E(E(x[a+4232>>2])*E(.03125)));case 5:return E(y[a+4241|0]?E(1):E(0));case 6:return E(y[a+4242|0]?E(1):E(0));case 7:c=y[a+4244|0]?E(1):E(0);break;default:break a}}return E(c)}function qs(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;x[a+4>>2]=0;x[a>>2]=47892;h=Dc(80);x[31785]=0;d=R(1108,d|0)|0;i=x[31785];x[31785]=0;a:{b:{if((i|0)!=1){x[g+8>>2]=d;d=x[oe(g+12|0,g+8|0)>>2];x[31785]=0;b=ha(f|0,h|0,b|0,c|0,d|0,e|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break b}x[a+4>>2]=b;Uc(g+8|0);fb=g+16|0;return a}a=N()|0;break a}a=N()|0;Uc(g+8|0)}Db(h);Q(a|0);p()}function lna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{c=x[b+4>>2];if(!c){break a}f=a+480190|0;w[d>>1]=z[f>>1];w[d+14>>1]=c-1;c=z[Mc(d,d+14|0)>>1];while(1){if(!c){break a}b:{if(mC(x[b>>2],c)){break b}if(GR(a,c&65535)){e=Cc(d,22485);zc(((c<<5)+a|0)+946304|0,e);tb(e)}if(c>>>0<2){break b}e=z[f>>1];if((e|0)!=(c|0)){break b}w[f>>1]=e-1}c=c-1|0;continue}}fb=d+16|0}function iea(a){a=a|0;var b=0,c=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31785]=0;b=R(1073,b|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,7298,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();b=0}return b|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function U5(a){a=a|0;if(y[500736]){return x[125183]}if(!y[501256]){v[501256]=1}sd(501088,120392);sd(501100,120420);sd(501112,120448);sd(501124,120480);sd(501136,120520);sd(501148,120556);sd(501160,120584);sd(501172,120620);sd(501184,120636);sd(501196,120652);sd(501208,120668);sd(501220,120684);sd(501232,120700);sd(501244,120716);v[500736]=1;x[125183]=501088;return 501088}function rC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;e=Nb(a);a=vb(x[b>>2]);x[d+28>>2]=a;b=vb(x[b+4>>2]);a:{while(1){if(Ib(a,b)){ti(d+8|0,x[a>>2],x[a+4>>2]);if(x[d+8>>2]==(c|0)){f=d+8|0;ep(f,a);x[31785]=0;O(363,e|0,f|0);a=x[31785];x[31785]=0;if((a|0)==1){break a}ub(d+8|0)}a=x[rn(d+28|0)>>2];continue}break}fb=d+32|0;return}a=N()|0;ub(d+8|0);Qc(e);Q(a|0);p()}function j9(){var a=0,b=0,c=0,d=0,e=0,f=0;b=fb-48|0;fb=b;if(tL(0,b+24|0)){qt(x[31660],12763);p()}a=te(b+16|0,x[b+24>>2],x[b+28>>2]);d=MA(b+8|0,x[b+32>>2]/1e3|0);c=fb-16|0;fb=c;a=nu(c,x[a>>2],x[a+4>>2]);e=x[a>>2];f=e+x[d>>2]|0;a=x[d+4>>2]+x[a+4>>2]|0;a=te(c+8|0,f,f>>>0<e>>>0?a+1|0:a);d=x[a>>2];fb=c+16|0;c=te(b+40|0,d,x[a+4>>2]);a=x[c>>2];fb=b+48|0;hb=x[c+4>>2];return a|0}function rea(a){a=a|0;var b=0,c=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;a:{b:{if((b|0)!=1){b=x[a+24>>2];x[31785]=0;c=+ia(1064,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break b}}Y(T(0)|0)|0;x[31785]=0;V(992,7698,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();c=0}return+c}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function ay(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;if(1073741807-b>>>0>=c>>>0){i=Jb(a);h=g+4|0;if(b>>>0<=536870886){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=jn(x[_c(g+4|0,g+12|0)>>2])+1|0}else{c=1073741807}Rj(h,c);c=x[g+4>>2];if(e){Wi(c,i,e)}h=e+f|0;if((h|0)!=(d|0)){e=e<<2;Wi(e+c|0,(e+i|0)+(f<<2)|0,d-h|0)}if((b|0)!=1){Db(i)}vd(a,c);nf(a,x[g+8>>2]);fb=g+16|0;return}of();p()}function VZ(a){var b=0,c=0;a:{if(Ob(a,15378,3)){break a}c=y[a+3|0];if(c>>>0>9){break a}if((Cb(y[a+202|0]|y[a+203|0]<<8)-1e4&65535)>>>0<57516){break a}b=1;b:{if(c>>>0>5){break b}if(!Cb(y[a+228|0]|y[a+229|0]<<8)){break a}if(!Cb(y[a+230|0]|y[a+231|0]<<8)){break a}b=0;if(Cb(y[a+232|0]|y[a+233|0]<<8)>>>0>4095){break b}b=Cb(y[a+234|0]|y[a+235|0]<<8)>>>0<100}return b}return 0}function TA(a,b,c){var d=0,e=0,f=0;f=Fb(a);d=y[b+11|0];e=x[b+4>>2];a=0;x[31785]=0;O(54,f|0,Wc(e,d)|0);d=x[31785];x[31785]=0;if((d|0)!=1){a:{while(1){if(Wc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=65533;e=v[cc(b,a)|0];if((e|0)>=-96){d=x[((e&255)<<2)+c>>2]}x[31785]=0;O(36,f|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Sb(f);Q(a|0);p()}function OP(a){var b=E(0),c=0,d=E(0);b=B[a+4224>>2];B[a+4260>>2]=M(E(E(1)-E(b*b)));v[a+4264|0]=B[a+4236>>2]>E(.5);d=E(A[a+4256>>2]);b=E(E(E(E(B[a+4228>>2]*E(1999))+E(1))/E(1e3))*d);a:{if(b<E(4294967296)&b>=E(0)){c=~~b>>>0;break a}c=0}x[a+4248>>2]=c;c=a+4252|0;b=E(E(E(E(B[a+4232>>2]*E(1999))+E(1))/E(1e3))*d);b:{if(b<E(4294967296)&b>=E(0)){a=~~b>>>0;break b}a=0}x[c>>2]=a}function ysa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-240|0;fb=d;c=fb-16|0;fb=c;f=d+4|0;TZ(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){SZ(f)}c=-1;a:{if(!e){break a}c=0;if(!VZ(d+4|0)){break a}c=xe(a,b,UZ(y[d+8|0]|y[d+9|0]<<8|(y[d+10|0]<<16|y[d+11|0]<<24)),hb)}fb=d+240|0;return c|0}function via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=Dc(64);x[31785]=0;e=R(882,c|0)|0;f=x[31785];x[31785]=0;a:{if((f|0)!=1){c=uf(d+8|0,e);e=x[c>>2];x[31785]=0;a=U(948,e|0,a|0,b|0)|0;b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}rc(d+12|0);break b}a=N()|0;Ig(c);break a}oe(d+12|0,c)}Ig(c);fb=d+16|0;return x[d+12>>2]}a=N()|0;Db(c)}Q(a|0);p()}function H3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=x[a>>2];f=6;a:{b:{if((e|0)==(b|0)){break b}e=x[e>>2];f=4;if(!uj(d,64,e)){break b}g=qk(d,e);f=4;while(1){c:{e=x[a>>2]+4|0;x[a>>2]=e;g=g-48|0;if((b|0)==(e|0)|f>>>0<2){break c}e=x[e>>2];if(!uj(d,64,e)){break a}f=f-1|0;g=qk(d,e)+D(g,10)|0;continue}break}if((b|0)!=(e|0)){break a}f=2}x[c>>2]=f|x[c>>2]}return g|0}function Gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a:{b:{if((uk(y[a+140|0])|0)!=1){break b}if((HM(a)|0)!=(b|0)){break b}d=a+120|0;Jt(y[d+20|0]);b=fb-16|0;fb=b;x[b+12>>2]=c+15;a=fb-16|0;fb=a;e=x[18443];x[a+8>>2]=x[18442];x[a+12>>2]=e;e=x[18441];x[a>>2]=x[18440];x[a+4>>2]=e;ib[x[bq(a,uk(y[d+20|0]))>>2]](b+12|0,d);fb=a+16|0;fb=b+16|0;break a}GM(a,1,b)}fb=c+16|0}function zH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=ac(8);x[31785]=0;c=P(37,f+4|0,8220)|0;b=x[31785];x[31785]=0;if((b|0)==1){break c}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}zl(a,b,e);c=rH(a,c,e,d,76384,77156);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;jc(a)}Q(b|0)}p()}function yH(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;a:{b:{c:{if(!d){a=ac(8);x[31785]=0;c=P(37,f+4|0,8220)|0;b=x[31785];x[31785]=0;if((b|0)==1){break c}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}b=N()|0;tb(c);break b}zl(a,b,e);c=rH(a,c,e,d,75556,76328);C[a+16>>3]=C[a+16>>3]+ +(c>>>0)/+(b|0);fb=f+16|0;return c}b=N()|0;jc(a)}Q(b|0)}p()}function rN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=ac(8);x[31785]=0;c=P(37,c+4|0,7874)|0;d=x[31785];x[31785]=0;if((d|0)==1){break c}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=Xe(65536/b),x[e+480244>>2]=f;oq(a);fb=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function oN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{b:{c:{if(b<=0|b>4){a=ac(8);x[31785]=0;c=P(37,c+4|0,7895)|0;d=x[31785];x[31785]=0;if((d|0)==1){break c}nc(a,c);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}d=N()|0;tb(c);break b}a=x[a+32>>2];e=a,f=Xe(b*65536),x[e+480240>>2]=f;oq(a);fb=c+16|0;return}d=N()|0;jc(a)}Q(d|0)}p()}function i0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;b:{c:{d:{e:{if((b|0)==4){Of(a,c);break e}e=d+8|0;Of(e,c);x[31785]=0;S(126,d+20|0,b|0,e|0);b=x[31785];x[31785]=0;if((b|0)==1){break d}x[31785]=0;S(247,a|0,4,d+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(d+20|0);tb(d+8|0)}fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Sb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function WU(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Fb(a);a=y[b+11|0];e=x[b+4>>2];x[31785]=0;O(117,d|0,Wc(e,a)|0);a=x[31785];x[31785]=0;a:{if((a|0)!=1){a=wd(b);x[c+12>>2]=a;b=yf(b);while(1){if(!Ib(a,b)){break a}a=y[a|0];x[31785]=0;O(118,d|0,((a|0)==13?10:a)<<24>>24);a=x[31785];x[31785]=0;if((a|0)!=1){a=x[je(c+12|0)>>2];continue}break}}a=N()|0;tb(d);Q(a|0);p()}fb=c+16|0}function Nz(a){var b=E(0),c=E(0),d=0,e=E(0),f=0;b=E(A[x[a+16>>2]+24620>>2]);c=E(E(E(ib[x[x[a>>2]+208>>2]](a))*b)/E(1e3));d=a,e=E(E(c*E(ib[x[x[a>>2]+200>>2]](a)))*E(2048)),B[d+4248>>2]=e;d=a,f=Il(E(E(c+E(2))*E(4096))),x[d+4256>>2]=f;c=E(ib[x[x[a>>2]+212>>2]](a));B[a+4252>>2]=c;b=E(c/b);if(!(ib[x[x[a>>2]+196>>2]](a)|0)){b=WP(E(b*E(3.1415927410125732)))}B[a+4244>>2]=b+b}function Nm(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;if(2147483631-b>>>0>=c>>>0){j=Jb(a);i=h+4|0;if(b>>>0<=1073741798){x[h+12>>2]=b<<1;x[h+4>>2]=b+c;c=Ah(x[_c(h+4|0,h+12|0)>>2])+1|0}else{c=2147483631}ng(i,c);c=x[h+4>>2];if(e){yg(c,j,e)}i=e+f|0;if((i|0)!=(d|0)){yg((c+e|0)+g|0,(e+j|0)+f|0,d-i|0)}if((b|0)!=10){Db(j)}vd(a,c);nf(a,x[h+8>>2]);fb=h+16|0;return}of();p()}function mj(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=b;b=0;g=6;a:{b:{if(ji(a,f+12|0)){break b}g=4;h=ql(x[a>>2]);if(!uj(d,64,h)){break b}b=qk(d,h);while(1){c:{b=b-48|0;h=ao(a);if(ji(h,f+12|0)|(e|0)<2){break c}g=ql(x[h>>2]);if(!uj(d,64,g)){break a}e=e-1|0;b=qk(d,g)+D(b,10)|0;continue}break}g=2;if(!ji(h,f+12|0)){break a}}x[c>>2]=x[c>>2]|g}fb=f+16|0;return b}function ps(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;x[a+4>>2]=0;x[a>>2]=47892;g=Dc(80);x[31785]=0;c=R(1108,c|0)|0;h=x[31785];x[31785]=0;a:{b:{if((h|0)!=1){x[f+8>>2]=c;c=x[oe(f+12|0,f+8|0)>>2];x[31785]=0;b=ba(e|0,g|0,b|0,c|0,d|0)|0;c=x[31785];x[31785]=0;if((c|0)==1){break b}x[a+4>>2]=b;Uc(f+8|0);fb=f+16|0;return a}a=N()|0;break a}a=N()|0;Uc(f+8|0)}Db(g);Q(a|0);p()}function cN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31785]=0;c=P(37,c+4|0,10745)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=x[a+32>>2]+D(b,872)|0;x[a+1075008>>2]=0;x[a+1075068>>2]=0;fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function K4(a,b){a=a|0;b=b|0;var c=0,d=0;c=Jb(b);b=fb-32|0;fb=b;a=td(a,0);x[a>>2]=113504;d=tk(c);x[a+8>>2]=d;if(!d){a=Cc(b+8|0,c);x[31785]=0;S(1020,b+20|0,17724,a|0);c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){x[31785]=0;W(1348,b+20|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}p()}c=N()|0;break a}c=N()|0;tb(b+20|0)}tb(a);Q(c|0);p()}fb=b+32|0;x[a>>2]=119880;return a|0}function Fm(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return v[a+89360|0]}if(a>>>0<=511){return v[(a>>>5|0)+89360|0]+5|0}return v[(a>>>10|0)+89360|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return v[(a>>>15|0)+89360|0]+15|0}return v[(a>>>20|0)+89360|0]+20|0}if(a>>>0<=536870911){return v[(a>>>25|0)+89360|0]+25|0}a=v[(a>>>30|0)+89360|0]+30|0}else{a=0}return a}function zta(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+14|0;g$(c,a,b);Mf(b,y[d+14|0],y[Ic(c)|0]);a=y[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=y[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}v[b+3|0]=45;v[b+5|0]=a&15;break a}if((a|0)!=64){break a}v[b+3|0]=0;v[b|0]=254;break a}v[b+3|0]=20;v[b+5|0]=a&15|160;break a}v[b+3|0]=0}fb=d+16|0}function K9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=pm(a);x[d>>2]=78132;a=$L(Ac(d),YL(b));x[a>>2]=78464;x[31785]=0;P(344,a+24|0,65536)|0;c=x[31785];x[31785]=0;a:{if((c|0)!=1){c=a+36|0;Tb(c,0,192);e=a+228|0;while(1){x[c>>2]=0;x[c+4>>2]=0;v[c+8|0]=0;c=c+12|0;if((e|0)!=(c|0)){continue}break}Tb(e,0,64);break a}b=N()|0;Bt(a);Q(b|0);p()}x[a+292>>2]=b;x[a>>2]=78276;return d|0}function nm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Ok(d)){Ke(c,d);break c}if(d>>>0>=2147483632){break b}ng(e+8|0,Ah(d)+1|0);b=x[e+8>>2];vd(c,b);nf(c,x[e+12>>2]);Vd(c,d);c=b}Tg(c,f,d+1|0);fb=e+16|0;break a}of();p()}return a|0}function fg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Ok(d)){Ke(c,d);break c}if(d>>>0>=2147483632){break b}ng(e+8|0,Ah(d)+1|0);b=x[e+8>>2];vd(c,b);nf(c,x[e+12>>2]);Vd(c,d);c=b}yg(c,f,d+1|0);fb=e+16|0;break a}of();p()}return a|0}function d$(a,b){var c=0,d=0;b=!x[a+24>>2]|b;x[a+16>>2]=b;if(b&x[a+20>>2]){a=fb-16|0;fb=a;c=ac(16);b=fb-16|0;fb=b;if(!y[497200]){v[497200]=1}gc(b+8|0,1,126324);d=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=d;fb=b+16|0;b=x[a+12>>2];a=x[a+8>>2];x[31785]=0;a=Ca(1196,c|0,8963,a|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){da(a|0,94812,1197);p()}a=N()|0;jc(c);Q(a|0);p()}}function _M(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31785]=0;c=P(37,c+4|0,10745)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+(x[(x[a+32>>2]+D(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=N()|0;jc(b)}Q(a|0)}p()}function Rs(a,b,c){var d=0,e=0;if(c&2048){v[a|0]=43;a=a+1|0}if(c&1024){v[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){v[a|0]=46;v[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}v[a|0]=b;return(d|0)!=260}function Rp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(!Cd(y[b+11|0])){c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];return a|0}c=a;f=x[b>>2];e=fb-16|0;fb=e;a:{b:{d=x[b+4>>2];c:{if(Nq(d)){Ke(c,d);break c}if(d>>>0>=1073741808){break b}Rj(e+8|0,jn(d)+1|0);b=x[e+8>>2];vd(c,b);nf(c,x[e+12>>2]);Vd(c,d);c=b}Wi(c,f,d+1|0);fb=e+16|0;break a}of();p()}return a|0}function YM(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31785]=0;c=P(37,c+4|0,10745)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}fb=c+16|0;return+(+w[(x[a+32>>2]+D(b,872)|0)+1075766>>1]*30517578125e-15)}a=N()|0;jc(b)}Q(a|0)}p()}function ora(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;c=Bf(a,c);Yd(f,x[a+36>>2]);a:{if(!c){Pc(f,a+32|0,5);e=0;if(Hb(x[x[f>>2]>>2],x[f+4>>2])){break a}}h=x[a+36>>2];g=fb-16|0;fb=g;e=Fb(g+4|0);x[31785]=0;ba(473,b|0,h|0,e|0,d|0)|0;b=x[31785];x[31785]=0;b:{if((b|0)!=1){tb(e);fb=g+16|0;break b}a=N()|0;tb(e);Q(a|0);p()}e=c}cf(a,e);fb=f+16|0}function IQ(a,b){var c=0,d=0,e=0,f=0,g=0,h=E(0);c=fb-16|0;fb=c;d=0;a:{if(x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){break a}x[c+12>>2]=0;Ik(a,c+12|0);e=x[c+12>>2];d=0;if(e>>>0>65535){break a}vk(b,e);while(1){if((f|0)==(e|0)){d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}else{x[c+8>>2]=0;jq(a,c+8|0);g=wb(x[b>>2],f),h=B[c+8>>2],B[g>>2]=h;f=f+1|0;continue}break}}a=d;fb=c+16|0;return a}function V3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=x[b>>2];a:{b:{if(a>>>0<=127){a=x[(a<<2)+112352>>2];break b}e=(et(a)|0)!=0;e=dt(a)?e|2:e;e=ct(a)?e|4:e;e=bt(a)?e|8:e;e=at(a)?e|16:e;e=$s(a)?e|32:e;e=Kh(a)?e|64:e;e=_s(a)?e|128:e;e=Zs(a)?e|256:e;x[d>>2]=e;if(!Ys(a)){break a}a=e|512}x[d>>2]=a}d=d+4|0;b=b+4|0;continue}break}return c|0}function AR(a,b){var c=0,d=0,e=0,f=0;a:{if(z[a+480188>>1]<=b>>>0){break a}b:{c:{c=D(b,872)+a|0;d=y[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(y[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=v[c+1075785|0];d:{if((c|0)>=0){d=Me(a+901692|0,y[(D(b,872)+a|0)+1075836|0]);break d}d=Me(a+902204|0,c&127)}XS(a,e,b,f,d,c&255)}}function Bo(a,b,c,d){a:{if(x[a+480180>>2]==4){if(c){v[b+810|0]=y[b+810|0]&15|c<<4;break a}c=y[b+810|0]>>>4|0;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]+((c&255)<<2)|0;x[b+688>>2]=(c|0)>=256?256:c;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function _Q(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;if((a|0)!=(b|0)){d=fb-16|0;fb=d;c=x[b>>2];b=x[b+4>>2];e=Od(c,b);a:{if(e>>>0<=Rg(a)>>>0){f=b;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=c;OC(d+12|0,h);f=x[d+12>>2]}c=Qi(c,f,g);if(!i){so(a,f,b,e-oc(x[a>>2],x[a+4>>2])|0);break a}Yh(a,c);break a}ar(a);hm(a,Tf(a,e));so(a,c,b,e)}fb=d+16|0}return a}function Vga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a>>2]=44100;b=a+4208|0;e=wb(b,0),f=1060320051,x[e>>2]=f;e=wb(b,1),f=1041865114,x[e>>2]=f;e=wb(b,2),f=1065353216,x[e>>2]=f;e=wb(b,3),f=1049951732,x[e>>2]=f;e=wb(b,4),f=1049951732,x[e>>2]=f;x[31785]=0;O(950,a+44|0,2);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;Uf(a);Q(b|0);p()}function npa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-1120|0;fb=d;c=fb-16|0;fb=c;mX(c+8|0,d+12|0);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!oX(d+12|0)){break a}c=xe(a,b,nX(y[d+1116|0]|y[d+1117|0]<<8|(y[d+1118|0]<<16|y[d+1119|0]<<24)),hb)}fb=d+1120|0;return c|0}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(!c){break a}x[31785]=0;O(1166,a|0,c|0);e=x[31785];x[31785]=0;if((e|0)!=1){x[31785]=0;V(1167,a|0,b|0,Dd(b,c)|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}a=N()|0;VL(d+8|0);Q(a|0);p()}b=d+8|0;Md(b);VL(b);fb=d+16|0;return a|0}function BO(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;a:{e=a+36|0;c=x[e>>2];d=x[a+40>>2];b:{if(Ib(c,d)){rc(b+12|0);break b}oo(b,a);x[31785]=0;c=R(1065,b|0)|0;d=x[31785];x[31785]=0;if((d|0)==1){break a}x[b+12>>2]=c;mf(b);d=x[a+40>>2];c=x[a+36>>2]}if(!Ib(c,d)){e=x[b+12>>2];c=x[e>>2]}a=lj(c,x[e+4>>2]);vl(b+12|0);fb=b+16|0;return a|0}a=N()|0;mf(b);Q(a|0);p()}function mka(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+32;xS(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+32;hc(c);fb=d+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=Qu(d+12|0,Hq(a,Hg(x[a>>2],x[a+4>>2])+1|0),Hg(x[a>>2],x[a+4>>2]),c);xS(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;Id(a,c);uV(c);fb=d+32|0}function Wu(a,b){var c=0,d=0;c=fb-32|0;fb=c;d=c+16|0;IV(d,a,a+1|0,a+2|0,a+3|0);IV(c,b,b+1|0,b+2|0,b+3|0);b=Vu(y[x[d>>2]],y[x[c>>2]]);a:{if(!Pj(b)){break a}b=y[x[d+4>>2]];a=y[x[c+4>>2]];b=(a|0)!=(b|0)?b<<24>>24<a<<24>>24?-1:1:0;if(!Pj(b)){break a}b=Vu(y[x[d+8>>2]],y[x[c+8>>2]]);if(!Pj(b)){break a}b=Vu(y[x[d+12>>2]],y[x[c+12>>2]])}a=Cd(b);fb=c+32|0;return a}function H9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=fb-32|0;fb=e;f=x[b+292>>2];eg(x[x[f>>2]-12>>2]+f|0,0);Yd(e+16|0,x[b+292>>2]);g=ei(e,-1,-1);f=x[e+24>>2];h=x[e+28>>2];a:{if(!Un(f,h,x[g+8>>2],x[g+12>>2])){b:{if((c|0)!=(f|0)|h){break b}break a}}Ei(x[b+292>>2],c,0,0)}c=x[d>>2];zj(x[b+292>>2],c,x[d+4>>2]);bc(a,c,x[x[b+292>>2]+4>>2]);fb=e+32|0}function ufa(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){b=x[a+24>>2];if(b){Db(hq(b))}x[a+24>>2]=0;b=x[a+20>>2];if(b){Db(b);x[a+20>>2]=0}Db(a);return}Y(T(0)|0)|0;x[31785]=0;V(992,5098,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Taa(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+24;PM(x[c+4>>2],b);x[c+4>>2]=x[c+4>>2]+24;hc(c);fb=d+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=wJ(d+12|0,CJ(a,lj(x[a>>2],x[a+4>>2])+1|0),lj(x[a>>2],x[a+4>>2]),c);PM(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+24;rJ(a,c);nJ(c);fb=d+32|0}function $la(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=Fb(a);c=y[b+11|0];e=x[b+4>>2];a=0;x[31785]=0;O(50,d|0,Wc(e,c)|0);c=x[31785];x[31785]=0;if((c|0)!=1){a:{b:{while(1){if(Wc(x[b+4>>2],y[b+11|0])>>>0<=a>>>0){break b}c=v[cc(b,a)|0];x[31785]=0;O(51,d|0,vf(vf(c))|0);c=x[31785];x[31785]=0;if((c|0)!=1){a=a+1|0;continue}break}break a}return}}a=N()|0;tb(d);Q(a|0);p()}function aK(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if((a|0)!=(b|0)){g=x[31660];x[31660]=0;Kd();a=bK(a,e+12|0,d);d=hb;f=x[31660];b:{if(f){if(x[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}x[c>>2]=4;b=!!a&(d|0)>=0|(d|0)>0;a=b?-1:0;d=b?2147483647:-2147483648;break a}x[31660]=g;if(x[e+12>>2]==(b|0)){break a}}}x[c>>2]=4;a=0;d=0}fb=e+16|0;hb=d;return a}function Og(a,b){var c=0,d=0,e=0,f=0,g=0;e=Jb(a);d=Bb(x[a+4>>2],y[a+11|0]);c=gf(b);a=0;a:{if(!c){break a}a=e;d=d+a|0;c=b+c|0;b:{if((c|0)==(b|0)){break b}c:{c=c-b|0;if((c|0)>(d-a|0)){break c}g=y[b|0];while(1){f=d-a|0;if((c|0)>(f|0)){break c}a=eq(a,(f-c|0)+1|0,g);if(!a){break c}if(!Tp(a,b,c)){break b}a=a+1|0;continue}}a=d}a=(a|0)==(d|0)?-1:a-e|0}return a}function DB(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;if(2147483631-b>>>0>=c>>>0){h=Jb(a);i=g+4|0;if(b>>>0<=1073741798){x[g+12>>2]=b<<1;x[g+4>>2]=b+c;c=Ah(x[_c(g+4|0,g+12|0)>>2])+1|0}else{c=2147483631}ng(i,c);c=x[g+4>>2];if(e){Tg(c,h,e)}if((d|0)!=(e|0)){Tg((c+e|0)+f|0,e+h|0,d-e|0)}if((b|0)!=10){Db(h)}vd(a,c);nf(a,x[g+8>>2]);fb=g+16|0;return}of();p()}function qfa(a,b){a=a|0;b=b|0;var c=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){x[a+16>>2]=b;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31785]=0;V(992,5680,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function RA(a,b,c,d){a:{if(x[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=D(b,872)+a|0;x[c+1075688>>2]=0;d=c+1075e3|0;x[d>>2]=0;x[d+4>>2]=0;c=x[c+1075080>>2]|4096;break b}c=D(b,872)+a|0;x[c+1075680>>2]=0;c=x[c+1075080>>2]}d=D(b,872)+a|0;x[d+1075080>>2]=c|2097152;Um(a,b,255,0);if(!(y[d+1075081|0]&2)){break a}a=x[a+1298300>>2];if(!xd(a)){break a}Jj(a,b,0)}}function uH(a,b,c){var d=0;d=fb-16|0;fb=d;a:{b:{c:{if(b>>>0>=256){b=ac(8);x[31785]=0;c=P(37,d+4|0,10745)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}a=(x[a+32>>2]+D(b,872)|0)+1075080|0;x[a>>2]=x[a>>2]|c;fb=d+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function sN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ac(8);x[31785]=0;c=P(37,c+4|0,9383)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074420>>2]=D(b,1e4);fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function nka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;x[a>>2]=b;c=fb-16|0;fb=c;d=Dc(223888);x[31785]=0;b=P(849,d|0,b+1074376|0)|0;e=x[31785];x[31785]=0;a:{if((e|0)!=1){b=x[uf(c+12|0,b)>>2];fb=c+16|0;break a}a=N()|0;Db(d);Q(a|0);p()}x[a+4>>2]=b;b=Nb(a+8|0);x[31785]=0;W(610,a|0);c=x[31785];x[31785]=0;if((c|0)!=1){return a|0}c=N()|0;ze(b);MS(a+4|0);Q(c|0);p()}function j8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=x[a+84>>2];f=x[e>>2];d=x[e+4>>2];h=x[a+28>>2];g=x[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){yc(f,h,g);f=g+x[e>>2]|0;x[e>>2]=f;d=x[e+4>>2]-g|0;x[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){yc(f,b,d);f=d+x[e>>2]|0;x[e>>2]=f;x[e+4>>2]=x[e+4>>2]-d}v[f|0]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;return c|0}function Up(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;$c(d+12|0,b);x[31785]=0;b=R(1221,x[d+12>>2])|0;e=x[31785];x[31785]=0;a:{if((e|0)==1){break a}x[31785]=0;e=R(1229,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break a}x[c>>2]=e;x[31785]=0;O(1230,a|0,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Zb(d+12|0);fb=d+16|0;return}a=N()|0;Zb(d+12|0);Q(a|0);p()}function Hga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=dQ(a,b,c,d,e^1);x[b>>2]=44712;a=b+4208|0;f=wb(a,0),g=1056964608,x[f>>2]=g;f=wb(a,1),g=1065353216,x[f>>2]=g;f=wb(a,2),g=1020054733,x[f>>2]=g;f=wb(a,3),g=1065353216,x[f>>2]=g;f=wb(a,4),g=1056964608,x[f>>2]=g;f=wb(a,5),g=1048406533,x[f>>2]=g;f=wb(a,6),g=1056964608,x[f>>2]=g;return b|0}function oQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=KD(b,c);a:{if(e>>>0<=Qo(a)>>>0){x[d+12>>2]=c;g=x[a>>2];f=Sc(g,x[a+4>>2]);h=f>>>0>=e>>>0;if(h){f=c}else{x[d+12>>2]=b;y_(d+12|0,f);f=x[d+12>>2]}b=Qv(b,f,g);if(!h){JD(a,x[d+12>>2],c,e-Sc(x[a>>2],x[a+4>>2])|0);break a}Tq(a,b);break a}Pv(a);Yk(a,Ul(a,e));JD(a,b,c,e)}fb=d+16|0}function asa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-576|0;fb=d;c=fb-16|0;fb=c;vZ(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){uZ(d)}c=-1;a:{if(!e){break a}c=0;if(!xZ(d)){break a}c=xe(a,b,wZ(y[d+34|0]|y[d+35|0]<<8,y[d+36|0]|y[d+37|0]<<8),hb)}fb=d+576|0;return c|0}function Wp(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;$c(d+12|0,b);x[31785]=0;b=R(1204,x[d+12>>2])|0;e=x[31785];x[31785]=0;a:{if((e|0)==1){break a}x[31785]=0;e=R(1216,b|0)|0;f=x[31785];x[31785]=0;if((f|0)==1){break a}v[c|0]=e;x[31785]=0;O(1217,a|0,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Zb(d+12|0);fb=d+16|0;return}a=N()|0;Zb(d+12|0);Q(a|0);p()}function xZ(a){var b=0,c=0,d=0;a:{if(Ob(a+60|0,15756,4)|(y[a+32|0]|y[a+33|0]<<8)>>>0>256|(y[a+49|0]<32|(y[a+36|0]|y[a+37|0]<<8)>>>0>255)){break a}if(v[a+51|0]<4|y[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(y[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function G5(a){a=a|0;if(y[500728]){return x[125181]}if(!y[501080]){v[501080]=1}id(500912,5260);id(500924,5267);id(500936,5233);id(500948,5241);id(500960,5224);id(500972,5274);id(500984,5251);id(500996,9768);id(501008,9974);id(501020,11315);id(501032,12951);id(501044,5523);id(501056,10807);id(501068,6642);v[500728]=1;x[125181]=500912;return 500912}function dsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;if(A[a+4>>2]<A[Ab(a)>>2]){d=fb-16|0;fb=d;a=th(d+4|0,a,1);DZ(x[a+4>>2],z[b>>1],y[c|0]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=d+16|0;return}e=fb-32|0;fb=e;d=Ab(a);d=hg(e+12|0,Tf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),d);DZ(x[d+8>>2],z[b>>1],y[c|0]);x[d+8>>2]=x[d+8>>2]+4;Id(a,d);gg(d);fb=e+32|0}function Jr(a,b,c){var d=0,e=0,f=0,g=0;a:{d=zk(b,wd(a));b=zk(c,b);if(Bb(x[a+4>>2],y[a+11|0])>>>0>=d>>>0){if((b|0)==-1){zT(a,d);break a}e=fb-16|0;fb=e;x[e+12>>2]=b;if(b){f=Bb(x[a+4>>2],y[a+11|0]);g=Jb(a);c=f-d|0;x[e+8>>2]=c;b=x[Gb(e+12|0,e+8|0)>>2];b:{if((c|0)==(b|0)){b=c;break b}d=d+g|0;Ri(d,b+d|0,c-b|0)}Cu(a,g,f-b|0)}fb=e+16|0;break a}Pl();p()}}function Gta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;a:{if(!(c&1024)){break a}f=e,g=wd(b),x[f+12>>2]=g;c=Wc(x[b+4>>2],y[b+11|0]);b:{if(!c){break b}if(y[cc(b,0)|0]!=43){if(y[cc(b,0)|0]!=45){break b}}d=d+1|0;UU(e+12|0)}if(c>>>0>=d>>>0){break a}sE(b,x[zb(e+8|0,x[e+12>>2])>>2],d-Wc(x[b+4>>2],y[b+11|0])|0,48)}Yc(a,b);fb=e+16|0}function $Z(a){var b=0,c=0;a:{if(Ob(a,13981,3)|(y[a+3|0]-1&255)>>>0>3){break a}if(Cb(y[a+196|0]|y[a+197|0]<<8)>>>0>255){break a}if((Cb(y[a+198|0]|y[a+199|0]<<8)-1&65535)>>>0>255){break a}if((Cb(y[a+200|0]|y[a+201|0]<<8)-1&65535)>>>0>31){break a}b=Cb(y[a+202|0]|y[a+203|0]<<8);if(b>>>0>256){break a}c=Cb(y[a+204|0]|y[a+205|0]<<8)>>>0<b>>>0}return c}function tN(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ac(8);x[31785]=0;c=P(37,c+4|0,5868)|0;a=x[31785];x[31785]=0;if((a|0)==1){break c}nc(b,c);x[31785]=0;S(100,b|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c);break b}x[x[a+32>>2]+1074416>>2]=b;fb=c+16|0;return}a=N()|0;jc(b)}Q(a|0)}p()}function Ao(a,b,c,d){a:{if(x[a+480180>>2]==4){d=y[b+810|0];if(c){v[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){v[b+834|0]=c;break a}c=y[b+834|0];break a}if(c){v[b+810|0]=c;break a}c=y[b+810|0]}b:{if(!(v[b+851|0]&1)){break b}c=x[b+688>>2]-((c&255)<<2)|0;x[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180|0]&1)){break b}x[b+88>>2]=x[b+88>>2]|2097152}}function vH(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=fb-16|0;fb=h;a:{b:{c:{if(b<g|b>f){a=ac(8);x[31785]=0;d=P(37,h+4|0,e|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}nc(a,d);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}e=N()|0;tb(d);break b}i=x[a+32>>2]+d|0,j=Xe(b*c),x[i>>2]=j;fb=h+16|0;return}e=N()|0;jc(a)}Q(e|0)}p()}function gw(a,b,c,d){var e=0,f=0;a:{e=y[a|0];f=y[c|0];b:{if(!(y[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){v[a|0]=(f|0)==5?7:6;break b}if(!(y[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){v[a|0]=(e|0)==5?7:6;v[b|0]=y[d|0];break b}if(!((e|0)!=10|(f|0)!=20|y[d|0]!=159)){v[a|0]=42;break b}if(y[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}v[a|0]=42;v[b|0]=y[d|0]}v[c|0]=0}}function Vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{e=x[b+1298404>>2];b=fb-32|0;fb=b;d=b+8|0;Of(d,c);x[31785]=0;S(506,b+20|0,e|0,d|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){x[31785]=0;S(247,a|0,0,b+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(b+20|0);tb(b+8|0);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Sb(b+20|0)}tb(b+8|0);Q(a|0);p()}}function Ix(a,b,c,d){v[a+53|0]=1;a:{if(x[a+4>>2]!=(c|0)){break a}v[a+52|0]=1;c=x[a+16>>2];b:{if(!c){x[a+36>>2]=1;x[a+24>>2]=d;x[a+16>>2]=b;if((d|0)!=1){break a}if(x[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=x[a+24>>2];if((c|0)==2){x[a+24>>2]=d;c=d}if(x[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}x[a+36>>2]=x[a+36>>2]+1}v[a+54|0]=1}}function tfa(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;a:{b:{if((b|0)!=1){x[a+16>>2]=0;b=x[a+20>>2];if(!b){break b}Db(b);x[a+20>>2]=0;return}Y(T(0)|0)|0;x[31785]=0;V(992,8936,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z()}return}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function kF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<3){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==2){dj(c+10|0,z[c+14>>1]);d=z[c+10>>1];break a}else{v[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){ch(a,c+13|0);e=y[c+13|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11256,9099,324,14333);p()}fb=c+16|0;return d&65535}function fl(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;x[f+8>>2]=a;x[f+12>>2]=b;h=x[a+8>>2]+120|0;Jt(y[h+20|0]);g=fb-16|0;fb=g;x[g+12>>2]=f+8;e=fb-16|0;fb=e;i=x[d+4>>2];x[e+8>>2]=x[d>>2];x[e+12>>2]=i;d=x[c+4>>2];x[e>>2]=x[c>>2];x[e+4>>2]=d;ib[x[bq(e,uk(y[h+20|0]))>>2]](g+12|0,h);fb=e+16|0;fb=g+16|0;x[a+4>>2]=x[a+4>>2]+x[b+8>>2];fb=f+16|0}function aM(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=x[a>>2];b:{if(!b){break b}c=x[a+8>>2];if(!c){break b}d=x[a+12>>2];if(!d){break b}a=ib[d|0](b)|0;e=hb;if((e|0)<0){break b}if((ib[c|0](b,0,0,0)|0)<0){break a}if((ib[c|0](b,0,0,2)|0)<0){break a}d=ib[d|0](b)|0;f=hb;ib[c|0](b,a,e,0)|0;if((f|0)<0){break b}g=Au(d,f)}return g}ib[c|0](b,a,e,0)|0;return 0}function W2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb+-64|0;fb=d;e=1;a:{if(kh(a,b,0)){break a}e=0;if(!b){break a}b=WA(b,124848,124896);e=0;if(!b){break a}Tb(d+12|0,0,52);x[d+56>>2]=1;x[d+20>>2]=-1;x[d+16>>2]=a;x[d+8>>2]=b;ib[x[x[b>>2]+28>>2]](b,d+8|0,x[c>>2],1);a=x[d+32>>2];if((a|0)==1){x[c>>2]=x[d+24>>2]}e=(a|0)==1}a=e;fb=d- -64|0;return a|0}function Qf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Bb(x[a+4>>2],y[a+11|0])|(c-b|0)<5){break a}Us(b,c);e=Jb(a);g=e+Bb(x[a+4>>2],y[a+11|0])|0;a=c-4|0;b:{while(1){c:{c=v[e|0];f=c-127|0;if(a>>>0<=b>>>0){break c}if((c|0)!=x[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;e=((g-e|0)>1)+e|0;continue}break}if((f&255)>>>0<130|c>>>0>x[a>>2]-1>>>0){break a}}x[d>>2]=4}}function Psa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-112|0;fb=d;c=fb-16|0;fb=c;f=d+14|0;m_(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){l_(f)}c=-1;a:{if(!e){break a}c=0;if(!o_(d+14|0)){break a}c=xe(a,b,n_(y[d+61|0]|y[d+62|0]<<8),hb)}fb=d+112|0;return c|0}function zI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=$I(a,c);x[a>>2]=113384;c=tk(Jb(b));x[a+16>>2]=c;a:{b:{c:{if(!c){x[31785]=0;S(1011,d+4|0,18185,b|0);b=x[31785];x[31785]=0;if((b|0)==1){break c}x[31785]=0;W(1348,d+4|0);b=x[31785];x[31785]=0;if((b|0)!=1){break a}b=N()|0;tb(d+4|0);break b}fb=d+16|0;return a|0}b=N()|0}Hs(a);Q(b|0)}p()}function m0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;mE(e+8|0,c);c=y[d|0];x[31785]=0;O(246,e+20|0,c|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){ok(e,e+8|0);x[31785]=0;V(95,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}wg(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;wg(e+8|0)}Q(a|0);p()}}function Nja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;w[a>>1]=0;c=Nb(a+4|0);d=Nb(a+16|0);x[a+36>>2]=0;e=Fb(a+40|0);f=lg(a+52|0);Gf(c);w[a+28>>1]=65472;x[31785]=0;x[b+12>>2]=1065353216;O(886,c|0,b+12|0);g=x[31785];x[31785]=0;if((g|0)!=1){x[a+32>>2]=0;w[a+30>>1]=0;Gf(d);fb=b+16|0;return a|0}a=N()|0;bZ(f);tb(e);sc(d);sc(c);Q(a|0);p()}function rfa(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;a:{b:{if((b|0)!=1){a=x[a+20>>2];if(!a){break b}return xg(a)|0}Y(T(0)|0)|0;x[31785]=0;V(992,12264,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();return 0}return xg(22485)|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function G0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-512|0;fb=d;c=fb-16|0;fb=c;f=d+15|0;$E(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){_E(f)}c=-1;a:{if(!e){break a}c=0;if(!bF(d+15|0)){break a}c=xe(a,b,aF(y[d+125|0],y[d+126|0]),hb)}fb=d+512|0;return c|0}function nT(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=fb-16|0;fb=f;i=x[d+20>>2];h=x[d+52>>2];g=!h|e;v[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}x[(D(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}x[d+24>>2]=0;x[d+16>>2]=0;x[d+20>>2]=0;x[d+48>>2]=h;w[d+72>>1]=z[d+74>>1];ae(a,i>>>0>1&e&(b|0)==1,f+15|0);fb=f+16|0}function mk(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)>=3069?3069:b)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)<=-2960?-2960:b)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function cea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;x[31785]=0;W(1005,a|0);f=x[31785];x[31785]=0;if((f|0)!=1){return Qt(x[x[a+24>>2]+24>>2],b,c,d,e)|0}Y(T(0)|0)|0;x[31785]=0;V(992,12507,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Xu(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;c=D(a,b);sua(b,0,a,0);a=hb?0:c}else{a=0}a:{if(!a){break a}x[31785]=0;b=R(786,a|0)|0;c=x[31785];x[31785]=0;b:{c:{if((c|0)==1){Y(T(0)|0)|0;x[31785]=0;X(26);c=x[31785];x[31785]=0;b=0;if((c|0)==1){break c}}break b}T(0)|0;Rb();p()}if(!b){break a}d=Tb(b,0,a)- -64|0}return d}function E1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;x[d>>2]=b;x[d+4>>2]=c;x[d+8>>2]=b;x[d+12>>2]=c;f=fb-16|0;fb=f;g=fb-16|0;fb=g;e=g+4|0;x[e+4>>2]=1;h=e,i=Dc(24),x[h+8>>2]=i;b=pm(x[e+8>>2]);x[b>>2]=78792;jG(Ac(b),x[d>>2],x[d+4>>2]);c=f+8|0;b=Kn(e);Jn(c,Ac(b),b);qm(e);fb=g+16|0;zf(a,c);he(c);fb=f+16|0;fb=d+16|0}function ef(a,b,c){var d=0,e=0,f=0;e=Fb(a);d=y[b+11|0];f=x[b+4>>2];a=0;x[31785]=0;O(54,e|0,Wc(f,d)|0);d=x[31785];x[31785]=0;if((d|0)!=1){a:{while(1){if(Wc(x[b+4>>2],y[b+11|0])>>>0>a>>>0){d=x[(y[cc(b,a)|0]<<2)+c>>2];x[31785]=0;O(36,e|0,d|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}a=a+1|0;continue}break}return}}a=N()|0;Sb(e);Q(a|0);p()}function Cqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=wb(b,c);d=fb-16|0;fb=d;e=Od(b,c);a:{if(e>>>0<=Rg(a)>>>0){f=c;g=x[a>>2];h=oc(g,x[a+4>>2]);i=h>>>0>=e>>>0;if(!i){x[d+12>>2]=b;OC(d+12|0,h);f=x[d+12>>2]}b=Qi(b,f,g);if(!i){gY(a,f,c,e-oc(x[a>>2],x[a+4>>2])|0);break a}Yh(a,b);break a}ar(a);hm(a,Tf(a,e));gY(a,b,c,e)}fb=d+16|0}function CB(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+23|0]=0;v[a+24|0]=0;v[a+25|0]=0;v[a+26|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function C6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=fb-16|0;fb=g;k=Jh(g+12|0,x[a+8>>2]);i=gt(0,c,d-c|0,b?b:500444);Ih(k);fb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function vJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[ec(a)>>2]==1241;f=x[c>>2];g=f-h|0;f=g>>>0>=2147483647?-1:(h|0)==(f|0)?4:g<<1;g=sv(e?0:h,f);if(g){if(!e){ie(a)}x[d+4>>2]=1208;e=Ae(d+8|0,g,d+4|0);a=sJ(a,e);Kc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=x[a>>2]+(f&-4);fb=d+16|0;return}sy();p()}function o1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;f=x[b+16>>2];a:{if(f>>>0<=c>>>0){bc(a,x[d>>2],0);break a}g=x[b+12>>2];b=x[b+4>>2];x[e+20>>2]=x[d+4>>2];x[e+16>>2]=f-c;bc(e+24|0,x[d>>2],x[Gb(e+20|0,e+16|0)>>2]);d=x[x[b>>2]+28>>2];f=x[e+28>>2];x[e+8>>2]=x[e+24>>2];x[e+12>>2]=f;ib[d|0](a,b,c+g|0,e+8|0)}fb=e+32|0}function baa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=fb-16|0;fb=e;g=x[d+4>>2];hz(b,c,g);f=x[b+16>>2];a:{if(f>>>0<=c>>>0){bc(a,x[d>>2],0);break a}x[e+12>>2]=f-c;x[e+8>>2]=g;d=x[d>>2];f=x[Gb(e+12|0,e+8|0)>>2];jr(e,d,g,0,f);h=x[e>>2];i=x[e+4>>2];Qv(Ne(vb(x[b+4>>2]),c),Ne(Ne(vb(x[b+4>>2]),c),i),h);jr(a,d,g,0,f)}fb=e+16|0}function BK(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;e=b+16|0;a:{while(1){d=x[a+36>>2];c=b+8|0;f=ib[x[x[d>>2]+20>>2]](d,x[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=x[b+4>>2]-c|0;if((Mk(g,1,c,x[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=St(x[a+32>>2])?-1:0}fb=b+16|0;return d|0}function pqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;rr(e+8|0,c);x[31785]=0;O(600,e+20|0,d|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){ok(e,e+8|0);x[31785]=0;V(304,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}wg(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;wg(e+8|0)}Q(a|0);p()}}function lF(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(b>>>0<5){if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}while(1)if((d|0)==4){Hm(c+4|0,x[c+12>>2]);d=x[c+4>>2];break a}else{v[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){ch(a,c+11|0);e=y[c+11|0]}else{e=0}v[f|0]=e;d=d+1|0;continue}}_(11256,9099,324,14333);p()}fb=c+16|0;return d}function HS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=x[a+16>>2];e=d?y[(D(b,872)+a|0)+1429|0]:e;f=x[a+40>>2];b=D(b,872)+a|0;a=b+1467|0;v[a|0]=y[a|0]|64;a=b+1468|0;h=a;i=x[a>>2];g=(+(d>>>0)+1)*+(c|0)/+(f>>>0);a:{if(F(g)<2147483648){a=~~g;break a}a=-2147483648}x[h>>2]=i+(a+((c|0)<0?e:0-e|0)|0);c=(d+1|0)==(f|0)?c:a;a=c>>31;v[b+1429|0]=(a^c)-a}function z8(a){a=a|0;a:{x[31785]=0;R(1199,499464)|0;a=x[31785];x[31785]=0;b:{if((a|0)==1){break b}x[31785]=0;R(1199,499800)|0;a=x[31785];x[31785]=0;if((a|0)==1){break b}x[31785]=0;R(1200,499548)|0;a=x[31785];x[31785]=0;if((a|0)==1){break b}x[31785]=0;R(1200,499884)|0;a=x[31785];x[31785]=0;if((a|0)==1){break b}break a}T(0)|0;Rb();p()}}function kqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{if(!b){break a}x[31785]=0;O(593,a|0,b|0);d=x[31785];x[31785]=0;if((d|0)!=1){x[31785]=0;O(594,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}a=N()|0;XX(c+8|0);Q(a|0);p()}b=c+8|0;Md(b);XX(b);fb=c+16|0;return a|0}function x0(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{if(!b){break a}x[31785]=0;O(229,a|0,b|0);d=x[31785];x[31785]=0;if((d|0)!=1){x[31785]=0;O(230,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){break a}}a=N()|0;FE(c+8|0);Q(a|0);p()}b=c+8|0;Md(b);FE(b);fb=c+16|0;return a|0}function tr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=vb(x[b>>2]);g=vb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,g)){break a}f=fb-16|0;fb=f;ti(f+8|0,x[d>>2],x[d+4>>2]);h=$b(x[f+8>>2]);fb=f+16|0;if((c|0)==(h|0)){break a}d=x[rn(e+12|0)>>2];continue}break}fb=e+16|0;if(mc(d,vb(x[b+4>>2]))){_h(a);return}ep(a,d)}function rsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;zZ(e+8|0,c);x[31785]=0;O(94,e+20|0,d|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){ok(e,e+8|0);x[31785]=0;V(95,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}wg(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;wg(e+8|0)}Q(a|0);p()}}function x4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;Tn(e+8|0,c);x[31785]=0;O(94,e+20|0,d|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){ok(e,e+8|0);x[31785]=0;V(95,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}wg(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;wg(e+8|0)}Q(a|0);p()}}function vja(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;v[b+23|0]=0;v[b+24|0]=0;v[b+25|0]=0;v[b+26|0]=0;v[b+27|0]=0;v[b+28|0]=0;v[b+29|0]=0;v[b+30|0]=0;x[b+16>>2]=0;x[b+20>>2]=0;c=gc(b,b+16|0,15);kc(b+8|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);c=0;a:{if(x[b+12>>2]!=15){break a}if(Ob(b+16|0,8545,15)){break a}Yb(a,15);c=1}fb=b+32|0;return c|0}function tha(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[x[a+20>>2]+148>>2]=-1;ur(b+8|0,a+4228|0);c=x[a+20>>2];d=vb(x[b+8>>2]);e=Tk(x[b+8>>2],x[b+12>>2]);x[31785]=0;S(974,c+4|0,d|0,e|0);c=x[31785];x[31785]=0;a:{if((c|0)==1){c=T(125240)|0;if((gb|0)!=($(125240)|0)){break a}Y(c|0)|0;So(x[a+20>>2]+4|0);Z()}fb=b+16|0;return}Q(c|0);p()}function kE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=fb-32|0;fb=e;nw(e+8|0,c);x[31785]=0;O(94,e+20|0,d|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){ok(e,e+8|0);x[31785]=0;V(95,a|0,b|0,x[e>>2],x[e+4>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}wg(e+8|0);fb=e+32|0;break a}a=N()|0;tb(e+8|0);break b}a=N()|0;wg(e+8|0)}Q(a|0);p()}}function Nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,52)+f;b=x[d>>2];a:{while(1){if(x[d+4>>2]==(b|0)){break a}x[31785]=0;O(927,b|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){b=x[d>>2]+52|0;x[d>>2]=b;continue}break}a=N()|0;ee(d);Q(a|0);p()}ee(d);fb=e+16|0}function Lna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=4925421;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){cd();p()}if(b>>>0>=4925422){Xj();p()}c=Dc(D(b,872));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=Ab(a),g=b+D(x[d+12>>2],872)|0,x[f>>2]=g;fb=d+16|0}function Aq(a){var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=vb(x[a>>2]);e=a;f=vb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=d;while(1){if(Ib(d,f)){b=b+C[d>>3];d=x[Hu(a+12|0)>>2];continue}break}fb=a+16|0;a=vb(x[e>>2]);x[c+12>>2]=a;b=-b;e=vb(x[e+4>>2]);while(1){if(Ib(a,e)){b=b+C[a>>3];C[a>>3]=b;a=x[Hu(c+12|0)>>2];continue}else{fb=c+16|0}break}}function jd(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;hn(a);x[a+16>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0;x[a+4>>2]=0;w[a+32>>1]=64;x[a+24>>2]=8363;x[a+28>>2]=16777344;x[a+36>>2]=0;v[a+39|0]=0;v[a+40|0]=0;v[a+41|0]=0;v[a+42|0]=0;d=z[a+34>>1]&-25151;w[a+34>>1]=(b|0)==4?d|32:d;b=Cc(c+4|0,22485);ye(a+43|0,b);tb(b);NV(a);fb=c+16|0}function Zc(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;cl(b);f=uf(e+12|0,b);a:{d=a+8|0;b=x[d>>2];if(oc(b,x[a+12>>2])>>>0<=c>>>0){x[31785]=0;O(1295,d|0,c+1|0);a=x[31785];x[31785]=0;if((a|0)==1){break a}b=x[d>>2]}a=wb(b,c);b=x[a>>2];if(b){rm(b);a=wb(x[d>>2],c)}g=a,h=ie(f),x[g>>2]=h;OI(f);fb=e+16|0;return}a=N()|0;OI(f);Q(a|0);p()}function esa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[c+12>>2]=1;a:{if(Rg(a)){d=x[a>>2];e=oc(d,x[a+4>>2]);x[c+8>>2]=e;f=x[Gb(c+12|0,c+8|0)>>2];while(1){if(f){w[d>>1]=z[b>>1];v[d+2|0]=y[b+2|0];f=f-1|0;d=d+4|0;continue}break}if(!e){HZ(a,1-e|0,b);break a}Yh(a,x[a>>2]+4|0);break a}ar(a);hm(a,Tf(a,1));HZ(a,1,b)}fb=c+16|0}function Zta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bc(c+8|0,b,10);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0}return a|0}function J0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-784|0;fb=d;c=fb-16|0;fb=c;f=d+12|0;hF(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){gF(f)}c=-1;a:{if(!e){break a}c=0;if(!jF(d+12|0)){break a}c=xe(a,b,iF(y[d+527|0]),0)}fb=d+784|0;return c|0}function wha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Mi(a,b,c,d);x[a>>2]=43600;c=Nb(a+4208|0);x[a+4220>>2]=0;x[a+4224>>2]=1056964608;b=a+4228|0;v[b+4|0]=0;v[b+5|0]=4;v[b|0]=69;v[b+1|0]=99;v[b+2|0]=104;v[b+3|0]=111;v[b+6|0]=1;x[31785]=0;O(950,a+44|0,2);b=x[31785];x[31785]=0;if((b|0)!=1){Wt(a);return a|0}b=N()|0;sc(c);Uf(a);Q(b|0);p()}function gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=fb-32|0;fb=d;Fv(d+8|0,c);x[31785]=0;O(478,d+20|0,41916);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){ok(d,d+8|0);x[31785]=0;V(95,a|0,b|0,x[d>>2],x[d+4>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}wg(d+8|0);fb=d+32|0;break a}a=N()|0;tb(d+8|0);break b}a=N()|0;wg(d+8|0)}Q(a|0);p()}}function SP(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+24620>>2]/5|0;b=Fc(b,b>>31);x[a+4272>>2]=b;x[31785]=0;x[c+12>>2]=0;S(956,a+4256|0,b<<1,c+12|0);b=x[31785];x[31785]=0;a:{if((b|0)==1){b=T(125240)|0;if((gb|0)!=($(125240)|0)){break a}Y(b|0)|0;x[a+4272>>2]=0;Z()}x[a+4276>>2]=0;x[a+4268>>2]=0;fb=c+16|0;return}Q(b|0);p()}function Hqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb+-64|0;fb=d;c=fb-16|0;fb=c;f=d+12|0;rY(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){qY(f)}c=-1;a:{if(!e){break a}c=0;if(!tY(d+12|0)){break a}c=xe(a,b,sY(d+12|0),hb)}fb=d- -64|0;return c|0}function mP(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;a=Nb(a);x[31785]=0;W(995,b+4|0);c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){c=vb(x[b+4>>2]);d=vb(x[b+8>>2]);e=x[zb(b,a)>>2];x[31785]=0;S(996,c|0,d|0,e|0);c=x[31785];x[31785]=0;if((c|0)==1){break b}sc(b+4|0);fb=b+16|0;return}c=N()|0;break a}c=N()|0;sc(b+4|0)}Pd(a);Q(c|0);p()}
function _6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=fb-16|0;fb=d;i=x[b>>2];h=x[a>>2];e=x[ec(a)>>2]==1241;f=x[c>>2]-h|0;g=f<<1;f=f>>>0>=2147483647?-1:g>>>0<=1?1:g;g=sv(e?0:h,f);if(g){if(!e){ie(a)}x[d+4>>2]=1208;e=Ae(d+8|0,g,d+4|0);a=sJ(a,e);Kc(e);x[b>>2]=x[a>>2]+(i-h|0);x[c>>2]=f+x[a>>2];fb=d+16|0;return}sy();p()}function Qra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{e=Mb(x[b>>2],x[b+8>>2],c<<2);if(!e){break a}vc(d+12|0,65535);tg(a,z[d+12>>1]);c=vb(x[a>>2]);x[d+4>>2]=c;a=vb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}f=d+8|0;if(!Gn(b,f)){vn(f)}w[c>>1]=x[d+8>>2];c=x[Wd(d+4|0)>>2];continue}}fb=d+16|0;return e|0}function E0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-48|0;fb=d;c=fb-16|0;fb=c;f=d+10|0;UE(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){TE(f)}c=-1;a:{if(!e){break a}c=0;if(!WE(d+10|0)){break a}c=xe(a,b,VE(y[d+45|0]),hb)}fb=d+48|0;return c|0}function rR(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;a:{b:{while(1){x[e+12>>2]=b;x[e+8>>2]=d;if(A[Gb(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=xq(v[xb(a,f)|0]);h=xq(v[xb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}fb=e+16|0;return a}function O8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=x[a+44>>2];c=x[a+24>>2];if(e>>>0<c>>>0){x[a+44>>2]=c;e=c}c=x[a+12>>2];f=x[a+8>>2];d=-1;a:{if(c>>>0<=f>>>0){break a}if(mc(b,-1)){_n(a,f,c-1|0,e);return Ey(b)|0}g=b<<24>>24;if(!(x[a+48>>2]&16)){d=-1;if(!mc(g,v[c-1|0])){break a}}_n(a,f,c-1|0,e);v[x[a+12>>2]]=g;d=b}return d|0}function x9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Ko(e,c);x[31785]=0;S(506,d+20|0,b|0,e|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;S(247,a|0,0,d+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Sb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function us(a,b,c,d,e,f){var g=0;g=fb-16|0;fb=g;x[g+12>>2]=d;d=x[oe(g+8|0,g+12|0)>>2];x[31785]=0;ha(f|0,a+8|0,b|0,c|0,d|0,e|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){a=xz(a);b=wz(a+88|0);c=vz(a+92|0);d=uz(a+96|0);x[a>>2]=48012;x[b>>2]=48128;x[c>>2]=48208;x[d>>2]=48248;Uc(g+12|0);fb=g+16|0;return a}a=N()|0;Uc(g+12|0);Q(a|0);p()}function sE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=zk(b,wd(a));a:{f=Bb(x[a+4>>2],y[a+11|0]);if(b>>>0<=f>>>0){if(c){e=Lc(a);b:{if(e-f>>>0>=c>>>0){e=Jb(a);if((b|0)==(f|0)){break b}g=b+e|0;Ri(g+c|0,g,f-b|0);break b}Nm(a,e,(c+f|0)-e|0,f,b,0,c);e=x[a>>2]}$l(b+e|0,c,d);b=c+f|0;jg(a,b);ed(b+e|0,0)}break a}Pl();p()}wd(a)}function dla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-32|0;fb=e;x[e+28>>2]=d;c=Bf(a,c);Yd(e+8|0,x[a+36>>2]);f=a;a:{if(!c){Pc(e+8|0,a+32|0,5);d=0;if(Hb(x[x[e+8>>2]>>2],x[e+12>>2])){break a}}d=x[a+36>>2];a=0;JE(b,x[e+28>>2]);while(1){if(A[e+28>>2]>a>>>0){wU(d,_b(x[b>>2],a));a=a+1|0;continue}break}d=c}cf(f,d);fb=e+32|0}function Ioa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-608|0;fb=d;c=fb-16|0;fb=c;MW(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){LW(d)}c=-1;a:{if(!e){break a}c=0;if(!OW(d)){break a}c=xe(a,b,NW(y[d+34|0]|y[d+35|0]<<8),hb)}fb=d+608|0;return c|0}function Cia(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=th(c+4|0,a,1);wk(x[a+4>>2],B[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=hg(d+12|0,Tf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);wk(x[c+8>>2],B[b>>2]);x[c+8>>2]=x[c+8>>2]+4;Id(a,c);gg(c);fb=d+32|0}function yqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;pp(e,b,c);x[31785]=0;S(126,d+20|0,28,e|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;O(12,a|0,d+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Sb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function wl(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=fb-16|0;fb=f;x[f+12>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=fb-32|0;fb=c;d=pc(c+24|0,x[a>>2]);e=x[f+12>>2];g=x[e>>2];e=x[e+4>>2];x[c+16>>2]=g;x[c+20>>2]=e;h=x[d+4>>2];d=x[d>>2];x[c+8>>2]=g;x[c+12>>2]=e;d=Oc(d,h,c+8|0);fb=c+32|0;if(!d){break a}b=a}fb=f+16|0;return b}a=a+8|0;continue}}function U$(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=vi(c+4|0,a,1);dk(x[a+4>>2],z[b>>1]);x[a+4>>2]=x[a+4>>2]+2;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=hk(d+12|0,ik(a,Xc(x[a>>2],x[a+4>>2])+1|0),Xc(x[a>>2],x[a+4>>2]),c);dk(x[c+8>>2],z[b>>1]);x[c+8>>2]=x[c+8>>2]+2;Id(a,c);fj(c);fb=d+32|0}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31785]=0;W(1005,a|0);d=x[31785];x[31785]=0;if((d|0)!=1){x[a+16>>2]=0;x[a+12>>2]=c;x[a+8>>2]=b;return}Y(T(0)|0)|0;x[31785]=0;V(992,13128,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Gsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-208|0;fb=d;c=fb-16|0;fb=c;f=d+2|0;ZZ(c+8|0,f);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(g|0);if(!e){YZ(f)}c=-1;a:{if(!e){break a}c=0;if(!$Z(d+2|0)){break a}c=xe(a,b,_Z(d+2|0),hb)}fb=d+208|0;return c|0}function Fra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a>>2];d=Sc(e,x[a+4>>2]);if(d>>>0<b>>>0){e=fb-32|0;fb=e;b=b-d|0;d=x[Ab(a)>>2];f=x[a+4>>2];a:{if(b>>>0<=d-f>>>0){qp(a,b,c);break a}d=Ab(a);d=gn(e+12|0,Ul(a,Sc(x[a>>2],f)+b|0),Sc(x[a>>2],x[a+4>>2]),d);PY(d,b,c);Id(a,d);en(d)}fb=e+32|0;return}if(b>>>0<d>>>0){Tq(a,b+e|0)}}function wja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Ko(e,c);x[31785]=0;O(14,d+20|0,e|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){x[31785]=0;S(848,a|0,b|0,d+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Sb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function b3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{e=x[b>>2];if(xd(e)){f=d+4|0;if(!yd(x[c+4>>2],y[c+11|0])){lP(c,18589);e=x[b>>2]}b=x[b+4>>2];ib[x[x[b>>2]+24>>2]](f,b,e);x[31785]=0;P(845,c|0,f|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}tb(d+4|0)}Yc(a,c);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function Xn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{f=Od(b,c);if(f>>>0<1073741808){b:{if(Nq(f)){Ke(d,f);break b}Rj(e+8|0,jn(f)+1|0);g=x[e+8>>2];vd(d,g);nf(d,x[e+12>>2]);Vd(d,f);d=g}while(1){if((b|0)!=(c|0)){vd(d,x[b>>2]);d=d+4|0;b=b+4|0;continue}break}vd(d,0);fb=e+16|0;break a}of();p()}return a|0}function Mpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Ko(e,c);x[31785]=0;S(126,d+20|0,b|0,e|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;O(12,a|0,d+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Sb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function u$(a,b,c,d){var e=0,f=0,g=0,h=0;e=Bb(x[a+4>>2],y[a+11|0]);if(e>>>0>=b>>>0){f=Lc(a);a:{if(f-e>>>0>=d>>>0){if(!d){break a}f=Jb(a);h=f+b|0;if((b|0)!=(e|0)){g=b+f|0;Ri(g+d|0,g,e-b|0);c=(c>>>0>=g>>>0?e+f>>>0>c>>>0?d:0:0)+c|0}Ri(h,c,d);b=d+e|0;jg(a,b);ed(b+f|0,0);return a}Mp(a,f,(d+e|0)-f|0,e,b,0,d,c)}return a}Pl();p()}function pi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=fb-16|0;fb=e;a:{f=Tj(b,c);if(f>>>0<2147483632){b:{if(Ok(f)){Ke(d,f);break b}ng(e+8|0,Ah(f)+1|0);g=x[e+8>>2];vd(d,g);nf(d,x[e+12>>2]);Vd(d,f);d=g}while(1){if((b|0)!=(c|0)){ed(d,y[b|0]);d=d+1|0;b=b+1|0;continue}break}ed(d,0);fb=e+16|0;break a}of();p()}return a|0}function eZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Of(e,c);x[31785]=0;S(506,d+20|0,b|0,e|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;O(12,a|0,d+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Sb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function dua(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-1968|0;fb=e;c=fb-16|0;fb=c;f=e+14|0;N$(c+8|0,f);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){M$(f)}c=-1;a:{if(!d){break a}c=0;if(!O$(e+14|0)){break a}c=xe(a,b,1024,0)}fb=e+1968|0;return c|0}function Lj(a){var b=0,c=0,d=0,e=0,f=0;b=x[a+4>>2];if(mc(x[a>>2],b)){a=0}else{b=Yi(b);e=Yi(x[a>>2]);c=fb-16|0;fb=c;x[c+12>>2]=b;while(1){a:{if(!Vg(b,e)){break a}d=fb-16|0;fb=d;x[d+12>>2]=b;f=aw(d+12|0);fb=d+16|0;if(z[x[f>>2]>>1]!=65535){break a}b=x[aw(c+12|0)>>2];continue}break}fb=c+16|0;a=ZD(vb(x[a>>2]),b)}return a&65535}function Pja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(!xd(x[a+1298300>>2])){d=x[a+24620>>2];e=fb-16|0;fb=e;b=Dc(536);x[31785]=0;d=P(881,b|0,d|0)|0;f=x[31785];x[31785]=0;a:{if((f|0)!=1){b=x[uf(e+12|0,d)>>2];fb=e+16|0;break a}a=N()|0;Db(b);Q(a|0);p()}x[c+12>>2]=b;b=a+1298300|0;a=c+12|0;ZR(b,ie(a));JA(a)}fb=c+16|0}function Kqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=x[a+8>>2];e=x[a+8>>2];x[c+8>>2]=a+8;x[c+4>>2]=D(b,20)+e;b=x[c>>2];a:{while(1){if(x[c+4>>2]==(b|0)){break a}x[31785]=0;W(231,b|0);a=x[31785];x[31785]=0;if((a|0)!=1){b=x[c>>2]+20|0;x[c>>2]=b;continue}break}a=N()|0;ee(c);Q(a|0);p()}ee(c);fb=d+16|0}function vk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=x[a>>2];c=oc(d,x[a+4>>2]);if(c>>>0<b>>>0){d=fb-32|0;fb=d;b=b-c|0;c=x[Ab(a)>>2];e=x[a+4>>2];a:{if(b>>>0<=c-e>>2>>>0){Ou(a,b);break a}c=Ab(a);c=hg(d+12|0,Tf(a,oc(x[a>>2],e)+b|0),oc(x[a>>2],x[a+4>>2]),c);RQ(c,b);Id(a,c);gg(c)}fb=d+32|0;return}if(b>>>0<c>>>0){Yh(a,d+(b<<2)|0)}}function rs(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;x[f+12>>2]=c;c=x[oe(f+8|0,f+12|0)>>2];x[31785]=0;ba(e|0,a+8|0,b|0,c|0,d|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){a=xz(a);b=wz(a+88|0);c=vz(a+92|0);d=uz(a+96|0);x[a>>2]=48012;x[b>>2]=48128;x[c>>2]=48208;x[d>>2]=48248;Uc(f+12|0);fb=f+16|0;return a}a=N()|0;Uc(f+12|0);Q(a|0);p()}function Lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=33;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;VC(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);VC(e,b);Tb(x[d+8>>2]+c|0,0,33-c|0);Yb(a,x[d+28>>2]);fb=d+32|0;return c|0}function oA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=c>=.999?.999:c;h=c*3.141592653589793;i=Ju(b);while(1){if((e|0)!=32768){f=((e^-1)<<12&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=Ti(g)*Ju(M(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=dC(c*d*32768),w[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function pU(a){a=a|0;var b=0,c=0,d=0;b=fb-16|0;fb=b;if(y[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){v[a+534|0]=0}else{Jj(a,d,1);c=c+1|0;continue}break}}v[b+15|0]=0;Rh(a+8|0,18,b+15|0);uv(a+26|0,18,27802);v[b+14|0]=255;Rh(a+62|0,256,b+14|0);wh(x[a>>2],x[a+4>>2],65535,261,1);wh(x[a>>2],x[a+4>>2],65535,260,0);fb=b+16|0}function dM(a){var b=0,c=0,d=0,e=0;b=fb-32|0;fb=b;if(!y[a+20|0]){while(1){if(!(ib[x[x[a>>2]+40>>2]](a)|0)){bM(a,65536);c=gc(b+16|0,xb(x[a+4>>2],x[a+16>>2]),65536);d=x[x[a>>2]+44>>2];e=x[c+4>>2];x[b+8>>2]=x[c>>2];x[b+12>>2]=e;ib[d|0](b+24|0,a,b+8|0);x[a+16>>2]=x[a+16>>2]+x[b+28>>2];continue}break}v[a+20|0]=1}fb=b+32|0}function OR(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;MR(d,b+80|0);x[31785]=0;S(126,c+20|0,0,d|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;O(12,a|0,c+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Sb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function O2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(kh(a,x[b+8>>2],e)){Hx(b,c,d);return}a:{if(!kh(a,x[b>>2],e)){break a}if(!(x[b+16>>2]!=(c|0)&x[b+20>>2]!=(c|0))){if((d|0)!=1){break a}x[b+32>>2]=1;return}x[b+20>>2]=c;x[b+32>>2]=d;x[b+40>>2]=x[b+40>>2]+1;if(!(x[b+36>>2]!=1|x[b+24>>2]!=2)){v[b+54|0]=1}x[b+44>>2]=4}}function Dpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-128|0;fb=e;c=fb-16|0;fb=c;f=e+2|0;wX(c+8|0,f);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){vX(f)}c=-1;a:{if(!d){break a}c=0;if(!xX(e+2|0)){break a}c=xe(a,b,256,0)}fb=e+128|0;return c|0}function lta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-32|0;fb=e;c=fb-16|0;fb=c;f=e+15|0;Z$(c+8|0,f);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;d=(d|0)==(g|0);if(!d){nE(f)}c=-1;a:{if(!d){break a}c=0;if(!C_(e+15|0)){break a}c=xe(a,b,72,0)}fb=e+32|0;return c|0}function fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a+4272>>2]=1065353216;x[a>>2]=45744;b=a+4208|0;e=wb(b,0),f=1056880300,x[e>>2]=f;e=wb(b,1),f=1050733080,x[e>>2]=f;e=wb(b,2),f=1056964608,x[e>>2]=f;x[31785]=0;O(950,a+44|0,2);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;Uf(a);Q(b|0);p()}function _fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a>>2]=45980;b=a+4208|0;e=wb(b,0),f=1065353216,x[e>>2]=f;e=wb(b,1),f=1065353216,x[e>>2]=f;e=wb(b,2),f=1051372203,x[e>>2]=f;e=wb(b,3),f=0,x[e>>2]=f;x[31785]=0;O(950,a+44|0,2);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;Uf(a);Q(b|0);p()}function Uy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=fb-240|0;fb=g;x[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-x[(i<<2)+d>>2]|0;if((fo(a,f,b)|0)>=0){if((fo(a,e,b)|0)>=0){break a}}j=f;f=(fo(f,e,b)|0)>=0;e=f?j:e;x[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}qL(g,h);fb=g+240|0}function DQ(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=Wz(a);b=jk(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31785]=0;b=ba(954,c+12|0,b|0,b|0,Ab(a)|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){Id(a,b);AQ(b);break b}Y(T(0)|0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Rb();p()}function CQ(a){var b=0,c=0,d=0;c=fb-32|0;fb=c;a:{d=Rg(a);b=oc(x[a>>2],x[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}x[31785]=0;b=ba(955,c+12|0,b|0,b|0,Ab(a)|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){Id(a,b);gg(b);break b}Y(T(0)|0)|0;x[31785]=0;X(26);a=x[31785];x[31785]=0;if((a|0)==1){break a}}fb=c+32|0;return}T(0)|0;Rb();p()}function k2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;$c(a,x[b+28>>2]);x[31785]=0;S(111,d+12|0,b|0,c|0);e=x[31785];x[31785]=0;a:{if((e|0)==1){break a}Zb(d+12|0);b=x[b+24>>2];if(b){x[31785]=0;S(112,d+8|0,b|0,c|0);b=x[31785];x[31785]=0;if((b|0)==1){break a}Zb(d+8|0)}fb=d+16|0;return}b=N()|0;Zb(a);Q(b|0);p()}function dpa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=pw(c+4|0,a,1);hX(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=BD(d+12|0,CD(a,Lf(x[a>>2],x[a+4>>2])+1|0),Lf(x[a>>2],x[a+4>>2]),c);hX(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;AD(a,c);Mv(c);fb=d+32|0}function hla(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=ZB(c+4|0,a,1);JB(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+32;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=Qu(d+12|0,Hq(a,Hg(x[a>>2],x[a+4>>2])+1|0),Hg(x[a>>2],x[a+4>>2]),c);JB(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+32;yU(a,c);LB(c);fb=d+32|0}function hM(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=x[a>>2];a:{if(!c){break a}d=x[a+8>>2];if(!d){break a}e=x[a+12>>2];if(!e){break a}a=ib[e|0](c)|0;f=hb;if((f|0)<0){break a}b=0;b:{if((ib[d|0](c,0,0,0)|0)<0){break b}b=0;if((ib[d|0](c,0,0,2)|0)<0){break b}ib[e|0](c)|0;b=hb;b=(b|0)>0|(b|0)>=0}ib[d|0](c,a,f,0)|0}return b|0}function VD(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=R_(c+4|0,a,1);Q_(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+40;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=O_(d+12|0,P_(a,mr(x[a>>2],x[a+4>>2])+1|0),mr(x[a>>2],x[a+4>>2]),c);Q_(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+40;N_(a,c);M_(c);fb=d+32|0}function Ssa(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=pw(c+4|0,a,1);DD(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+20;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=BD(d+12|0,CD(a,Lf(x[a>>2],x[a+4>>2])+1|0),Lf(x[a>>2],x[a+4>>2]),c);DD(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+20;AD(a,c);Mv(c);fb=d+32|0}function Nsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-224|0;fb=d;c=fb-16|0;fb=c;e_(c+8|0,d+6|0);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!g_(d+6|0)){break a}c=xe(a,b,f_(y[d+222|0],y[d+223|0]),hb)}fb=d+224|0;return c|0}function Ida(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;x[31785]=0;W(1005,a|0);d=x[31785];x[31785]=0;if((d|0)!=1){x[a+4>>2]=c;x[a>>2]=b?b:986;return}Y(T(0)|0)|0;x[31785]=0;V(992,13158,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Fea(a,b){a=a|0;b=b|0;var c=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;if((c|0)!=1){return E(TO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31785]=0;V(992,6249,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Of(d,b);x[31785]=0;O(967,c+20|0,d|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;S(968,a|0,0,c+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Sb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function Eea(a,b){a=a|0;b=b|0;var c=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;if((c|0)!=1){return E(SO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31785]=0;V(992,9397,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Dea(a,b){a=a|0;b=b|0;var c=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;if((c|0)!=1){return E(RO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31785]=0;V(992,6292,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Cea(a,b){a=a|0;b=b|0;var c=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;if((c|0)!=1){return E(QO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31785]=0;V(992,6194,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Bea(a,b){a=a|0;b=b|0;var c=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;if((c|0)!=1){return E(PO(x[x[a+24>>2]+24>>2],b))}Y(T(0)|0)|0;x[31785]=0;V(992,6150,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return E(E(0))}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function vE(a){var b=0,c=0,d=0,e=0;c=y[a+9|0]|y[a+10|0]<<8;d=sua(y[a+3|0],0,18,0);c=c+d|0;b=hb;e=d>>>0>c>>>0?b+1|0:b;d=y[a+6|0]|y[a+7|0]<<8;b=d>>>31|0;d=d<<1;c=d+c|0;b=b+e|0;d=d>>>0>c>>>0?b+1|0:b;a=y[a+4|0]|y[a+5|0]<<8;b=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+3|0;hb=b>>>0<3?a+1|0:a;return b}function sja(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Ko(d,b);x[31785]=0;O(14,c+20|0,d|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;S(247,a|0,0,c+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Sb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function noa(a,b){a=a|0;b=b|0;var c=0,d=0;if(x[a+4>>2]!=x[Ab(a)>>2]){c=fb-16|0;fb=c;a=px(c+4|0,a);hC(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=um(d+12|0,Dp(a,Qd(x[a>>2],x[a+4>>2])+1|0),Qd(x[a>>2],x[a+4>>2]),c);hC(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;jW(a,c);iW(c);fb=d+32|0}function aja(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Uk(d,b);x[31785]=0;O(14,c+20|0,d|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;S(247,a|0,0,c+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Sb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function Y0(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=fb-32|0;fb=c;d=c+8|0;Of(d,b);x[31785]=0;S(126,c+20|0,22,d|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;O(12,a|0,c+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(c+20|0);tb(c+8|0);fb=c+32|0;break a}a=N()|0;break b}a=N()|0;Sb(c+20|0)}tb(c+8|0);Q(a|0);p()}}function RW(a){var b=0,c=0;a:{if(Ob(a,3868,4)|y[a+63|0]!=26){break a}b=y[a+65|0];if(y[a+66|0]|(b|0)!=16&(b|0)!=1|(y[a+64|0]&3|(y[a+78|0]|y[a+79|0]<<8)>>>0>127)){break a}if((y[a+80|0]|y[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=_k(y[a|0]|y[a+1|0]<<8,y[b|0]|y[b+1|0]<<8)?b:a;c=(y[a|0]|y[a+1|0]<<8)!=0}return c}function wka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;b=fg(d+8|0,b);x[31785]=0;S(844,d+20|0,b|0,c|0);e=x[31785];x[31785]=0;a:{b:{if((e|0)!=1){x[31785]=0;S(74,a|0,d+20|0,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}tb(d+20|0);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function ona(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=4896;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;XC(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);XC(e,b);Tb(x[d+8>>2]+c|0,0,4896-c|0);Yb(a,x[d+28>>2]);fb=d+32|0}function bA(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;h=z[b>>1];c=$d(a);e=ec(a);f=fb-16|0;fb=f;while(1){if(c){g=Jq(z[c+16>>1],h);e=g?e:c;c=x[(g?c+4|0:c)>>2];continue}break}c=x[zb(f+12|0,e)>>2];fb=f+16|0;a:{if(Ib(c,mg(a))){if(!Jq(z[b>>1],z[qd(c)>>1])){break a}}c=mg(a)}a=x[zb(d+12|0,c)>>2];fb=d+16|0;return a}function OW(a){var b=0;a:{if(Ob(a+44|0,14290,4)|y[a+28|0]!=26|(y[a+40|0]|y[a+41|0]<<8|y[a+30|0]>2)){break a}if(((y[a+38|0]|y[a+39|0]<<8)-33&65535)>>>0<65504|((y[a+32|0]|y[a+33|0]<<8)-257&65535)>>>0<65280|((y[a+34|0]|y[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((y[a+36|0]|y[a+37|0]<<8)-1&65535)>>>0<128}return b}function YG(a,b,c,d,e){var f=0;a:{f=fb-32|0;fb=f;Cp(f+8|0,c);x[31785]=0;O(e|0,f+20|0,d|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){ok(f,f+8|0);x[31785]=0;V(95,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}wg(f+8|0);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;wg(f+8|0)}Q(a|0);p()}}function X0(a,b){a=a|0;b=b|0;var c=0,d=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=ZF(c+4|0,a);Sw(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+36;hc(a);fb=c+16|0;return}d=fb-32|0;fb=d;c=Ab(a);c=XF(d+12|0,YF(a,Sr(x[a>>2],x[a+4>>2])+1|0),Sr(x[a>>2],x[a+4>>2]),c);Sw(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+36;WF(a,c);Uw(c);fb=d+32|0}function Uta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}vc(d+12|0,65535);tg(a,z[d+12>>1]);c=vb(x[a>>2]);x[d+4>>2]=c;a=vb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}hw(b,d+10|0);e=c,f=Cb(z[d+10>>1]),w[e>>1]=f;c=x[Wd(d+4|0)>>2];continue}}fb=d+16|0}function RG(a,b,c,d,e){var f=0;a:{f=fb-32|0;fb=f;q_(f+8|0,c);x[31785]=0;O(e|0,f+20|0,d|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){ok(f,f+8|0);x[31785]=0;V(95,a|0,b|0,x[f>>2],x[f+4>>2]);a=x[31785];x[31785]=0;if((a|0)==1){break c}wg(f+8|0);fb=f+32|0;break a}a=N()|0;tb(f+8|0);break b}a=N()|0;wg(f+8|0)}Q(a|0);p()}}function wna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=263;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;dV(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);dV(e,b);Tb(x[d+8>>2]+c|0,0,263-c|0);Yb(a,x[d+28>>2]);fb=d+32|0}function pX(a){var b=0,c=0,d=0,e=0,f=0;f=y[a+28|0]|y[a+29|0]<<8;c=sua(y[a+30|0],0,37,0);d=hb;b=sua(y[a+24|0]|y[a+25|0]<<8,0,192,0);c=b+c|0;d=hb+d|0;b=b>>>0>c>>>0?d+1|0:d;a=y[a+26|0];d=a>>>26|0;e=c;c=a<<6;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+f|0;a=b>>>0<e>>>0?a+1|0:a;b=b+192|0;hb=b>>>0<192?a+1|0:a;return b}function lsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=102;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;JZ(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);JZ(e,b);Tb(x[d+8>>2]+c|0,0,102-c|0);Yb(a,x[d+28>>2]);fb=d+32|0}function O1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;b=nm(d+8|0,b);x[31785]=0;S(151,d+20|0,b|0,c|0);e=x[31785];x[31785]=0;a:{b:{if((e|0)!=1){x[31785]=0;S(4,a|0,d+20|0,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}tb(d+20|0);tb(b);fb=d+32|0;return}c=N()|0;break a}c=N()|0;tb(d+20|0)}tb(b);Q(c|0);p()}function Hsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;x[d+8>>2]=c;x[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Bb(x[a+4>>2],y[a+11|0]),x[f>>2]=g;e=x[Gb(d+12|0,d)>>2];x[d+4>>2]=e;a=Tp(Jb(a),b,x[Gb(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}fb=d+16|0;return a|0}Pl();p()}function gA(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=a;a=x[a+4>>2];x[d+4>>2]=a;x[d+8>>2]=a+D(b,52);b=x[d+4>>2];f=x[d+8>>2];a:{while(1){if((b|0)==(f|0)){break a}x[31785]=0;O(927,b|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){b=b+52|0;x[d+4>>2]=b;continue}break}a=N()|0;hc(d);Q(a|0);p()}hc(d);fb=e+16|0}function k7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=x[28051];x[g+24>>2]=x[28050];x[g+28>>2]=h;h=x[28049];x[g+16>>2]=x[28048];x[g+20>>2]=h;h=x[28047];x[g+8>>2]=x[28046];x[g+12>>2]=h;h=x[28045];x[g>>2]=x[28044];x[g+4>>2]=h;h=a;a=g+32|0;b=rk(h,b,c,d,e,f,g,a);fb=a;return b|0}function b2(a){a=a|0;var b=0,c=0;a:{b=fb-32|0;fb=b;c=b+8|0;Cc(c,13554);x[31785]=0;S(126,b+20|0,1,c|0);c=x[31785];x[31785]=0;b:{c:{if((c|0)!=1){x[31785]=0;O(12,a|0,b+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(b+20|0);tb(b+8|0);fb=b+32|0;break a}a=N()|0;break b}a=N()|0;Sb(b+20|0)}tb(b+8|0);Q(a|0);p()}}function W3(a,b,c){a=a|0;b=b|0;c=c|0;a=0;if(b&1){a=(et(c)|0)!=0}if(b&2){a=(dt(c)|0)!=0|a}if(b&4){a=(ct(c)|0)!=0|a}if(b&8){a=(bt(c)|0)!=0|a}if(b&16){a=(at(c)|0)!=0|a}if(b&32){a=($s(c)|0)!=0|a}if(b&64){a=(Kh(c)|0)!=0|a}if(b&128){a=(_s(c)|0)!=0|a}if(b&256){a=(Zs(c)|0)!=0|a}if(b&512){a=(Ys(c)|0)!=0|a}return a|0}
function Dqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=22;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;Nv(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);Nv(e,b);Tb(x[d+8>>2]+c|0,0,22-c|0);Yb(a,x[d+28>>2]);fb=d+32|0}function Bqa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=40;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;PC(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);PC(e,b);Tb(x[d+8>>2]+c|0,0,40-c|0);Yb(a,x[d+28>>2]);fb=d+32|0}function t0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=65;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;ow(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);ow(e,b);Tb(x[d+8>>2]+c|0,0,65-c|0);Yb(a,x[d+28>>2]);fb=d+32|0}function dea(a,b){a=a|0;b=b|0;var c=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;if((c|0)!=1){return xO(x[x[a+24>>2]+24>>2],b)|0}Y(T(0)|0)|0;x[31785]=0;V(992,6679,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function MP(a){var b=0,c=E(0),d=0,e=0;e=x[x[a+16>>2]+24620>>2];b=fb-16|0;fb=b;x[b+12>>2]=0;x[b+8>>2]=1065353216;c=oi(E(B[Bv(a+4208|0,b+12|0,b+8|0)>>2]*E(999)));a:{if(c<E(4294967296)&c>=E(0)){d=~~c>>>0;break a}d=0}fb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0<=2?2:b;x[a+4216>>2]=b;x[a+4220>>2]=b>>>1;vc(a+4224|0,b)}function Eda(a,b){a=a|0;b=b|0;var c=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;if((c|0)!=1){cO(x[x[a+24>>2]+24>>2],b);return 1}Y(T(0)|0)|0;x[31785]=0;V(992,5804,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function WG(a,b,c,d){var e=0,f=0;a:{e=fb-32|0;fb=e;f=e+8|0;Ec(f,c);x[31785]=0;S(d|0,e+20|0,b|0,f|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;O(12,a|0,e+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(e+20|0);tb(e+8|0);fb=e+32|0;break a}a=N()|0;break b}a=N()|0;Sb(e+20|0)}tb(e+8|0);Q(a|0);p()}}function HQ(a,b){var c=0,d=0,e=0,f=0,g=E(0);c=fb-16|0;fb=c;if(!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]){w[c+14>>1]=0;kg(a,c+14|0);e=z[c+14>>1];vk(b,e);while(1){if((d|0)!=(e|0)){x[c+8>>2]=0;jq(a,c+8|0);f=wb(x[b>>2],d),g=B[c+8>>2],B[f>>2]=g;d=d+1|0;continue}break}d=!x[(x[x[a>>2]-12>>2]+a|0)+16>>2]}fb=c+16|0;return d}function Bsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=5;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;ck(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);ck(e,b);Tb(x[d+8>>2]+c|0,0,5-c|0);Yb(a,x[d+28>>2]);fb=d+32|0}function voa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb+-64|0;fb=d;c=fb-16|0;fb=c;Zv(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){Sv(d)}c=-1;a:{if(!e){break a}c=0;if(!sW(d)){break a}c=xe(a,b,rW(d),hb)}fb=d- -64|0;return c|0}function tQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4232>>2];b=(b>>>1)+(b>>>6)|0;x[a+4220>>2]=b;x[31785]=0;x[c+12>>2]=0;S(956,a+4208|0,b<<1,c+12|0);b=x[31785];x[31785]=0;a:{if((b|0)==1){b=T(125240)|0;if((gb|0)!=($(125240)|0)){break a}Y(b|0)|0;x[a+4220>>2]=0;Z()}x[a+4224>>2]=0;fb=c+16|0;return}Q(b|0);p()}function lm(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=D(c,872)+b|0;f=BS(x[d+720>>2],x[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return AS(a,b,c,e);case 1:break b;default:break a}}f=AS(a,b,c,e);if((f+5&255)>>>0>5){break a}a=D(c,872)+b|0;f=BS(x[a+720>>2],x[a+1272>>2],e)}return f}function ir(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=fb-16|0;fb=d;e=x[b+4>>2];f=zb(d+12|0,c);g=zb(d+8|0,x[a>>2]);h=zb(d+4|0,x[b+4>>2]);i=b,j=ZV(x[f>>2],x[g>>2],x[h>>2]),x[i+4>>2]=j;i=b,j=Ov(c,x[a+4>>2],x[b+8>>2]),x[i+8>>2]=j;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),Ac(b));x[b>>2]=x[b+4>>2];fb=d+16|0;return e}function d1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;d=c+8|0;Uk(d,b);x[31785]=0;O(14,c+20|0,d|0);b=x[31785];x[31785]=0;a:{b:{if((b|0)!=1){x[31785]=0;O(15,a|0,c+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}Sb(c+20|0);tb(c+8|0);fb=c+32|0;return}b=N()|0;break a}b=N()|0;Sb(c+20|0)}tb(c+8|0);Q(b|0);p()}function _t(a){var b=0,c=0,d=0;b=zi(+B[a+4228>>2]*8)*.25+-.25;C[a+4248>>3]=b;if(y[a+4240|0]){if(b>45e-5){c=Xp(b)/.6931471805599453;b=c-J(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=zi(d+c)*.5}else{b=0}C[a+4248>>3]=b}Zt(a)}function Ura(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-192|0;fb=d;c=fb-16|0;fb=c;ew(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){pZ(d)}c=-1;a:{if(!e){break a}c=0;if(!rZ(d)){break a}c=xe(a,b,qZ(d),hb)}fb=d+192|0;return c|0}function BQ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=2097152){Xj();p()}d=Dc(b<<11);x[e+12>>2]=b;x[e+8>>2]=d;d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<11)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=Ac(a),g=b+(d<<11)|0,x[f>>2]=g;fb=e+16|0;return a|0}function $G(a,b,c){var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+8|0;Cc(e,b);x[31785]=0;S(126,d+20|0,c|0,e|0);b=x[31785];x[31785]=0;b:{c:{if((b|0)!=1){x[31785]=0;O(12,a|0,d+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break c}Sb(d+20|0);tb(d+8|0);fb=d+32|0;break a}a=N()|0;break b}a=N()|0;Sb(d+20|0)}tb(d+8|0);Q(a|0);p()}}function Dn(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(x[c>>2]|x[d>>2]){while(1){if((b|0)==(f|0)){break a}e=x[d>>2];g=x[c>>2];h=c,i=g-od((od(0-g|0,31)&255)+g|0,8)|0,x[h>>2]=i;h=d,i=x[d>>2]-od(e+(od(0-e|0,31)&255)|0,8)|0,x[h>>2]=i;e=(f<<3)+a|0;x[e>>2]=x[c>>2];x[e+4>>2]=x[d>>2];f=f+1|0;continue}}Tb(a,0,b<<3)}}function loa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;c=fb-16|0;fb=c;x[c+12>>2]=477218588;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;if(A[e>>2]<b>>>0){cd();p()}c=Dc(D(b,9));x[d+12>>2]=b;x[d+8>>2]=c;b=x[d+8>>2];x[a+4>>2]=b;x[a>>2]=b;f=Ab(a),g=b+D(x[d+12>>2],9)|0,x[f>>2]=g;fb=d+16|0}function Ss(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}v[a|0]=43;a=a+1|0}if(d&512){v[a|0]=35;a=a+1|0}while(1){e=y[b|0];if(e){v[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}v[a|0]=b}function E6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;x[e>>2]=c;a=_x(f+12|0,0,x[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-x[e>>2]>>>0){break a}b=f+12|0;while(1){if(c){a=y[b|0];d=x[e>>2];x[e>>2]=d+1;v[d|0]=a;c=c-1|0;b=b+1|0;continue}break}b=0}fb=f+16|0;return b|0}function Ana(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-80|0;fb=d;c=fb-16|0;fb=c;LY(c+8|0,d);e=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);f=x[c+4>>2];if((f|0)==(e|0)){fd(a,x[c+12>>2])}fb=c+16|0;e=(e|0)==(f|0);if(!e){ZC(d)}c=-1;a:{if(!e){break a}c=0;if(!iV(d)){break a}c=xe(a,b,hV(d),hb)}fb=d+80|0;return c|0}function vI(a){a=a|0;var b=0,c=0,d=0;b=a+12|0;Sb(b+520|0);Sb(b+508|0);Sb(b+496|0);d=b+460|0;c=Sb(b+484|0);while(1){c=Sb(c-12|0);if((d|0)!=(c|0)){continue}break}c=b+172|0;while(1){d=Sb(d-12|0);if((d|0)!=(c|0)){continue}break}d=b+4|0;while(1){c=Sb(c-12|0);if((d|0)!=(c|0)){continue}break}Fs(b);return a|0}function iI(a){a=a|0;var b=0,c=0,d=0;b=a+12|0;tb(b+520|0);tb(b+508|0);tb(b+496|0);d=b+460|0;c=tb(b+484|0);while(1){c=tb(c-12|0);if((d|0)!=(c|0)){continue}break}c=b+172|0;while(1){d=tb(d-12|0);if((d|0)!=(c|0)){continue}break}d=b+4|0;while(1){c=tb(c-12|0);if((d|0)!=(c|0)){continue}break}Fs(b);return a|0}function cla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=Bf(a,c);Yd(d,x[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{d:{switch(e+1|0){case 0:case 2:Hi(f,b);break c;default:break d}}ZY(f,b,e)}f=c}cf(a,f);fb=d+16|0}function Zu(a){var b=0,c=0;b=x[a+76>>2];a:{if(!((b|0)>=0&(!b|x[124273]!=(b&-1073741825)))){b=x[a+4>>2];if((b|0)!=x[a+8>>2]){x[a+4>>2]=b+1;a=y[b|0];break a}a=Cy(a);break a}b=a+76|0;c=x[b>>2];x[b>>2]=c?c:1073741823;c=x[a+4>>2];b:{if((c|0)!=x[a+8>>2]){x[a+4>>2]=c+1;a=y[c|0];break b}a=Cy(a)}ie(b)}return a}function YT(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=Ps(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);Ml(e,b,+n());return}a:{if(!wf(b)){break a}d=F(c)<Infinity;if(b<0){c=d?c:1;break a}if(d){break a}Ml(a,b,wf(c)?NaN:c);return}b=Ps(b);g=Ti(c);Ml(a,b*ff(c),g*b)}function gy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;f=fb-16|0;fb=f;a:{if(b>>>0<1073741808){b:{if(Nq(b)){Ke(d,b);break b}Rj(f+8|0,jn(b)+1|0);e=x[f+8>>2];vd(d,e);nf(d,x[f+12>>2]);Vd(d,b);d=e}e=fb-16|0;fb=e;x[e+12>>2]=c;sF(d,b,e+12|0);fb=e+16|0;vd((b<<2)+d|0,0);fb=f+16|0;break a}of();p()}return a|0}function aV(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;e=c+14|0;b=fb-16|0;fb=b;d=x[a+24>>2];a:{if(!d){ip(e);break a}QD(b+8|0,Xb(Xi(Xp(+(d>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);d=x[b+8>>2];v[b+7|0]=x[b+12>>2];ae(e,d,b+7|0)}fb=b+16|0;b=c+4|0;GD(b,a+36|0,a+37|0);FD(b,e);fb=c+16|0}function ft(a,b,c,d){var e=0,f=0,g=0;e=fb-160|0;fb=e;f=b?a:e+158|0;x[e+148>>2]=f;a=-1;g=b-1|0;x[e+152>>2]=b>>>0>=g>>>0?g:0;e=Tb(e,0,144);x[e+76>>2]=-1;x[e+36>>2]=1203;x[e+80>>2]=-1;x[e+44>>2]=e+159;x[e+84>>2]=e+148;a:{if((b|0)<0){x[31660]=61;break a}v[f|0]=0;a=lL(e,c,d,1179,1180)}fb=e+160|0;return a}function eR(a){var b=0,c=0;a:{if(Ob(a,14324,4)){break a}b=y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=y[a+16|0]|y[a+17|0]<<8|(y[a+18|0]<<16|y[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(y[a+8|0]|y[a+9|0]<<8|(y[a+10|0]<<16|y[a+11|0]<<24))}return c}function Q$(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=d+8|0;Of(e,c);x[31785]=0;S(126,d+20|0,b|0,e|0);b=x[31785];x[31785]=0;a:{b:{if((b|0)!=1){x[31785]=0;O(12,a|0,d+20|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}Sb(d+20|0);tb(d+8|0);fb=d+32|0;return}c=N()|0;break a}c=N()|0;Sb(d+20|0)}tb(d+8|0);Q(c|0);p()}function uea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return KO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,12886,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function lha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Ld(c,E(0));a:{b:{switch(b-3|0){case 0:c=oi(c);if(c==B[wb(a+4208|0,3)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 1:break b;default:break a}}c=E(oi(E(c*E(4)))*E(.25))}d=wb(a+4208|0,b),e=c,B[d>>2]=e;Nz(a)}}function fea(a,b){a=a|0;b=b|0;var c=0;x[31785]=0;W(1005,a|0);c=x[31785];x[31785]=0;if((c|0)!=1){return zO(x[a+24>>2],b)|0}Y(T(0)|0)|0;x[31785]=0;V(992,9811,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Wta(a){a=a|0;var b=0,c=0,d=0;c=fb-32|0;fb=c;b=255;a:{if(Kj(x[a>>2],x[a+4>>2])>>>0<=49){b=PB(c,x[a+12>>2]);x[31785]=0;O(294,a|0,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}Ol(b);ak(a,Kj(x[a>>2],x[a+4>>2])-1&255);b=Kj(x[a>>2],x[a+4>>2])-1|0}fb=c+32|0;return b&255}a=N()|0;Ol(b);Q(a|0);p()}function TD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=fb-32|0;fb=f;x[f+8>>2]=c;g=f,h=jf(b),x[g+28>>2]=h;c=f+8|0;Zf(c,b,x[Gb(c,f+28|0)>>2]);b=Se(c);x[31785]=0;aa(239,a|0,b|0,x[f+8>>2],d|0,e|0);a=x[31785];x[31785]=0;if((a|0)!=1){Jc(f+8|0);fb=f+32|0;return}a=N()|0;Jc(f+8|0);Q(a|0);p()}function Fga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=6){c=Ld(c,E(0));a:{b:{switch(b-1|0){case 0:c=oi(c);if(c==B[wb(a+4208|0,1)>>2]){break a}x[a+4236>>2]=0;B[a+4240>>2]=E(c*E(.5))+E(.5);break a;case 3:break b;default:break a}}c=E(oi(E(c*E(4)))*E(.25))}d=wb(a+4208|0,b),e=c,B[d>>2]=e;Nz(a)}}function zea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return OO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,8816,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function wea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return MO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,7185,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function vea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return LO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,5339,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function tea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return JO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,9350,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function nea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return Nf(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,7153,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function mea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return gq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,6842,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function lea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return DO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,6960,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function kea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return CO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,7028,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function jea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return fq(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,7500,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function $da(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return vO(x[x[a+24>>2]+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,5836,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function sea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return+IO(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31785]=0;V(992,15321,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function jm(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;d=Jb(b);e=c,f=Wc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;x[c+8>>2]=x[a+4>>2]-1;Qi(d,d+x[Gb(c+12|0,c+8|0)>>2]|0,x[a>>2]);d=x[a>>2];e=c,f=Wc(x[b+4>>2],y[b+11|0]),x[e+12>>2]=f;a=x[a+4>>2];x[c+8>>2]=a-1;Mm(d+x[Gb(c+12|0,c+8|0)>>2]|0,a+d|0,79024);fb=c+16|0}function Zq(a){var b=0,c=0;b=fb-32|0;fb=b;x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;c=a+288|0;WB(c,ZU(c),b);x[b+24>>2]=0;x[b+28>>2]=0;x[b+16>>2]=0;x[b+20>>2]=0;x[b+8>>2]=0;x[b+12>>2]=0;x[b>>2]=0;x[b+4>>2]=0;a=a+800|0;WB(a,fC(a),b);fb=b+32|0}function Aea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return+CA(x[x[a+24>>2]+24>>2])}Y(T(0)|0)|0;x[31785]=0;V(992,10159,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function mQ(a){a=a|0;var b=0,c=0,d=0;b=C[a+4264>>3]*+A[x[a+16>>2]+1074376>>2];a:{if(F(b)<0x8000000000000000){d=~~b>>>0;c=F(b)>=1?~~(b>0?H(J(b*2.3283064365386963e-10),4294967295):K((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}C[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function gka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=yc(a,b,614);e=c+616|0;a=0;while(1){d=D(a,872);sq(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=kC(c+223848|0,b+223848|0);x[31785]=0;P(850,c+223860|0,b+223860|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){return c|0}b=N()|0;dc(a);Q(b|0);p()}function Q2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(kh(a,x[b+8>>2],0)){Gx(b,c,d);return}e=x[a+12>>2];f=a+16|0;XH(x[f>>2],x[a+20>>2],b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){XH(x[a>>2],x[a+4>>2],b,c,d);if(y[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function $F(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;d=c+8|0;Ew(d,b);x[31785]=0;S(11,c+20|0,1,d|0);b=x[31785];x[31785]=0;a:{if((b|0)!=1){x[31785]=0;O(12,a|0,c+20|0);a=x[31785];x[31785]=0;if((a|0)==1){b=N()|0;Sb(c+20|0);break a}Sb(c+20|0);tb(c+8|0);fb=c+32|0;return}b=N()|0}tb(c+8|0);Q(b|0);p()}function pR(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;ue(d+8|0,b);f=x[d+8>>2];b=x[d+12>>2];c=fb-16|0;fb=c;e=Bb(x[a+4>>2],y[a+11|0]);x[c+12>>2]=e;x[c+8>>2]=b;g=Gb(c+12|0,c+8|0);a=lx(Jb(a),f,x[g>>2]);a:{if(a){break a}a=-1;if(b>>>0>e>>>0){break a}a=b>>>0<e>>>0}fb=c+16|0;fb=d+16|0;return a>>>31|0}function Bu(a,b){var c=0,d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;ue(d+8|0,b);f=x[d+8>>2];b=x[d+12>>2];c=fb-16|0;fb=c;e=Bb(x[a+4>>2],y[a+11|0]);x[c+12>>2]=e;x[c+8>>2]=b;g=Gb(c+12|0,c+8|0);a=Tp(Jb(a),f,x[g>>2]);a:{if(a){break a}a=-1;if(b>>>0>e>>>0){break a}a=b>>>0<e>>>0}fb=c+16|0;fb=d+16|0;return a>>>31|0}function jh(a,b){var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=G(e);Vf(d,e,0,0,0,c+81|0);e=0+x[d+8>>2]|0;c=(x[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=x[d+4>>2];b=x[d>>2]}x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=e;x[a+12>>2]=f;fb=d+16|0}function bea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return+C[x[a+24>>2]+16>>3]}Y(T(0)|0)|0;x[31785]=0;V(992,7662,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function Zda(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return x[x[a+24>>2]+8>>2]}Y(T(0)|0)|0;x[31785]=0;V(992,10940,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function S$(a,b,c){var d=0,e=0,f=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+8>>2]=192;e=x[a>>2];f=x[a+8>>2];c=x[Gb(d+28|0,d+8|0)>>2];if(!Mb(e,f,c)){c=jf(a)}e=d+8|0;ew(e,b);f=gc(d+16|0,x[d+8>>2],c);kc(d,x[a>>2],x[a+8>>2],x[f>>2],x[f+4>>2]);ew(e,b);Tb(x[d+8>>2]+c|0,0,192-c|0);Yb(a,x[d+28>>2]);fb=d+32|0}function HK(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a=rt(a);x[a+32>>2]=b;x[a>>2]=95100;$c(d+12|0,x[a+4>>2]);x[31785]=0;b=R(1201,x[d+12>>2])|0;e=x[31785];x[31785]=0;if((e|0)!=1){Zb(d+12|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=Zn(b),v[f+44|0]=g;fb=d+16|0;return}b=N()|0;Zb(d+12|0);$n(a);Q(b|0);p()}function sia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Mi(a,b,c,d);x[a>>2]=42540;b=Nb(a+4208|0);x[a+4228>>2]=0;x[a+4220>>2]=0;x[a+4224>>2]=0;x[a+4232>>2]=x[c+24620>>2];B$(a+4260|0,80,150,80,255);x[31785]=0;O(950,a+44|0,2);c=x[31785];x[31785]=0;if((c|0)!=1){return a|0}c=N()|0;sc(b);Uf(a);Q(c|0);p()}function iZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb+-64|0;fb=c;d=c+44|0;Zf(d,a,32);a=x[c+44>>2];e=c+20|0;rg(e,2,Se(d),a);x[31785]=0;O(221,c+32|0,e|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=c+12|0;zn(a,b);b=a;a=c+32|0;jm(b,a);tb(a);Jc(c+44|0);fb=c- -64|0;break a}a=N()|0;Jc(c+44|0);Q(a|0);p()}}function h0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;a:{if(!Mb(x[b>>2],x[b+8>>2],c<<1)){break a}vc(d+12|0,65535);tg(a,z[d+12>>1]);c=vb(x[a>>2]);x[d+4>>2]=c;a=vb(x[a+4>>2]);while(1){if(!Ib(c,a)){break a}hw(b,d+10|0);w[c>>1]=z[d+10>>1];c=x[Wd(d+4|0)>>2];continue}}fb=d+16|0}function Vp(a,b){var c=0,d=0;c=fb-16|0;fb=c;$c(c+12|0,a);x[31785]=0;a=R(1220,x[c+12>>2])|0;d=x[31785];x[31785]=0;a:{b:{if((d|0)==1){break b}x[31785]=0;V(1231,a|0,111968,111994,b|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}Zb(c+12|0);fb=c+16|0;break a}a=N()|0;Zb(c+12|0);Q(a|0);p()}return b}function PV(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=fb-16|0;fb=e;x[e+12>>2]=6553600;i=e,j=$b(b),x[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=gr(f*+A[Gb(g,b)>>2]);x[e+8>>2]=6553600;i=e,j=$b(c),x[i+4>>2]=j;i=e,j=gr(f*+A[Gb(b,e+4|0)>>2]),x[i+12>>2]=j;x[e+8>>2]=d-h;Qj(a,h,Gb(b,g));fb=e+16|0}function uy(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-160|0;fb=e;x[e+60>>2]=b;x[e+20>>2]=b;x[e+24>>2]=-1;f=e+16|0;Fi(f,0,0);vK(e,f,d,1);d=x[e+8>>2];g=x[e+12>>2];f=x[e>>2];h=x[e+4>>2];if(c){x[c>>2]=((x[e+20>>2]+x[e+136>>2]|0)-x[e+60>>2]|0)+b}x[a+8>>2]=d;x[a+12>>2]=g;x[a>>2]=f;x[a+4>>2]=h;fb=e+160|0}function u_(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function gx(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+20|0]=0;v[a+21|0]=0;v[a+22|0]=0;v[a+23|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function PN(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;x[a+4>>2]=0;x[a>>2]=47892;a=ac(8);x[31785]=0;b=P(37,b+4|0,12154)|0;c=x[31785];x[31785]=0;a:{b:{if((c|0)!=1){nc(a,b);x[31785]=0;S(100,a|0,48732,1009);a=x[31785];x[31785]=0;if((a|0)!=1){break a}c=N()|0;tb(b);break b}c=N()|0;jc(a)}Q(c|0)}p()}function FK(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;a=TK(a);x[a+32>>2]=b;x[a>>2]=95468;$c(d+12|0,x[a+4>>2]);x[31785]=0;b=R(39,x[d+12>>2])|0;e=x[31785];x[31785]=0;if((e|0)!=1){Zb(d+12|0);x[a+40>>2]=c;x[a+36>>2]=b;f=a,g=Zn(b),v[f+44|0]=g;fb=d+16|0;return}b=N()|0;Zb(d+12|0);lt(a);Q(b|0);p()}function yea(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return NO(x[a+24>>2])|0}Y(T(0)|0)|0;x[31785]=0;V(992,9776,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return 0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function aB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+813|0];if(c){v[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}xk(a,b,b+700|0,c<<2,0)}}function NP(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[a+4256>>2];x[a+4240>>2]=b<<1;x[31785]=0;x[c+12>>2]=0;S(956,a+4208|0,b<<2,c+12|0);b=x[31785];x[31785]=0;a:{if((b|0)==1){b=T(125240)|0;if((gb|0)!=($(125240)|0)){break a}Y(b|0)|0;x[a+4240>>2]=0;Z()}x[a+4244>>2]=0;fb=c+16|0;return}Q(b|0);p()}function JM(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=x[a>>2];d=gf(e);b:{c:{if((Bb(x[c+4>>2],y[c+11|0])|0)==(d|0)){x[31785]=0;d=U(373,c|0,e|0,d|0)|0;e=x[31785];x[31785]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}T(0)|0;Rb();p()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function FF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=x[a+92>>2];e=x[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){x[a+96>>2]=e;x[a+92>>2]=d}else{f=(g<<3)+b|0;h=x[f>>2];d=d-od((od(0-d|0,31)&255)+d|0,8)|0;x[f>>2]=h+d;h=x[f+4>>2];e=e-od((od(0-e|0,31)&255)+e|0,8)|0;x[f+4>>2]=h+e;g=g+1|0;continue}break}}}function ara(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;rf(b);x[d+12>>2]=0;a:{if(!Ik(a,d+12|0)){break a}f=c;c=x[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}v[d+11|0]=0;if(ki(a,d+11|0)){Ep(b,v[d+11|0]);e=e+1|0;continue}break}e=0}fb=d+16|0;return e|0}function OZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=lg(a);b=b+236|0;e=fr(b);a:{while(1){if((b|0)!=(e|0)){d=z[b>>1];w[c+14>>1]=d;if(d){x[31785]=0;S(405,c+4|0,a|0,c+14|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}fb=c+16|0;return}b=N()|0;Hv(a);Q(b|0);p()}function eka(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(Ad(y[b+24|0])){a=lg(a);c=Yi(x[b>>2]);d=Jf(b);x[31785]=0;S(853,a|0,c|0,d|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}x[31785]=0;P(852,a+12|0,b+12|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}v[a+24|0]=1}return}b=N()|0;KS(a);Q(b|0);p()}function bB(a,b,c){var d=0;d=x[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=y[b+814|0];if(c){v[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){v[b+813|0]=c;break a}c=y[b+813|0]}b:{if(!(v[b+851|0]&1)|!x[b+700>>2]){break b}c=c&255;if(!c){break b}xk(a,b,b+700|0,c,0)}}function MD(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;x[e+8>>2]=c;f=e,g=jf(b),x[f+28>>2]=g;c=e+8|0;Zf(c,b,x[Gb(c,e+28|0)>>2]);b=Se(c);x[31785]=0;V(346,a|0,b|0,x[e+8>>2],d|0);a=x[31785];x[31785]=0;if((a|0)!=1){Jc(e+8|0);fb=e+32|0;return}a=N()|0;Jc(e+8|0);Q(a|0);p()}function iC(a,b,c,d,e){var f=0;a:{f=x[a>>2];if(!ge(f,x[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}hn(b);b=Oo(b,a);x[b+20>>2]=0;x[b>>2]=d;if(!Bh(b)){break a}if(x[a>>2]!=(d|0)){Pr(b+68|0)}yc(x[b+20>>2],x[a+20>>2]+c|0,d);x[b+8>>2]=e?d:0;x[b+4>>2]=0;w[b+34>>1]=z[b+34>>1]&65533|(e?2:0)}}function UG(a,b,c){var d=0,e=0;d=fb-32|0;fb=d;e=Fb(a+16|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[31785]=0;b=P(c|0,d+8|0,b+16|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){a=d+20|0;Oh(a,b);yb(e,a);tb(a);tb(b);fb=d+32|0;return}b=N()|0;Dh(a);Q(b|0);p()}function HM(a){var b=0,c=0,d=0,e=0;d=fb-16|0;fb=d;b=a+120|0;Jt(y[b+20|0]);c=fb-16|0;fb=c;x[c+12>>2]=d+15;a=fb-16|0;fb=a;e=x[18439];x[a+8>>2]=x[18438];x[a+12>>2]=e;e=x[18437];x[a>>2]=x[18436];x[a+4>>2]=e;b=ib[x[bq(a,uk(y[b+20|0]))>>2]](c+12|0,b)|0;fb=a+16|0;fb=c+16|0;fb=d+16|0;return b}function lk(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=x[a+4>>2];e=x[a+12>>2];i=x[a+8>>2];d=x[a>>2];while(1){if((b|0)!=(f|0)){if(!d){x[a>>2]=8;c=i;if((e|0)!=(c|0)){c=e-1|0;x[a+12>>2]=c}d=8;e=c;c=y[c|0]}g=c;d=d-1|0;x[a>>2]=d;c=g>>>1|0;x[a+4>>2]=c;h=g&1|h<<1;f=f+1|0;continue}break}return h}function Saa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=fb-16|0;fb=d;c=d+4|0;oo(c,a);if(x[b>>2]){_Y(b);a=x[b>>2];Ks(b);Db(a);e=Ab(b),f=0,x[e>>2]=f;x[b>>2]=0;x[b+4>>2]=0}x[b>>2]=x[c>>2];x[b+4>>2]=x[c+4>>2];a=Ab(c);e=Ab(b),f=x[a>>2],x[e>>2]=f;x[a>>2]=0;x[c>>2]=0;x[c+4>>2]=0;mf(c);fb=d+16|0}function S9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{if(!x[b+28>>2]){break a}if((ib[x[b+32>>2]](x[b+24>>2],c,0,0)|0)<0){break a}c=x[d+4>>2];f=x[d>>2];while(1){if(!c){break a}e=ib[x[b+28>>2]](x[b+24>>2],f,c)|0;if(!e){break a}g=e+g|0;c=c-e|0;f=f+e|0;continue}}bc(a,x[d>>2],g)}function OQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(Rg(a)>>>0>=b>>>0){f=x[a>>2];e=oc(f,x[a+4>>2]);x[d+8>>2]=e;MQ(f,x[Gb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){fA(a,b-e|0,c);break a}Yh(a,x[a>>2]+(b<<2)|0);break a}ar(a);hm(a,Tf(a,b));fA(a,b,c)}fb=d+16|0}function sfa(a){a=a|0;var b=0;x[31785]=0;W(1005,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return x[a+16>>2]}Y(T(0)|0)|0;x[31785]=0;V(992,5710,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)!=1){Z();return-1}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function _h(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;g=c,h=Dc(16),x[g+8>>2]=h;b=pm(x[c+8>>2]);x[b>>2]=41432;g=In(Ac(b)),h=41564,x[g>>2]=h;b=d+8|0;f=Kn(c);Jn(b,Ac(f),f);qm(c);fb=e+16|0;zf(a,b);he(b);fb=d+16|0;x[a+8>>2]=0;Jd(a+12|0);return a}function Kea(a){a=a|0;var b=0;x[31785]=0;W(1030,a|0);b=x[31785];x[31785]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31785]=0;V(992,11995,a|0,0,0);a=x[31785];x[31785]=0;if((a|0)==1){break a}Z();a=0}return a|0}a=N()|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;if((b|0)!=1){Q(a|0);p()}T(0)|0;Rb();p()}function zpa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31785]=0;O(644,a|0,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break a}jp(a,b,c)}b=d+8|0;Md(b);Wj(b);fb=d+16|0;return a|0}a=N()|0;Wj(d+8|0);Q(a|0);p()}function vx(a,b,c,d,e){var f=0,g=0;a:{f=fb+-64|0;fb=f;g=f+44|0;Zf(g,a,e);a=x[f+44>>2];e=f+20|0;rg(e,d,Se(g),a);x[31785]=0;O(221,f+32|0,e|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=f+12|0;gc(a,b,c);b=a;a=f+32|0;jm(b,a);tb(a);Jc(f+44|0);fb=f- -64|0;break a}a=N()|0;Jc(f+44|0);Q(a|0);p()}}function Um(a,b,c,d){var e=0,f=0;a:{f=x[(D(b,872)+a|0)+1075648>>2];if(!f){break a}if(!Nj(y[f+31|0])){break a}e=y[f+34|0]-1|0;if((e&255)>>>0>249){break a}e=x[rd(a+906300|0,e)>>2];if(!e){break a}ib[x[x[e>>2]+96>>2]](e,f,c,d,b);if(c>>>0>250){break a}w[(D(b,872)+a|0)+1075834>>1]=65535}}function y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31785]=0;O(228,a|0,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break a}HE(a,b,c)}b=d+8|0;Md(b);_g(b);fb=d+16|0;return a|0}a=N()|0;_g(d+8|0);Q(a|0);p()}function mZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31785]=0;O(464,a|0,b|0);e=x[31785];x[31785]=0;if((e|0)==1){break a}dD(a,b,c)}b=d+8|0;Md(b);am(b);fb=d+16|0;return a|0}a=N()|0;am(d+8|0);Q(a|0);p()}function AP(a,b,c){v[a+12|0]=0;x[c>>2]=0;x[b>>2]=0;x[a+28>>2]=0;x[a+32>>2]=0;w[a+24>>1]=0;x[a+36>>2]=0;x[a+40>>2]=0;x[a+44>>2]=0;x[a+48>>2]=0;zP(a+60|0);zP(a+52|0);pq(a+49956|0);pq(a+58148|0);pq(a+66340|0);pq(a+74532|0);Tb(a+228|0,0,32768);Tb(a+32996|0,0,512);Tb(a+33508|0,0,16384)}function ru(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!b){break a}i=Pb(a+1074312|0,73)?c- -64|0:c;c=120;g=Ej(a);j=g^-1;e=1;while(1){if(!c){break a}k=c;c=c>>>1|0;h=e+c|0;f=vh(a,h,i,d);if(!(f>>>0>b>>>0&j)&(!(!f|g)|b>>>0<=f>>>0)){continue}e=h+1|0;c=(c^-1)+k|0;continue}}return e}function oj(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=d;g=Jh(e+8|0,b);b=fb-16|0;fb=b;d=x[e+12>>2];x[b+12>>2]=d;x[b+8>>2]=d;f=-1;d=ft(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Ed(d);x[h>>2]=a;if(!a){break a}f=ft(a,d,c,x[b+12>>2])}fb=b+16|0;Ih(g);fb=e+16|0;return f}function Via(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;c=Bf(a,c);Yd(d,x[a+36>>2]);a:{b:{if(!c){Pc(d,a+32|0,5);e=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}e=x[c+16>>2]}f=x[a+36>>2];c:{if(!((e|0)!=4&(e|0)!=-1)){Ik(f,b);break c}VM(f,b,e)}f=c}cf(a,f);fb=d+16|0}function Nka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+12>>2]=b;a:{if(Qo(a)>>>0>=b>>>0){f=x[a>>2];e=Sc(f,x[a+4>>2]);x[d+8>>2]=e;Rh(f,x[Gb(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){qp(a,b-e|0,c);break a}Tq(a,x[a>>2]+b|0);break a}Pv(a);Yk(a,Ul(a,b));qp(a,b,c)}fb=d+16|0}function Gp(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}if(b>>>0>=f>>>0){Xj();p()}d=Dc(D(b,e));x[g+12>>2]=b;x[g+8>>2]=d;d=x[g+12>>2];b=x[g+8>>2]}x[a>>2]=b;c=b+D(c,e)|0;x[a+8>>2]=c;x[a+4>>2]=c;h=Ac(a),i=b+D(d,e)|0,x[h>>2]=i;fb=g+16|0;return a}function oi(a){var b=E(0),c=0,d=0;c=(q(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return E(a*E(0))}a=(c|0)>=0?a:E(-a);b=E(E(E(a+E(8388608))+E(-8388608))-a);a:{if(b>E(.5)){a=E(E(a+b)+E(-1));break a}a=E(a+b);if(!(b<=E(-.5))){break a}a=E(a+E(1))}a=(c|0)>=0?a:E(-a)}return a}function l2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=vt(c);x[a>>2]=94560;x[d>>2]=94580;x[a+60>>2]=94620;x[a>>2]=94600;x[a+4>>2]=0;e=c;c=a+8|0;go(e,c);x[a>>2]=94560;x[d>>2]=94580;x[31785]=0;P(110,c|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}a=N()|0;sl(d);Q(a|0);p()}function As(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=y[b|0];a:{if(!d){d=0;break a}b:{if(!y[b+1|0]){v[a|0]=d;break b}d=0;if(!Np(e+12|0,b,c)){break a}f=x[e+12>>2];b=Mx(f,c);c:{if((b|0)!=-1){break c}b=32;if((f|0)==8239){break c}if((f|0)!=160){break a}}v[a|0]=b}d=1}fb=e+16|0;return d}function wF(a,b,c,d){var e=0,f=0,g=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;e=d;d=x[a+1068>>2];w[e+(d<<1)>>1]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;f=a,g=Xd(z[x[a+1060>>2]+34>>1])+d|0,x[f+1068>>2]=g;x[a+1072>>2]=x[a+1072>>2]-1}function i7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;$c(g+8|0,x[d+28>>2]);x[31785]=0;b=R(1220,x[g+8>>2])|0;d=x[31785];x[31785]=0;if((d|0)!=1){Zb(g+8|0);MJ(a,f+24|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function h7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;$c(g+8|0,x[d+28>>2]);x[31785]=0;b=R(1220,x[g+8>>2])|0;d=x[31785];x[31785]=0;if((d|0)!=1){Zb(g+8|0);LJ(a,f+16|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function fP(a,b){var c=0,d=0,e=0,f=0;c=fb-96|0;fb=c;jQ(b,c,c+96|0);b=0;while(1){if((b|0)==12){x[a+104>>2]=0;x[a+96>>2]=!(x[a+88>>2]|x[a+92>>2]);x[a+100>>2]=0;fb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=x[f+4>>2];x[e>>2]=x[f>>2];x[e+4>>2]=d&65535;b=b+1|0;continue}break}x[a+112>>2]=0}function jY(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;x[e+12>>2]=a;a:{if(!(!c|b)){a=Xe(+(D(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){vc(e+12|0,10);a=D(y[x[e+12>>2]+25408|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Xe(733.8401379310345/f*1e4);break a}a=Xe(f/.264*1e4)}fb=e+16|0;return a}function Loa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+14|0;QW(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){PW(e)}if(a){d=RW(b+14|0)}fb=b+160|0;return d|0}function Dta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-624|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+14|0;k$(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){j$(e)}if(a){d=l$(b+14|0)}fb=b+624|0;return d|0}function y$(a){var b=0,c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;e=xb(a,31),f=0,v[e|0]=f;d=Ii(a,Lo(a),0);v[c+15|0]=0;d=Tj(a,d);Mm(d+a|0,Lo(a),c+15|0);while(1){if((b|0)!=(d|0)){a:{if(v[xb(a,b)|0]>=32){if(y[xb(a,b)|0]!=127){break a}}e=xb(a,b),f=32,v[e|0]=f}b=b+1|0;continue}break}fb=c+16|0}function xja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;rf(b);e=d+28|0;Zf(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,1,Se(e),a);x[31785]=0;O(221,d+16|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=d+16|0;yb(b,a);tb(a);Jc(d+28|0);fb=d+48|0;break a}a=N()|0;Jc(d+28|0);Q(a|0);p()}}function o7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;$c(g+8|0,x[d+28>>2]);x[31785]=0;b=R(28,x[g+8>>2])|0;d=x[31785];x[31785]=0;if((d|0)!=1){Zb(g+8|0);PJ(a,f+24|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function n7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=fb-16|0;fb=g;x[g+12>>2]=b;$c(g+8|0,x[d+28>>2]);x[31785]=0;b=R(28,x[g+8>>2])|0;d=x[31785];x[31785]=0;if((d|0)!=1){Zb(g+8|0);OJ(a,f+16|0,g+12|0,c,e,b);fb=g+16|0;return x[g+12>>2]}a=N()|0;Zb(g+8|0);Q(a|0);p()}function lia(a,b){a=a|0;b=b|0;var c=0;a:{b:{c=x[a+20>>2];b=x[c+4>>2];if((Sc(b,x[c+8>>2])|0)!=8){break b}if(Ob(b,9576,4)){break b}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;break a}Uz(a,a)}$t(a)}function Ye(a){var b=0,c=0;b=fb-32|0;fb=b;v[b+8|0]=0;x[b>>2]=0;x[b+4>>2]=4194432;XE(b+9|0);x[a>>2]=x[b>>2];c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;c=x[b+16>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=c;c=x[b+24>>2];x[a+20>>2]=x[b+20>>2];x[a+24>>2]=c;v[a+28|0]=y[b+28|0];fb=b+32|0}function toa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-208|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+4|0;pW(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){oW(e)}if(a){d=qW(b+4|0)}fb=b+208|0;return d|0}function qt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=ac(16);if(!y[502433]){v[502433]=1}a=gc(c+8|0,a,126624);x[31785]=0;e=x[a+4>>2];x[c>>2]=x[a>>2];x[c+4>>2]=e;a=U(1181,d|0,c|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){da(a|0,124548,1182);p()}a=N()|0;jc(d);Q(a|0);p()}function ata(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-32|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+10|0;Nv(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){u_(e)}if(a){d=v_(b+10|0)}fb=b+32|0;return d|0}function Xqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-16|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+11|0;ck(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){FY(e)}if(a){d=GY(b+11|0)}fb=b+16|0;return d|0}function Ksa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=fb-160|0;fb=b;d=-1;c=fb-16|0;fb=c;e=b+3|0;b_(c+8|0,e);f=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);g=x[c+4>>2];if((g|0)==(f|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(f|0)==(g|0);if(!a){a_(e)}if(a){d=c_(b+3|0)}fb=b+160|0;return d|0}function xX(a){var b=0;a:{if(Ob(a,15726,4)|((y[a+8|0]|y[a+9|0]<<8)-768&65535)>>>0<65280|(((y[a+112|0]|y[a+113|0]<<8)-65&65535)>>>0<65472|(y[a+106|0]|y[a+107|0]<<8)>>>0>256)){break a}if((y[a+122|0]|y[a+123|0]<<8)>>>0>255){break a}b=(y[a+124|0]|y[a+125|0]<<8)>>>0<4e3}return b}function eQ(a){a=a|0;var b=0,c=0;c=fb-16|0;fb=c;b=x[x[a+16>>2]+1074404>>2];x[31785]=0;x[c+12>>2]=0;S(956,a+4208|0,D(b,254)|0,c+12|0);b=x[31785];x[31785]=0;a:{if((b|0)==1){b=T(125240)|0;if((gb|0)!=($(125240)|0)){break a}Y(b|0)|0;Z()}x[a+4220>>2]=0;fb=c+16|0;return}Q(b|0);p()}function dH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=fb-16|0;fb=g;x[g+12>>2]=c;c=g+12|0;vc(c,f);vc(c,65535);h=z[g+12>>1];tg(a,h);c=0;while(1){if((c|0)==(h|0)){fb=g+16|0}else{f=y[b+c|0];i=Er(x[a>>2],x[a+4>>2],c),j=(d|0)==(f|0)?-1:(e|0)==(f|0)?-2:f,w[i>>1]=j;c=c+1|0;continue}break}}function p$(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=153391689;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=$D(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[_c(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}cd();p()}function ila(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=sV(d+4|0,a+8|0,b);b=x[a>>2];a:{while(1){if(x[a+4>>2]==(b|0)){break a}x[31785]=0;O(789,b|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){b=x[a>>2]+32|0;x[a>>2]=b;continue}break}b=N()|0;ee(a);Q(b|0);p()}ee(a);fb=d+16|0}function P_(a,b){var c=0,d=0,e=0;d=fb-16|0;fb=d;x[d+12>>2]=b;c=fb-16|0;fb=c;x[c+12>>2]=107374182;x[c+8>>2]=2147483647;e=Gb(c+12|0,c+8|0);fb=c+16|0;c=b;b=x[e>>2];if(c>>>0<=b>>>0){a=L_(a);if(a>>>0<b>>>1>>>0){x[d+8>>2]=a<<1;b=x[_c(d+8|0,d+12|0)>>2]}fb=d+16|0;return b}cd();p()}function Kna(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=bj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=1;c=Sh(c);if((c|0)!=1){break b}}ay(a,d,1,d,d,0);c=d}d=x[a>>2];Vd(a,c+1|0);break a}Ke(a,c+1|0);d=a}a=(c<<2)+d|0;vd(a,b);vd(a+4|0,0)}function tna(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{if(b){x[31785]=0;O(228,a|0,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}Ou(a,b)}b=c+8|0;Md(b);_g(b);fb=c+16|0;return a|0}a=N()|0;_g(c+8|0);Q(a|0);p()}function nqa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(c+8|0,x[zb(c+4|0,a)>>2]);a:{if(b){x[31785]=0;O(592,a|0,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}WC(a,b)}b=c+8|0;Md(b);_g(b);fb=c+16|0;return a|0}a=N()|0;_g(c+8|0);Q(a|0);p()}function md(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-32|0;fb=e;g=x[b+8>>2];f=x[b>>2];kf(e+16|0,c,d);c=x[x[f>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,f,g,e+8|0);kf(a,x[e+24>>2],x[e+28>>2]);x[b+8>>2]=x[b+8>>2]+x[a+4>>2];fb=e+32|0}function dY(a,b){var c=0,d=0;a:{c=x[b>>2];d=x[b+20>>2];if(!ge(c,d)){break a}if(x[a+20>>2]==(d|0)){x[a+20>>2]=0;c=x[b>>2]}vc(a,c);c=z[a+34>>1]&-2|w[b+34>>1]&1;w[a+34>>1]=c;w[a+34>>1]=c&65471|z[b+34>>1]&64;if(!Bh(a)){break a}yc(x[a+20>>2],x[b+20>>2],Rk(x[a>>2],z[a+34>>1]))}}function WL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;kf(e+24|0,b,c);b=zf(e+16|0,d);x[31785]=0;c=x[b+4>>2];x[e+8>>2]=x[b>>2];x[e+12>>2]=c;dg(166,a,x[e+24>>2],x[e+28>>2],e+8|0);a=x[31785];x[31785]=0;if((a|0)!=1){he(d);fb=e+32|0;return}a=N()|0;he(d);Q(a|0);p()}function F$(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function vF(a,b,c,d){var e=0,f=0;b=x[a+1076>>2]+(b-(b&c?c<<1:0)|0)|0;x[a+1076>>2]=b;c=b+x[a+1080>>2]|0;x[a+1080>>2]=c;v[x[a+1068>>2]+d|0]=y[a+1084|0]?c:b;x[a+1064>>2]=x[a+1064>>2]+1;e=a,f=x[a+1068>>2]+Xd(z[x[a+1060>>2]+34>>1])|0,x[e+1068>>2]=f;x[a+1072>>2]=x[a+1072>>2]-1}function i8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b|0];g=v[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function cra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a:{if(oc(x[a>>2],x[a+4>>2])>>>0>511){break a}if(!xd(b)){break a}x[31785]=0;O(504,a|0,c+12|0);a=x[31785];x[31785]=0;d=b;if((a|0)!=1){break a}a=N()|0;Ig(c+12|0);Q(a|0);p()}Ig(c+12|0);fb=c+16|0;return d|0}function co(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=uua(a,b,10,0);e=hb;a=sua(d,e,246,0)+a|0;c=c-1|0;v[c|0]=a|48;f=b>>>0>9;a=d;b=e;if(f){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;v[c|0]=D(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function Y$(a,b,c){var d=0,e=0,f=0;d=fb-48|0;fb=d;rf(b);e=d+28|0;Zf(e,a,c);a=x[d+28>>2];f=d+4|0;rg(f,3,Se(e),a);x[31785]=0;O(221,d+16|0,f|0);e=x[31785];x[31785]=0;if((e|0)!=1){e=b;b=d+16|0;yb(e,b);tb(b);Jc(d+28|0);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Jc(d+28|0);Q(a|0);p()}function Tpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=fJ(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31785]=0;W(601,b|0);e=x[31785];x[31785]=0;if((e|0)!=1){b=b+24|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=c+16|0}function Ep(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=bj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Sh(c);if((c|0)!=10){break b}}Nm(a,d,1,d,d,0,0);c=d}d=x[a>>2];Vd(a,c+1|0);break a}Ke(a,c+1|0);d=a}a=c+d|0;ed(a,b);ed(a+1|0,0)}function tja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;Zf(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,1,Se(e),a);x[31785]=0;O(221,d+16|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=d+16|0;ye(b,a);tb(a);Jc(d+28|0);fb=d+48|0;break a}a=N()|0;Jc(d+28|0);Q(a|0);p()}}function j_(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=d+12|0;vc(c,256);vc(c,65535);f=z[d+12>>1];tg(a,f);c=0;while(1){if((c|0)==(f|0)){fb=d+16|0}else{e=y[b+c|0];g=Er(x[a>>2],x[a+4>>2],c),h=(e|0)==255?-1:(e|0)==254?-2:e,w[g>>1]=h;c=c+1|0;continue}break}}function Oka(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c=y[a+11|0];c:{d:{if(Cd(c)){c=x[a+4>>2];d=bj(x[a+8>>2])-1|0;if((c|0)==(d|0)){break d}break c}d=10;c=Sh(c);if((c|0)!=10){break b}}DB(a,d,1,d,d,0);c=d}d=x[a>>2];Vd(a,c+1|0);break a}Ke(a,c+1|0);d=a}a=c+d|0;ed(a,b);ed(a+1|0,0)}function Mra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;Zf(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,2,Se(e),a);x[31785]=0;O(221,d+16|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=d+16|0;fm(b,a);tb(a);Jc(d+28|0);fb=d+48|0;break a}a=N()|0;Jc(d+28|0);Q(a|0);p()}}function GE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=pw(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}x[31785]=0;W(231,b|0);e=x[31785];x[31785]=0;if((e|0)!=1){b=b+20|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=c+16|0}function De(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function uW(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=vb(x[a>>2]);x[c+12>>2]=b;e=vb(x[a+4>>2]);while(1){a:{d=Ib(b,e);if(!d){break a}a=z[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){w[b>>1]=65535;break b}if(a>>>0>63){break a}}b=x[Wd(c+12|0)>>2];continue}break}fb=c+16|0;return d^1}function i$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-48|0;fb=d;e=d+28|0;Zf(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,2,Se(e),a);x[31785]=0;O(221,d+16|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=d+16|0;zc(b,a);tb(a);Jc(d+28|0);fb=d+48|0;break a}a=N()|0;Jc(d+28|0);Q(a|0);p()}}function Kha(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=4104;a=0;d=x[b+8>>2];a:{if(d>>>0<4096){break a}c=x[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}x[b+12>>2]=e;x[b+8>>2]=d-c;a=e}if(!a){_(6073,9034,88,7420);p()}fb=b+16|0;return a|0}function g7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=fb-16|0;fb=a;x[a+12>>2]=b;$c(a+8|0,x[d+28>>2]);x[31785]=0;b=R(1220,x[a+8>>2])|0;d=x[31785];x[31785]=0;if((d|0)!=1){Zb(a+8|0);KJ(f+20|0,a+12|0,c,e,b);fb=a+16|0;return x[a+12>>2]}b=N()|0;Zb(a+8|0);Q(b|0);p()}function Yj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=vb(x[b>>2]);f=vb(x[b+4>>2]);e=fb-16|0;fb=e;x[e+12>>2]=d;while(1){a:{if(!Ib(d,f)){break a}if(S_(c,x[d>>2],x[d+4>>2])){break a}d=x[rn(e+12|0)>>2];continue}break}fb=e+16|0;if(mc(d,vb(x[b+4>>2]))){_h(a);return}ep(a,d)}function Wt(a){var b=0,c=0,d=E(0);b=a+4232|0;c=y[b|0];if(c>>>0>=5){v[b|0]=0;c=0}if(v[a+4233|0]<0){v[a+4233|0]=127}b=v[a+4234|0];if((b|0)<0){v[a+4234|0]=127;b=127}a:{if((c|0)==3){d=E(E(1)-Ce(E(2),E(-E((b&255)+1|0))));break a}d=Ce(E(2),E(-E((b&255)>>>0)))}B[a+4224>>2]=d}function xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=fb-48|0;fb=c;d=c+28|0;Zf(d,a,32);a=x[c+28>>2];e=c+4|0;rg(e,1,Se(d),a);x[31785]=0;O(221,c+16|0,e|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=c+16|0;zc(b,a);tb(a);Jc(c+28|0);fb=c+48|0;break a}a=N()|0;Jc(c+28|0);Q(a|0);p()}}function uF(a,b,c){var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=x[a+4>>2];f=e+b|0;x[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=x[a>>2];break a}a=x[a>>2];x[a+((f>>>0>=33?g>>>5|0:0)<<2)>>2]=0}op(d+8|0,a,e);Gw(x[d+8>>2],x[d+12>>2],b,c);fb=d+16|0}function Kia(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;x[c+12>>2]=-1;x[c+16>>2]=0;x[c+4>>2]=0;Fb(c+20|0);x[31785]=0;x[c+4>>2]=x[c+4>>2]&-1332|1058;x[c+8>>2]=1;S(82,a|0,b|0,c+4|0);a=x[31785];x[31785]=0;if((a|0)!=1){Dh(c+4|0);fb=c+32|0;return}a=N()|0;Dh(c+4|0);Q(a|0);p()}function q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=vf(v[b|0]),e=x[x[a>>2]+52>>2],ib[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=Mk(b,1,c,x[a+32>>2])}return c|0}function m7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=fb-16|0;fb=a;x[a+12>>2]=b;$c(a+8|0,x[d+28>>2]);x[31785]=0;b=R(28,x[a+8>>2])|0;d=x[31785];x[31785]=0;if((d|0)!=1){Zb(a+8|0);NJ(f+20|0,a+12|0,c,e,b);fb=a+16|0;return x[a+12>>2]}b=N()|0;Zb(a+8|0);Q(b|0);p()}function gJ(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;x[a>>2]=0;x[a+4>>2]=0;d=rc(a+8|0),e=0,v[d+128|0]=e;Nd(b+8|0,x[zb(b+4|0,a)>>2]);x[31785]=0;O(1294,a|0,30);c=x[31785];x[31785]=0;if((c|0)!=1){Ou(a,30);c=b+8|0;Md(c);cJ(c);fb=b+16|0;return a}a=N()|0;cJ(b+8|0);Q(a|0);p()}function Z9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(y[b+40|0]){break a}b:{if(!x[b+28>>2]){break b}d=x[c+4>>2];f=x[c>>2];while(1){if(!d){break a}e=ib[x[b+28>>2]](x[b+24>>2],f,d)|0;if(!e){break b}g=e+g|0;d=d-e|0;f=f+e|0;continue}}v[b+40|0]=1}bc(a,x[c>>2],g)}function Y_(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;v[d+15|0]=1;v[d+14|0]=a>>>2;a=y[af(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){v[d+13|0]=1;v[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=y[af(d+13|0,d+12|0)|0]}fb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function YL(a){var b=0,c=0,d=0;b=fb-48|0;fb=b;eg(x[x[a>>2]-12>>2]+a|0,0);Yd(b+32|0,a);a=Ei(a,0,0,2);Yd(b+16|0,a);c=x[b+44>>2];x[b+8>>2]=x[b+40>>2];x[b+12>>2]=c;c=x[b+36>>2];x[b>>2]=x[b+32>>2];x[b+4>>2]=c;c=x[b+28>>2];d=x[b+24>>2];Qm(a,b);a=Au(d,c);fb=b+48|0;return a}function Lp(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function LE(a,b){var c=0,d=0;c=fb-16|0;fb=c;$c(c+12|0,a);x[31785]=0;a=R(28,x[c+12>>2])|0;d=x[31785];x[31785]=0;a:{if((d|0)==1){break a}x[31785]=0;a=P(29,a|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}Zb(c+12|0);fb=c+16|0;return a}a=N()|0;Zb(c+12|0);Q(a|0);p()}function NG(a,b,c,d,e){var f=0,g=0;a:{f=fb-48|0;fb=f;rf(b);g=f+28|0;Zf(g,a,d);a=x[f+28>>2];d=f+4|0;rg(d,e,Se(g),a);x[31785]=0;S(602,f+16|0,c|0,d|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=f+16|0;yb(b,a);tb(a);Jc(f+28|0);fb=f+48|0;break a}a=N()|0;Jc(f+28|0);Q(a|0);p()}}function $$(a,b,c){var d=0,e=0,f=0;d=fb-48|0;fb=d;e=d+28|0;Zf(e,a,c);a=x[d+28>>2];f=d+4|0;rg(f,3,Se(e),a);x[31785]=0;O(221,d+16|0,f|0);e=x[31785];x[31785]=0;if((e|0)!=1){e=b;b=d+16|0;zc(e,b);tb(b);Jc(d+28|0);fb=d+48|0;return!c|(a|0)!=0}a=N()|0;Jc(d+28|0);Q(a|0);p()}function NB(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a=ZB(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}x[31785]=0;O(789,b|0,c|0);f=x[31785];x[31785]=0;if((f|0)!=1){b=b+32|0;x[a+4>>2]=b;continue}break}b=N()|0;hc(a);Q(b|0);p()}hc(a);fb=d+16|0}function Ch(a,b){var c=0,d=0,e=0;a:{if(!(v[a+480180|0]&1|b)){break a}e=x[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;w[c+480286>>1]=64;d=c+480280|0;x[d>>2]=x[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;w[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function w1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-32|0;fb=e;x[e+24>>2]=d;x[e+28>>2]=c;x[31785]=0;V(170,e+8|0,b|0,e+28|0,e+24|0);c=x[31785];x[31785]=0;if((c|0)!=1){c=e+16|0;d=e+8|0;xp(c,d);zf(a,c);he(c);he(d);he(b);fb=e+32|0;return}a=N()|0;he(b);Q(a|0);p()}function ht(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=x[b+76>>2]>=0;b:{c=x[b+4>>2];c:{if(!c){Oy(b);c=x[b+4>>2];if(!c){break c}}if(x[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;x[b+4>>2]=c;v[c|0]=a;x[b>>2]=x[b>>2]&-17;d=a&255}return d}function P8(a){a=a|0;var b=0,c=0,d=0;c=x[a+44>>2];b=x[a+24>>2];if(c>>>0<b>>>0){x[a+44>>2]=b;c=b}d=-1;a:{if(!(y[a+48|0]&8)){break a}b=x[a+16>>2];if(b>>>0<c>>>0){_n(a,x[a+8>>2],x[a+12>>2],c);b=x[a+16>>2]}a=x[a+12>>2];if(a>>>0>=b>>>0){break a}d=vf(v[a|0])}return d|0}function _O(a,b){var c=0,d=0;x[a+4>>2]=b;x[a>>2]=127148;x[a+20>>2]=0;x[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;x[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;x[a+8>>2]=d;x[a+32>>2]=d>>>0>=31?-1:-1>>>31-d|0;x[a+28>>2]=b>>>0>=c>>>0?-1>>>32-d|0:0;x[a+16>>2]=(D(c,d)-b|0)+c;return a}function yI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=_I(a,c);x[a>>2]=113436;c=tk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Jm(a,18124,b);x[31785]=0;W(1348,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(d+4|0);Q(a|0);p()}fb=d+16|0;return a|0}p()}function tl(a){var b=0,c=0;a:{b=x[a+1396>>2];if((b|0)>24){break a}if(!b){x[a+1392>>2]=0}while(1){if(y[a+1376|0]?0:x[a+1384>>2]){break a}c=xt(a);if((c|0)==-1){break a}b=x[a+1396>>2];x[a+1396>>2]=b+8;x[a+1392>>2]=x[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function ln(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=a;c=qC(b);e=fb-16|0;fb=e;a:{if(c>>>0<1073741808){b:{if(Nq(c)){Ke(d,c);break b}Rj(e+8|0,jn(c)+1|0);f=x[e+8>>2];vd(d,f);nf(d,x[e+12>>2]);Vd(d,c);d=f}vd(Wi(d,b,c)+(c<<2)|0,0);fb=e+16|0;break a}of();p()}return a|0}function S4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=bJ(a,c);x[a>>2]=112236;c=tk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Jm(a,18062,b);x[31785]=0;W(1348,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(d+4|0);Q(a|0);p()}fb=d+16|0;return a|0}p()}function P4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=aJ(a,c);x[a>>2]=112268;c=tk(Jb(b));x[a+8>>2]=c;a:{if(!c){a=d+4|0;Jm(a,18243,b);x[31785]=0;W(1348,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(d+4|0);Q(a|0);p()}fb=d+16|0;return a|0}p()}function Aha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;x[a+4>>2]=b;x[a>>2]=0;b=Xt(a+8|0,d);x[31785]=0;P(970,a+20|0,c|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){x[a+32>>2]=0;x[a+36>>2]=0;v[a+42|0]=0;v[a+40|0]=0;v[a+41|0]=y[a+41|0]&224|25;return a|0}a=N()|0;Eb(b);Q(a|0);p()}function qZ(a){var b=0,c=0,d=0,e=0;d=y[a+32|0]|y[a+33|0]<<8;e=y[a+38|0]|y[a+39|0]<<8;c=y[a+34|0]|y[a+35|0]<<8;b=c+(y[a+36|0]|y[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=(c>>>0>b>>>0?a+1|0:a)<<2|b>>>30;c=d;d=b<<2;b=c+d|0;hb=b>>>0<d>>>0?a+1|0:a;return b}function n3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=Xn(e+4|0,c,d);c=mK(0,Jb(b),0);x[31785]=0;a=U(1368,a|0,c|0,0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){mK(Jb(a),Jb(b),Bb(x[a+4>>2],y[a+11|0])+1|0);Sb(b);fb=e+16|0;return}a=N()|0;Sb(b);Q(a|0);p()}function aH(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(e+8|0,x[zb(e+4|0,a)>>2]);a:{if(b){x[31785]=0;O(d|0,a|0,b|0);d=x[31785];x[31785]=0;if((d|0)==1){break a}qp(a,b,c)}b=e+8|0;Md(b);aj(b);fb=e+16|0;return a}a=N()|0;aj(e+8|0);Q(a|0);p()}function Mn(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;a:{if(!b){b=0;break a}d=b;b=G(b);Vf(c,d,0,0,0,b+81|0);d=0+x[c+8>>2]|0;b=(x[c+12>>2]^65536)+(16414-b<<16)|0;f=e>>>0>d>>>0?b+1|0:b;e=x[c+4>>2];b=x[c>>2]}x[a>>2]=b;x[a+4>>2]=e;x[a+8>>2]=d;x[a+12>>2]=f;fb=c+16|0}function EC(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=fb-1024|0;fb=e;d=fb-16|0;fb=d;BC(d+8|0,e);f=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);g=x[d+4>>2];if((g|0)==(f|0)){Yb(a,x[d+12>>2])}fb=d+16|0;if((f|0)==(g|0)){h=CC(e,c)>>>0<=b>>>0}fb=e+1024|0;return h}function yB(a,b,c,d){var e=0,f=0,g=0;e=$d(a);a:{if(e){f=ec(a);while(1){a=e;e=z[a+16>>1];g=x[a+20>>2];if(Ll(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!Ll(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=ec(a);f=a}x[b>>2]=a;return f}function k3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;b=pi(e+4|0,c,d);c=oK(0,Jb(b),0);x[31785]=0;a=U(545,a|0,c|0,0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){oK(Jb(a),Jb(b),Bb(x[a+4>>2],y[a+11|0])+1|0);tb(b);fb=e+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function UA(a,b,c,d){var e=0,f=0,g=0;e=$d(a);a:{if(e){f=ec(a);while(1){a=e;e=y[a+16|0];g=x[a+20>>2];if(uo(c,d,e,g)){f=a;e=x[a>>2];if(e){continue}break a}if(!uo(e,g,c,d)){break a}f=a+4|0;e=x[a+4>>2];if(e){continue}break}break a}a=ec(a);f=a}x[b>>2]=a;return f}function C1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=x[b+8>>2];a:{if(f>>>0<=c>>>0){c=x[d>>2];b=0;break a}x[e+12>>2]=f-c;x[e+8>>2]=x[d+4>>2];c=x[b+4>>2]+c|0;f=c;b=x[Gb(e+12|0,e+8|0)>>2];g=c+b|0;c=x[d>>2];Qi(f,g,c)}bc(a,c,b);fb=e+16|0}function Bq(a,b,c,d){var e=0,f=0,g=0;a:{e=Nl(a,b);if((e|0)==255){break a}g=x[a>>2];if(Ak(g)){break a}f=Dd(a+318|0,e);e=nU(e);if(v[xb(f,10)|0]&1|d){wh(g,x[a+4>>2],b,e- -64|0,mU(c,y[xb(f,2)|0]))}if(d){break a}wh(x[a>>2],x[a+4>>2],b,e+67|0,mU(c,y[xb(f,3)|0]))}}function _qa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;rf(b);v[c+15|0]=0;a:{if(!ki(a,c+15|0)){break a}f=y[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}v[c+14|0]=0;if(ki(a,c+14|0)){Ep(b,v[c+14|0]);e=e+1|0;continue}break}d=0}fb=c+16|0;return d|0}function RY(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-16|0;fb=d;f=fb-16|0;fb=f;g=a;a=D((a-b|0)/-6|0,6)+c|0;QY(f+8|0,b,g,a);Td(d+8|0,b,zb(f+4|0,Sq(c,a)));fb=f+16|0;a=x[d+8>>2];x[d+4>>2]=x[d+12>>2];Td(e+8|0,a,d+4|0);fb=d+16|0;fb=e+16|0;return x[e+12>>2]}function Gh(a,b,c,d,e,f){var g=0;g=fb-32|0;fb=g;x[g+12>>2]=-1;x[g+16>>2]=0;x[g+4>>2]=0;Fb(g+20|0);x[g+8>>2]=f;x[31785]=0;x[g+4>>2]=x[g+4>>2]&e|d;S(c|0,a|0,b|0,g+4|0);a=x[31785];x[31785]=0;if((a|0)!=1){Dh(g+4|0);fb=g+32|0;return}a=N()|0;Dh(g+4|0);Q(a|0);p()}function f8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=x[b>>2];g=x[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function SG(a,b,c){var d=0;d=fb-16|0;fb=d;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);Nd(d+8|0,x[zb(d+4|0,a)>>2]);a:{if(b){x[31785]=0;O(c|0,a|0,b|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}eX(a,b)}b=d+8|0;Md(b);aj(b);fb=d+16|0;return a}a=N()|0;aj(d+8|0);Q(a|0);p()}function NO(a){var b=0,c=0;b=x[a+24>>2];c=z[b+1074448>>1];if(c>>>0>=Lj(Wb(x[b+484360>>2],y[b+484376|0]))>>>0){return z[x[a+24>>2]+1074446>>1]}a=x[a+24>>2];b=z[_b(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],c)>>1];return tn(x[a+484344>>2],x[a+484348>>2],b)?b:-1}function sx(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+12>>2]=-1;x[f+16>>2]=0;x[f+4>>2]=0;x[f+8>>2]=0;Fb(f+20|0);x[31785]=0;x[f+4>>2]=x[f+4>>2]&e|d;S(c|0,a|0,b|0,f+4|0);a=x[31785];x[31785]=0;if((a|0)!=1){Dh(f+4|0);fb=f+32|0;return}a=N()|0;Dh(f+4|0);Q(a|0);p()}function ela(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=b;d=fb-16|0;fb=d;b=Bf(a,c);Yd(d,x[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}IB(x[a+36>>2],e,c);f=1;g=b}cf(a,g);fb=d+16|0;return f|0}function qH(a,b,c,d){var e=0,f=0,g=0,h=0;a:{f=fb-16|0;fb=f;e=f+4|0;x[e+4>>2]=1;g=e,h=Dc(d),x[g+8>>2]=h;d=x[e+8>>2];x[31785]=0;P(c|0,d|0,b|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){b=a;a=Kn(e);Jn(b,Ac(a),a);qm(e);fb=f+16|0;break a}a=N()|0;qm(e);Q(a|0);p()}}function Yaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=d+4|0;tx(e,c);c=d+16|0;x[c>>2]=b;Yc(c+4|0,e);x[31785]=0;O(1134,a+4|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){Hk(d+16|0);tb(d+4|0);fb=d+32|0;return}a=N()|0;Hk(d+16|0);tb(d+4|0);Q(a|0);p()}function VG(a,b,c,d){var e=0,f=0;a:{e=fb-48|0;fb=e;f=e+28|0;Zf(f,a,d);a=x[e+28>>2];d=e+4|0;rg(d,c,Se(f),a);x[31785]=0;O(221,e+16|0,d|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=e+16|0;ye(b,a);tb(a);Jc(e+28|0);fb=e+48|0;break a}a=N()|0;Jc(e+28|0);Q(a|0);p()}}function Oy(a){var b=0,c=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;if(x[a+20>>2]!=x[a+28>>2]){ib[x[a+36>>2]](a,0,0)|0}x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;b=x[a>>2];if(b&4){x[a>>2]=b|32;return-1}c=x[a+44>>2]+x[a+48>>2]|0;x[a+8>>2]=c;x[a+4>>2]=c;return b<<27>>31}function z$(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;rf(b);e=d+28|0;Zf(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,2,Se(e),a);x[31785]=0;O(221,d+16|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=d+16|0;yb(b,a);tb(a);Jc(d+28|0);fb=d+48|0;return}a=N()|0;Jc(d+28|0);Q(a|0);p()}function __(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}v[d+15|0]=1;v[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=y[af(d+15|0,d+14|0)|0]}a=e;fb=d+16|0;return a&255}function zga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=Mi(a,b,c,d);x[a>>2]=45216;b=a+4208|0;e=wb(b,0),f=1017370378,x[e>>2]=f;e=wb(b,1),f=0,x[e>>2]=f;x[31785]=0;O(950,a+44|0,2);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;Uf(a);Q(b|0);p()}function pf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=a;e=fb-16|0;fb=e;a:{if(b>>>0<2147483632){b:{if(Ok(b)){Ke(d,b);break b}ng(e+8|0,Ah(b)+1|0);f=x[e+8>>2];vd(d,f);nf(d,x[e+12>>2]);Vd(d,b);d=f}ed($l(d,b,c)+b|0,0);fb=e+16|0;break a}of();p()}return a|0}function l3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-32|0;fb=a;b=pi(a+20|0,b,c);x[31785]=0;c=U(1369,a+8|0,d|0,e|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){d=li(Jb(b),Jb(c));tb(c);tb(b);fb=a+32|0;return((d|0)<0?-1:(d|0)!=0)|0}a=N()|0;tb(b);Q(a|0);p()}function W0(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!JF(a,c+12|0)){break a}d=0;if(!IF(c+12|0)){break a}if(b){a=x[b>>2];if(!x[b+4>>2]&a>>>0<$b(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))-8>>>0){break a}}d=1}fb=c+48|0;return d|0}function RC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;pY(a,b);bd(a,$b(y[b+8|0]|y[b+9|0]<<8|(y[b+10|0]<<16|y[b+11|0]<<24))+504|0);oY(a,d);a:{b=$b(y[b+32|0]|y[b+33|0]<<8|(y[b+34|0]<<16|y[b+35|0]<<24));if(!b){break a}if(!bd(a,b)){break a}TC(a,c);return}Tb(c,0,80)}function Caa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=x[b>>2];e=x[b+8>>2];f=x[b+4>>2];a=0;a:while(1){if((a|0)!=(f|0)){g=(a<<2)+d|0;b=0;while(1)if((b|0)==(e|0)){a=a+1|0;continue a}else{c=x[g>>2]+(b<<3)|0;x[c>>2]=0;x[c+4>>2]=0;b=b+1|0;continue}}break}}function AG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Cc(b+4|0,15187);a:{if(!Wc(x[a+4>>2],y[a+11|0])){break a}c=1;if((Og(a,14788)|0)!=-1){break a}if((Og(a,17006)|0)!=-1){break a}if((Og(a,13811)|0)!=-1){break a}c=(Og(a,13854)|0)!=-1}tb(a);fb=b+16|0;return c|0}function hg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Rj(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<2)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=Ac(a),g=b+(d<<2)|0,x[f>>2]=g;fb=e+16|0;return a|0}function gf(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!y[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=x[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(y[b|0]){continue}break}}return b-a|0}function U9(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;if(!y[a+8|0]){Uj(a+12|0,x[a+4>>2]);le(b+24|0,x[a+12>>2],x[a+16>>2]);c=x[x[a>>2]+40>>2];d=x[b+28>>2];x[b+8>>2]=x[b+24>>2];x[b+12>>2]=d;ib[c|0](b+16|0,a,0,b+8|0);v[a+8|0]=1}fb=b+32|0;return x[a+12>>2]}function z4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=XI(a,0);x[a>>2]=118344;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Jb(b);x[31785]=0;O(1351,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function w4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=WI(a,0);x[a>>2]=118448;c=Fb(a+12|0);d=Fb(a+24|0);e=Fb(a+36|0);f=Fb(a+48|0);b=Jb(b);x[31785]=0;O(1352,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}a=N()|0;tb(f);tb(e);tb(d);tb(c);Q(a|0);p()}function u4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=VI(a,0);x[a>>2]=118552;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Jb(b);x[31785]=0;O(1353,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}a=N()|0;Sb(f);Sb(e);Sb(d);tb(c);Q(a|0);p()}function s4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a=UI(a,0);x[a>>2]=118656;c=Fb(a+16|0);d=Fb(a+28|0);e=Fb(a+40|0);f=Fb(a+52|0);b=Jb(b);x[31785]=0;O(1354,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}a=N()|0;Sb(f);Sb(e);Sb(d);tb(c);Q(a|0);p()}function fK(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;x[b>>2]=0;v[c+15|0]=0;ki(a,c+15|0);d=y[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){x[b>>2]=e;if((d|0)==(f|0)){fb=c+16|0}else{v[c+15|0]=0;ki(a,c+15|0);d=d+1|0;e=x[b>>2]|y[c+15|0]<<(d<<3)-2;continue}break}}function dT(a,b){var c=0,d=0,e=0;a:{if(!(v[a+851|0]&1)){break a}c=x[a+104>>2];if(!c|!x[c>>2]){break a}d=x[a+88>>2];e=d|128;x[a+88>>2]=e;c=x[c>>2];x[a+88>>2]=b?d|134:e&-7;x[a+76>>2]=c;x[a>>2]=0;x[a+4>>2]=c-1;if(!b){break a}x[a+84>>2]=c;x[a+80>>2]=0}}function qW(a){var b=0;a:{if(Ob(a,15155,4)){break a}if(Cb(y[a+4|0]|y[a+5|0]<<8)>>>0>2|y[a+6|0]>128){break a}if(Cb(y[a+200|0]|y[a+201|0]<<8)>>>0>3999){break a}if(!Cb(y[a+140|0]|y[a+141|0]<<8)){break a}b=(Cb(y[a+148|0]|y[a+149|0]<<8)|0)==50}return b}function pE(a,b,c){var d=0,e=0;d=fb-48|0;fb=d;e=d+28|0;Zf(e,a,c);a=x[d+28>>2];c=d+4|0;rg(c,3,Se(e),a);x[31785]=0;O(221,d+16|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){a=d+16|0;fm(b,a);tb(a);Jc(d+28|0);fb=d+48|0;return}a=N()|0;Jc(d+28|0);Q(a|0);p()}function mL(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=mL(a*0x10000000000000000,b);c=x[b>>2]+-64|0}x[b>>2]=c;return a}x[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function SS(a,b,c,d){var e=0;e=-2147483648;e=!c|!(v[c+15|0]&1)?e:x[c+8>>2];a:{b:{if(!(!d|!(y[d+34|0]&32))){e=z[d+28>>1];break b}if((e|0)==-2147483648){break a}}Fq(b,e,a);if(!Pb(a+1074312|0,10)|y[a+480209|0]&64){break a}x[b+88>>2]=x[b+88>>2]&-257}}function era(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;while(1){a:{c=x[a>>2];if(oc(c,x[a+4>>2])>>>0>d>>>0){f=e+4|0;nm(f,x[wb(c,d)>>2]+40|0);c=Vq(f,b);tb(f);if(!c){break a}g=x[wb(x[a>>2],d)>>2]}fb=e+16|0;return g|0}d=d+1|0;continue}}function ZT(a){var b=0,c=0,d=0,e=0,f=0;b=fb-16|0;fb=b;c=a;d=x[a>>2];f=Dk(d,x[a+4>>2]);a=vb(d);x[b+12>>2]=a;e=+(f>>>0);c=vb(x[c+4>>2]);while(1){if(Ib(a,c)){C[a>>3]=C[a>>3]/e;C[a+8>>3]=C[a+8>>3]/e;a=x[Kq(b+12|0)>>2];continue}else{fb=b+16|0}break}}function Xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;c=Bf(a,c);Yd(e,x[a+36>>2]);a:{b:{if(!c){Pc(e,a+32|0,5);f=-1;if(!Hb(x[x[e>>2]>>2],x[e+4>>2])){break b}break a}f=x[c+16>>2]}ib[d|0](x[a+36>>2],b,f);g=c}cf(a,g);fb=e+16|0}function GV(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=d+4|0;x[c>>2]=a;a=x[a+4>>2];x[c+4>>2]=a;x[c+8>>2]=a+D(b,872);b=x[c+4>>2];a=x[c+8>>2];while(1){if((a|0)==(b|0)){hc(c);fb=d+16|0}else{DV(Tb(b,0,872));b=b+872|0;x[c+4>>2]=b;continue}break}}function DC(a,b,c){var d=0;d=fb-16|0;fb=d;w[d+12>>1]=c;w[d+14>>1]=b;b=vb(x[a>>2]);c=vb(x[a+4>>2]);a=fb-16|0;fb=a;x[a+12>>2]=b;while(1){if(Ib(b,c)){if(z[b>>1]==z[d+14>>1]){w[b>>1]=z[d+12>>1]}b=x[Wd(a+12|0)>>2];continue}break}fb=a+16|0;fb=d+16|0}function Ww(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+18|0]=0;v[a+19|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function MN(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=d,f=WN(c),x[e+8>>2]=f;c=x[oe(d+12|0,d+8|0)>>2];x[31785]=0;b=+pa(1123,a|0,+b,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){Uc(d+8|0);fb=d+16|0;return+b}a=N()|0;Uc(d+8|0);Q(a|0);p()}function Id(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=fb-16|0;fb=c;d=zb(c+12|0,x[a+4>>2]);e=zb(c+8|0,x[a>>2]);f=zb(c+4|0,x[b+4>>2]);g=b,h=ZV(x[d>>2],x[e>>2],x[f>>2]),x[g+4>>2]=h;wc(a,b+4|0);wc(a+4|0,b+8|0);wc(Ab(a),Ac(b));x[b>>2]=x[b+4>>2];fb=c+16|0}function Dca(a,b){a=a|0;b=b|0;var c=0;a:{if((a|0)==(b|0)){break a}c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22485}c=Ed(gf(b)+1|0);x[a+4>>2]=c;if(!c){break a}yc(c,b,gf(b)+1|0)}return a|0}function Rb(){var a=0;a=x[31657];x[31785]=0;X(a|0);a=x[31785];x[31785]=0;a:{if((a|0)!=1){x[31785]=0;X(1370);a=x[31785];x[31785]=0;if((a|0)!=1){break a}}Y(T(0)|0)|0;x[31785]=0;X(1370);a=x[31785];x[31785]=0;if((a|0)!=1){break a}T(0)|0;Rb()}p()}function Kp(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function ypa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Oq(e,c);yj(d+12|0,e);x[31785]=0;V(304,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31785];x[31785]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function hS(a,b){a=dS(a);dS(a+368680|0);if(b){cS(a,1);return}if(!y[496016]){hS(127312,1);v[496016]=1}Gk(258424,323960,a+131112|0);Gk(323960,389496,a+196648|0);Gk(389496,455032,a+262184|0);Gk(127336,258424,a+24|0);yc(a+327720|0,455032,40960)}function gn(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}ng(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+c|0;x[a+8>>2]=c;x[a+4>>2]=c;f=Ac(a),g=b+d|0,x[f>>2]=g;fb=e+16|0;return a|0}function ZV(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-16|0;fb=d;f=fb-16|0;fb=f;g=a;a=(b-a|0)+c|0;WV(f+8|0,b,g,a);Td(d+8|0,b,zb(f+4|0,a));fb=f+16|0;a=x[d+8>>2];x[d+4>>2]=x[d+12>>2];Td(e+8|0,a,d+4|0);fb=d+16|0;fb=e+16|0;return x[e+12>>2]}function Nta(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;rr(e,c);yj(d+12|0,e);x[31785]=0;V(304,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31785];x[31785]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function zra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Cp(e,c);yj(d+12|0,e);x[31785]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31785];x[31785]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function roa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;zZ(e,c);yj(d+12|0,e);x[31785]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31785];x[31785]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function ota(a,b){a=a|0;b=b|0;var c=0;b=fb-32|0;fb=b;c=-1;a:{if(!ND(a,b+20|0)){break a}c=0;if(!H_(b+20|0)){break a}if(!Ob(b+20|0,14295,4)){c=-1;if(!fd(a,4)){break a}}c=-1;if(!kk(a,b+12|0)){break a}c=!Ob(b+12|0,14248,4)}fb=b+32|0;return c|0}function oh(a,b){var c=0,d=0,e=0;d=y[a+11|0];c=Bb(x[a+4>>2],d);a:{if((c|0)!=(Bb(x[b+4>>2],y[b+11|0])|0)){break a}a=Jb(a);b=Jb(b);if(!Cd(d)){while(1){e=!c;if(!c|y[a|0]!=y[b|0]){break a}b=b+1|0;a=a+1|0;c=c-1|0;continue}}e=!Tp(a,b,c)}return e}function TP(a,b,c){var d=0,e=0;if(E(F(a))<E(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return E((e?b^-1|e:b)|0)}function IF(a){var b=0,c=0;a:{if(Ob(a,14309,4)){break a}if(Ob(a+8|0,14207,4)){break a}b=$b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24));if(!b){break a}c=($b(y[a+12|0]|y[a+13|0]<<8|(y[a+14|0]<<16|y[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function Cra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Fv(e,c);yj(d+12|0,e);x[31785]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31785];x[31785]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function $aa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=Ru(e+4|0,a,d);f=x[d+4>>2];x[31785]=0;a=ba(1132,Ab(a)|0,b|0,c|0,f|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){x[d+4>>2]=a;hc(d);fb=e+16|0;return}a=N()|0;hc(d);Q(a|0);p()}function xW(a){var b=0,c=0;a:{if(y[a+29|0]!=2){break a}b=y[a+28|0];if((b|0)!=26&(b|0)!=2|y[a+30|0]!=2){break a}b=y[a+31|0];if(b>>>0>21|!(1<<b&3146753)|y[a+33|0]>64){break a}b=y[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=vW(a+20|0)}return c}function wG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;Tn(e,c);yj(d+12|0,e);x[31785]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31785];x[31785]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function tT(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+3|0]|y[b+4|0]<<8|(y[b+5|0]<<16|y[b+6|0]<<24);v[a+3|0]=b;v[a+4|0]=b>>>8;v[a+5|0]=b>>>16;v[a+6|0]=b>>>24}function re(a,b){var c=0,d=0;c=x[a+4>>2];d=c+b|0;x[a+4>>2]=d;if(x[a+8>>2]>=(d|0)){d=x[a>>2]+(c>>3)|0;a=c&7;c=y[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=y[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function bD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Nb(a+8|0);x[31785]=0;d=R(205,b|0)|0;e=x[31785];x[31785]=0;b:{if((e|0)==1){break b}x[31785]=0;S(172,a|0,b|0,d|0);a=x[31785];x[31785]=0;if((a|0)==1){break b}break a}a=N()|0;dc(c);Q(a|0);p()}}function XG(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;x[e+12>>2]=c;c=e+12|0;vc(c,d);vc(c,65535);d=z[e+12>>1];tg(a,d);c=0;while(1){if((c|0)==(d|0)){fb=e+16|0}else{f=y[b+c|0];g=Er(x[a>>2],x[a+4>>2],c),h=f,w[g>>1]=h;c=c+1|0;continue}break}}function Rra(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;v[b+30|0]=0;w[b+28>>1]=0;c=gc(b+8|0,b+28|0,3);kc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+24>>2]!=3){break a}if(Ob(b+28|0,14892,3)){break a}Yb(a,3);d=1}fb=b+32|0;return d|0}function Pna(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;w[b+28>>1]=0;x[b+24>>2]=0;c=gc(b+8|0,b+24|0,6);kc(b+16|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+20>>2]!=6){break a}if(Ob(b+24|0,3856,6)){break a}Yb(a,6);d=1}fb=b+32|0;return d|0}function KE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;nw(e,c);yj(d+12|0,e);x[31785]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31785];x[31785]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function D9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;d=dv(e+4|0,a,d);f=x[d+4>>2];x[31785]=0;a=ba(1168,Ab(a)|0,b|0,c|0,f|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){x[d+4>>2]=a;hc(d);fb=e+16|0;return}a=N()|0;hc(d);Q(a|0);p()}function A_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=fb-32|0;fb=d;e=d+20|0;mE(e,c);yj(d+12|0,e);x[31785]=0;V(95,a|0,b|0,x[d+12>>2],x[d+16>>2]);a=x[31785];x[31785]=0;if((a|0)!=1){Eb(d+20|0);fb=d+32|0;break a}a=N()|0;Eb(d+20|0);Q(a|0);p()}}function qy(a,b){var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;w[b>>1]=0;v[c+15|0]=0;ki(a,c+15|0);d=y[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){w[b>>1]=e;if(d>>>0>=f>>>0){fb=c+16|0}else{v[c+15|0]=0;ki(a,c+15|0);e=z[b>>1]|y[c+15|0]<<7;d=1;continue}break}}function Zw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;kf(e+8|0,b,c);x[31785]=0;Ma(168,a|0,x[e+8>>2],x[e+12>>2]);b=x[31785];x[31785]=0;if((b|0)!=1){x[a+8>>2]=0;zf(a+12|0,d);he(d);fb=e+16|0;return a|0}a=N()|0;he(d);Q(a|0);p()}function HC(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];kf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);kf(a,x[e+24>>2],x[e+28>>2]);x[b+12>>2]=x[b+12>>2]+x[a+4>>2];fb=e+32|0}function dA(a,b){var c=0,d=0,e=0,f=0;c=a&16711680;d=c>>>8|0;e=c<<24;c=a&-16777216;f=c>>>24|0;c=e|c<<8;e=d|f|(a<<24|(a&65280)<<8);d=0;hb=e|(d|d);return((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24)|c}function W$(a){var b=0,c=0,d=0,e=0;c=y[a+2|0];b=c+(y[a+5|0]|y[a+6|0]<<8)|0;c=(b>>>0<c>>>0?1:d)<<1|b>>>31;d=b<<1;b=c;a=y[a+3|0]|y[a+4|0]<<8;c=a>>>30|0;e=d;d=a<<2;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e+47|0;hb=b>>>0<47?a+1|0:a;return b}function OS(a,b){var c=0,d=0;a:{if(!(y[a+89|0]&16)){break a}c=x[a+656>>2];if(!c){break a}c=x[c>>2];b:{if(c){d=a;a=x[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;x[d+696>>2]=a;a=(D(a,x[b>>2])|0)/65536|0;break b}if(x[a+696>>2]){break a}a=0}x[b>>2]=a}}function vta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;Qw(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;if((d|0)!=(e|0)){v[b+2|0]=0;v[b|0]=0;v[b+1|0]=0}}function Fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=b;d=fb-16|0;fb=d;b=Bf(a,c);Yd(d,x[a+36>>2]);a:{b:{if(!b){Pc(d,a+32|0,5);c=-1;if(!Hb(x[x[d>>2]>>2],x[d+4>>2])){break b}break a}c=x[b+16>>2]}IB(x[a+36>>2],e,c);f=b}cf(a,f);fb=d+16|0}function Fi(a,b,c){var d=0,e=0,f=0,g=0;x[a+112>>2]=b;x[a+116>>2]=c;e=x[a+4>>2];d=x[a+44>>2]-e|0;x[a+120>>2]=d;x[a+124>>2]=d>>31;d=a;a=x[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}x[d+104>>2]=a}function oha(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if(Ob(b,9576,4)){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4228>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4232>>2]=c;Wt(a)}}function dia(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(x[b+4>>2]!=8){break a}b=x[b>>2];if(Ob(b,9576,4)){break a}c=y[b+4|0]|y[b+5|0]<<8|(y[b+6|0]<<16|y[b+7|0]<<24);x[a+4260>>2]=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);x[a+4264>>2]=c;$t(a)}}function YU(a){var b=0,c=0,d=0;d=Lo(a);while(1){if((a|0)!=(d|0)){b=y[a|0];a:{b:{if((b-97&255)>>>0<=5){c=b-32|0;break b}if(!(b-88>>>0<2|b-120>>>0<2)){c=99;if((b|0)==75|(b|0)==107){break b}break a}c=122}v[a|0]=c}a=a+1|0;continue}break}}function DU(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=vi(e+4|0,a,c-f>>1);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){hc(g);hr(b,f,h);fb=e+16|0}else{dk(d,z[a>>1]);d=d+2|0;x[g+4>>2]=d;a=a+2|0;continue}break}}function mT(a,b,c){var d=0;d=x[b+48>>2]+1|0;x[b+52>>2]=d;a:{if(A[Vb(x[a+484344>>2],z[b+70>>1])+12>>2]>d>>>0){break a}if(!c){w[b+74>>1]=z[b+72>>1]+1}x[b+52>>2]=0;if(!Pb(a+1074312|0,63)){break a}a=x[b+56>>2];x[b+56>>2]=0;x[b+52>>2]=a}}function Zf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Nb(a+8|0);x[31785]=0;S(172,a|0,b|0,c|0);c=x[31785];x[31785]=0;a:{if((c|0)!=1){a=x[a>>2];x[31785]=0;P(186,b|0,a|0)|0;a=x[31785];x[31785]=0;if((a|0)!=1){break a}}a=N()|0;dc(d);Q(a|0);p()}}function Nra(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;XC(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,4896)}return a|0}function x_(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;h=x[a+4>>2];f=(h-d|0)+b|0;g=Sl(e+4|0,a,c-f|0);d=x[g+4>>2];a=f;while(1){if(a>>>0>=c>>>0){hc(g);hr(b,f,h);fb=e+16|0}else{ul(d,y[a|0]);d=d+1|0;x[g+4>>2]=d;a=a+1|0;continue}break}}function x8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!y[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((ib[x[x[a>>2]+52>>2]](a,x[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=Mk(b,4,c,x[a+32>>2])}return c|0}function nY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=kn(a);e=Bb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Wi(d+(e<<2)|0,b,c);b=c+e|0;jg(a,b);vd(d+(b<<2)|0,0);return a|0}aI(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function _Z(a){var b=0,c=0,d=0,e=0;b=y[a+3|0];c=sua(b>>>0<3?48:64,0,Cb(y[a+196|0]|y[a+197|0]<<8),0);d=hb;e=c;c=sua(sua(Cb(y[a+198|0]|y[a+199|0]<<8),0,b>>>0<4?4:5,0),hb,Cb(y[a+200|0]|y[a+201|0]<<8),0);b=e+c|0;b=b+512|0;hb=0;return b}function Yoa(a,b){a=a|0;b=b|0;var c=0;b=fb-32|0;fb=b;c=-1;a:{if(!ND(a,b+20|0)){break a}c=0;if(!aX(b+20|0)){break a}c=-1;if(!kk(a,b+12|0)){break a}c=0;if(!x[b+16>>2]){break a}a=x[b+12>>2];c=(a&2139062143)==(a|0)}fb=b+32|0;return c|0}function Sf(a,b,c){var d=0;a:{if(A[b+8>>2]<c>>>0){x[31785]=0;V(1153,17605,9130,435,6401);a=x[31785];x[31785]=0;if((a|0)==1){break a}p()}d=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=d;x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c;return}T(0)|0;Rb();p()}function aC(a,b){var c=0,d=0,e=0,f=0;w[a+24>>1]=0;x[a+20>>2]=0;x[a>>2]=0;x[a+4>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(F(d)<2147483648){b=~~d;break a}b=-2147483648}x[a+16>>2]=b;e=a,f=SV(c-+(b<<2)),x[e+8>>2]=f;x[a+12>>2]=hb;return a}function VA(a,b,c){var d=0,e=0;d=$d(a);a:{if(d){e=ec(a);while(1){a=d;d=y[a+16|0];if(vo(c,d)){e=a;d=x[a>>2];if(d){continue}break a}if(!vo(d,c)){break a}e=a+4|0;d=x[a+4>>2];if(d){continue}break}break a}a=ec(a);e=a}x[b>>2]=a;return e}function Lqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;VC(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,33)}return a|0}function HR(a){var b=0,c=0,d=0;c=fb-544|0;fb=c;a:{if(!(y[a+480210|0]&128)|!x[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=aC(c,x[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}yc(b+112|0,a,538);b=b+872|0;continue}}fb=c+544|0}function z0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;ow(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Tb(b,0,65)}return a|0}function tG(a){var b=0;if(!(Ob(a,13433,8)|(y[a+8|0]|y[a+9|0]<<8)!=14|(!(y[a+12|0]|y[a+13|0]<<8)|(y[a+14|0]|y[a+15|0]<<8|(y[a+16|0]<<16|y[a+17|0]<<24))<=0))){b=(y[a+18|0]|y[a+19|0]<<8|(y[a+20|0]<<16|y[a+21|0]<<24))>>>0>23}return b}function lua(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){Wh(a+b|0);a=a+1|0;continue}break}break a}bc(c+8|0,b,120);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Daa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=x[b>>2];d=x[b+8>>2];e=x[b+4>>2];a=0;a:while(1){if((a|0)!=(e|0)){f=(a<<2)+c|0;b=0;while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{x[x[f>>2]+(b<<2)>>2]=0;b=b+1|0;continue}}break}}function Zsa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){ip((a<<1)+b|0);a=a+1|0;continue}break}break a}Zv(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Ni(a){var b=0,c=0,d=0,e=0;b=be(a);c=b&63;e=b<<24>>24;a:{if(!(b&64)){break a}b=6;while(1){d=be(a);c=(d&127)<<b|c;if(d<<24>>24>=0){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}return(e|0)<0?(c|0)<0?-2147483648:0-c|0:c}function NQ(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=e>>>8|0;g=(e&255)<<24|d>>>8;d=(((y[b|0]^d)&255)<<3)+22520|0;e=x[d>>2];d=x[d+4>>2]^f;x[a>>2]=e^g;x[a+4>>2]=d;b=b+1|0;continue}break}return a}function Ag(a,b){var c=0,d=0,e=0,f=0;d=z[a+22>>1];e=d+z[a+20>>1]|0;c=z[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-D(x[wb(b,z[c+28>>1])>>2],w[c+26>>1])|0;d=d+1|0;continue}break}return a}function vr(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;b=fb-16|0;fb=b;Gr(b+8|0,c+15|0);d=x[b+12>>2];nd(b,a,x[b+8>>2],x[b+12>>2]);e=x[b+4>>2];if((e|0)==(d|0)){fd(a,x[b+12>>2])}fb=b+16|0;fb=c+16|0;return((d|0)==(e|0)?y[c+15|0]:0)&255}function um(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}EG(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,12)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=Ac(a),g=b+D(d,12)|0,x[f>>2]=g;fb=e+16|0;return a}function tR(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=x[a>>2];e=x[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Fc(tua(sua(d,d>>31,g,h),hb,256,0),hb);x[a+4>>2]=f-d;x[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function eT(a,b){var c=0,d=0;d=fb-16|0;fb=d;c=x[a+104>>2];if(!(!c|!x[c>>2])){x[a+88>>2]=x[a+88>>2]&-131|128;c=x[c>>2];x[a+76>>2]=c;x[d+12>>2]=b<<8;x[d+8>>2]=c-1;b=c+(x[Gb(d+12|0,d+8|0)>>2]^-1)|0;x[a>>2]=0;x[a+4>>2]=b}fb=d+16|0}function RD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=x[a>>2];f=Sk(e,x[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=sg(e,c);if(!Ib(x[c>>2],x[c+4>>2])){break a}d=d+1|0;continue}break}return(bh(a,d&65535,b)?d:-1)&65535}function Gna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-32|0;fb=d;e=pg(x[b>>2],x[b+4>>2]);c=oV(d+12|0,c);x[31785]=0;V(763,a|0,b|0,e-1&65535,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){$e(c);fb=d+32|0;return}a=N()|0;$e(c);Q(a|0);p()}function Fpa(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;w[b+30>>1]=0;c=gc(b+8|0,b+30|0,2);kc(b+20|0,x[a>>2],x[a+8>>2],x[c>>2],x[c+4>>2]);a:{if(x[b+24>>2]!=2){break a}if(Ob(b+30|0,13719,2)){break a}Yb(a,2);d=1}fb=b+32|0;return d|0}function BD(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}BE(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,20)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=Ac(a),g=b+D(d,20)|0,x[f>>2]=g;fb=e+16|0;return a}function tua(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=uua(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;hb=(g^hb)-((a>>>0<f>>>0)+g|0)|0;return b}function kT(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!c){break a}x[b+40>>2]=c;if(!c|x[a+480180>>2]!=256){break a}x[d+12>>2]=c>>>4;x[d+8>>2]=1;e=b,f=x[_c(d+12|0,d+8|0)>>2],x[e+40>>2]=f;e=b,f=jC(c&255),x[e+44>>2]=f}fb=d+16|0}function Xka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;gU(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){CB(b)}return a|0}function Upa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Hh(178956970)>>>0<b>>>0){cd();p()}d=Dc(D(b,24));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+D(x[c+12>>2],24)|0,x[e>>2]=f;fb=c+16|0}function Nna(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Hh(119304647)>>>0<b>>>0){cd();p()}d=Dc(D(b,36));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+D(x[c+12>>2],36)|0,x[e>>2]=f;fb=c+16|0}function xV(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}wV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<4)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=Ac(a),g=b+(d<<4)|0,x[f>>2]=g;fb=e+16|0;return a}function pj(a,b,c){c=c&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=y[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(y[a+1|0]|32)!=120){break a}a=a+2|0}return a}function kw(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;ww(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){uE(b)}return a|0}function kv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;bX(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){cX(b)}return a|0}function hk(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}Jw(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<1)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=Ac(a),g=b+(d<<1)|0,x[f>>2]=g;fb=e+16|0;return a}function Vr(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}_F(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<3)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=Ac(a),g=b+(d<<3)|0,x[f>>2]=g;fb=e+16|0;return a}function VY(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}SY(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+D(c,6)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=Ac(a),g=b+D(d,6)|0,x[f>>2]=g;fb=e+16|0;return a}function Qu(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;Gg(a+12|0,d);a:{if(!b){d=0;b=0;break a}tV(e+8|0,b);d=x[e+12>>2];b=x[e+8>>2]}x[a>>2]=b;c=b+(c<<5)|0;x[a+8>>2]=c;x[a+4>>2]=c;f=Ac(a),g=b+(d<<5)|0,x[f>>2]=g;fb=e+16|0;return a}function qta(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Hh(715827882)>>>0<b>>>0){cd();p()}d=Dc(D(b,6));x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+D(x[c+12>>2],6)|0,x[e>>2]=f;fb=c+16|0}function iu(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=42524;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=42376;break a;case 2:c=42372;break a;case 1:break b;case 0:break c}}c=42368;break a}c=42364}x[a>>2]=x[c>>2]}function Zd(a,b){var c=0,d=0,e=0,f=0,g=0;d=z[a+22>>1];g=d+z[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=z[e+28>>1]+b|0;w[e+28>>1]=f;if((f&65535)>>>0<2048){break a}w[a+20>>1]=c-d}return}c=c+1|0;continue}}function UY(a,b,c){var d=0,e=0,f=0;e=fb-16|0;fb=e;d=e+4|0;x[d>>2]=x[a+8>>2];f=x[a+8>>2];x[d+8>>2]=a+8;x[d+4>>2]=D(b,6)+f;b=x[d>>2];while(1){if(x[d+4>>2]!=(b|0)){Dv(b,c);b=x[d>>2]+6|0;x[d>>2]=b;continue}break}ee(d);fb=e+16|0}function Sra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[a+480180>>2]=b;cr(c,dr(a));d=x[c+12>>2];b=a+1074320|0;x[b>>2]=x[c+8>>2];x[b+4>>2]=d;b=x[c+4>>2];x[a+1074312>>2]=x[c>>2];x[a+1074316>>2]=b;iu(a+8|0,dr(a));fb=c+16|0}
function O9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;c=e+4|0;x[c+4>>2]=1;f=c,g=Dc(40),x[f+8>>2]=g;d=pm(x[c+8>>2]);x[d>>2]=78520;d=gM(Ac(d));x[d+24>>2]=b;x[d>>2]=78668;b=a;a=Kn(c);Jn(b,Ac(a),a);qm(c);fb=e+16|0}function zsa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=fb-16|0;fb=c;if(Hh(2147483647)>>>0<b>>>0){cd();p()}d=Dc(b<<1);x[c+12>>2]=b;x[c+8>>2]=d;b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;e=Ab(a),f=b+(x[c+12>>2]<<1)|0,x[e>>2]=f;fb=c+16|0}function zq(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(C[b-8>>3]-C[a>>3]);b=0;while(1){if((b|0)!=2048){d=-De(f*C[Re(a,b)>>3]);a:{if(F(d)<2147483648){e=~~d;break a}e=-2147483648}g=wb(c,b),h=e,x[g>>2]=h;b=b+1|0;continue}break}}function gV(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;a:{if(!(c&32)){break a}c=wd(b);x[d+12>>2]=c;f=yf(b);while(1){if(!Ib(c,f)){break a}e=y[c|0];if((e-97&255)>>>0<=25){v[c|0]=e-32}c=x[je(d+12|0)>>2];continue}}Yc(a,b);fb=d+16|0}function qpa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){Wh(a+b|0);a=a+1|0;continue}break}break a}ED(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function ot(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Lc(a);e=Bb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);yg(d+e|0,b,c);b=c+e|0;jg(a,b);ed(b+d|0,0);return a|0}Mp(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function cja(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;d=-1;a:{if(!vG(a,c+8|0)){break a}d=0;if(!eR(c+8|0)|(x[b>>2]!=(y[c+16|0]|y[c+17|0]<<8|(y[c+18|0]<<16|y[c+19|0]<<24))|x[b+4>>2]?b:0)){break a}d=1}fb=c+32|0;return d|0}function cH(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;x[f+24>>2]=a;x[f+28>>2]=b;x[f+16>>2]=d;x[f+20>>2]=e;x[f+8>>2]=c;x[f+12>>2]=0;a=R$(f+24|0,f+8|0);b=f+16|0;a=Pp(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?a:b;fb=f+32|0;return x[a>>2]}function jv(a,b){var c=0,d=0,e=0;if(x[a>>2]){x$(a);c=x[a>>2];$D(a);Db(c);d=Ab(a),e=0,x[d>>2]=e;x[a>>2]=0;x[a+4>>2]=0}x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0}function It(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=fb-16|0;fb=c;d=x[b>>2];b=oc(d,x[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){fb=c+16|0}else{x[c+12>>2]=0;e=rc(c+12|0);f=wb(d,a),g=x[e>>2],x[f>>2]=g;a=a+1|0;continue}break}}function zW(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){v[d+14|0]=(z[(b<<1)+31294>>1]-z[(c<<1)+31294>>1]|0)/5;a=y[Ub(d+15|0,d+14|0)|0]}fb=d+16|0;return a&255}function iha(a){a=a|0;var b=0;ib[x[x[a>>2]+132>>2]](a);Nz(a);x[a+4236>>2]=0;v[a+4202|0]=1;b=ib[x[x[a>>2]+196>>2]](a)|0;x[a+4328>>2]=0;x[a+4312>>2]=0;B[a+4240>>2]=b?E(.5):E(1);b=x[a+4256>>2];x[a+4324>>2]=b;x[a+4320>>2]=b}function Waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;e=d+4|0;QM(e,c);a=x[a+1298472>>2];x[31785]=0;S(389,a|0,b|0,e|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(d+4|0);fb=d+16|0;return}a=N()|0;tb(d+4|0);Q(a|0);p()}function IS(a,b){var c=0,d=0,e=0,f=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];d=Ab(a);c=ec(a);a:{if(!x[d>>2]){x[a>>2]=c;break a}x[x[c>>2]+8>>2]=c;c=ec(b);x[b>>2]=c;x[c>>2]=0;e=Ab(b),f=0,x[e>>2]=f}return a}function Ax(a,b,c,d,e){var f=0,g=0,h=0;f=fb-16|0;fb=f;g=zf(f+8|0,d);x[31785]=0;h=x[g+4>>2];x[f>>2]=x[g>>2];x[f+4>>2]=h;a=dg(e,a,b,c,f);b=x[31785];x[31785]=0;if((b|0)!=1){he(d);fb=f+16|0;return a}a=N()|0;he(d);Q(a|0);p()}function AA(a,b){var c=0;c=x[b+24>>2];c=c>>>0<=1?1:c;x[a+24628>>2]=c>>>0>=512?512:c;a:{if(!(x[b+16>>2]!=x[a+24620>>2]|x[b+20>>2]!=x[a+24624>>2])){c=0;if(x[b+12>>2]==x[a+24616>>2]){break a}}c=1}yc(a+24604|0,b,40);CR(a,c)}function xt(a){var b=0;a:{b=y[a+1376|0];b:{if(!b){b=-1;if(x[a+1384>>2]){break b}if(!_y(a)){break b}b=y[a+1376|0];if(!b){break a}}v[a+1376|0]=b-1;x[a+1400>>2]=x[a+1400>>2]+1;b=df(a)}return b}_(15920,13279,1578,5449);p()}function uda(a,b){a=a|0;b=b|0;var c=0;a=x[a+8>>2];a:{if(yd(x[b+4>>2],y[b+11|0])){c=0}else{c=a;if(ke(b,47600)){break a}c=a+88|0;if(ke(b,47612)){break a}c=a+92|0;if(ke(b,47624)){break a}c=ke(b,47637)?a+96|0:0}}return c|0}function bta(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(Hh(1073741823)>>>0<=8191){cd();p()}c=Dc(32768);x[b+12>>2]=8192;x[b+8>>2]=c;c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=Ab(a),e=c+(x[b+12>>2]<<2)|0,x[d>>2]=e;fb=b+16|0}function bi(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);e=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Yb(a,x[d+12>>2])}fb=d+16|0;a=(e|0)==(f|0);if(!a){Tb(b,0,c)}return a}function _W(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=zb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-56|0;iv(b);continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];XW(a);Db(b)}fb=c+16|0}function Yqa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=fb-16|0;fb=d;c=-1;a:{if(!kk(a,d+8|0)){break a}e=x[d+12>>2];c=0;if(!(x[d+8>>2]==(yn(8998)|0)&e>>>0>255&e>>>0<260)){break a}c=xe(a,b,e>>>0<259?80:76,0)}fb=d+16|0;return c|0}function IU(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=vi(e+4|0,a,d);a=x[f+4>>2];d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if(Ib(b,c)){dk(a,z[b>>1]);a=a+2|0;b=x[Wd(d+12|0)>>2];continue}break}fb=d+16|0;x[f+4>>2]=a;hc(f);fb=e+16|0}function AY(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+17|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function AS(a,b,c,d){var e=0,f=0;e=x[(D(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=z[(D(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=y[((b<<5)+a|0)+480288|0]}return f}function xI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=a;a=tk(Jb(b));x[d>>2]=a;a:{if(!a){a=c+4|0;Jm(a,17806,b);x[31785]=0;W(1348,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c+4|0);Q(a|0);p()}fb=c+16|0;return}p()}function rU(a,b){a:{if(y[a+76|0]==(b|0)){break a}v[a+76|0]=b;if(b){b=0;if(z[a+24>>1]==15){w[a+20>>1]=0;b=1}x[a+8>>2]=0;x[a+16>>2]=b;return}b:{switch(x[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}x[a+16>>2]=3}}function nF(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;ch(a,c+15|0);d=y[c+15|0]}fb=c+16|0;a=d<<24>>24;break a}_(11256,9099,324,14333);p()}return a}function jB(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=x[b+480180>>2];if(f&64671904){b=y[(d&15)+42448|0];v[a+2|0]=0;w[a>>1]=b;return}g=a;a=(c&255)==4&(f|0)==4;c=(d&255)<<a<<4;Yl(g,(h=Pb(b+1074312|0,66)?0:c,i=c,j=e,j?h:i),a)}function JD(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=Sl(e+4|0,a,d);a=x[f+4>>2];d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if(Ib(b,c)){ul(a,y[b|0]);a=a+1|0;b=x[je(d+12|0)>>2];continue}break}fb=d+16|0;x[f+4>>2]=a;hc(f);fb=e+16|0}function sua(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=D(e,f);g=c&65535;h=a&65535;i=D(g,h);f=(i>>>16|0)+D(f,g)|0;e=(f&65535)+D(e,h)|0;hb=(D(b,c)+j|0)+D(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function rZ(a){var b=0;a:{b:{if(Ob(a,13938,4)){if(Ob(a,16487,4)){break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0<=255){break b}break a}if((y[a+34|0]|y[a+35|0]<<8)>>>0>255){break a}}b=(y[a+36|0]|y[a+37|0]<<8)>>>0<4e3}return b}function br(a,b,c){var d=0,e=0;e=z[a+480192>>1];a:{if(e){if(!zd(b)|c>>>0>e>>>0){break a}c=x[((c<<2)+a|0)+900380>>2];if(!c){break a}d=z[_b(c+236|0,b-1|0)>>1];break a}d=c}return(z[a+480190>>1]>=(d&65535)>>>0?d:0)&65535}function wI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=tk(Jb(b));x[a>>2]=d;a:{if(!d){a=c+4|0;Jm(a,17847,b);x[31785]=0;W(1348,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(c+4|0);Q(a|0);p()}fb=c+16|0;return a}p()}function qL(a,b){var c=0,d=0,e=0;c=fb-256|0;fb=c;if((b|0)>=2){x[(b<<2)+a>>2]=c;yc(c,x[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;yc(x[e>>2],x[(d<<2)+a>>2],4);x[e>>2]=x[e>>2]+4;if((b|0)!=(d|0)){continue}break}}fb=c+256|0}function Yy(a){var b=0;a:{b:{while(1){if(x[a+1380>>2]!=-1){break b}b=0;if(!wt(a)){break a}if(!(v[a+1375|0]&1)){continue}break}fc(a,32);return 0}x[a+1396>>2]=0;x[a+1400>>2]=0;x[a+1384>>2]=0;v[a+1376|0]=0;b=1}return b}function Ufa(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;a:{if(er(a,10275)){c=b+4|0;Jm(c,18393,a);a=Jb(c);x[31785]=0;O(69,44,a|0);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;tb(b+4|0);Q(a|0);p()}fb=b+16|0;return}p()}function UT(a,b){var c=0,d=0,e=0,f=0;e=C[a+48>>3];c=C[a+40>>3];C[a+48>>3]=c;f=C[a+64>>3];d=C[a+56>>3];C[a+64>>3]=d;C[a+40>>3]=b;b=e*C[a+16>>3]+(C[a>>3]*b+c*C[a+8>>3])-d*C[a+24>>3]-f*C[a+32>>3];C[a+56>>3]=b;return b}function IB(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:wU(a,b);return;default:break a}}d=fb-32|0;fb=d;x[d+28>>2]=c;w[d+26>>1]=0;x[d+12>>2]=2;iz(d+16|0,a,d+26|0,x[Gb(d+28|0,d+12|0)>>2]);dj(b,z[d+26>>1]);fb=d+32|0}function sq(a,b){a=yc(a,b,88);x[a+88>>2]=x[b+88>>2];yc(a+92|0,b+92|0,576);x[a+668>>2]=x[b+668>>2];yc(a+672|0,b+672|0,52);YA(a+724|0,b+724|0);YA(a+732|0,b+732|0);YA(a+740|0,b+740|0);yc(a+748|0,b+748|0,123);return a}function eo(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return E(b?-1/a:a)}function SU(a){var b=0;b=w[a+784>>1];if(b){x[a+692>>2]=(b&32767)-1;if((b|0)<0){x[a+88>>2]=x[a+88>>2]|256}w[a+784>>1]=0}b=y[a+795|0];if(b){v[a+795|0]=0;v[a+838|0]=b-1}b=y[a+796|0];if(b){v[a+796|0]=0;v[a+837|0]=b-1}}function nra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=Bf(a,c);Yd(e,x[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}fZ(x[a+36>>2],b,d,0);f=c}cf(a,f);fb=e+16|0}function xT(a){var b=0,c=0,d=0,e=0;c=fb-16|0;fb=c;d=zb(c+12|0,a);a=x[d>>2];if(x[a>>2]){e=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(e|0)){b=b-7|0;continue}break}x[a+4>>2]=e;a=x[d>>2];b=x[a>>2];uB(a);Db(b)}fb=c+16|0}function Aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Rg(a)>>>0<b>>>0){if(Hh(1073741823)>>>0<b>>>0){break a}d=Ab(a);e=a;a=hg(c+12|0,b,oc(x[a>>2],x[a+4>>2]),d);Id(e,a);gg(a)}fb=c+32|0;return}cd();p()}function zD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;h_(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){i_(b)}return a}function pY(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;rY(c+8|0,b);d=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){qY(b)}return a}function ooa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(el(a)>>>0<b>>>0){if(Hh(357913941)>>>0<b>>>0){break a}d=Ab(a);e=a;a=um(c+12|0,b,Qd(x[a>>2],x[a+4>>2]),d);jW(e,a);iW(a)}fb=c+32|0;return}cd();p()}function mu(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Ok(c)){Ke(a,c);break a}ng(d+8|0,Ah(c)+1|0);e=x[d+8>>2];vd(a,e);nf(a,x[d+12>>2]);Vd(a,c);a=e}ed(yg(a,b,c)+c|0,0);fb=d+16|0;return}of();p()}function kY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Bn(a)>>>0<b>>>0){if(Hh(2147483647)>>>0<b>>>0){break a}d=Ab(a);e=a;a=hk(c+12|0,b,Xc(x[a>>2],x[a+4>>2]),d);Id(e,a);fj(a)}fb=c+32|0;return}cd();p()}function Xk(a){vc(a+16|0,x[a>>2]);vc(a+8|0,x[a>>2]);if(A[a+12>>2]>=A[a+16>>2]){x[a+12>>2]=0;x[a+16>>2]=0;w[a+34>>1]=z[a+34>>1]&65511}if(A[a+4>>2]>=A[a+8>>2]){x[a+4>>2]=0;x[a+8>>2]=0;w[a+34>>1]=z[a+34>>1]&65529}}function Sm(a,b){var c=E(0),d=0,e=0;c=E(1);d=w[a+28>>1];a:{if((d|0)>(b|0)){break a}e=x[a+4>>2];if((oc(e,x[a+8>>2])+d|0)-1<<16>>16<(b|0)){break a}c=B[wb(e,b-d|0)>>2];c=c<=E(10000000036274937e-31)?E(1):c}return c}function Qka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Ln(a)>>>0<b>>>0){if(Hh(536870911)>>>0<b>>>0){break a}d=Ab(a);e=a;a=Vr(c+12|0,b,gh(x[a>>2],x[a+4>>2]),d);Id(e,a);Ur(a)}fb=c+32|0;return}cd();p()}function Iia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;c=Bf(a,c);Yd(e,x[a+36>>2]);a:{if(!c){Pc(e,a+32|0,5);f=0;if(Hb(x[x[e>>2]>>2],x[e+4>>2])){break a}}KQ(d,x[a+36>>2],b);f=c}cf(a,f);fb=e+16|0}function GF(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;if(c>>>0<2147483632){a:{if(Ok(c)){Ke(a,c);break a}ng(d+8|0,Ah(c)+1|0);e=x[d+8>>2];vd(a,e);nf(a,x[d+12>>2]);Vd(a,c);a=e}ed(Tg(a,b,c)+c|0,0);fb=d+16|0;return}of();p()}function Fka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(uB(a)>>>0<b>>>0){if(Hh(613566756)>>>0<b>>>0){break a}d=Ab(a);e=a;a=wT(c+12|0,b,tB(x[a>>2],x[a+4>>2]),d);vT(e,a);uT(a)}fb=c+32|0;return}cd();p()}function Cja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(el(a)>>>0<b>>>0){if(Hh(357913941)>>>0<b>>>0){break a}d=Ab(a);e=a;a=um(c+12|0,b,Qd(x[a>>2],x[a+4>>2]),d);ox(e,a);gs(a)}fb=c+32|0;return}cd();p()}function yA(a,b){var c=0,d=0;c=x[b+4>>2];x[a+24648>>2]=x[b>>2];x[a+24652>>2]=c;d=x[b+20>>2];c=a+24664|0;x[c>>2]=x[b+16>>2];x[c+4>>2]=d;d=x[b+12>>2];c=a+24656|0;x[c>>2]=x[b+8>>2];x[c+4>>2]=d;BR(a+24648|0);HR(a)}function Uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=Aj(a);if(d){e=x[b+4>>2];b=x[b>>2];x[c+8>>2]=b;x[c+12>>2]=e;a=x[x[d>>2]+72>>2];x[c>>2]=b;x[c+4>>2]=e;a=ib[a|0](d,c)|0}else{a=1}fb=c+16|0;return a|0}function OK(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a>>2];a:{if(!c){break a}d=x[c+24>>2];b:{if((d|0)==x[c+28>>2]){b=ib[x[x[c>>2]+52>>2]](c,b)|0;break b}x[c+24>>2]=d+4;x[d>>2]=b}if(!bo(b)){break a}x[a>>2]=0}return a|0}function Ada(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;QM(d,b);a=x[a+1298472>>2];x[31785]=0;S(389,a|0,1,d|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(c+4|0);fb=c+16|0;return}a=N()|0;tb(c+4|0);Q(a|0);p()}function mJ(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Sp(d+24|0,a,b);Fk(d+16|0,x[d+24>>2],x[d+28>>2],c);a=ID(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Td(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function lJ(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Sp(d+24|0,a,b);Fk(d+16|0,x[d+24>>2],x[d+28>>2],c);a=cA(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Td(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Qv(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Vl(d+24|0,a,b);Fk(d+16|0,x[d+24>>2],x[d+28>>2],c);a=ID(a,x[d+16>>2]);x[d+12>>2]=x[d+20>>2];Td(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0;return x[e+12>>2]}function Gx(a,b,c){var d=0;d=x[a+16>>2];if(!d){x[a+36>>2]=1;x[a+24>>2]=c;x[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(x[a+24>>2]!=2){break a}x[a+24>>2]=c;return}v[a+54|0]=1;x[a+24>>2]=2;x[a+36>>2]=x[a+36>>2]+1}}function vA(a,b,c){var d=0,e=0;d=x[b+656>>2];if(!d){return 0}d=yw(d,c);a=a+1074312|0;if(!Pb(a,31)){e=Pb(a,93)^1}a:{if(!(v[wR(b,c)+6|0]&1)){a=0;if(!(v[d+12|0]&1)|e){break a}}a=mc(x[d>>2],x[d+4>>2])^1}return a}function SV(a){a=a*4294967296;if(F(a)<0x8000000000000000){hb=F(a)>=1?~~(a>0?H(J(a*2.3283064365386963e-10),4294967295):K((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}hb=-2147483648;return 0}function CC(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=hG(a);a:while(1){if((a|0)!=(e|0)){f=qd(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((y[xb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function xS(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function nE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+16|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function hoa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;bn(a,b);b=vb(x[a>>2]);x[c+12>>2]=b;a=vb(x[a+4>>2]);while(1){if(Ib(b,a)){d=y[b|0]+(d&255)|0;v[b|0]=d;b=x[je(c+12|0)>>2];continue}else{fb=c+16|0}break}}function bV(a,b,c){var d=0;a:{b:{if(!((c|0)==255|(b|0)!=11)){c=c+1|0;b=11;break b}if((b|0)==16){c=c&15|-128;b=14;break b}if(b>>>0>16){break a}}Mf(a,b,c&255);d=1;if(y[a+3|0]!=13){break a}v[a+3|0]=46}return d}function $u(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-32|0;fb=d;Vl(d+24|0,a,b);Fk(d+16|0,x[d+24>>2],x[d+28>>2],c);a=x[d+16>>2];f=d,g=HD(c,x[d+20>>2]),x[f+12>>2]=g;Td(e+8|0,a,d+12|0);fb=d+32|0;fb=e+16|0}function nd(a,b,c,d){var e=0,f=0;e=fb-32|0;fb=e;f=x[b+12>>2];kf(e+16|0,c,d);c=x[x[b>>2]+28>>2];d=x[e+20>>2];x[e+8>>2]=x[e+16>>2];x[e+12>>2]=d;ib[c|0](e+24|0,b,f,e+8|0);kf(a,x[e+24>>2],x[e+28>>2]);fb=e+32|0}function Rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Nb(a);d=lg(a+12|0);v[a+32|0]=c;x[a+28>>2]=0;x[a+24>>2]=b;x[31785]=0;O(808,a|0,1);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;MT(d);QT(a);Q(b|0);p()}function Gd(a,b){var c=0,d=0;c=fb-16|0;fb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Mb(x[a>>2],x[a+8>>2],1)){break b}v[c+15|0]=0;ch(a,c+15|0);d=y[c+15|0]}fb=c+16|0;break a}_(11256,9099,324,14333);p()}return d}function Ai(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);e=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);f=x[d+4>>2];if((f|0)==(e|0)){Yb(a,x[d+12>>2])}fb=d+16|0;if((e|0)!=(f|0)){Tb(b,0,c)}}function zO(a,b){var c=0,d=0;c=-1;a:{if((b|0)<0){break a}d=x[a+24>>2];if(Lj(Wb(x[d+484360>>2],y[d+484376|0]))>>>0<=b>>>0){break a}a=x[a+24>>2];c=z[_b(x[Wb(x[a+484360>>2],y[a+484376|0])>>2],b)>>1]}return c}function tU(a){var b=0,c=0,d=0;b=z[a+20>>1];w[a+28>>1]=z[a+22>>1]<<1|(y[x[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=x[c>>2];if(d){Io(d);sU(x[c>>2])}b=b+1|0;continue}break}}function Wka(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],27)){a=0;while(1){if((a|0)!=27){Wh(a+b|0);a=a+1|0;continue}break}break a}gU(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Ata(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],64)){a=0;while(1){if((a|0)!=64){Wh(a+b|0);a=a+1|0;continue}break}break a}Zv(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function sga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=fb-16|0;fb=f;b=Fc(tua(sua(d,d>>31,b,0),hb,1e3,0),hb);x[a+16>>2]=0;x[a+12>>2]=b+c;LP(a,e);b=x[a+12>>2];x[f+12>>2]=0;OQ(a,b,f+12|0);fb=f+16|0}function rw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],32)){a=0;while(1){if((a|0)!=32){Wh(a+b|0);a=a+1|0;continue}break}break a}yE(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function Z2(a){a=a|0;var b=0;a:{b:{if(!a){break b}b=At(a);if(_H(b,-1)|y[b+13|0]){break b}b=x[b+8>>2];if(b){x[31785]=0;R(b|0,a|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}}jc(a)}return}T(0)|0;Rb();p()}function Rf(a,b,c,d,e){var f=0;f=fb-256|0;fb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Tb(f,b&255,c?d:256);if(!c){while(1){Ff(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}Ff(a,f,d)}fb=f+256|0}function yN(a,b){a=a|0;b=b|0;var c=0;a=Ij(a);x[a+4>>2]=0;x[a>>2]=47872;if(ib[x[x[b>>2]+8>>2]](b)|0){b=ib[x[x[b>>2]+8>>2]](b)|0}else{b=22485}c=Ed(gf(b)+1|0);x[a+4>>2]=c;if(c){yc(c,b,gf(b)+1|0)}return a|0}function vY(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;ED(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function qe(a,b){var c=0,d=0,e=0;b=b+7&-8;x[a+8>>2]=b+x[a+8>>2];d=x[a+80>>2];a:{if(d){c=b;b=x[a+88>>2];e=c+b|0;c=0;if((e|0)>x[a+92>>2]){break a}x[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Ed(b)}return c}function ko(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-32|0;fb=c;a:{if(Qo(a)>>>0<b>>>0){if(Hh(-1)>>>0<b>>>0){break a}d=Ab(a);e=a;a=gn(c+12|0,b,Sc(x[a>>2],x[a+4>>2]),d);Id(e,a);en(a)}fb=c+32|0;return}cd();p()}function d9(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=x[b+52>>2];if(c&16){d=x[b+48>>2];c=x[b+28>>2];if(d>>>0<c>>>0){x[b+48>>2]=c;d=c}pi(a,x[b+24>>2],d);break a}if(c&8){pi(a,x[b+12>>2],x[b+20>>2]);break a}Fb(a)}}function c_(a){var b=0;a:{if(Ob(a,3873,4)|y[a+68|0]!=13|(y[a+69|0]!=10|y[a+70|0]!=26)){break a}if(Ob(a+71|0,13799,4)|y[a+75|0]!=1|y[a+76|0]){break a}b=((y[a+116|0]|y[a+117|0]<<8)-1&65535)>>>0<9}return b}function Zh(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;al(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)|0}function Uia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;c=Bf(a,c);Yd(d,x[a+36>>2]);a:{if(!c){Pc(d,a+32|0,5);e=0;if(Hb(x[x[d>>2]>>2],x[d+4>>2])){break a}}jZ(x[a+36>>2],b,a);e=c}cf(a,e);fb=d+16|0}function Nca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a=x[a+4>>2];b=fg(d+4|0,b);x[31785]=0;V(1021,a|0,b|0,c|0,1);a=x[31785];x[31785]=0;if((a|0)!=1){tb(b);fb=d+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function Dna(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if((b|0)>=0){d=2147483647;a=Pu(a);if(a>>>0<=1073741822){x[c+12>>2]=a<<1;x[c+8>>2]=b+31&-32;d=x[_c(c+12|0,c+8|0)>>2]}fb=c+16|0;return d|0}cd();p()}function ni(a){var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;c=2;if(a>>>0>=2){x[b+12>>2]=a>>>1;x[b+8>>2]=a^-1;d=b,e=x[Gb(b+12|0,b+8|0)>>2]+a|0,x[d+12>>2]=e;x[b+8>>2]=-1;c=x[Gb(b+12|0,b+8|0)>>2]}fb=b+16|0;return c}function JJ(a,b,c,d,e,f){var g=0,h=0,i=0;g=fb-16|0;fb=g;v[g+15|0]=0;v[g+14|0]=f;v[g+13|0]=e;v[g+12|0]=37;if(f){og(g+13|0,g+14|0)}h=c,i=(fa(b|0,Sc(b,x[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,x[h>>2]=i;fb=g+16|0}function E$(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],8)){a=0;while(1){if((a|0)!=8){Wh(a+b|0);a=a+1|0;continue}break}break a}al(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function i2(a,b){a=a|0;b=b|0;var c=0;a=rt(a);x[a>>2]=93880;c=Fb(a+32|0);x[a+44>>2]=0;x[a+48>>2]=8;x[31785]=0;O(115,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;tb(c);$n(a);Q(b|0);p()}function Nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;b=x[b+4>>2];c=fg(d+4|0,c);x[31785]=0;S(1007,a|0,b|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){tb(c);fb=d+16|0;return}a=N()|0;tb(c);Q(a|0);p()}function Cha(a){a=a|0;var b=0,c=0,d=0;b=fb-32|0;fb=b;a:{if(Rg(a)>>>0<=12){if(Hh(1073741823)>>>0<=12){break a}c=Ab(a);d=a;a=hg(b+12|0,13,oc(x[a>>2],x[a+4>>2]),c);Id(d,a);gg(a)}fb=b+32|0;return}cd();p()}function tX(a,b){a=a|0;b=b|0;var c=0,d=0;d=x[a>>2];c=65535;a:{if(!Ge(d,x[a+4>>2],b)){break a}d=RD(a,x[sg(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=x[a>>2];a=sg(c,b);$Q(sg(c,d),a);c=d}return c|0}function sl(a){a=a|0;var b=0;x[a>>2]=95076;x[31785]=0;O(116,a|0,0);b=x[31785];x[31785]=0;if((b|0)!=1){Zb(a+28|0);Db(x[a+32>>2]);Db(x[a+36>>2]);Db(x[a+48>>2]);Db(x[a+60>>2]);return a|0}T(0)|0;Rb();p()}function dJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Hh(1073741823)>>>0<b>>>0){cd();p()}NI(c+8|0,Js(a),b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function Y8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;f=x[x[b>>2]+20>>2];e=x[c+12>>2];x[d+8>>2]=x[c+8>>2];x[d+12>>2]=e;e=x[c+4>>2];x[d>>2]=x[c>>2];x[d+4>>2]=e;ib[f|0](a,b,d,8);fb=d+16|0}function WR(a,b,c){var d=0,e=0;d=Lc(a);e=Bb(x[a+4>>2],y[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Jb(a);Tg(d+e|0,b,c);b=c+e|0;jg(a,b);ed(b+d|0,0);return a}Dq(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a}function o2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Bb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){Pl();p()}b=Jb(b);x[e+8>>2]=d-c;GF(a,b+c|0,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function jx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;d=Bb(x[b+4>>2],y[b+11|0]);if(d>>>0<c>>>0){Pl();p()}b=Jb(b);x[e+8>>2]=d-c;mu(a,b+c|0,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function L$(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],512)){a=0;while(1){if((a|0)!=128){vn((a<<2)+b|0);a=a+1|0;continue}break}break a}fE(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function sw(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[a>>2],x[a+8>>2],256)){a=0;while(1){if((a|0)!=256){Wh(a+b|0);a=a+1|0;continue}break}break a}bc(c+8|0,b,256);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function is(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;if(b){e=Lc(a);d=Bb(x[a+4>>2],y[a+11|0]);f=d+b|0;if(e-d>>>0<b>>>0){Nm(a,e,f-e|0,d,d,0,0)}e=d;d=Jb(a);$l(e+d|0,b,c);jg(a,f);ed(d+f|0,0)}return a|0}function g_(a){var b=0,c=0,d=0;a:{if(Ob(a,22474,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|y[a+16|0]>3|y[a+17|0]>3){break a}d=a;a=a+19|0;if(y[d+18|0]<16){continue}break}}return b}function _d(a,b){var c=0,d=0,e=0;d=z[a+24>>1];if((d|0)!=(b&65535)){c=z[a+22>>1]-1&127;w[a+22>>1]=c;e=z[a+20>>1];if(e>>>0<=127){w[a+20>>1]=e+1}c=(c<<2)+a|0;w[c+26>>1]=b-d;w[c+28>>1]=0;w[a+24>>1]=b}}function XT(a,b,c,d,e,f){x[a+40>>2]=0;x[a+44>>2]=0;C[a+32>>3]=f;C[a+24>>3]=e;C[a+16>>3]=d;C[a+8>>3]=c;C[a>>3]=b;x[a+48>>2]=0;x[a+52>>2]=0;x[a+56>>2]=0;x[a+60>>2]=0;a=a- -64|0;x[a>>2]=0;x[a+4>>2]=0}function VT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=Tr(e+4|0,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){C[a>>3]=C[b>>3];a=a+8|0;b=b+8|0;continue}break}x[d+4>>2]=a;hc(d);fb=e+16|0}function HZ(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=th(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Vo(b,z[c>>1]|z[c+2>>1]<<16);b=b+4|0;x[a+4>>2]=b;continue}break}}function xj(a){var b=0;b=32767;a:{if(a>=E(32766.5)){break a}b=32768;if(a<=E(-32767.5)){break a}a=E(a+E(.5));b:{if(E(F(a))<E(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function eda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=fb-16|0;fb=d;e=x[a+4>>2];a=x[b+4>>2];b=x[b>>2];x[d+8>>2]=b;x[d+12>>2]=a;f=x[c>>2];c=x[c+4>>2];x[d>>2]=b;x[d+4>>2]=a;Ez(e,d,f,c,1);fb=d+16|0}function yW(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;h_(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){i_(b)}return a}function vG(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;sG(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){gx(b)}return a}function so(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=th(e+4|0,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){po(a,x[b>>2]);a=a+4|0;b=b+4|0;continue}break}x[d+4>>2]=a;hc(d);fb=e+16|0}function rja(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;a:{if(!kk(a,b+8|0)){break a}c=0;if(!iR(x[b+8>>2],x[b+12>>2])){break a}c=-1;if(!RE(a,b+4|0)){break a}c=hR(x[b+4>>2])}fb=b+16|0;return c|0}function or(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a+12|0]=0;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0}function kk(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;al(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){bl(b)}return a}function gX(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;bX(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){cX(b)}return a}function f$(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Yv(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){WD(b)}return a}function Vpa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Hh(1073741823)>>>0<b>>>0){cd();p()}tF(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function SO(a,b){var c=E(0),d=E(0);if(!((b|0)<0|z[a+480188>>1]<=b>>>0)){a=D(b,872)+a|0;c=E(E(y[a+1075834|0])*E(.0078125));d=E(c*c);c=E(E(y[a+1075835|0])*E(.0078125));c=E(M(E(d+E(c*c))))}return c}function ND(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;kr(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){G_(b)}return a}function MX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(!Gn(b,a)|!c){break a}lh(d+8|0,a);a=0;while(1){if(a>>>0>=4){break a}b=x[d+8>>2];og(xb(b,a),xb(b,a|1));a=a+2|0;continue}}fb=d+16|0}function MB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=vi(e+4|0,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){dk(a,z[b>>1]);a=a+2|0;b=b+2|0;continue}break}x[d+4>>2]=a;hc(d);fb=e+16|0}function KR(a){var b=0,c=0;a=a+906300|0;c=Dj(a);while(1){if((a|0)!=(c|0)){b=x[a>>2];a:{if(!b){break a}if(!(ib[x[x[b>>2]+120>>2]](b)|0)){break a}ib[x[x[b>>2]+100>>2]](b)}a=a+160|0;continue}break}}function JF(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Nr(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Pr(b)}return a}function DW(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;Vw(c+8|0,b);d=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);e=x[c+4>>2];if((e|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;a=(d|0)==(e|0);if(!a){Ww(b)}return a}function tC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Hh(2147483647)>>>0<b>>>0){cd();p()}Jw(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<1)|0,x[d>>2]=e;fb=c+16|0}function q0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Hh(214748364)>>>0<b>>>0){cd();p()}BE(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+D(x[c+12>>2],20)|0,x[d>>2]=e;fb=c+16|0}function jia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);d=fb-16|0;fb=d;e=d,f=E(E(ib[x[x[a>>2]+48>>2]](a,b))+c),B[e+12>>2]=f;pT(d+12|0,E(0),E(1));ib[x[x[a>>2]+44>>2]](a,b,B[d+12>>2]);fb=d+16|0}function jL(a){var b=0,c=0,d=0;d=x[a>>2];while(1){c=v[d|0];if(Kh(c)){d=d+1|0;x[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=D(b,10);b=(c|0)>(b^2147483647)?-1:c+b|0}else{b=-1}continue}break}return b}
function iE(a,b,c){var d=0;a=(a&65535)>>>D(c,3)|0;d=a>>>2&1|y[b+12|0]&-8;v[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=y[b+13|0]|y[b+14|0]<<8;v[b+15|0]=a;v[b+16|0]=a>>>8;v[b+12|0]=d|4}}function hm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Hh(1073741823)>>>0<b>>>0){cd();p()}Rj(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<2)|0,x[d>>2]=e;fb=c+16|0}function fv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=Sl(e+4|0,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){ul(a,y[b|0]);a=a+1|0;b=b+1|0;continue}break}x[d+4>>2]=a;hc(d);fb=e+16|0}function bR(a,b,c){var d=0,e=0,f=0,g=0;e=fb-16|0;fb=e;d=fb-16|0;fb=d;QY(d+8|0,a,b,c);a=Sq(a,x[d+8>>2]);f=d,g=Sq(c,x[d+12>>2]),x[f+4>>2]=g;Td(e+8|0,a,d+4|0);fb=d+16|0;fb=e+16|0;return x[e+12>>2]}function PD(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=1;x[c+8>>2]=a>>>4;b=Xb(128/(D(x[We(c+12|0,c+8|0)>>2],b)|0)|0,1,15);v[c+7|0]=1;v[c+6|0]=a&15;a=y[af(c+7|0,c+6|0)|0];fb=c+16|0;return a|b<<4&240}function Jka(a){a=a|0;var b=0,c=0,d=0,e=0;b=fb-16|0;fb=b;if(Hh(2147483647)>>>0<=2303){cd();p()}Jw(b+8|0,2304);c=x[b+8>>2];x[a+4>>2]=c;x[a>>2]=c;d=Ab(a),e=(x[b+12>>2]<<1)+c|0,x[d>>2]=e;fb=b+16|0}function E9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Hh(357913941)>>>0<b>>>0){cd();p()}EG(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+D(x[c+12>>2],12)|0,x[d>>2]=e;fb=c+16|0}function zS(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Tr(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{yS(b,x[c>>2],x[c+4>>2]);b=b+8|0;x[a+4>>2]=b;continue}break}}function jZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;kg(a,d+14|0);e=z[d+14>>1];QR(b,e);c=0;while(1){if((c|0)==(e|0)){DA(b);fb=d+16|0}else{Ik(a,wb(x[b>>2],c));c=c+1|0;continue}break}}function gZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Hh(715827882)>>>0<b>>>0){cd();p()}SY(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+D(x[c+12>>2],6)|0,x[d>>2]=e;fb=c+16|0}function WT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Hh(536870911)>>>0<b>>>0){cd();p()}_F(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<3)|0,x[d>>2]=e;fb=c+16|0}function TT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Hh(268435455)>>>0<b>>>0){cd();p()}wV(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+(x[c+12>>2]<<4)|0,x[d>>2]=e;fb=c+16|0}function Np(a,b,c){var d=0;d=fb-16|0;fb=d;if(y[b|0]){x[d+8>>2]=0;x[d+12>>2]=0;b=Zx(d+4|0,b,gf(b),d+8|0,c);if(b>>>0<=4294967293){x[a>>2]=x[d+4>>2]}a=b>>>0<4294967294}else{a=0}fb=d+16|0;return a}function LL(a,b){var c=0,d=0,e=0,f=E(0),g=E(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=B[e>>2];c=c+h|0;g=B[c>>2];B[e>>2]=f+g;B[c>>2]=f-g;d=d+1|0;continue}break}}function OM(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=Dc(1298480);x[31785]=0;c=R(1136,b|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){b=x[uf(a+12|0,c)>>2];fb=a+16|0;return b|0}a=N()|0;Db(b);Q(a|0);p()}function Lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=fb-16|0;fb=d;e=z[a+28>>1];w[d+12>>1]=e;f=d,g=(oc(x[a+4>>2],x[a+8>>2])+e|0)-1|0,w[f+14>>1]=g;a=QQ(a,b,c,d+12|0);fb=d+16|0;return a|0}function BA(a,b){var c=0;a=$V(a,b);v[a+12|0]=y[b+12|0];c=y[b+13|0]|y[b+14|0]<<8|(y[b+15|0]<<16|y[b+16|0]<<24);v[a+13|0]=c;v[a+14|0]=c>>>8;v[a+15|0]=c>>>16;v[a+16|0]=c>>>24;v[a+17|0]=y[b+17|0]}function AI(a){a=a|0;var b=0,c=0,d=0;x[a>>2]=112216;d=a+8|0;while(1){b=x[a+8>>2];if(oc(b,x[a+12>>2])>>>0>c>>>0){b=x[wb(b,c)>>2];if(b){rm(b)}c=c+1|0;continue}break}tb(a+152|0);Yx(d);return a|0}function ke(a,b){var c=0;a:{c=gf(b);if((c|0)==(Bb(x[a+4>>2],y[a+11|0])|0)){x[31785]=0;a=U(373,a|0,b|0,c|0)|0;b=x[31785];x[31785]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}T(0)|0;Rb();p()}function kc(a,b,c,d,e){var f=0;f=fb-32|0;fb=f;kf(f+16|0,d,e);d=x[x[b>>2]+28>>2];e=x[f+20>>2];x[f+8>>2]=x[f+16>>2];x[f+12>>2]=e;ib[d|0](f+24|0,b,c,f+8|0);kf(a,x[f+24>>2],x[f+28>>2]);fb=f+32|0}function ik(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(2147483647);if(d>>>0<=b>>>0){a=Bn(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Tf(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(1073741823);if(d>>>0<=b>>>0){a=Rg(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Jj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Nl(a,b);if((d|0)==255){break a}yk(a,b);Bq(a,b,0,0);if(!c){break a}e=_b(a+26|0,d),f=65535,w[e>>1]=f;a=xb(a+62|0,b);v[a|0]=y[a|0]|128}}function yV(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(268435455);if(d>>>0<=b>>>0){a=Su(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function rD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=(Xp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),C[d+8>>3]=e;qT(c+8|0,127);a=Zl(C[c+8>>3]);fb=c+16|0;return a}function _C(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(715827882);if(d>>>0<=b>>>0){a=Tv(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function YF(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(119304647);if(d>>>0<=b>>>0){a=Tw(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Wr(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(536870911);if(d>>>0<=b>>>0){a=Ln(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Hq(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(134217727);if(d>>>0<=b>>>0){a=Po(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Dp(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(357913941);if(d>>>0<=b>>>0){a=el(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function CJ(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(178956970);if(d>>>0<=b>>>0){a=Ks(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function CD(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(214748364);if(d>>>0<=b>>>0){a=DE(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function ux(a,b,c){var d=0;d=fb-16|0;fb=d;bc(d+8|0,b,c);b=x[d+12>>2];kc(d,x[a>>2],x[a+8>>2],x[d+8>>2],x[d+12>>2]);c=x[d+4>>2];if((b|0)==(c|0)){Yb(a,x[d+12>>2])}fb=d+16|0;return(b|0)==(c|0)}function tp(a,b){var c=0,d=0;c=fb-16|0;fb=c;sp(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function tK(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:v[a|0]=c;return;case 1:w[a>>1]=c;return;case 2:case 3:x[a>>2]=c;return;case 5:break b;default:break a}}x[a>>2]=c;x[a+4>>2]=d}}function rB(a,b,c,d){var e=0,f=0,g=0;e=c-b|0;a:{if((e|0)<=9){g=e;e=D(32-G(d|1)|0,1233)>>>12|0;f=61;if((g|0)<(e+(A[(e<<2)+124016>>2]<=d>>>0)|0)){break a}}c=pB(b,d);f=0}x[a+4>>2]=f;x[a>>2]=c}function kX(a,b){var c=0,d=0;c=fb-16|0;fb=c;PC(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function hV(a){var b=0,c=0,d=0;c=y[a+64|0]|y[a+65|0]<<8;b=y[a+72|0]|y[a+73|0]<<8;a=y[a+70|0]|y[a+71|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<2|b>>>30;b=b<<2;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function hE(a,b){var c=0,d=0;c=fb-16|0;fb=c;ck(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function gu(a){var b=0;x[31785]=0;a=R(859,a|0)|0;b=x[31785];x[31785]=0;a:{if((b|0)==1){Y(T(0)|0)|0;x[31785]=0;X(26);b=x[31785];x[31785]=0;a=0;if((b|0)==1){break a}}return a}T(0)|0;Rb();p()}function gE(a,b){var c=0,d=0;c=fb-16|0;fb=c;ur(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function du(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;d=nr(e+4|0,a,d);a=x[d+4>>2];while(1){if((b|0)!=(c|0)){Dv(a,b);a=a+6|0;b=b+6|0;continue}break}x[d+4>>2]=a;hc(d);fb=e+16|0}function ch(a,b){var c=0,d=0;c=fb-16|0;fb=c;Gr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function a0(a){var b=0;b=x[a+72>>2];x[a+72>>2]=b-1|b;b=x[a>>2];if(b&8){x[a>>2]=b|32;return-1}x[a+4>>2]=0;x[a+8>>2]=0;b=x[a+44>>2];x[a+28>>2]=b;x[a+20>>2]=b;x[a+16>>2]=b+x[a+48>>2];return 0}function _z(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Ab(a);c=hg(d+12|0,Tf(a,oc(x[a>>2],x[a+4>>2])+1|0),oc(x[a>>2],x[a+4>>2]),c);po(x[c+8>>2],x[b>>2]);x[c+8>>2]=x[c+8>>2]+4;Id(a,c);gg(c);fb=d+32|0}function _u(a){var b=0;a:{if(Ob(a,13699,4)|y[a+4|0]){break a}if(Cb(y[a+6|0]|y[a+7|0]<<8)>>>0>1){break a}if(Cb(y[a+12|0]|y[a+13|0]<<8)){break a}b=(Cb(y[a+16|0]|y[a+17|0]<<8)|0)==20}return b}function _$(a,b){var c=0,d=0;c=fb-16|0;fb=c;Z$(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function YQ(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(82595524);if(d>>>0<=b>>>0){a=ju(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Xw(a,b){var c=0,d=0;c=fb-16|0;fb=c;Vw(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function W_(a,b){var c=0,d=0;c=fb-16|0;fb=c;Br(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function TF(a,b){var c=0,d=0;c=fb-16|0;fb=c;sG(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function NY(a,b){var c=0,d=0;c=fb-16|0;fb=c;LY(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function KF(a,b){var c=0,d=0;c=fb-16|0;fb=c;Nr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function J_(a,b){var c=0,d=0;c=fb-16|0;fb=c;Yv(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function JW(a){var b=0,c=0,d=0;c=y[a+32|0]|y[a+33|0]<<8;b=y[a+36|0]|y[a+37|0]<<8;a=y[a+34|0]|y[a+35|0]<<8;b=b+a|0;a=(a>>>0>b>>>0|d)<<1|b>>>31;b=b<<1;c=b+c|0;hb=b>>>0>c>>>0?a+1|0:a;return c}function Gn(a,b){var c=0,d=0;c=fb-16|0;fb=c;lh(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function GX(a,b){var c=0,d=0;c=fb-16|0;fb=c;rv(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function E_(a,b){var c=0,d=0;c=fb-16|0;fb=c;Zv(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function D_(a,b){var c=0,d=0;c=fb-16|0;fb=c;kr(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function AC(a,b){var c=0,d=0;c=fb-16|0;fb=c;FC(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){Yb(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function Ry(a,b,c,d,e,f,g,h,i){var j=0;j=fb-16|0;fb=j;Qg(j,b,c,d,e,f,g,h,i^-2147483648);d=x[j>>2];c=x[j+4>>2];b=x[j+12>>2];x[a+8>>2]=x[j+8>>2];x[a+12>>2]=b;x[a>>2]=d;x[a+4>>2]=c;fb=j+16|0}function PL(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Ab(a);c=gn(d+12|0,Ul(a,Sc(x[a>>2],x[a+4>>2])+1|0),Sc(x[a>>2],x[a+4>>2]),c);ul(x[c+8>>2],y[b|0]);x[c+8>>2]=x[c+8>>2]+1;Id(a,c);en(c);fb=d+32|0}function CU(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;v[a+16|0]=0;c=PB(b,x[a+12>>2]);x[31785]=0;O(788,a|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){Ol(c);fb=b+32|0;return}a=N()|0;Ol(c);Q(a|0);p()}function $f(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb+-64|0;fb=c;d=hA(c+12|0,a);x[31785]=0;S(202,a|0,b|0,d|0);a=x[31785];x[31785]=0;if((a|0)!=1){Dl(d);fb=c- -64|0;return}a=N()|0;Dl(d);Q(a|0);p()}function $U(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function li(a,b){var c=0,d=0;c=y[a|0];d=y[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=y[b+1|0];c=y[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function k8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=x[a+84>>2];d=c+256|0;f=Pt(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;yc(b,e,c);b=e+d|0;x[a+84>>2]=b;x[a+8>>2]=b;x[a+4>>2]=c+e;return c|0}function WY(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=b;x[e+8>>2]=d;c=Tp(a,c,x[Gb(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}fb=e+16|0;return c}function Ifa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;a=iP(f,b,c,d,0,0,0,0,e);fb=f+16|0;return a|0}function yk(a,b){var c=0,d=0,e=0;a:{c=Nl(a,b);if((c|0)==255){break a}if(Ak(x[a>>2])){break a}e=a+8|0;d=xb(e,c);v[d|0]=y[d|0]&223;d=Lu(c);c=xb(e,c);wh(x[a>>2],x[a+4>>2],b,d|176,y[c|0])}}function q7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-16|0;fb=g;x[g+8>>2]=624576549;x[g+12>>2]=1394948685;h=a;a=g+16|0;b=sk(h,b,c,d,e,f,g+8|0,a);fb=a;return b|0}function mo(a){var b=0,c=0;b=fb-16|0;fb=b;a:{if(!FM(y[a+20|0])){x[31785]=0;O(1143,b+15|0,a|0);c=x[31785];x[31785]=0;if((c|0)==1){break a}}v[a+20|0]=255;fb=b+16|0;return}T(0)|0;Rb();p()}function Jaa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=x[18447];x[c+8>>2]=x[18446];x[c+12>>2]=d;d=x[18445];x[c>>2]=x[18444];x[c+4>>2]=d;ib[x[bq(c,uk(y[b+20|0]))>>2]](a,b);fb=c+16|0}function Kra(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],12);a:{if(!d){v[c|0]=0;Rh(b,12,c);break a}kr(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Ft(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=x[a+4>>2];d=((b<<2)+(Dw(x[a>>2],1)^270549120)|0)+2019860093|0;x[a>>2]=d;b=b+D(Dw(d,16),5)|0;x[a+4>>2]=b;continue}break}return b}function FG(a,b){var c=0,d=0;d=fb-32|0;fb=d;c=Ab(a);c=um(d+12|0,Dp(a,Qd(x[a>>2],x[a+4>>2])+1|0),Qd(x[a>>2],x[a+4>>2]),c);hs(x[c+8>>2],b);x[c+8>>2]=x[c+8>>2]+12;ox(a,c);gs(c);fb=d+32|0}function yP(a){var b=0,c=0;if(!a){return 1}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(F(c)<2147483648){a=~~c;break a}a=-2147483648}b=zi(b-+(a|0))}else{b=0}return b}function jp(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=vi(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{dk(b,z[c>>1]);b=b+2|0;x[a+4>>2]=b;continue}break}}function j7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Jb(a);return rk(g,h,c,d,e,f,b,b+(Bb(x[a+4>>2],y[a+11|0])<<2)|0)|0}function fA(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=th(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{wk(b,B[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function Ul(a,b){var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=b;d=b;b=Hh(-1);if(d>>>0<=b>>>0){a=Qo(a);if(a>>>0<b>>>1>>>0){x[c+8>>2]=a<<1;b=x[_c(c+8|0,c+12|0)>>2]}fb=c+16|0;return b}cd();p()}function Th(a,b){var c=0;b=Tc(b);c=x[a+8>>2];if(oc(c,x[a+12>>2])>>>0>b>>>0){a=x[wb(c,b)>>2]!=0}else{a=0}if(!a){a=Ij(ac(4));x[a>>2]=125696;da(a|0,125832,1193);p()}return x[wb(c,b)>>2]}function Il(a){var b=0;a=oi(a);b=2147483647;a:{if(a>=E(2147483648)){break a}b=-2147483648;if(a<=E(-2147483648)){break a}b=~~a;if(E(F(a))<E(2147483648)){break a}b=-2147483648}return b}function HE(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=th(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{po(b,x[c>>2]);b=b+4|0;x[a+4>>2]=b;continue}break}}function vP(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=fb-16|0;fb=f;x[f+8>>2]=x[a+8>>2];g=x[a+4>>2];x[f>>2]=x[a>>2];x[f+4>>2]=g;c=uP(f,b,c,d,e,0,0,0,0);fb=f+16|0;return+c}function qp(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=Sl(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{ul(b,y[c|0]);b=b+1|0;x[a+4>>2]=b;continue}break}}function Pra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;IY(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<2);if(c){HY(d+8|0,x[b>>2],x[b+4>>2]);md(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function Ona(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){v[c|0]=0;r_(b,4,c);break a}lh(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function Ir(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if((b|0)<0){cd();p()}tF(c+8|0,(b-1>>>5|0)+1|0);b=x[c+8>>2];x[a+4>>2]=0;x[a>>2]=b;d=Ab(a),e=x[c+12>>2],x[d>>2]=e;fb=c+16|0}function Gm(a,b){x[a+28>>2]=0;w[a+24>>1]=65535;x[a+16>>2]=0;x[a+20>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;v[a|0]=0;x[a+32>>2]=11;x[a+36>>2]=b;Nb(a+40|0);Nb(a+52|0);Tb(a- -64|0,0,48);return a}function zB(a){var b=0,c=0;b=x[a>>2];c=x[b>>2];a:{if(!c){while(1){c=Qh(b);b=x[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=x[b+4>>2];if(c){continue}break}}x[a>>2]=b;return a}function y1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=ib[x[x[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function ou(a,b){var c=0;a=lS(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=x[b+12>>2];x[a+16>>2]=x[b+16>>2];c=x[b+28>>2];x[a+24>>2]=x[b+24>>2];x[a+28>>2]=c}function Yk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;if(Hh(-1)>>>0<b>>>0){cd();p()}ng(c+8|0,b);b=x[c+8>>2];x[a+4>>2]=b;x[a>>2]=b;d=Ab(a),e=b+x[c+12>>2]|0,x[d>>2]=e;fb=c+16|0}function I1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;cG(b,c);c=Mb(x[a>>2],x[a+8>>2],c<<3);if(c){bG(d+8|0,x[b>>2],x[b+4>>2]);md(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0;return c|0}function Gt(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;x[b+12>>2]=12;while(1){x[b+8>>2]=32;if(A[Gb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&4095}else{c=c+15|0;d=wo(a);continue}break}return a}function gT(a,b,c,d){a:{if((a|0)!=67108864){break a}a=D(d,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=D(a,872)+c|0;x[a+704>>2]=x[a+704>>2]&-129}}function Rna(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;_V(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<8)){c=x[b>>2];bc(d+8|0,c,Ph(c,x[b+4>>2])<<8);md(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function H1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(Sc(x[c>>2],x[c+4>>2])>>>0>=a>>>0){break a}Uj(c,a)}return!d|0}function xR(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;while(1){x[b+12>>2]=7;x[b+8>>2]=32;if(A[Gb(b+12|0,b+8|0)>>2]<=c>>>0){fb=b+16|0;a=d&127}else{c=c+15|0;d=wo(a);continue}break}return a}function l5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];if(a>>>0<=127){a=x[(a<<2)+112352>>2]}else{a=0}x[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function Qz(a){var b=0,c=0,d=0;C[a+4272>>3]=C[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=wo(d)|b<<15;continue}break}C[c+4280>>3]=+(b|0)*-4.656612873077393e-10}function Fh(a,b,c){a:{if(b>>>0<=c>>>0){a=ac(8);x[31785]=0;b=R(191,a|0)|0;c=x[31785];x[31785]=0;if((c|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}return y[a+c|0]}da(b|0,24664,165);p()}function Dv(a,b){var c=0;c=y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24);v[a|0]=c;v[a+1|0]=c>>>8;v[a+2|0]=c>>>16;v[a+3|0]=c>>>24;b=y[b+4|0]|y[b+5|0]<<8;v[a+4|0]=b;v[a+5|0]=b>>>8}function p7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=ib[x[x[a+8>>2]+20>>2]](a+8|0)|0;b=Jb(a);return sk(g,h,c,d,e,f,b,Bb(x[a+4>>2],y[a+11|0])+b|0)|0}function kga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=12){c=Ld(c,E(0));d=a+4208|0;if((b|0)==12){c=E(oi(E(c*E(3)))/E(3));b=12}e=wb(d,b),f=c,B[e>>2]=f;v[a+5046|0]=1}}function Tl(a,b){var c=0,d=0,e=0;x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function FT(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;while(1){if(c){f=Ll(z[c+16>>1],x[c+20>>2],a,b);d=f?d:c;c=x[(f?c+4|0:c)>>2];continue}break}a=x[zb(e+12|0,d)>>2];fb=e+16|0;return a}function Bra(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;x[c+24>>2]=0;x[c+28>>2]=0;x[c+16>>2]=0;x[c+20>>2]=0;x[c+8>>2]=0;x[c+12>>2]=0;x[c>>2]=0;x[c+4>>2]=0;iZ(b,c);hZ(a,c);fb=c+32|0}function zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=fb-16|0;fb=e;f=x[c>>2];if(f>>>0<Sc(a,b)>>>0){a=ol(e+4|0,xb(a,f),z[c+20>>1]);g=zy(d,a);Eb(a)}fb=e+16|0;return g|0}function x2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=fb-16|0;fb=e;a=x[a+4>>2];f=x[b+4>>2];b=x[b>>2];x[e>>2]=b;x[e+4>>2]=f;x[e+8>>2]=b;x[e+12>>2]=f;Fz(a,e,c,d,1);fb=e+16|0}function dD(a,b,c){var d=0,e=0;d=fb-16|0;fb=d;a=nr(d+4|0,a,b);b=x[a+4>>2];e=x[a+8>>2];while(1){if((b|0)==(e|0)){hc(a);fb=d+16|0}else{Dv(b,c);b=b+6|0;x[a+4>>2]=b;continue}break}}function Wo(a){var b=0,c=0;b=x[31540];c=a+7&-8;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>jb()<<16>>>0){if(!(eb(a|0)|0)){break a}}x[31540]=a;return b}x[31660]=48;return-1}function DS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Lc(a);d=Bb(x[a+4>>2],y[a+11|0]);e=d+1|0;if((c|0)==(d|0)){DB(a,c,e-c|0,c,c,0)}c=Jb(a);$l(c+d|0,1,b);jg(a,e);ed(c+e|0,0);return a|0}function CG(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function y2(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b>>2];b=x[b+4>>2];x[c>>2]=d;x[c+4>>2]=b;x[c+8>>2]=d;x[c+12>>2]=b;a=bP(a,c,1);fb=c+16|0;gb=hb;return a|0}function hq(a){var b=0;b=x[a+24>>2];x[31785]=0;W(860,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){Pd(a+68|0);mf(a+36|0);yl(a+32|0);sh(a+24|0);rh(a+4|0);return Uc(a)}T(0)|0;Rb();p()}function Ysa(a,b){a=a|0;b=b|0;if(!D_(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b+6|0]=0;v[b+7|0]=0;v[b+8|0]=0;v[b+9|0]=0;v[b+10|0]=0;v[b+11|0]=0}}function TX(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-24|0;ub(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];Ks(a);Db(b)}}function TM(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-16|0;Hk(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];Su(a);Db(b)}}function KH(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-12|0;Eb(c);continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];el(a);Db(b)}}function $9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;hz(a,b,c);c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+8|0,d+12|0)>>2]}fb=d+16|0;return c|0}function ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=b;while(1){if(Ib(b,c)){x[d+8>>2]=x[b>>2];kA(a,d+8|0);b=x[Pe(d+12|0)>>2];continue}else{fb=d+16|0}break}}function koa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;b=-1;a:{if(!kk(a,c+8|0)){break a}b=0;if(!aW(c+8|0)){break a}b=-1;if(!ih(a,4)){break a}b=BW(a)>>>31|0}fb=c+16|0;return b|0}function g3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;ib[x[x[a>>2]+12>>2]](d+8|0,a,b);a=x[d+8>>2];b=x[c>>2];a=mc(x[d+12>>2],x[c+4>>2])&(a|0)==(b|0);fb=d+16|0;return a|0}function dX(a){var b=0,c=0,d=0,e=0;d=y[a+4|0];e=y[a+92|0];c=y[a+94|0]|y[a+95|0]<<8;b=c+y[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=b+e|0;a=d;d=b<<2;b=a+d|0;b=b-96|0;hb=0;return b}function nc(a,b){a=a|0;b=b|0;var c=0;a=Ij(a);x[a+4>>2]=0;x[a>>2]=47872;c=Ed(Wc(x[b+4>>2],y[b+11|0])+1|0);x[a+4>>2]=c;if(c){yc(c,Jb(b),Wc(x[b+4>>2],y[b+11|0])+1|0)}return a|0}function K3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;while(1){if((b|0)!=(c|0)){f=Mx(x[b>>2],x[a+8>>2]);v[e|0]=(f|0)==-1?d:f;e=e+1|0;b=b+4|0;continue}break}return c|0}function v_(a){var b=0;a:{if(Ob(a,16924,4)){break a}if($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Cb(y[a+8|0]|y[a+9|0]<<8)}return b}function jw(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;Uj(b,c);if(Mb(x[a>>2],x[a+8>>2],c)){c=x[b>>2];bc(d+8|0,c,Sc(c,x[b+4>>2]));md(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function ev(a,b){a:{b:{if((b|0)!=31){if((b|0)!=15){break b}b=0;if(!Ob(a,14248,4)){break b}break a}b=0;if(Ob(a,15542,4)){break a}}b=Cb(y[a+4|0]|y[a+5|0]<<8)>>>0>177}return b}function eX(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Sl(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{FW(b);b=b+1|0;x[a+4>>2]=b;continue}break}}function _ba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;e=cP(a,c,1);fb=c+16|0;return+e}function WC(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=th(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{vn(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function Sja(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Dc(1);x[31785]=0;X(60);c=x[31785];x[31785]=0;if((c|0)!=1){b=x[uf(a+12|0,b)>>2];fb=a+16|0;return b|0}a=N()|0;Db(b);Q(a|0);p()}function Ou(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=th(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{eV(b);b=b+4|0;x[a+4>>2]=b;continue}break}}function OX(a,b){var c=0,d=0;c=fb-16|0;fb=c;rv(c+8|0,b);b=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function ME(a,b){var c=0,d=0;c=fb-16|0;fb=c;lh(c+8|0,b);b=x[c+12>>2];nd(c,a,x[c+8>>2],x[c+12>>2]);d=x[c+4>>2];if((b|0)==(d|0)){fd(a,x[c+12>>2])}fb=c+16|0;return(b|0)==(d|0)}function Lg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Fh(x[d>>2],x[d+4>>2],a);return((Fh(x[d>>2],x[d+4>>2],a+1|0)<<8|e<<16|Fh(x[d>>2],x[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function AE(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=vi(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{Kw(b);b=b+2|0;x[a+4>>2]=b;continue}break}}function ki(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;v[c+31|0]=0;yj(c+8|0,c+31|0);Im(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];v[b|0]=y[c+31|0];fb=c+32|0;return(a|0)==1|0}function j5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=x[c>>2];if(!(a>>>0>127|!(x[(a<<2)+112352>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function zca(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;a=x[a+4>>2];d=x[b+4>>2];b=x[b>>2];x[c>>2]=b;x[c+4>>2]=d;x[c+8>>2]=b;x[c+12>>2]=d;a=dP(a,c,1);fb=c+16|0;return a|0}function wta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;al(c+8|0,b);b=x[c+12>>2];kc(c,x[a>>2],x[a+8>>2],x[c+8>>2],x[c+12>>2]);if((b|0)==x[c+4>>2]){Yb(a,x[c+12>>2])}fb=c+16|0}function qf(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;x[d+8>>2]=c;x[d+4>>2]=31;e=d,f=w$(b,c),x[e+12>>2]=f;c=b;b=aE(d+4|0);Qi(c,c+b|0,a);e=xb(a,b),f=0,v[e|0]=f;y$(a);fb=d+16|0}function cF(a,b,c){var d=0;d=fb-16|0;fb=d;a=rp(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){dk(b,z[c>>1]);b=x[a>>2]+2|0;x[a>>2]=b;continue}break}ee(a);fb=d+16|0}function MG(a,b){var c=0,d=0,e=0;c=x[a>>2];if(x[c>>2]){e=x[c>>2];d=x[c+4>>2];while(1){if((d|0)!=(e|0)){d=d-b|0;continue}break}x[c+4>>2]=e;a=x[a>>2];b=x[a>>2];Ab(a);Db(b)}}function z1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=ib[x[x[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function qsa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;a:{if(a){ib[x[x[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}TR(d,9173,10901,171,42);rG(d,b,c)}fb=d+16|0}function pka(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],16);a:{if(!d){zE(b);break a}Br(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function k5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=x[c>>2];if(a>>>0>127|!(x[(a<<2)+112352>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function PY(a,b,c){var d=0;d=fb-16|0;fb=d;a=gC(d+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){ul(b,y[c|0]);b=x[a>>2]+1|0;x[a>>2]=b;continue}break}ee(a);fb=d+16|0}function LV(a){var b=0,c=0,d=0;b=x[a>>2];if(x[b>>2]){d=x[b>>2];c=x[b+4>>2];while(1){if((c|0)!=(d|0)){c=c-36|0;continue}break}x[b+4>>2]=d;a=x[a>>2];b=x[a>>2];Tw(a);Db(b)}}function Bx(a,b,c,d,e){var f=0;a:{f=gu(4332);if(f){x[31785]=0;ha(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break a}}return f}a=N()|0;Db(f);Q(a|0);p()}function kA(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=th(c+4|0,a,1);po(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0;return}_z(a,b)}function fV(a,b,c,d){a=gc(a,b,c);b=x[a+4>>2];a:{if((d|0)>=0){b=b+d|0;c=x[a>>2]+(b>>>3&536870908)|0;break a}b=b+d|0;c=x[a>>2]+((b-31|0)/32<<2)|0}x[a>>2]=c;x[a+4>>2]=b&31}function dka(a,b){a=a|0;b=b|0;var c=0;a=lg(a);c=Yi(x[b>>2]);b=Jf(b);x[31785]=0;S(854,a|0,c|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;LS(a);Q(b|0);p()}function _S(a,b,c){var d=0;d=c&15;if(d){v[b+824|0]=d}c=c&240;if(c){v[b+823|0]=c>>>4}x[b+88>>2]=x[b+88>>2]|131072;if(!(!d|!Pb(a+1074312|0,80))){v[b+824|0]=y[b+824|0]<<2}}function Dm(a){a=a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function lv(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=y[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Hz(a,d,c,1);fb=d+16|0}function Yq(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=Mb(x[a>>2],x[a+8>>2],4);a:{if(!d){YC(b);break a}lh(c+8|0,b);md(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0;return d|0}function ML(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=y[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function Hja(){var a=0,b=0,c=0;a=fb-16|0;fb=a;b=Cc(a+4|0,10275);x[31785]=0;W(64,b|0);c=x[31785];x[31785]=0;if((c|0)!=1){tb(b);fb=a+16|0;return}a=N()|0;tb(b);Q(a|0);p()}function D4(a,b,c){a=a|0;b=b|0;c=c|0;a=ZI(a,c);x[a>>2]=113676;b=Jb(b);x[31785]=0;O(1349,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;Ux(a);Q(b|0);p()}function Cca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;b=x[b+4>>2];e=x[c+4>>2];c=x[c>>2];x[d>>2]=c;x[d+4>>2]=e;x[d+8>>2]=c;x[d+12>>2]=e;$O(a,b,d,1);fb=d+16|0}function B4(a,b,c){a=a|0;b=b|0;c=c|0;a=YI(a,c);x[a>>2]=113716;b=Jb(b);x[31785]=0;O(1350,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;Vx(a);Q(b|0);p()}function xoa(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-48|0;fb=c;d=-1;a:{if(!yW(a,c)){break a}d=0;if(!xW(c)){break a}d=xe(a,b,wW(y[c+31|0],y[c+33|0]),hb)}fb=c+48|0;return d|0}function upa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;cG(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<3)){bG(d+8|0,x[b>>2],x[b+4>>2]);md(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function _ca(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=fb-16|0;fb=d;a=x[a+4>>2];e=x[b+4>>2];b=x[b>>2];x[d>>2]=b;x[d+4>>2]=e;x[d+8>>2]=b;x[d+12>>2]=e;Gz(a,d,c,1);fb=d+16|0}function Ob(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=y[a|0];e=y[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function HH(a,b,c){var d=0;a:{if(!a){a=ac(8);x[31785]=0;c=R(c|0,a|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){break a}b=N()|0;jc(a);Q(b|0);p()}return}da(c|0,b|0,1009);p()}function CM(a,b){var c=0,d=0;c=fb-16|0;fb=c;a=Sl(c+4|0,a,b);b=x[a+4>>2];d=x[a+8>>2];while(1){if((b|0)==(d|0)){hc(a);fb=c+16|0}else{b=b+1|0;x[a+4>>2]=b;continue}break}}function m1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+16>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Bb(x[b+4>>2],y[b+11|0]);e=a;a=Bb(x[c+4>>2],y[c+11|0]);b=Tg(Jb(yz(e,d+a|0)),Jb(b),d)+d|0;$l(Tg(b,Jb(c),a)+a|0,1,0)}function aaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;hz(a,b,c);a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function SC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;IY(b,c);if(Mb(x[a>>2],x[a+8>>2],c<<2)){HY(d+8|0,x[b>>2],x[b+4>>2]);md(d,a,x[d+8>>2],x[d+12>>2])}fb=d+16|0}function Ov(a,b,c){var d=0,e=0;e=fb-16|0;fb=e;d=fb-16|0;fb=d;WV(d+8|0,a,b,c);a=x[d+8>>2];x[d+4>>2]=x[d+12>>2];Td(e+8|0,a,d+4|0);fb=d+16|0;fb=e+16|0;return x[e+12>>2]}function AW(a,b){var c=0;c=fb-32|0;fb=c;jX(c+24|0,a);ue(c+16|0,b);a=x[c+20>>2];x[c+8>>2]=x[c+16>>2];x[c+12>>2]=a;a=Oc(x[c+24>>2],x[c+28>>2],c+8|0);fb=c+32|0;return a}function $h(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Or(b);d=Lc(a);if(c>>>0<=d>>>0){Cu(a,Ri(Jb(a),b,c),c);break a}e=a;a=Bb(x[a+4>>2],y[a+11|0]);Dq(e,d,c-d|0,a,0,a,c,b)}}function vsa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],12)){w[c>>1]=0;yZ(a,6,c);break a}kr(c+8|0,a);md(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function m9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;a=Sy(Pa(x[a+60>>2],b|0,c|0,d&255,e+8|0)|0);fb=e+16|0;hb=a?-1:x[e+12>>2];return(a?-1:x[e+8>>2])|0}function aZ(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;b=ec(b);a=zh(a,Dc(32),Kg(d+8|0,b));b=x[a>>2]+16|0;w[b>>1]=z[x[c>>2]>>1];Fb(b+4|0);e=ec(a),f=1,v[e+4|0]=f;fb=d+16|0}function XU(a){var b=0,c=0;a:{if(y[a|0]!=255){break a}b=y[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=y[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function GU(a,b,c,d){var e=0;e=fb-32|0;fb=e;Vl(e+24|0,b,c);Fk(e+16|0,x[e+24>>2],x[e+28>>2],d);b=FU(b,x[e+16>>2]-b>>1);x[e+12>>2]=x[e+20>>2];Td(a,b,e+12|0);fb=e+32|0}function A1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;c=0;a=x[a+8>>2];if(a>>>0>b>>>0){x[d+8>>2]=a-b;c=x[Gb(d+12|0,d+8|0)>>2]}fb=d+16|0;return c|0}function rT(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=dv(c+4|0,a,1);hs(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}FG(a,b)}function ppa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-80|0;fb=d;c=-1;a:{if(!f$(a,d+14|0)){break a}c=0;if(!qX(d+14|0)){break a}c=xe(a,b,pX(d+14|0),hb)}fb=d+80|0;return c|0}function jI(a,b,c){var d=0,e=0;d=kn(a);if(d>>>0>=c>>>0){e=b;b=c<<2;d=ai(Jb(a),e,b);jg(a,c);vd(b+d|0,0);return}e=a;a=Bb(x[a+4>>2],y[a+11|0]);aI(e,d,c-d|0,a,0,a,c,b)}function fpa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],8)){w[c>>1]=0;yZ(a,4,c);break a}al(c+8|0,a);md(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function YK(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>2];if((c|0)==x[a+28>>2]){return e=a,f=vf(b),d=x[x[a>>2]+52>>2],ib[d](e|0,f|0)|0}x[a+24>>2]=c+1;v[c|0]=b;return vf(b)}function Zoa(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],5)){v[c|0]=0;Rh(a,5,c);break a}ck(c+8|0,a);md(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function DV(a){x[a>>2]=0;x[a+4>>2]=0;x[a+88>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;aC(a+112|0,48e3);x[a+668>>2]=0;$B(a+724|0);$B(a+732|0);$B(a+740|0);Jg(a+788|0);return a}function wn(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],4)){v[c|0]=0;Rh(a,4,c);break a}lh(c+8|0,a);md(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function s_(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],6)){v[c|0]=0;Rh(a,6,c);break a}ED(c+8|0,a);md(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function n2(a,b){a=a|0;b=b|0;var c=0;if(A[a+4>>2]<A[Ab(a)>>2]){c=fb-16|0;fb=c;a=px(c+4|0,a);hs(x[a+4>>2],b);x[a+4>>2]=x[a+4>>2]+12;hc(a);fb=c+16|0;return}FG(a,b)}function kda(a,b){a=a|0;b=b|0;var c=0;a=ac(8);x[31785]=0;b=P(1060,a|0,12118)|0;c=x[31785];x[31785]=0;if((c|0)!=1){da(b|0,125600,165);p()}b=N()|0;jc(a);Q(b|0);p()}function aE(a){var b=0,c=0;a:{c=wb(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=_D(x[b>>2],x[a>>2])?b:a;continue}}return x[a>>2]}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;while(1){if((b|0)!=(c|0)){e=d,f=lI(v[b|0],x[a+8>>2]),x[e>>2]=f;d=d+4|0;b=b+1|0;continue}break}return c|0}function L2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;x[d+12>>2]=x[c>>2];a=ib[x[x[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){x[c>>2]=x[d+12>>2]}fb=d+16|0;return a|0}function Jja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Vi(b),x[d+12>>2]=e;x[c+8>>2]=0;d=a,e=x[bk(c+12|0,c+8|0,42528)>>2],x[d+36>>2]=e;kq(a);fb=c+16|0}function Gq(a){x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=128;x[a+4>>2]=256;x[a+32>>2]=363;x[a+36>>2]=952;x[a+16>>2]=48e3;x[a+20>>2]=2;x[a+24>>2]=128;x[a+28>>2]=0;return a}function Dc(a){a=a|0;var b=0;a=a>>>0<=1?1:a;a:{while(1){b=Ed(a);if(b){break a}b=x[125609];if(b){ib[b|0]();continue}break}da(Om(ac(4))|0,125240,34);p()}return b|0}function D8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=fb-16|0;fb=e;x[e>>2]=c;x[e+4>>2]=d;x[e+8>>2]=c;x[e+12>>2]=d;a=JK(a,e,b);x[a>>2]=94756;fb=e+16|0;return a|0}function tE(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(ch(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=Y$(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function tD(a){var b=0,c=0;b=fb-16|0;fb=b;w[b+14>>1]=a;Pf(b+14|0,4095);a=z[b+14>>1];c=sD(zi(+((a&255)>>>0)*.00390625)*32768);fb=b+16|0;return c>>>15-(a>>>8|0)|0}function f0(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(ch(a,c+11|0)){x[c+4>>2]=y[c+11|0];d=$$(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0;return d|0}function _q(a){var b=0,c=0,d=0,e=0;b=x[a>>2];c=x[b+4>>2];x[a>>2]=c;if(c){nn(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(Qh(a)?0:4)|0,e=b,x[d>>2]=e;x[b+4>>2]=a;nn(a,b)}function Yha(a){a=a|0;var b=0;b=fb-16|0;fb=b;pQ(b+8|0,a,0);if(x[b+12>>2]){a=x[a+20>>2];x[a+148>>2]=-1;oQ(a+4|0,vb(x[b+8>>2]),Tk(x[b+8>>2],x[b+12>>2]))}fb=b+16|0}function VR(a){var b=0,c=0,d=0;b=x[a+112>>2];if((b|0)>=11){b=378;while(1){if(b|c){UR(a);d=b;b=b-1|0;c=c-!d|0;continue}break}b=0}x[a+112>>2]=b+1;a=UR(a);return a}function RQ(a,b){var c=0;c=fb-16|0;fb=c;a=An(c+4|0,a+8|0,b);b=x[a>>2];while(1){if((b|0)!=x[a+4>>2]){eV(b);b=x[a>>2]+4|0;x[a>>2]=b;continue}break}ee(a);fb=c+16|0}function $q(a){var b=0,c=0,d=0,e=0;b=x[a+4>>2];c=x[b>>2];x[a+4>>2]=c;if(c){nn(c,a)}x[b+8>>2]=x[a+8>>2];d=x[a+8>>2]+(Qh(a)?0:4)|0,e=b,x[d>>2]=e;x[b>>2]=a;nn(a,b)}function xw(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],2)){v[c|0]=0;eF(a,c);break a}sp(c+8|0,a);md(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function wt(a){var b=0;a:{if((df(a)|0)!=79){break a}if((df(a)|0)!=103){break a}if((df(a)|0)!=103){break a}b=(df(a)|0)==83}if(!b){fc(a,30);return 0}return FL(a)}function nS(a,b){var c=0;c=fb-32|0;fb=c;a=te(c+8|0,a,b);a=nu(c+16|0,x[a>>2],x[a+4>>2]);a=te(c+24|0,x[a>>2],x[a+4>>2]);b=x[a>>2];fb=c+32|0;hb=x[a+4>>2];return b}function bM(a,b){var c=0,d=0;d=a+4|0;c=Sc(x[d>>2],x[a+8>>2]);a=x[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=ni(c);if(a>>>0<=b>>>0){break a}}b=cM(a,65536)}Uj(d,b)}}function ai(a,b,c){var d=0;if(a>>>0<b>>>0){return yc(a,b,c)}if(c){d=a+c|0;b=b+c|0;while(1){d=d-1|0;b=b-1|0;v[d|0]=y[b|0];c=c-1|0;if(c){continue}break}}return a}function _ka(a,b){a=a|0;b=b|0;a=rc(a);v[a+534|0]=0;x[a+4>>2]=0;x[31785]=0;O(794,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;Cj(a);Q(b|0);p()}function CH(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(!(v[a+1075081|0]&1)){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function Bia(a){a=a|0;var b=0;b=fb-16|0;fb=b;Pc(b+4|0,a+32|0,4);if(!Hb(x[x[b+4>>2]>>2],x[b+8>>2])){hy(a)}a=x[zb(b+12|0,vb(x[a+52>>2]))>>2];fb=b+16|0;return a|0}function Aia(a){a=a|0;var b=0;b=fb-16|0;fb=b;Pc(b+4|0,a+32|0,4);if(!Hb(x[x[b+4>>2]>>2],x[b+8>>2])){hy(a)}a=x[zb(b+12|0,vb(x[a+56>>2]))>>2];fb=b+16|0;return a|0}function mn(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(F(a)<2147483648){return~~a}b=-2147483648}return b}function RF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Nb(a+8|0);x[31785]=0;S(172,a|0,b|0,c|0);a=x[31785];x[31785]=0;if((a|0)!=1){break a}a=N()|0;dc(d);Q(a|0);p()}}function PM(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;c=x[b+20>>2];x[a+16>>2]=x[b+16>>2];x[a+20>>2]=c;c=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=c}function Ld(a,b){var c=0,d=0,e=E(0);c=fb-16|0;fb=c;x[c+8>>2]=1065353216;B[c+12>>2]=b;d=c,e=Wf(a),B[d+4>>2]=e;a=B[Bv(c+4|0,c+12|0,c+8|0)>>2];fb=c+16|0;return a}function Ik(a,b){var c=0;c=fb-32|0;fb=c;x[c+28>>2]=0;Tx(c+8|0,c+28|0);Im(c+20|0,a,x[c+8>>2],x[c+12>>2]);a=x[c+24>>2];Hm(b,x[c+28>>2]);fb=c+32|0;return(a|0)==4}function C_(a){var b=0;if(!(Ob(a,18668,8)|y[a+8|0]>1|((y[a+9|0]-1&255)>>>0>7|(y[a+10|0]|y[a+11|0]<<8)>>>0>4096))){b=(y[a+12|0]|y[a+13|0]<<8)>>>0<4097}return b}function xC(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=a;c=c&65535;while(1){if(!(!Ib(a,b)|(c|0)==z[a>>1])){a=x[Wd(d+12|0)>>2];continue}break}fb=d+16|0;return a}function v8(a,b){a=a|0;b=b|0;var c=0,d=0;b=lD(x[b>>2]);x[a+36>>2]=b;c=a,d=hh(b),x[c+44>>2]=d;c=a,d=Zn(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Yn(5583);p()}}function o8(a,b){a=a|0;b=b|0;var c=0,d=0;b=Dy(x[b>>2]);x[a+36>>2]=b;c=a,d=hh(b),x[c+44>>2]=d;c=a,d=Zn(x[a+36>>2]),v[c+53|0]=d;if(x[a+44>>2]>=9){Yn(5583);p()}}function dC(a){var b=0;a=De(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(F(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function d8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=x[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function aS(){var a=0,b=0,c=0,d=0;a=fb-16|0;fb=a;b=a+12|0;while(1){if(c>>>0<32){c=c+48|0;d=GA(127184);continue}break}x[b>>2]=d;wo(b);fb=a+16|0;return x[b>>2]}function SF(a){var b=0;if(!(Ob(a,15741,4)|(y[a+4|0]-16&255)>>>0<249|((y[a+5|0]-16&255)>>>0<249|(y[a+6|0]-16&255)>>>0<249))){b=(y[a+7|0]-9&255)>>>0<7}return b}function S5(a){a=a|0;if(y[500768]){return x[125191]}if(!y[501928]){v[501928]=1}sd(501904,121252);sd(501916,121264);v[500768]=1;x[125191]=501904;return 501904}function EP(a){a=a|0;var b=0;x[a+4240>>2]=0;x[a+4244>>2]=0;b=a+4264|0;x[b>>2]=0;x[b+4>>2]=0;b=a+4256|0;x[b>>2]=0;x[b+4>>2]=0;a=a+4248|0;x[a>>2]=0;x[a+4>>2]=0}function wQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=fb-16|0;fb=d;while(1){if((b|0)==(c|0)){fb=d+16|0}else{x[d+12>>2]=x[b>>2];kA(a,d+12|0);b=b+4|0;continue}break}}function g8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function Yb(a,b){a=a|0;b=b|0;var c=0;c=Mb(x[a>>2],x[a+8>>2],b);a:{if(c){b=x[a+8>>2]+b|0;break a}b=x[a>>2];b=ib[x[x[b>>2]+24>>2]](b)|0}x[a+8>>2]=b;return c|0}function Oe(a,b){var c=0;c=x[a>>2];x[a>>2]=b;a:{if(c){a=x[ec(a)>>2];x[31785]=0;W(a|0,c|0);a=x[31785];x[31785]=0;if((a|0)==1){break a}}return}T(0)|0;Rb();p()}function Jna(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-48|0;fb=d;c=-1;a:{if(!yW(a,d)){break a}c=0;if(!qV(d)){break a}c=xe(a,b,pV(y[d+47|0]),hb)}fb=d+48|0;return c|0}function DH(a,b,c){var d=E(0);a:{if((b|0)<0|z[a+480188>>1]<=b>>>0){break a}a=D(b,872)+a|0;if(v[a+1075081|0]&1){break a}d=E(E(y[a+c|0])*E(.0078125))}return d}function pu(a,b){var c=0,d=0,e=E(0);c=fb-16|0;fb=c;B[c+12>>2]=b;x[c+8>>2]=0;x[c+4>>2]=1065353216;d=a,e=B[Bv(c+12|0,c+8|0,c+4|0)>>2],B[d+144>>2]=e;fb=c+16|0}function mla(a,b){a=a|0;b=b|0;a=Nb(a);v[a+16|0]=0;x[a+12>>2]=b;x[31785]=0;W(787,a|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a|0}b=N()|0;OB(a);Q(b|0);p()}function E5(a){a=a|0;if(y[500760]){return x[125189]}if(!y[501896]){v[501896]=1}id(501872,13961);id(501884,13940);v[500760]=1;x[125189]=501872;return 501872}function wZ(a,b){var c=0;c=sua(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;hb=b>>>0<256?a+1|0:a;return b}function n1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function jj(a,b,c,d,e){a:{e=gu(e);if(e){x[31785]=0;ba(d|0,e|0,a|0,b|0,c|0)|0;a=x[31785];x[31785]=0;if((a|0)==1){break a}}return e}a=N()|0;Db(e);Q(a|0);p()}function bz(a,b){var c=0;while(1){c=(b|0)>=120?120:b;a=E(a*E(B[((c&3)<<2)+82480>>2]*E(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function ac(a){var b=0,c=0;x[31785]=0;b=YX(a+24|0);a=R(35,b|0)|0;c=x[31785];x[31785]=0;a:{if((c|0)!=1){if(!a){break a}return DR(Tb(a,0,b))}T(0)|0}Rb();p()}function Lq(a,b){var c=0,d=0;a:{if(!a){break a}c=sua(a,0,b,0);d=hb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Ed(c);if(!(!a|!(y[a-4|0]&3))){Tb(a,0,c)}return a}function Ci(a){var b=0,c=0;b=a*a;c=b*a;return E(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function C$(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=x[c>>2];v[a|0]=d;v[a+1|0]=d>>>8;v[a+2|0]=d>>>16;v[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function Bj(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;C[a>>3]=C[a>>3]-c;C[a+8>>3]=C[a+8>>3]-d}function h2(a,b,c){a=a|0;b=b|0;c=c|0;a=ks(a,x[b+28>>2]);GG(b+28|0,c);x[31785]=0;O(116,b|0,1);b=x[31785];x[31785]=0;if((b|0)==1){b=N()|0;Zb(a);Q(b|0);p()}}function aga(a){a=a|0;var b=0,c=E(0);v[a+4202|0]=1;b=a,c=oB(E(E(E(E(A[x[a+16>>2]+24620>>2])/E(3))+E(-80))/E(15920)),E(0),E(1)),B[b+4272>>2]=c;FP(a);EP(a)}function DX(a,b,c,d){var e=0;e=fb-32|0;fb=e;Vl(e+24|0,b,c);Fk(e+16|0,x[e+24>>2],x[e+28>>2],d);b=x[e+16>>2];x[e+12>>2]=x[e+20>>2];Td(a,b,e+12|0);fb=e+32|0}function B1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=x[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ho(a,b){var c=0,d=0;b=b+7&-8;d=x[a+80>>2];a:{if(d){b=x[a+92>>2]-b|0;c=0;if((b|0)<x[a+88>>2]){break a}x[a+92>>2]=b;return b+d|0}c=Ed(b)}return c}function Yg(a){var b=0,c=0;b=x[a>>2];c=x[b+4>>2];a:{if(!c){while(1){if(!Qh(b)){b=x[b+8>>2];continue}break}b=x[b+8>>2];break a}b=CZ(c)}x[a>>2]=b;return a}function pn(a,b){var c=0,d=0,e=0;Pv(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function c5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=x[b>>2];v[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function VM(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;x[d+24>>2]=0;x[d+12>>2]=4;iz(d+16|0,a,d+24|0,x[Gb(d+28|0,d+12|0)>>2]);Hm(b,x[d+24>>2]);fb=d+32|0}function $V(a,b){var c=0,d=0,e=0;ar(a);x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];c=Ab(b);d=Ab(a),e=x[c>>2],x[d>>2]=e;x[c>>2]=0;x[b>>2]=0;x[b+4>>2]=0;return a}function sO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;SL(i,b,c,d,e,f,g);Yc(a,h+20|0);Ym(i);fb=h+32|0}function qq(a,b,c){var d=0;a:{if(b&134218752){break a}if(!Gj(c)){break a}b=y[c+34|0];if((b+5&255)>>>0<6){break a}d=x[rd(a+906300|0,b-1|0)>>2]}return d}function go(a,b){x[a+20>>2]=0;x[a+24>>2]=b;x[a+12>>2]=0;x[a+4>>2]=4098;x[a+8>>2]=6;x[a+16>>2]=!b;Tb(a+32|0,0,40);bL(a+28|0);x[a+72>>2]=0;x[a+76>>2]=-1}function bd(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(A[a+8>>2]<b>>>0){d=x[a>>2];c=0;if(!(ib[x[x[d>>2]+32>>2]](d,0,b)|0)){break a}}x[a+8>>2]=b;c=1}return c|0}function ZY(a,b,c){var d=0;d=fb-32|0;fb=d;x[d+28>>2]=c;v[d+27|0]=0;x[d+12>>2]=1;iz(d+16|0,a,d+27|0,x[Gb(d+28|0,d+12|0)>>2]);v[b|0]=y[d+27|0];fb=d+32|0}function eJ(a){x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;w[a+20>>1]=0;x[a+16>>2]=-1;x[a+8>>2]=0;x[a+12>>2]=0;x[a>>2]=0}function aT(a,b,c){var d=0,e=0;x[b+56>>2]=0;d=b,e=zo(a,z[b+70>>1],x[b+48>>2],c,0),w[d+68>>1]=e;if(!(!(y[a+480180|0]&5)|x[b+60>>2]==-1)){x[b+60>>2]=0}}function Rw(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!Mb(x[b>>2],x[b+8>>2],3)){v[c|0]=0;Rh(a,3,c);break a}Qw(c+8|0,a);md(c,b,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function tP(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-16|0;fb=d;c=Ot(Dc(12));x[c+8>>2]=b;x[c+4>>2]=a;x[c>>2]=47772;a=x[uf(d+12|0,c)>>2];fb=d+16|0;return a|0}function t9(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=fg(a,b);x[31785]=0;P(73,a+12|0,c|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){break a}b=N()|0;tb(a);Q(b|0);p()}}function mh(a,b){var c=0;if(Cd(y[a+11|0])){c=x[a>>2];bj(x[a+8>>2]);Db(c)}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Ke(b,0);vd(b,0)}function lI(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=Jh(c+12|0,b);b=a&255;if(b>>>0>=128){b=(a|0)==-1?-1:x[x[124291]>>2]?-1:a&57343}Ih(d);fb=c+16|0;return b}function bpa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!gX(a,d)){break a}c=0;if(!fX(d)){break a}c=xe(a,b,dX(d),hb)}fb=d+96|0;return c|0}function W4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b|0];v[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function Lw(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){B[b>>2]=E(x[a>>2])*e;B[c>>2]=E(x[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function Eoa(a,b){a=a|0;b=b|0;var c=0,d=0;d=fb-96|0;fb=d;c=-1;a:{if(!gX(a,d)){break a}c=0;if(!KW(d)){break a}c=xe(a,b,JW(d),hb)}fb=d+96|0;return c|0}function BG(){var a=0,b=0,c=0;b=fb-16|0;fb=b;a=Cc(b+4|0,15187);if(Wc(x[a+4>>2],y[a+11|0])){c=(Og(a,13962)|0)!=-1}else{c=0}tb(a);fb=b+16|0;return c|0}function n$(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;x[a+8>>2]=b;Fd(b);continue}break}c=x[a>>2];if(c){Ac(a);Db(c)}}function mK(a,b,c){var d=0,e=0,f=0,g=0;d=qC(b);if(d>>>0<c>>>0){nK(a,b,d+1|0);return d}if(c){e=a;a=c-1|0;f=nK(e,b,a)+(a<<2)|0,g=0,x[f>>2]=g}return d}function jS(a,b){var c=0,d=0;c=fb-16|0;fb=c;b=te(c+8|0,sua(b,b>>31,500654080,20),hb);d=x[b>>2];b=x[b+4>>2];fb=c+16|0;x[a>>2]=d;x[a+4>>2]=b;return a}function gs(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;Eb(b);continue}break}c=x[a>>2];if(c){fs(a);Db(c)}}function WW(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;x[a+8>>2]=b;iv(b);continue}break}c=x[a>>2];if(c){Ac(a);Db(c)}}function WQ(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;x[a+8>>2]=b;Dl(b);continue}break}c=x[a>>2];if(c){Ac(a);Db(c)}}function V2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(kh(a,x[b+8>>2],f)){Ix(b,c,d,e);return}a=x[a+8>>2];ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)}function Uw(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;x[a+8>>2]=b;Rr(b);continue}break}c=x[a>>2];if(c){Ac(a);Db(c)}}function Mv(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;x[a+8>>2]=b;ub(b);continue}break}c=x[a>>2];if(c){Ac(a);Db(c)}}function LB(a){var b=0,c=0;c=x[a+4>>2];while(1){b=x[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;Ol(b);continue}break}c=x[a>>2];if(c){fs(a);Db(c)}}function Fq(a,b,c){a:{if(!Pb(c+1074312|0,102)){break a}c=z[a+692>>1]+1|0;w[a+784>>1]=c;if(!(v[a+89|0]&1)){break a}w[a+784>>1]=c|32768}x[a+692>>2]=b}function CA(a){if(y[a+480224|0]==2){return+A[a+1074420>>2]/1e4}return+A[a+24620>>2]/(+A[a+1074404>>2]*+(D(x[a+1074408>>2],x[a+1074416>>2])>>>0))*60}function xga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0,f=E(0);if(b>>>0<=1){c=Ld(c,E(0));if((b|0)==1){d=1;c=oi(c)}e=wb(a+4208|0,d),f=c,B[e>>2]=f;MP(a)}}function os(a,b,c,d){var e=0;e=ac(8);x[31785]=0;a=P(d|0,e|0,a|0)|0;d=x[31785];x[31785]=0;if((d|0)!=1){da(a|0,c|0,b|0);p()}a=N()|0;jc(e);Q(a|0);p()}function lU(a){var b=0,c=0,d=0;d=y[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=y[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function f_(a,b){var c=0;c=sua(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+hb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;hb=b>>>0<11?a+1|0:a;return b}function cf(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!b){Pc(c+8|0,a+32|0,5);if(Hb(x[x[c+8>>2]>>2],x[c+12>>2])){break a}}x[a+28>>2]=x[a+28>>2]+1}fb=c+16|0}function TH(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Mia(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;w[c+30>>1]=b;b=c+30|0;sp(c+20|0,b);d=x[c+20>>2];sp(c+12|0,b);ol(a,d,x[c+16>>2]);fb=c+32|0}function G_(a){v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0;v[a+11|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function GB(a,b,c){var d=0,e=0,f=0;d=Nl(a,b);if((d|0)!=255){e=_b(a+26|0,d),f=c,w[e>>1]=f;a=a+62|0;e=xb(a,b),f=255,v[e|0]=f;e=xb(a,c),f=d,v[e|0]=f}}function C8(a,b){a=a|0;b=b|0;var c=0,d=0;c=x[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;ib[x[x[a+32>>2]+d>>2]](b,a,x[d+x[a+36>>2]>>2]);continue}break}}function xB(a){var b=0,c=0;b=fb-16|0;fb=b;x[b+12>>2]=a;c=b+12|0;a=1;while(1){if((a|0)>0){Yg(c);a=a-1|0;continue}break}fb=b+16|0;return x[b+12>>2]}function uE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0;v[a+7|0]=0;v[a+8|0]=0;v[a+9|0]=0;v[a+10|0]=0}function hQ(a,b){var c=0;c=x[b+4>>2];if(x[a>>2]==(b|0)){x[a>>2]=c}if(c){x[c+8>>2]=x[b+8>>2]}a=x[b+8>>2];if(a){x[a+4>>2]=c}x[b+4>>2]=0;x[b+8>>2]=0}function et(a){var b=0,c=0,d=0;if(!a){return 0}d=99200;while(1){b=d;c=x[b>>2];if(c){d=b+4|0;if((a|0)!=(c|0)){continue}}break}return((c?b:0)|0)!=0}function bla(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-32|0;fb=c;v[c+31|0]=b;b=c+31|0;Gr(c+20|0,b);d=x[c+20>>2];Gr(c+12|0,b);ol(a,d,x[c+16>>2]);fb=c+32|0}function YO(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=fb-32|0;fb=h;i=h+8|0;SL(i,b,c,d,e,f,g);Yc(a,i);Ym(i);fb=h+32|0}function UF(a){a=a|0;var b=0;a=Fb(a);x[31785]=0;R(171,a+12|0)|0;b=x[31785];x[31785]=0;if((b|0)!=1){rc(a+32|0);return a|0}b=N()|0;tb(a);Q(b|0);p()}function $i(a,b){var c=0;c=x[a>>2];if(Xc(c,x[a+4>>2])>>>0>b>>>0){a=x[a+24>>2];a=Ge(x[a+484344>>2],x[a+484348>>2],z[_b(c,b)>>1])}else{a=0}return a}function yz(a,b){var c=0,d=0;if(b>>>0<2147483632){if(Ok(b)){cx(a);Ke(a,b);return a}c=Ah(b)+1|0;d=Dc(c);nf(a,c);vd(a,d);Vd(a,b);return a}of();p()}function xP(a,b){var c=0;if(a>.999999){c=0}else{a=a*a;b=ff(31415.926535897932/b);c=Xi(32768/(1-a)*(1-(a*b+M((a+a)*(1-b)-a*a*(1-b*b)))))}return c}function aq(a,b){var c=0;a:{if(!ML(b)|(y[b+1|0]^y[a+1|0])>>>0>1){break a}b=y[b+2|0];a=y[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Sta(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(ch(a,c+11|0)){x[c+4>>2]=y[c+11|0];z$(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0}function LQ(a){var b=0;b=fb-16|0;fb=b;B[b+12>>2]=F(a);x[b+8>>2]=646978941;x[b+4>>2]=1259902592;a=B[Bv(b+12|0,b+8|0,b+4|0)>>2];fb=b+16|0;return a}function Cy(a){var b=0,c=0;b=fb-16|0;fb=b;c=-1;a:{if(Oy(a)){break a}if((ib[x[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=y[b+15|0]}fb=b+16|0;return c}function l0(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;x[c+12>>2]=-1;if(ch(a,c+11|0)){x[c+4>>2]=y[c+11|0];pE(a,b,x[Gb(c+4|0,c+12|0)>>2])}fb=c+16|0}function VS(a,b){v[a+840|0]=b;v[a+812|0]=b;v[a+811|0]=b;v[a+809|0]=b;v[a+807|0]=b;v[a+806|0]=b;v[a+833|0]=b;v[a+826|0]=b>>>4;v[a+827|0]=b<<2&60}function Mk(a,b,c,d){var e=0;e=D(b,c);a:{if(x[d+76>>2]<0){a=bE(a,e,d);break a}a=bE(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function Lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){zz(a,0,0,0,0,0,0,c,d);return}zz(a,x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2],x[b+24>>2],b,c,d)}function xpa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Mg(b);Mg(b);break a}a=eh(b);eh(b)}while(1){if(a){if(a&1){Yb(b,260)}a=a>>>1|0;continue}break}}function vm(a,b){var c=0,d=0;d=x[a+4>>2];c=x[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;x[a+8>>2]=c;continue}break}b=x[a>>2];if(b){Ac(a);Db(b)}}function uL(a,b,c,d,e,f){var g=0,h=0;g=x[a+32>>2];if(!y[a+23|0]){x[(c<<2)+g>>2]=b;return}h=g;g=d<<2;x[h+g>>2]=b;v[x[a+8>>2]+d|0]=e;x[f+g>>2]=c}function kg(a,b){a=a|0;b=b|0;var c=0;c=fb-32|0;fb=c;w[c+30>>1]=0;ok(c+8|0,c+30|0);Im(c+20|0,a,x[c+8>>2],x[c+12>>2]);dj(b,z[c+30>>1]);fb=c+32|0}function eY(a){var b=0;if(!(Ob(a,15174,3)|(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))-2147483647>>>0<2147484072)){b=y[a+3|0]<6}return b}function QY(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=c-b|0;c=D((f|0)/6|0,6);g=e,h=ai(d,b,f)+c|0,x[g+12>>2]=h;Td(a,b+c|0,e+12|0);fb=e+16|0}function NE(a,b){var c=0;a:{if(!(y[a+2|0]|y[a+3|0]<<8)|(!y[a|0]|!y[a+1|0])){break a}c=1;if(b>>>0<9){break a}c=(y[a+4|0]-1&255)>>>0<32}return c}function Jm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=gf(b);e=a;a=Bb(x[c+4>>2],y[c+11|0]);b=yg(Jb(yz(e,d+a|0)),b,d)+d|0;$l(yg(b,Jb(c),a)+a|0,1,0)}function GW(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}ad(a,8,1,0,10);return}b=16;if(e){break a}}b=8}ad(a,b,c&2|1,0,d^1)}function uV(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){fs(a);Db(b)}}function iW(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;x[a+8>>2]=b;continue}break}b=x[a>>2];if(b){fs(a);Db(b)}}function g$(a,b,c){var d=0;d=fb-16|0;fb=d;wn(d+12|0,b);x[d+8>>2]=y[d+12|0]|y[d+13|0]<<8|(y[d+14|0]<<16|y[d+15|0]<<24);Yo(a,d+8|0,c);fb=d+16|0}function Uf(a){a=a|0;var b=0;x[a>>2]=43016;x[x[a+20>>2]>>2]=0;b=x[a+16>>2];x[b+946300>>2]=x[b+946300>>2]-1;x[a+20>>2]=0;lQ(a+44|0);return a|0}function Gu(a,b){var c=0,d=0;d=pg(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!Ge(a,b,d&65535)){continue}}break}return c&65535}function En(a,b){var c=0;a=In(a);x[a>>2]=78928;c=x[b+8>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=c;v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function Bi(a){var b=0;a=a*a;b=a*a;return E(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function rO(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;UL(h,b,c,d,e,f);Yc(a,g+20|0);Ym(h);fb=g+32|0}function UD(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;w[c+14>>1]=1;d=c,e=dm(a,b),w[d+12>>1]=e;a=z[se(c+14|0,c+12|0)>>1];fb=c+16|0;return a-1&65535}function zw(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=1){c=kF(a,1);break a}c=eh(a);Yb(a,b-2|0)}return c}function yb(a,b){var c=0;if(Cd(y[a+11|0])){Db(x[a>>2])}c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];Ke(b,0);ed(b,0);return a}function mf(a){var b=0,c=0,d=0;d=fb-16|0;fb=d;b=zb(d+12|0,a);c=x[b>>2];if(x[c>>2]){_Y(c);b=x[b>>2];c=x[b>>2];Ks(b);Db(c)}fb=d+16|0;return a}function lp(a,b){var c=0;a:{if(!b){break a}if(!Mb(x[a>>2],x[a+8>>2],b)){break a}if(b>>>0<=3){c=lF(a,b);break a}c=Mg(a);Yb(a,b-4|0)}return c}function UZ(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=b,d=$b(a),x[c+12>>2]=d;x[b+8>>2]=236;a=x[_c(b+12|0,b+8|0)>>2];fb=b+16|0;hb=0;return a-216|0}function Le(a,b,c){v[a+11|0]=c;v[a+10|0]=b;v[a+12|0]=y[a+12|0]&251;w[a+8>>1]=65535;x[a>>2]=0;x[a+4>>2]=0;v[a+12|0]=y[a+12|0]&252|1;return a}function Lb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=fb-16|0;fb=d;if(b>>>0>=121){Cq(12231);p()}e=d+8|0;Kb(e,a,b);Df(e,c);fb=d+16|0;return a|0}function nO(a,b,c){var d=0,e=0;d=Lc(a);if(d>>>0>=c>>>0){Cu(a,Ri(Jb(a),b,c),c);return}e=a;a=Bb(x[a+4>>2],y[a+11|0]);Mp(e,d,c-d|0,a,0,a,c,b)}function n5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=fb-16|0;fb=a;x[a+12>>2]=e;x[a+8>>2]=d-c;b=Gb(a+12|0,a+8|0);fb=a+16|0;return x[b>>2]}function bL(a){var b=0,c=0;x[31785]=0;c=ca(1183)|0;b=x[31785];x[31785]=0;if((b|0)!=1){b=a;a=x[c>>2];x[b>>2]=a;cl(a);return}T(0)|0;Rb();p()}function XH(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=Fx(x[d>>2],c)}ib[x[x[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function Mx(a,b){var c=0;c=fb-16|0;fb=c;b=Jh(c+12|0,b);a=a>>>0>=128?(a&-128)!=57216?-1:x[x[124291]>>2]?-1:a&255:a;Ih(b);fb=c+16|0;return a}function Fl(a){var b=0,c=0,d=0;b=fb-16|0;fb=b;c=x[a+24>>2];d=x[a+40>>2];x[b+12>>2]=1;a=x[_c(a+20|0,b+12|0)>>2];fb=b+16|0;return D(a,c+d|0)}function z_(a){var b=0,c=0,d=0;c=fb-16|0;fb=c;b=c+13|0;Rw(b,a);a=y[xb(b,0)|0];d=y[xb(b,1)|0];b=y[xb(b,2)|0];fb=c+16|0;return a|d<<8|b<<16}function xO(a,b){var c=0,d=0;a:{if(!zt(b)){break a}c=x[a+484344>>2];if(!Ge(c,x[a+484348>>2],b&65535)){break a}d=x[Vb(c,b)+12>>2]}return d}function lC(a,b){var c=0,d=0;x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[a+8>>2]=x[b+8>>2];x[b>>2]=0;x[b+4>>2]=0;c=Ab(b),d=0,x[c>>2]=d;return a}function jC(a){a=50-(D(y[(a>>>4|0)+30144|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Fc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function gk(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Ub(d+15|0,d+14|0)|0]|(c?-128:0),v[e+21|0]=f;fb=d+16|0}function fk(a,b,c){var d=0,e=0,f=0;d=fb-16|0;fb=d;v[d+15|0]=b;v[d+14|0]=127;e=a,f=y[Ub(d+15|0,d+14|0)|0]|(c?-128:0),v[e+22|0]=f;fb=d+16|0}function dd(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-32768;x[b+4>>2]=32767;a=w[We(b+8|0,pd(b+12|0,b+4|0))>>1];fb=b+16|0;return a}function Xha(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=x[a+20>>2];le(b,x[c+4>>2],x[c+8>>2]);nQ(a,gc(b+8|0,x[b>>2],x[b+4>>2]),0);fb=b+16|0}function Bka(a){a=a|0;var b=0;b=x[a>>2];if(ib[x[x[b>>2]+32>>2]](b,0,32)|0){a=x[a>>2];a=ib[x[x[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function lH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=x[a>>2];if(d>>>0<=127){d=x[(d<<2)+c>>2]}x[a>>2]=d;a=a+4|0;continue}break}return b}function R3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=vy(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function P3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=wy(x[b>>2]),x[d>>2]=e;b=b+4|0;continue}break}return c|0}function rS(a,b,c,d){var e=0;e=a+1074376|0;cB(a,e,b,c,d);e=0-y[(D(b,872)+e|0)+1428|0]|0;if(d){c=0}else{c=qu(x[a+480180>>2])}to(a,b,e,c)}function k9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=x[b>>2]+7&-8;x[c>>2]=b+16;d=a,e=kx(x[b>>2],x[b+4>>2],x[b+8>>2],x[b+12>>2]),C[d>>3]=e}function fd(a,b){var c=0,d=0,e=0;c=ih(a,b);if(c){x[a+12>>2]=x[a+12>>2]+b;return c}d=a,e=ib[x[x[a>>2]+24>>2]](a)|0,x[d+12>>2]=e;return c}function WO(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=fb-32|0;fb=g;h=g+8|0;UL(h,b,c,d,e,f);Yc(a,h);Ym(h);fb=g+32|0}function RX(a){w[a+10>>1]=0;w[a+12>>1]=0;w[a+8>>1]=1084;x[a>>2]=0;x[a+4>>2]=40;v[a+13|0]=0;v[a+14|0]=0;v[a+15|0]=0;v[a+16|0]=0;return a}function IC(a){var b=0;b=Cb(y[a+26|0]|y[a+27|0]<<8);return((y[a+24|0]>15)+(y[a+25|0]>64)|0)+(Cb(y[a+22|0]|y[a+23|0]<<8)<<1>>>0<b>>>0)|0}function z3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=kK(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function nu(a,b,c){var d=0;d=fb-16|0;fb=d;b=te(d+8|0,sua(b,c,1e6,0),hb);c=x[b>>2];b=x[b+4>>2];fb=d+16|0;x[a>>2]=c;x[a+4>>2]=b;return a}function mua(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){un(b)}v[a|0]=1}return a|0}function lW(a){var b=0,c=0;c=fb-16|0;fb=c;b=zb(c+12|0,a);a=x[b>>2];if(x[a>>2]){fW(a,x[a>>2]);a=x[b>>2];b=x[a>>2];el(a);Db(b)}fb=c+16|0}function fka(a,b){a=a|0;b=b|0;a=XA(a);x[31785]=0;O(851,a|0,b|0);b=x[31785];x[31785]=0;if((b|0)==1){b=N()|0;tq(a);Q(b|0);p()}return a|0}function en(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;x[a+8>>2]=b;continue}break}a=x[a>>2];if(a){Db(a)}}function Ro(a){var b=0,c=0;c=fb-16|0;fb=c;b=zb(c+12|0,a);a=x[b>>2];if(x[a>>2]){xY(a,x[a>>2]);a=x[b>>2];b=x[a>>2];yY(a);Db(b)}fb=c+16|0}function Pha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!zd(c&255))){qQ(a,8,E(0))}a=Aj(a);if(a){ib[x[x[a>>2]+96>>2]](a,b,c,d,e)}}function Kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Qt(x[a+32>>2],b,c,d,2);if(a>>>0<=15){a=y[a+42432|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function Jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Qt(x[a+32>>2],b,c,d,3);if(a>>>0<=46){a=y[a+42384|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function B3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;while(1){if((b|0)!=(c|0)){d=b,e=lK(y[b|0]),v[d|0]=e;b=b+1|0;continue}break}return c|0}function dt(a){return a>>>0<=254?(a+1&127)>>>0>32:(a&65534)!=65534&a-65532>>>0<1048580|(a-57344>>>0<8185|a>>>0<8232|a-8234>>>0<47062)}function S8(a,b){a=a|0;b=b|0;x[a+4>>2]=b;v[a|0]=0;b=x[x[b>>2]-12>>2]+b|0;if(!x[b+16>>2]){b=x[b+72>>2];if(b){SK(b)}v[a|0]=1}return a|0}function Eca(a,b){a=a|0;b=b|0;var c=0;if((a|0)!=(b|0)){c=x[a+4>>2];if(c){Db(c);x[a+4>>2]=0}x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0}return a|0}function ti(a,b,c){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24;v[a+4|0]=c;v[a+5|0]=c>>>8;v[a+6|0]=c>>>16;v[a+7|0]=c>>>24}function kH(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a|0];if((d|0)>=0){d=x[(d<<2)+c>>2]}v[a|0]=d;a=a+1|0;continue}break}return b}function UX(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=-128;x[b+4>>2]=127;a=v[We(b+8|0,pd(b+12|0,b+4|0))|0];fb=b+16|0;return a}function Mga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0;if(b>>>0<=4){c=Ld(c,E(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=oi(c)}B[d>>2]=c;OP(a)}}function Eka(a,b){a=a|0;b=b|0;a=gE(a,b);if(!a){v[b+6|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0}return a|0}function st(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=x[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=x[c>>2];x[a>>2]=d<<b;x[a+4>>2]=c<<b|d>>>32-b}function sS(a,b,c,d){var e=0;e=a+1074376|0;dB(a,e,b,c,d);e=y[(D(b,872)+e|0)+1427|0];if(d){c=0}else{c=qu(x[a+480180>>2])}to(a,b,e,c)}function mi(a,b){var c=0,d=0;c=x[a>>2];d=x[a+4>>2];b=x[a+16>>2]+b|0;a=x[a+12>>2];b=(b|0)%(a|0)|0;return B[Nc(c,d,(b>>31&a)+b|0)>>2]}function Yf(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=121){Cq(12196);p()}d=c+8|0;Kb(d,a,b);Df(d,0);fb=c+16|0;return a|0}function Jy(a){a=a|0;var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+1;return vf(v[b|0])|0}function Aj(a){var b=0,c=0;b=km(x[x[a+20>>2]+28>>2]);if(!(b>>>0>249|y[a+4200|0]>=b>>>0)){c=x[rd(x[a+16>>2]+906300|0,b)>>2]}return c}function ut(a,b){var c=0,d=0;c=x[a+4>>2];a:{if(b>>>0<=31){d=x[a>>2];break a}b=b-32|0;d=c;c=0}x[a+4>>2]=c>>>b;x[a>>2]=c<<32-b|d>>>b}function jka(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;if(b>>>0>=250){Cq(12231);p()}d=c+8|0;Kb(d,a,b);Uo(d);fb=c+16|0;return a|0}function f9(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+1;a=vf(v[a|0])}else{a=-1}return a|0}function zY(a,b){var c=0;c=fb-16|0;fb=c;a=th(c+4|0,a,1);Vo(x[a+4>>2],z[b>>1]|z[b+2>>1]<<16);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0}function Zg(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=0;x[b+4>>2]=255;a=y[We(b+8|0,pd(b+12|0,b+4|0))|0];fb=b+16|0;return a}function Vy(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}_(14357,13279,1180,5754);p()}if((b|0)==255){return 0}a=b>>>0>10}return a}function mC(a,b){var c=0;c=fb-16|0;fb=c;a=gc(c+8|0,(b>>>3&536870908)+a|0,1<<b);a=Hb(x[x[a>>2]>>2],x[a+4>>2]);fb=c+16|0;return a}function he(a){var b=0;a=x[a+4>>2];if(a){if(rm(a)){a:{b=a+8|0;if(x[b>>2]){if((Yw(b)|0)!=-1){break a}}ib[x[x[a>>2]+16>>2]](a)}}}}function eH(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+8>>2]=a;x[d+12>>2]=b;x[d>>2]=c;x[d+4>>2]=0;a=Hr(d+8|0,d);fb=d+16|0;return x[a>>2]}function e5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){x[d>>2]=v[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function Zy(a,b,c){var d=0;d=x[a+32>>2];if(A[a+40>>2]<d+c>>>0){x[a+96>>2]=1;return 0}yc(b,d,c);x[a+32>>2]=x[a+32>>2]+c;return 1}function WN(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=Ot(Dc(8));x[c+4>>2]=a;x[c>>2]=48720;a=x[uf(b+12|0,c)>>2];fb=b+16|0;return a|0}function Vq(a,b){var c=0;c=Bb(x[a+4>>2],y[a+11|0]);if((c|0)==(Bb(x[b+4>>2],y[b+11|0])|0)){a=lx(Jb(a),Jb(b),c)}else{a=1}return!a}function U8(a){a=a|0;var b=0;if((ib[x[x[a>>2]+36>>2]](a)|0)!=-1){b=a;a=x[a+12>>2];x[b+12>>2]=a+4;a=x[a>>2]}else{a=-1}return a|0}function OJ(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Xs(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function OG(a,b,c,d){a=Nb(a);x[31785]=0;S(d|0,a|0,b|0,c|0);b=x[31785];x[31785]=0;if((b|0)!=1){return a}b=N()|0;sc(a);Q(b|0);p()}function NM(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=zM(Dc(8));x[c+4>>2]=a;x[c>>2]=73800;a=x[uf(b+12|0,c)>>2];fb=b+16|0;return a|0}function LJ(a,b,c,d,e,f){a=ib[x[x[a+8>>2]+4>>2]](a+8|0)|0;a=Ts(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){x[b>>2]=((a|0)/12|0)%12}}function AB(a,b){var c=0;c=x[a+484360>>2];b=b&255;if(Kj(c,x[a+484364>>2])>>>0<=b>>>0){return Wb(c,y[a+484376|0])}return Sj(c,b)}function $S(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(y[a+480180|0]&2){break a}}x[b+56>>2]=0;d=zo(a,z[b+70>>1],x[b+48>>2],c,0)}return d}function vU(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(b){Vd(b,a)}if(c){Vd(c,a)}if(d){Vd(d,a)}if(e){Vd(e,a)}}function gr(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function fe(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){x$(b);a=x[a>>2];b=x[a>>2];$D(a);Db(b)}fb=c+16|0}function fS(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Wv(b);a=x[a>>2];b=x[a>>2];L_(a);Db(b)}fb=c+16|0}function eW(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){kW(b);a=x[a>>2];b=x[a>>2];el(a);Db(b)}fb=c+16|0}function cv(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){vV(b);a=x[a>>2];b=x[a>>2];_B(a);Db(b)}fb=c+16|0}function Zt(a){var b=0;b=C[a+4248>>3]/+A[x[a+16>>2]+24620>>2];C[a+4264>>3]=b;if(y[a+4240|0]){C[a+4264>>3]=b*(C[a+4288>>3]/60)}}function Yt(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){Xz(b);a=x[a>>2];b=x[a>>2];Wz(a);Db(b)}fb=c+16|0}function YR(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){ku(b);a=x[a>>2];b=x[a>>2];ju(a);Db(b)}fb=c+16|0}function Y4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function Ui(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){IX(b);a=x[a>>2];b=x[a>>2];Po(a);Db(b)}fb=c+16|0}function RR(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){zp(b);a=x[a>>2];b=x[a>>2];Tw(a);Db(b)}fb=c+16|0}function QT(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){LT(b);a=x[a>>2];b=x[a>>2];el(a);Db(b)}fb=c+16|0}function QF(a,b){var c=0;c=x[b+4>>2];if(c){bc(a,c,x[b>>2]);return}c=x[b+8>>2];b=x[b+12>>2];if(!mc(c,b)){le(a,c,b);return}Jd(a)}function OB(a){var b=0,c=0;c=fb-16|0;fb=c;a=zb(c+12|0,a);b=x[a>>2];if(x[b>>2]){BU(b);a=x[a>>2];b=x[a>>2];Po(a);Db(b)}fb=c+16|0}function LG(a,b,c){a=oi(a);a:{if(a>=b){break a}c=0;if(a<=E(0)){break a}if(a<E(4294967296)&a>=E(0)){c=~~a>>>0;break a}}return c}function Fk(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=c-b|0;if((b|0)!=(c|0)){ai(d,b,f)}x[e+12>>2]=d+f;Td(a,b+f|0,e+12|0);fb=e+16|0}function zr(a,b){return Qq(y[b|0]|y[b+1|0]<<8|(y[b+2|0]<<16|y[b+3|0]<<24),y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24))?b:a}function xG(a){a=a|0;var b=0;a=Fb(a);x[31785]=0;O(133,a|0,13757);b=x[31785];x[31785]=0;if((b|0)==1){b=N()|0;tb(a);Q(b|0);p()}}function WV(a,b,c,d){var e=0,f=0,g=0,h=0;e=fb-16|0;fb=e;f=b;b=c-b|0;g=e,h=ai(d,f,b)+b|0,x[g+12>>2]=h;Td(a,c,e+12|0);fb=e+16|0}function S2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(kh(a,x[b+8>>2],0)){Gx(b,c,d);return}a=x[a+8>>2];ib[x[x[a>>2]+28>>2]](a,b,c,d)}function Lx(a,b){var c=0,d=0,e=0,f=0;c=gf(b);d=Dc(c+13|0);x[d+8>>2]=0;x[d+4>>2]=c;x[d>>2]=c;e=a,f=yc(Ac(d),b,c+1|0),x[e>>2]=f}function o_(a){var b=0;a:{if(Ob(a,3863,4)){break a}if(Ob(a+44|0,18660,3)){break a}b=(y[a+47|0]|y[a+48|0]<<8)>>>0>97}return b}function oT(a){gB(a);x[a>>2]=0;x[a+4>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;a=lg(a);lg(a+12|0);v[a+24|0]=1}function lY(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;if((dm(x[a>>2],x[a+4>>2])|0)!=65535){U$(a,c+14|0)}fb=c+16|0}function Wl(a,b){var c=0;a:{if(A[a+12>>2]<b>>>0){c=0;if(!(ib[x[x[a>>2]+32>>2]](a,0,b)|0)){break a}}x[a+12>>2]=b;c=1}return c}function Rc(a,b,c){var d=0;d=a;a=c&31;if((c&63)>>>0>=32){c=b>>31;a=b>>a}else{c=b>>a;a=((1<<a)-1&b)<<32-a|d>>>a}hb=c;return a}function PJ(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=Xs(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function MJ(a,b,c,d,e,f){a=ib[x[x[a+8>>2]>>2]](a+8|0)|0;a=Ts(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){x[b>>2]=((a|0)/12|0)%7}}function Bg(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return Go(a,d)}function Al(a,b,c,d){var e=0;e=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=e;e=x[b+12>>2];x[a+8>>2]=x[b+8>>2];x[a+12>>2]=e;mA(a,c,d)}function vha(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=xh(E(Ld(c,E(0))*E(127))),v[d|0]=e;Wt(a)}}function oia(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=xh(E(Ld(c,E(0))*E(255))),v[d|0]=e;$t(a)}}function Wq(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return ib[x[x[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function KP(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=sc(b-24|0);if((c|0)!=(b|0)){continue}break}return Uf(a)|0}function sC(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function nR(a,b){var c=0;if(!(y[a|0]!=y[b|0]|C[a+8>>3]!=C[b+8>>3]|y[a+16|0]!=y[b+16|0])){c=x[a+20>>2]==x[b+20>>2]}return c}function lu(a,b,c){c=c&255;while(1){a:{if(!b){a=0;break a}if(mc(y[a|0],c)){break a}b=b-1|0;a=a+1|0;continue}break}return a}function bp(a){x[a+32>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function IG(a,b){x[a>>2]=b;bL(a+4|0);x[a+24>>2]=0;x[a+28>>2]=0;x[a+16>>2]=0;x[a+20>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function yM(a,b,c,d){var e=0,f=0;e=fb-16|0;fb=e;f=e+8|0;mz(f,b);zj(x[f+4>>2],c,d);bc(a,c,oZ(x[x[f+4>>2]+4>>2]));fb=e+16|0}function vp(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=x[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}x[a>>2]=b}}function Ee(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=x[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}x[a>>2]=b}}function $s(a){if(a>>>0<=131071){a=y[(a>>>3&31|y[(a>>>8|0)+103856|0]<<5)+103856|0]>>>(a&7)&1}else{a=a>>>0<196606}return a}function vW(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((y[a+b|0]-32&255)>>>0<95){continue}}break}return(b|0)==8}function nh(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;x[f+12>>2]=e;c=Jh(f+8|0,c);a=ft(a,b,d,x[f+12>>2]);Ih(c);fb=f+16|0;return a}function aF(a,b){var c=0;c=sua(b&255,0,1536,0);b=hb;a=sua(a&255,0,25,0);c=a+c|0;b=hb+b|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function SX(a,b){var c=0;c=fb-16|0;fb=c;a:{if(!ih(a,4)){YC(b);break a}lh(c+8|0,b);HC(c,a,x[c+8>>2],x[c+12>>2])}fb=c+16|0}function PK(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+40>>2]](a)|0}x[a+12>>2]=b+4;return x[b>>2]}function NV(a){var b=0;if(!(y[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){x[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function MU(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){JU(a,1);JU(a,0)}}function LU(a,b,c,d,e,f,g){v[a+17|0]=g;v[a+16|0]=f;x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;if(d){KU(a,1);KU(a,0)}}function gY(a,b,c,d){var e=0,f=0,g=0;e=fb-16|0;fb=e;a=th(e+4|0,a,d);f=a,g=YY(b,c,x[a+4>>2]),x[f+4>>2]=g;hc(a);fb=e+16|0}function yZ(a,b,c){var d=0;while(1){if(b){d=y[c|0]|y[c+1|0]<<8;v[a|0]=d;v[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}}function r2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return ib[a|0](h|b,c,d,e,b|f,g)|0}function qX(a){var b=0;if(!(Ob(a,13914,3)|y[a+3|0]>31|(v[a+27|0]<0|y[a+32|0]>64))){b=(y[a+33|0]-1&255)>>>0<32}return b}function df(a){var b=0;b=x[a+32>>2];a:{if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1;a=0;break a}x[a+32>>2]=b+1;a=y[b|0]}return a}function RS(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Xb(x[a>>2]+((D(c<<24>>24,(d^-1|-256)+b|0)|0)/2|0)|0,0,256),x[e>>2]=f}}function QE(a){var b=0;b=0;a:{if(Ob(a,14305,3)){break a}a=y[a+3|0];b=1;if((a|0)==1){break a}b=(a-8&255)>>>0<7}return b}function Nt(a){a=a|0;var b=0;x[a>>2]=47932;Vd(a,0);b=x[a+8>>2];if(b){ib[x[x[b>>2]+4>>2]](b)}x[a+8>>2]=0;return Lm(a)|0}function Mka(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=uf(b+12|0,Tb(Dc(6668),0,6668));fb=b+16|0;x[a>>2]=x[c>>2];return a|0}function Ju(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function Jfa(a){a=a|0;var b=0;b=fb-16|0;fb=b;if(a){a=pc(b+8|0,a);a=Jz(x[a>>2],x[a+4>>2])}else{a=0}fb=b+16|0;return a|0}function Ii(a,b,c){c=c&255;while(1){a:{if((a|0)!=(b|0)){if((c|0)!=y[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function y8(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=lD(x[b>>2]);x[a+36>>2]=b;c=a,d=Zn(b),v[c+44|0]=d}function r8(a,b){a=a|0;b=b|0;var c=0,d=0;ib[x[x[a>>2]+24>>2]](a)|0;b=Dy(x[b>>2]);x[a+36>>2]=b;c=a,d=Zn(b),v[c+44|0]=d}function dga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=2){c=Ld(c,E(0));d=wb(a+4208|0,b),e=c,B[d>>2]=e;FP(a)}}function _ga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=5){c=Ld(c,E(0));d=wb(a+4208|0,b),e=c,B[d>>2]=e;UP(a)}}function Yfa(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=3){c=Ld(c,E(0));d=wb(a+4208|0,b),e=c,B[d>>2]=e;DP(a)}}function Uh(a){var b=0;while(1){a:{if((b|0)!=47){if(y[b+42464|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function Tga(a,b,c){a=a|0;b=b|0;c=E(c);var d=0,e=E(0);if(b>>>0<=4){c=Ld(c,E(0));d=wb(a+4208|0,b),e=c,B[d>>2]=e;QP(a)}}function SJ(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;b=Jh(d+8|0,b);a=sK(a,9282,x[d+12>>2]);Ih(b);fb=d+16|0;return a}function QG(a,b,c){a=De(a);a:{if(a>=b){break a}c=0;if(a<=0){break a}if(a<4294967296&a>=0){c=~~a>>>0;break a}}return c}function zp(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;Rr(b);continue}break}x[a+4>>2]=c}function x$(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Fd(b);continue}break}x[a+4>>2]=c}function nK(a,b,c){var d=0;if(c){d=a;while(1){x[d>>2]=x[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a}function a8(a){a=a|0;var b=0,c=0;c=x[a+4>>2];b=x[a>>2];a=x[a+8>>2];b=b+(a>>1)|0;if(a&1){c=x[c+x[b>>2]>>2]}ib[c|0](b)}function TU(a){x[a+700>>2]=0;w[a+842>>1]=0;x[a+688>>2]=0;x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0}function Nl(a,b){a=a+62|0;if(v[xb(a,b)|0]<0){return 255}if(y[xb(a,b)|0]!=255){a=y[xb(a,b)|0]&127}else{a=255}return a}function Bh(a){var b=0;hn(a);b=Xu(x[a>>2],$k(z[a+34>>1]));x[a+20>>2]=b;if(!b){return 0}return Rk(x[a>>2],z[a+34>>1])}function xK(a,b,c,d,e,f,g,h,i){x[a>>2]=b;x[a+4>>2]=c;x[a+8>>2]=d;x[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function ar(a){var b=0,c=0,d=0;if(x[a>>2]){Gf(a);b=x[a>>2];Rg(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function aR(a){var b=0,c=0,d=0;if(x[a>>2]){U_(a);b=x[a>>2];Tv(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function Vi(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=x[Gb(b+12|0,b+8|0)>>2];fb=b+16|0;return a}function Hh(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=2147483647;a=Gb(b+12|0,b+8|0);fb=b+16|0;return x[a>>2]}function HU(a){var b=0,c=0,d=0;if(x[a>>2]){gj(a);b=x[a>>2];Bn(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function HT(a){var b=0,c=0,d=0;if(x[a>>2]){oG(a);b=x[a>>2];Ln(a);Db(b);c=Ab(a),d=0,x[c>>2]=d;x[a>>2]=0;x[a+4>>2]=0}}function yc(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=y[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function sL(a,b,c){var d=0,e=0,f=0;e=c*c;C[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;C[b>>3]=d*d+((c+c)*d+(c*c-e))}function TL(a,b){var c=0;c=fb-16|0;fb=c;a=Sl(c+4|0,a,1);ul(x[a+4>>2],y[b|0]);x[a+4>>2]=x[a+4>>2]+1;hc(a);fb=c+16|0}function KW(a){var b=0;if(!(Ob(a+44|0,13923,4)|y[a+29|0]!=16)){b=((y[a+42|0]|y[a+43|0]<<8)-1&65535)>>>0<2}return b}function B$(a,b,c,d,e){v[a+4|0]=b;v[a|0]=69;v[a+1|0]=99;v[a+2|0]=104;v[a+3|0]=111;v[a+7|0]=e;v[a+6|0]=d;v[a+5|0]=c}function zda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=ib[x[x[b>>2]+8>>2]](b)|0;d=c,e=xg(a?a:22485),x[d>>2]=e}}function ym(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}og(a,b);a=a+1|0;continue}}}function sR(a,b){var c=0,d=0;c=x[a+4>>2];d=x[b+4>>2];if((c|0)==(d|0)){a=rR(x[a>>2],c,x[b>>2],d)}else{a=1}return!a}function ZS(a,b){var c=0;c=b&15;if(c){v[a+827|0]=c<<2}b=b&240;if(b){v[a+826|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|262144}function VK(a,b){a=a|0;b=b|0;var c=0;c=x[a>>2];a:{if(!c){break a}if(!mc(YK(c,b),-1)){break a}x[a>>2]=0}return a|0}function Us(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}wc(a,b);a=a+4|0;continue}}}function PP(a){a=a|0;x[a+4244>>2]=0;x[a+4248>>2]=0;x[a+4228>>2]=0;x[a+4232>>2]=0;a=a+4252|0;x[a>>2]=0;x[a+4>>2]=0}function NR(a,b){var c=0;c=fb-16|0;fb=c;a=XB(c+4|0,a);po(x[a+4>>2],x[b>>2]);x[a+4>>2]=x[a+4>>2]+4;hc(a);fb=c+16|0}function El(a,b){var c=0;c=b&15;if(c){v[a+824|0]=c<<2}b=b&240;if(b){v[a+823|0]=b>>>4}x[a+88>>2]=x[a+88>>2]|131072}function kl(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,Jb(a)+(Bb(x[a+4>>2],y[a+11|0])<<2)|0)>>2];fb=b+16|0;return a}function aW(a){if(Ob(a,13896,4)){a=0}else{a=($b(y[a+4|0]|y[a+5|0]<<8|(y[a+6|0]<<16|y[a+7|0]<<24))|0)==1}return a}function JP(a){var b=0,c=0;c=x[a+4>>2];b=x[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;x[a+8>>2]=b;continue}break}}function oJ(a,b){var c=0;c=Jb(a);if(c>>>0<=b>>>0){a=(Bb(x[a+4>>2],y[a+11|0])<<2)+c>>>0>=b>>>0}else{a=0}return a}function ky(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(x[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function NA(a,b){var c=0;c=fb-16|0;fb=c;a=te(c+8|0,tua(a,b,1e6,0),hb);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function Hl(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function yn(a){a=y[a|0]|y[a+1|0]<<8|(y[a+2|0]<<16|y[a+3|0]<<24);return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function kh(a,b,c){if(!c){return x[a+4>>2]==x[b+4>>2]}if((a|0)==(b|0)){return 1}return!li(x[a+4>>2],x[b+4>>2])}function kW(a){var b=0,c=0;c=x[a>>2];b=x[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;continue}break}x[a+4>>2]=c}function fH(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=wb(c,a);a=a+1|0;x[d>>2]=a<<b;continue}break}}function cm(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=65535;a=z[Gb(b+12|0,b+8|0)>>1];fb=b+16|0;return a}function Uv(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=(D(a,b)>>>0)/255;Ee(c+12|0,0,15);fb=c+16|0;return y[c+12|0]}function TQ(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=32767;a=w[Gb(b+12|0,b+8|0)>>1];fb=b+16|0;return a}function Df(a,b){var c=0;c=x[a+4>>2];if(b){a=x[a>>2];x[a>>2]=x[a>>2]|c;return}a=x[a>>2];x[a>>2]=x[a>>2]&(c^-1)}function wR(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function lS(a){x[a>>2]=0;x[a+4>>2]=0;x[a+24>>2]=0;x[a+28>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;return a}function jq(a,b){var c=0;c=fb-32|0;fb=c;lh(c+16|0,b);Im(c+24|0,a,x[c+16>>2],x[c+20>>2]);lh(c+8|0,b);fb=c+32|0}function j3(){if(y[500636]){return x[125158]}ks(500628,x[sH()>>2]);v[500636]=1;x[125158]=500628;return 500628}function Rv(a){var b=0;b=fb-16|0;fb=b;w[b+14>>1]=a;w[b+12>>1]=255;a=y[Mc(b+14|0,b+12|0)|0];fb=b+16|0;return a}function Jl(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;x[e+8>>2]=c;gc(a,b,x[Gb(e+12|0,e+8|0)>>2]);fb=e+16|0}function Ex(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=Fx(x[e>>2],h)}ib[x[x[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function Ek(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=c+12|0;x[a>>2]=x[a>>2]+(b<<2);fb=c+16|0;return x[a>>2]}function yta(a,b){a=a|0;b=b|0;var c=0;b=fb-80|0;fb=b;c=-1;if(f$(a,b+14|0)){c=e$(b+14|0)}fb=b+80|0;return c|0}function sU(a){var b=0;b=x[a+4>>2];w[a+70>>1]=y[((z[b+20>>1]>>>6|z[b+22>>1]<<4)&65535)+27664|0]>>>z[a+68>>1]}function _K(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return vf(v[b|0])}function NJ(a,b,c,d,e){b=nj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function M9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[c>>2];zj(x[b+24>>2],d,x[c+4>>2]);bc(a,d,x[x[b+24>>2]+4>>2])}function KJ(a,b,c,d,e){b=mj(b,c,d,e,4);if(!(y[d|0]&4)){x[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function yf(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,Jb(a)+Bb(x[a+4>>2],y[a+11|0])|0)>>2];fb=b+16|0;return a}function hA(a,b){a=Nb(a);x[a+20>>2]=0;x[a+12>>2]=0;x[a+16>>2]=0;Nb(a+24|0);Fb(a+36|0);x[a+48>>2]=b;return a}function ej(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=255;a=y[Gb(b+12|0,b+8|0)|0];fb=b+16|0;return a}function afa(){var a=0;a=fb-16|0;fb=a;if($a(a+12|0,4)|0){qt(x[31660],12731);p()}fb=a+16|0;return x[a+12>>2]}function VU(a,b){a=a|0;b=b|0;var c=0;c=Bb(x[a+4>>2],y[a+11|0]);if(c>>>0<b>>>0){is(a,b-c|0,0);return}zT(a,b)}function Tda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return BH(a,b,c,d,e,f,g,12998,1087)|0}function Mda(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return BH(a,b,c,d,e,f,g,13066,1094)|0}function Ll(a,b,c,d){a=a&65535;c=c&65535;a=(a|0)!=(c|0)?a>>>0<c>>>0?-1:1:0;if(Pj(a)){a=GT(b,d)}return Cd(a)}function JX(a,b){v[a+6|0]=255;x[a+16>>2]=0;w[a+4>>1]=0;x[a>>2]=0;if(b>=0){C[a+8>>3]=b;x[a+16>>2]=3}return a}function IL(a,b,c,d){B[d+4>>2]=a+c;a=E(a+E(c*E(-.5)));b=E(b*E(.8660253882408142));B[d+8>>2]=a-b;B[d>>2]=b+a}function Eqa(a,b){a=a|0;b=b|0;if(!vY(a,b)){v[b+4|0]=0;v[b+5|0]=0;v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0}}function yw(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function wu(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=wo(a);continue}break}return a}function wW(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;hb=a>>>0>c>>>0?b+1|0:b;return c}function vqa(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(kk(a,b+8|0)){c=eY(b+8|0)}fb=b+16|0;return c|0}function oZ(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=a;x[b+8>>2]=0;a=x[We(b+8|0,b+12|0)>>2];fb=b+16|0;return a}function fX(a){var b=0;if(!(Ob(a,18655,4)|y[a+5|0]!=16|(y[a+54|0]-33&255)>>>0<224)){b=y[a+4|0]>95}return b}function aua(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(kk(a,b+8|0)){c=J$(b+8|0)}fb=b+16|0;return c|0}function Hpa(a,b){a=a|0;b=b|0;var c=0;b=fb-16|0;fb=b;c=-1;if(ND(a,b+4|0)){c=yX(b+4|0)}fb=b+16|0;return c|0}function Dz(a,b){var c=0;c=Jb(a);if(c>>>0<=b>>>0){a=Bb(x[a+4>>2],y[a+11|0])+c>>>0>=b>>>0}else{a=0}return a}function zs(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=Fx(x[d>>2],g)}ib[x[x[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function zN(a,b){a=a|0;b=b|0;a=Ij(a);x[a+4>>2]=0;x[a>>2]=47872;x[a+4>>2]=x[b+4>>2];x[b+4>>2]=0;return a|0}function ql(a){var b=0;b=x[a+12>>2];if((b|0)==x[a+16>>2]){return ib[x[x[a>>2]+36>>2]](a)|0}return x[b>>2]}function bua(a){a=a|0;var b=0;b=x[a+76>>2];if(mc(-1,b)){b=LE(x[a+28>>2],32);x[a+76>>2]=b}return b<<24>>24}function RH(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=0;return Az(g|a,b,c,d,a|e,f)|0}function Pb(a,b){var c=0;c=fb-16|0;fb=c;DF(c+8|0,a,b);a=Hb(x[x[c+8>>2]>>2],x[c+12>>2]);fb=c+16|0;return a}function DI(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;x[e>>2]=c;x[h>>2]=f;return 3}function pT(a,b,c){var d=E(0);a:{if(b>c){break a}d=B[a>>2];if(!(d<b)){b=c;if(!(d>b)){break a}}B[a>>2]=b}}function ida(a){a=a|0;var b=0;b=fb-16|0;fb=b;ue(b+8|0,a);a=Jz(x[b+8>>2],x[b+12>>2]);fb=b+16|0;return a|0}function fW(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;eW(c);continue}break}x[a+4>>2]=b}function ez(a,b,c){b=(D(D(cz(a),dz(a,b)),125)>>>0)/(QL(a,b)>>>0)|0;a=(a&6)==6?b&134217724:b;return a?a:c}function XR(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Dl(c);continue}break}x[a+4>>2]=b}function Rca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return pO(x[a+4>>2],b,c,d,e,f,g)|0}function Qb(a,b,c){var d=0;c=c+x[a+4>>2]|0;d=b;b=x[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;x[a>>2]=b;x[a+4>>2]=c}function Oca(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return hO(x[a+4>>2],b,c,d,e,f,g)|0}function KT(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;$e(c);continue}break}x[a+4>>2]=b}function Cx(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;x[c+12>>2]=x[c+12>>2]-b;fb=c+16|0;return x[c+12>>2]}function CE(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;ub(c);continue}break}x[a+4>>2]=b}function AU(a,b){var c=0;c=x[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Ol(c);continue}break}x[a+4>>2]=b}function A$(a,b){a=mm(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];mm(a+12|0,x[b+12>>2],x[b+16>>2]);return a}function sj(a){a:{a=a&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function qT(a,b){var c=0,d=0;a:{if(b<0){break a}c=C[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}C[a>>3]=d}}function hJ(a){var b=0,c=0;b=fb-16|0;fb=b;a=Jh(b+12|0,a);c=x[x[124291]>>2];Ih(a);fb=b+16|0;return c?4:1}function Nu(a,b){b=sua(a,a>>31,b,b>>31);a=hb;b=b+5e5|0;a=b>>>0<5e5?a+1|0:a;return Fc(tua(b,a,1e6,0),hb)}function H_(a){a:{if(Ob(a,14314,4)){break a}if(Ob(a+8|0,14295,4)){break a}return 1}return!Ob(a,14295,4)}function fp(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(Gn(a,b+12|0)){c=$b(x[b+12>>2])}fb=b+16|0;return c|0}function Qk(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;if(tp(a,b+14|0)){c=Cb(z[b+14>>1])}fb=b+16|0;return c|0}function zZ(a,b){var c=0,d=0,e=0;c=fb-16|0;fb=c;d=c,e=Cb(b&65535),w[d+14>>1]=e;Fv(a,c+14|0);fb=c+16|0}function iV(a){if(((y[a+68|0]|y[a+69|0]<<8)-128&65535)>>>0>=65409){a=Ob(a,18503,17)}else{a=1}return!a}function gS(a){a=Fb(a);Fb(a+12|0);Fb(a+24|0);Fb(a+36|0);Fb(a+48|0);Gc(a+60|0,0);x[a+64>>2]=0;return a}function e1(a){a=a|0;var b=0,c=0;b=fb-16|0;fb=b;c=-1;if(kk(a,b+8|0)){c=SF(b+8|0)}fb=b+16|0;return c|0}function Tb(a,b,c){var d=0;if(c){d=a;while(1){v[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function Pv(a){var b=0,c=0;if(x[a>>2]){So(a);Db(x[a>>2]);b=Ab(a),c=0,x[b>>2]=c;x[a>>2]=0;x[a+4>>2]=0}}function LD(a,b){if(b>>>0<=126){Ye(((b<<5)+a|0)+480280|0);Jo((D(b,872)+a|0)+1074992|0,a,b,134217728)}}function L1(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=-1;if(vG(a,b+8|0)){c=tG(b+8|0)}fb=b+32|0;return c|0}function Kv(a){a=a|0;var b=0;w[a+34>>1]=0;b=a+43|0;Mm(b,b+22|0,79024);x[a+20>>2]=0;jd(a,0);return a|0}function xH(a,b,c){var d=0;d=fb-16|0;fb=d;c=Cc(d+4|0,c);a=nc(a,c);tb(c);x[a>>2]=b;fb=d+16|0;return a}function w9(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;oE(c+8|0,b);pp(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function vda(a,b){a=a|0;b=b|0;var c=0;b=Jb(b);c=x[a+4>>2];if(c){ib[c|0](b,x[a+8>>2]);return}Tt(b,a)}
function pC(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=(WY(a,b,x[c>>2],d)|0)!=0}else{a=1}return a}function lE(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0}function kV(a){fe(a+140|0);ub(a+120|0);ub(a+100|0);ub(a+80|0);ub(a+60|0);ub(a+40|0);ub(a+20|0);ub(a)}function hqa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=tp(a,b+14|0);fb=b+16|0;return(a?w[b+14>>1]:0)<<16>>16}function dS(a){x[a+20>>2]=0;v[a+16|0]=7;x[a+8>>2]=1889785610;x[a+12>>2]=1072630333;v[a|0]=3;return a}function cZ(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){bZ(c+52|0);tb(c+40|0);sc(c+16|0);sc(c+4|0);Db(c)}}function bl(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;v[a+6|0]=0;v[a+7|0]=0}function Rha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=Aj(a);if(a){ib[x[x[a>>2]+88>>2]](a,b,c,d,e)}}function P0(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;zn(c+8|0,b);pp(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function O0(a,b){a=a|0;b=b|0;x[a>>2]=0;x[a+4>>2]=0;Gc(a+8|0,0);Ir(a,127);uF(a,127,y[b|0]);return a|0}function Dg(a,b,c){var d=0;d=x[a>>2];c=x[a+4>>2]-(c+(d>>>0<b>>>0)|0)|0;b=d-b|0;x[a>>2]=b;x[a+4>>2]=c}function $e(a){var b=0,c=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,a)>>2];c=x[a>>2];if(c){Ab(a);Db(c)}fb=b+16|0}function ci(a,b,c){var d=0;d=x[a+4>>2];while(1){if((b|0)!=(d|0)){d=d-c|0;continue}break}x[a+4>>2]=b}function Zx(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=Jh(f+12|0,e);a=gt(a,b,c,d);Ih(e);fb=f+16|0;return a}function Yc(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2];cx(b);return a}function Nha(a,b,c){a=a|0;b=b|0;c=c|0;a=Aj(a);if(!a){return 0}return ib[x[x[a>>2]+104>>2]](a,b,c)|0}function NT(a,b,c){var d=0;d=fb-16|0;fb=d;a=x[zb(d+12|0,FT(b,c,$d(a),ec(a)))>>2];fb=d+16|0;return a}function NI(a,b,c){a:{if(!(y[b+120|0]|c>>>0>30)){v[b+120|0]=1;break a}b=PX(c)}x[a+4>>2]=c;x[a>>2]=b}function IR(a,b){if(b>>>0<=255){a=x[((b<<2)+a|0)+900380>>2];a=a?a+492|0:22485}else{a=22485}return a}function Di(a,b,c,d,e){var f=0;f=fb-16|0;fb=f;e=Jh(f+12|0,e);a=hK(a,b,c,d);Ih(e);fb=f+16|0;return a}function Aw(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=ch(a,b+15|0);fb=b+16|0;return(a?v[b+15|0]:0)<<24>>24}function xJ(a,b){a=a|0;b=b|0;b=x[b+72>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function cg(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=uc(c+4|0,b);Yc(d,a);tb(a);fb=c+16|0}function bw(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=a;a=Cc(c+4|0,b);Yc(d,a);tb(a);fb=c+16|0}function Zqa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Gn(a,b+12|0);fb=b+16|0;return E(a?B[b+12>>2]:E(0))}function Wda(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return GH(a,b,c,d,e,f,10658,1084)|0}function Ms(a,b){a=a|0;b=b|0;b=x[b+68>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function Kd(){var a=0;if(y[500612]){return x[125152]}a=tk(14426);v[500612]=1;x[125152]=a;return a}function Kaa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=x[uf(b+12|0,Tl(Dc(12),a))>>2];fb=b+16|0;return a|0}function Jea(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return GH(a,b,c,d,e,f,10703,1057)|0}function JQ(a,b){var c=0;c=fb-16|0;fb=c;a=te(c+8|0,a,b);b=x[a>>2];fb=c+16|0;hb=x[a+4>>2];return b}function DJ(a,b){a=a|0;b=b|0;b=x[b+64>>2];v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function xD(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=x[d_(c+12|0,0-b|0)>>2];fb=c+16|0;return a}function jua(a,b){a=a|0;b=b|0;if(!hE(a,b)){v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0;v[b|0]=0}}function iz(a,b,c,d){var e=0;e=fb-16|0;fb=e;bc(e+8|0,c,d);yM(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function b9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+24>>2]](a,b,c,d,e,f)|0}function a9(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f)|0}function _8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+20>>2]](a,b,c,d,e,f)|0}function Z8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+44>>2]](a,b,c,d,e,f)|0}function Oz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Im(a,b,c,d){var e=0;e=fb-16|0;fb=e;kf(e+8|0,c,d);yM(a,b,x[e+8>>2],x[e+12>>2]);fb=e+16|0}function $8(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[x[x[a>>2]+28>>2]](a,b,c,d,e,f)|0}function sX(a){var b=0,c=0;b=1;c=x[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}x[a>>2]=b}}function Yba(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;YO(a,x[b+4>>2],c,d,e,f,g)}function W1(a,b){a=a|0;b=b|0;var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;BI(d,b);Oh(a,d);tb(d);fb=c+16|0}function Tba(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;sO(a,x[b+4>>2],c,d,e,f,g)}function T$(a,b){a=a|0;b=b|0;if(!hE(a,b)){v[b|0]=0;v[b+1|0]=0;v[b+2|0]=0;v[b+3|0]=0;v[b+4|0]=0}}function Nw(a,b){a=LF(a,x[b>>2],x[b+4>>2]);x[a+8>>2]=x[b+8>>2];LF(a+12|0,x[b+12>>2],x[b+16>>2])}function M2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(kh(a,x[b+8>>2],f)){Ix(b,c,d,e)}}function K8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[b>>2]+16>>2]](a,b,x[c+8>>2],x[c+12>>2],0,d)}function Bja(a,b){a=a|0;b=b|0;Ni(a);Ni(a);a:{if(b>>>0>=60){Yb(a,4);break a}Ni(a)}return Ni(a)|0}function xx(a,b,c,d){var e=0;x[a>>2]=x[b>>2];e=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=(c<<d)+e;return a}function vL(a){var b=0;b=+((a&2097151)>>>0);return E(mk(+E((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function uD(a){var b=0,c=0;b=fb-16|0;fb=b;if(tp(a,b+14|0)){c=ve(w[b+14>>1])}fb=b+16|0;return c}function l$(a){var b=0;if(!(Ob(a,24932,20)|(y[a+25|0]-9&255)>>>0<248)){b=v[a+47|0]>=0}return b}function iK(a){var b=0;b=x[124291];if(a){x[124291]=(a|0)==-1?500420:a}return(b|0)==500420?-1:b}function be(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=ch(a,b+15|0);fb=b+16|0;return(a?y[b+15|0]:0)&255}function Z_(a,b){return(Xb((D(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Xb((D(a&15,b)>>>0)/15|0,1,15))&255}function Pba(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;WO(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function Oba(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;rO(a,x[x[b+4>>2]+24>>2],c,d,e,f)}function BW(a){var b=0,c=0;b=fb-16|0;fb=b;if(ME(a,b+12|0)){c=$b(x[b+12>>2])}fb=b+16|0;return c}function cW(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=D(c,12)+d;return a}function _s(a){return y[(a>>>3&31|y[(a>>>8|0)+107760|0]<<5)+107760|0]>>>(a&7)&1&a>>>0<=131071}function Sba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Qt(x[x[a+4>>2]+24>>2],b,c,d,e)|0}function Rpa(a){a=a|0;var b=0,c=0;b=fb-32|0;fb=b;c=a;a=_h(b+12|0);cY(c,a,0,0);ub(a);fb=b+32|0}function Oc(a,b,c){var d=0;d=x[c+4>>2];if((d|0)==(b|0)){a=WY(a,b,x[c>>2],d)}else{a=1}return!a}function Mm(a,b,c){b=b-a|0;while(1){if((b|0)>0){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function Lm(a){a=a|0;var b=0;x[a>>2]=47892;b=x[a+4>>2];if(b){Db(hq(b))}x[a+4>>2]=0;return a|0}function Hs(a){a=a|0;var b=0;x[a>>2]=112300;b=x[a+8>>2];if(!(!b|!y[a+12|0])){Db(b)}return a|0}function qC(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(x[b>>2]){continue}break}return b-a>>2}function W8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return ib[x[x[a>>2]+32>>2]](a,b,c,d,e)|0}function Ne(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=x[hU(c+12|0,b)>>2];fb=c+16|0;return a}function FU(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=a;a=x[EU(c+12|0,b)>>2];fb=c+16|0;return a}function wD(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=0;iu(b+12|0,a);fb=b+16|0;return x[b+12>>2]}function rpa(a){a=a|0;var b=0;b=fb-16|0;fb=b;a=Zh(a,b+8|0);fb=b+16|0;return+(a?C[b+8>>3]:0)}function pN(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=eN(d);b=b+1|0}cU(a,b,c,d,e)}function pF(a,b){if((a&4088)>>>0>=520){b=Dw(0-vua(b^1230262859,25)|0,4)^1247037516}return b}function l4(a,b){a=a|0;b=b|0;a=td(a,0);xI(a+8|0,b);x[a>>2]=117332;x[a>>2]=117616;return a|0}function j4(a,b){a=a|0;b=b|0;a=td(a,0);xI(a+8|0,b);x[a>>2]=117488;x[a>>2]=117732;return a|0}function fB(a){var b=0;x[a+84>>2]=0;x[a+88>>2]=0;b=x[a+80>>2];x[a+92>>2]=b;x[a+96>>2]=b<<12}function eh(a){var b=0;b=fb-16|0;fb=b;a=tp(a,b+14|0);fb=b+16|0;return(a?z[b+14>>1]:0)&65535}function ag(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){LD(a,c);b=b+1|0;continue}break}}function aX(a){a:{if(Ob(a,18448,4)){break a}if(Ob(a+8|0,14352,4)){break a}return 1}return 0}function _x(a,b,c){var d=0;d=fb-16|0;fb=d;c=Jh(d+12|0,c);a=Py(a,b);Ih(c);fb=d+16|0;return a}function Sfa(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;zz(a,b,c,d,e,0,0,f,g)}function EE(a){var b=0;b=x[a>>2];if(x[b>>2]){CE(b,x[b>>2]);a=x[a>>2];b=x[a>>2];DE(a);Db(b)}}function $I(a,b){a=td(a,b);v[a+12|0]=0;x[a+8>>2]=0;x[a>>2]=112300;x[a+8>>2]=112352;return a}function wm(a,b,c){var d=E(0);if(b>>>0<=c>>>0){d=B[wb(a+4208|0,b)>>2]}else{d=E(0)}return d}function _w(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=x[(b<<2)+22496>>2]}else{b=9752}uc(a,b)}function ZK(a){var b=0;b=x[a>>2];if(b){if(!mc(_K(b),-1)){return!x[a>>2]}x[a>>2]=0}return 1}function Tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Aj(a);if(a){ib[x[x[a>>2]+76>>2]](a,b,c,d)}}function Sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Aj(a);if(a){ib[x[x[a>>2]+84>>2]](a,b,c,d)}}function Qha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Aj(a);if(a){ib[x[x[a>>2]+92>>2]](a,b,c,d)}}function LP(a,b){var c=0;c=x[a+12>>2];if((c|0)>0){x[a+20>>2]=(x[a+16>>2]+(b+c|0)|0)%(c|0)}}function LF(a,b,c){var d=0;d=fb-16|0;fb=d;b=mm(d+8|0,b,c);lG(b,a);he(b);fb=d+16|0;return a}function Ah(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function yy(a,b,c,d){var e=0;e=fb-16|0;fb=e;x[e+12>>2]=d;a=ft(a,b,c,d);fb=e+16|0;return a}function vua(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function iU(a,b,c){while(1){if((b|0)!=(c|0)){fU(a,y[b|0]);b=b+1|0;continue}break}return a}function g2(a,b,c){a=a|0;b=b|0;c=c|0;ib[x[x[b>>2]+8>>2]](b,c);ks(a,x[b+4>>2]);GG(b+4|0,c)}function ex(){var a=0,b=0;a=fb-16|0;fb=a;b=uf(a+12|0,Nb(Dc(12)));fb=a+16|0;return x[b>>2]}function eA(a,b){if((a|0)>=0){return(a>>>0)%(b>>>0)|0}return(((a^-1)>>>0)%(b>>>0)^-1)+b|0}function dq(a){a=a|0;var b=0;x[a>>2]=47872;b=x[a+4>>2];if(b){Db(b);x[a+4>>2]=0}return a|0}function VE(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;hb=b>>>0<2624?a+1|0:a;return b}function S_(a,b,c){var d=0;d=fb-16|0;fb=d;ti(d+8|0,b,c);fb=d+16|0;return x[d+8>>2]==(a|0)}function Or(a){var b=0;while(1){if(!mc(y[a|0],0)){a=a+1|0;b=b+1|0;continue}break}return b}function Bl(a,b,c){a=a+1074992|0;return x[(a+D(b,872)|0)+680>>2]>x[(a+D(c,872)|0)+680>>2]}function pr(a,b){var c=0;c=fb-16|0;fb=c;a=x[zb(c+12|0,D(b,6)+a|0)>>2];fb=c+16|0;return a}function jn(a){var b=0;if(a>>>0>=2){b=YX(a+1|0);a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function jX(a,b){var c=0;c=fb-16|0;fb=c;zn(c+8|0,b);XY(a,x[c+8>>2],x[c+12>>2]);fb=c+16|0}function eS(a){var b=0;b=a+4e4|0;while(1){b=HA(b-160|0);if((b|0)!=(a|0)){continue}break}}function YI(a,b){a=td(a,b);x[a+8>>2]=46;x[a+12>>2]=44;x[a>>2]=113592;Fb(a+16|0);return a}function Vha(a,b){a=a|0;b=b|0;a=Aj(a);if(!a){return 1}return ib[x[x[a>>2]+68>>2]](a,b)|0}function TI(a,b){a=td(a,b);b=a+8|0;x[b>>2]=121284;x[a>>2]=116268;x[b>>2]=116316;return a}function SI(a,b){a=td(a,b);b=a+8|0;x[b>>2]=121320;x[a>>2]=116532;x[b>>2]=116580;return a}function Jt(a){if(FM(a)){a=ac(4);x[a>>2]=0;a=Ij(a);x[a>>2]=124764;da(a|0,124800,34);p()}}function JB(a,b){a=Tl(a,b);Yc(a+12|0,b+12|0);w[a+28>>1]=z[b+28>>1];x[a+24>>2]=x[b+24>>2]}function GS(a,b){var c=0;c=y[a+851|0];if(c&1){v[a+851|0]=c|64;x[a+852>>2]=x[a+852>>2]+b}}function $m(a,b){var c=0;c=fb-16|0;fb=c;a=x[zb(c+12|0,(b<<1)+a|0)>>2];fb=c+16|0;return a}function rq(a,b,c){a=Fl(a)-x[a+16>>2]|0;if(a>>>0>=2){c=E(E(E(c-b)/E(a>>>0))+b)}return c}function rm(a){var b=0;b=Yw(a+4|0);if((b|0)==-1){ib[x[x[a>>2]+8>>2]](a)}return(b|0)==-1}function rK(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;a=sK(a,11209,b);fb=c+16|0;return a}function q1(a){a=a|0;var b=0;b=x[a+4>>2];return(ib[x[x[b>>2]+20>>2]](b)|0)+x[a+12>>2]|0}function kD(a){var b=0;b=_U(a);while(1){if((a|0)!=(b|0)){y$(a);a=a+32|0;continue}break}}function gC(a,b,c){var d=0;x[a>>2]=x[b>>2];d=x[b>>2];x[a+8>>2]=b;x[a+4>>2]=c+d;return a}function ds(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){v[b|0]=45;d=eN(d);b=b+1|0}rB(a,b,c,d)}function Vda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FH(a,b,c,d,e,12454,1085)|0}function QK(a){var b=0;b=x[a>>2];if(b){if(!bo(ql(b))){return!x[a>>2]}x[a>>2]=0}return 1}function Jg(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0;return a}function Iea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return FH(a,b,c,d,e,12554,1058)|0}function Bv(a,b,c){var d=E(0);d=B[a>>2];if(!Av(d,B[b>>2])){b=Av(B[c>>2],d)?c:a}return b}function $l(a,b,c){var d=0;d=fb-16|0;fb=d;v[d+15|0]=c;Rh(a,b,d+15|0);fb=d+16|0;return a}function zc(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;zn(d,a);jm(d,b);fb=c+16|0;return a}function s5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[x[x[b>>2]+16>>2]](a,b,c,d,e,8)}function pV(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;hb=b>>>0<259?a+1|0:a;return b}function mU(a,b){return(a>>>0<=62?63-(D((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function mG(a,b){var c=0;c=fb-16|0;fb=c;b=zf(c+8|0,b);lG(b,a);he(b);fb=c+16|0;return a}function mE(a,b){a=a|0;b=b|0;var c=0;c=fb-16|0;fb=c;v[c+15|0]=b;nw(a,c+15|0);fb=c+16|0}function V1(){var a=0;a:{if(CG(19988519)){break a}if(BG()){break a}a=AG()^1}return a|0}function Tt(a,b){a=a|0;b=b|0;b=fb-16|0;fb=b;x[b>>2]=a;kP(18677,b);St(126176);fb=b+16|0}function Sda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return AH(a,b,c,d,e,9636,1088)|0}function Lda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return AH(a,b,c,d,e,9708,1095)|0}function K$(a,b,c){v[a+2|0]=1;b=b&15;if(c){b=y[b+24880|0]}else{b=(b<<2)+4|0}v[a+4|0]=b}function yv(a,b){var c=0;c=fb-16|0;fb=c;w[c+14>>1]=b;uv(a+236|0,128,c+14|0);fb=c+16|0}function x7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mH(b,c,d,e,f,1)|0}function v7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return mH(b,c,d,e,f,0)|0}function v5(a){a=a|0;a=501896;while(1){a=tb(a-12|0);if((a|0)!=501872){continue}break}}function uu(a,b){if(!(v[b+851|0]&1&x[a+480180>>2]==8)){wA(a,b,0);wA(a,b,1);wA(a,b,2)}}function u5(a){a=a|0;a=501552;while(1){a=tb(a-12|0);if((a|0)!=501264){continue}break}}function t5(a){a=a|0;a=501080;while(1){a=tb(a-12|0);if((a|0)!=500912){continue}break}}function sJ(a,b){var c=0,d=0;Oe(a,ie(b));b=ec(b);c=ec(a),d=x[b>>2],x[c>>2]=d;return a}function q9(a,b){a=a|0;b=b|0;a=z[a>>1];b=z[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function pK(a){return(a|0)!=0&(a|0)!=121724&(a|0)!=121748&(a|0)!=500336&(a|0)!=500360}function p9(a,b){a=a|0;b=b|0;a=x[a>>2];b=x[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function gv(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function a5(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+98176>>2]}return b<<24>>24}function _4(a,b){a=a|0;b=b|0;if((b|0)>=0){b=x[((b&255)<<2)+96640>>2]}return b<<24>>24}function Qi(a,b,c){var d=0;d=fb-16|0;fb=d;DX(d+8|0,a,b,c);fb=d+16|0;return x[d+12>>2]}function PI(a){var b=0;b=x[a>>2];if(x[b>>2]){Gf(b);a=x[a>>2];Xx(Js(a),x[a>>2],Rg(a))}}function J5(a){a=a|0;a=501928;while(1){a=Sb(a-12|0);if((a|0)!=501904){continue}break}}function I5(a){a=a|0;a=501856;while(1){a=Sb(a-12|0);if((a|0)!=501568){continue}break}}function H7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return oH(b,c,d,e,f,1)|0}function H5(a){a=a|0;a=501256;while(1){a=Sb(a-12|0);if((a|0)!=501088){continue}break}}function F7(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return oH(b,c,d,e,f,0)|0}function wx(a,b){var c=0;while(1){if((b|0)!=(c|0)){Wh(a+c|0);c=c+1|0;continue}break}}function wo(a){var b=0;b=a;a=x[a>>2];x[b>>2]=D(a,214013)+2531011;return a>>>16&32767}function uha(a,b){a=a|0;b=b|0;return E(b>>>0<=2?E(E(y[(a+b|0)+4232|0])/E(127)):E(0))}function nia(a,b){a=a|0;b=b|0;return E(b>>>0<=3?E(E(y[(a+b|0)+4264|0])/E(255)):E(0))}function jf(a){a=a|0;var b=0;b=x[a>>2];return(ib[x[x[b>>2]+24>>2]](b)|0)-x[a+8>>2]|0}function hC(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;x[a+8>>2]=x[b+8>>2]}function bk(a,b,c){var d=0;d=x[a>>2];if(!Iq(d,x[b>>2])){b=Iq(x[c>>2],d)?c:a}return b}function Ug(a,b,c){var d=0;d=C[a>>3];if(!jV(d,C[b>>3])){b=jV(C[c>>3],d)?c:a}return b}function Sca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return oO(x[a+4>>2],b,c,d,e)|0}function Pca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return gO(x[a+4>>2],b,c,d,e)|0}function Mg(a){var b=0;b=fb-16|0;fb=b;a=Gn(a,b+12|0);fb=b+16|0;return a?x[b+12>>2]:0}function M3(a,b,c){a=a|0;b=b|0;c=c|0;a=Mx(b,x[a+8>>2]);return((a|0)==-1?c:a)<<24>>24}function HV(a,b,c,d,e,f){a=zb(a,b);zb(a+4|0,c);zb(a+8|0,d);zb(a+12|0,e);zb(a+16|0,f)}function Ge(a,b,c){if(tn(a,b,c)){a=sg(a,c);a=Ib(x[a>>2],x[a+4>>2])}else{a=0}return a}function Ffa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return hP(a,b,c,d,0,0,0,0,e)|0}function $x(a){a=a|0;x[a>>2]=113504;if(x[a+8>>2]!=(Kd()|0)){nl(x[a+8>>2])}return a|0}function zf(a,b){x[a>>2]=x[b>>2];x[a+4>>2]=x[b+4>>2];x[b>>2]=0;x[b+4>>2]=0;return a}function zQ(a){var b=0;b=x[a>>2];if(x[b>>2]){Gf(b);a=x[a>>2];b=x[a>>2];Rg(a);Db(b)}}function zF(a){var b=0;b=x[a>>2];if(x[b>>2]){gj(b);a=x[a>>2];b=x[a>>2];Bn(a);Db(b)}}function v$(a,b,c){a=a|0;b=b|0;c=c|0;return u$(a,b,Jb(c),Bb(x[c+4>>2],y[c+11|0]))|0}function pG(a){var b=0;b=x[a>>2];if(x[b>>2]){oG(b);a=x[a>>2];b=x[a>>2];Ln(a);Db(b)}}function oR(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){Eb(b+16|0)}Db(b)}}function fia(a){a=a|0;v[a+4202|0]=1;x[a+4232>>2]=x[x[a+16>>2]+24620>>2];$t(a);tQ(a)}function dz(a,b){return y[(D(a>>>1&3,15)+D(a>>>3&1,45)+((b&240)>>>4)|0)+81377|0]<<1}function de(a){var b=0;b=fb-16|0;fb=b;x[b+12>>2]=48856;Td(a,48752,b+12|0);fb=b+16|0}function _l(a,b){var c=0,d=0,e=0;c=x[a+24>>2];d=a,e=Xe(zi(b)*+(c>>>0)),x[d+24>>2]=e}function Yp(a){a=a|0;x[a+56>>2]=94416;x[a>>2]=94396;kt(a+4|0);sl(a+56|0);return a|0}function V_(a){var b=0;b=x[a>>2];if(x[b>>2]){U_(b);a=x[a>>2];b=x[a>>2];Tv(a);Db(b)}}function VV(a){var b=0;b=x[a>>2];if(x[b>>2]){AV(b);a=x[a>>2];b=x[a>>2];Su(a);Db(b)}}function Tk(a,b){var c=0;c=fb-16|0;fb=c;a=x[zb(c+12|0,a+b|0)>>2];fb=c+16|0;return a}function Jga(a){a=a|0;v[a+4202|0]=1;x[a+4256>>2]=x[x[a+16>>2]+24620>>2];OP(a);NP(a)}function IT(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){JT(b+16|0)}Db(b)}}function GA(a){var b=0;b=fb-16|0;fb=b;zb(b+12|0,a+116|0);a=VR(a);fb=b+16|0;return a}function D6(a){a=a|0;Qp(x[a+8>>2]);a=x[a+8>>2];if(!a){return 1}return(hJ(a)|0)==1|0}function Af(a){a=a|0;x[a+60>>2]=94580;x[a>>2]=94560;kt(a+8|0);sl(a+60|0);return a|0}function $Y(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){if(y[ec(a)+4|0]){Hk(b+16|0)}Db(b)}}function yL(a,b){b=x[a+32>>2]+b|0;x[a+32>>2]=b;if(b>>>0>=A[a+40>>2]){x[a+96>>2]=1}}function v6(){var a=0,b=0,c=0;a=td(501984,1);x[a>>2]=113504;b=a,c=Kd(),x[b+8>>2]=c}function YS(a,b){var c=0;c=b&15;if(c){v[a+830|0]=c}b=b&240;if(b){v[a+829|0]=b>>>4}}function Tu(a,b){a=Cb(a&65535);b=Cb(b&65535);return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function Hp(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+(c<<d);return a}function Fp(a,b,c,d){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+D(c,d);return a}function xp(a,b){var c=0;x[a>>2]=x[b>>2];c=a;a=x[b+4>>2];x[c+4>>2]=a;if(a){cl(a)}}function wd(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,Jb(a))>>2];fb=b+16|0;return a}function vs(a,b,c,d){if(b>>>0>=d>>>0){Xj();p()}c=Dc(D(b,c));x[a+4>>2]=b;x[a>>2]=c}function uv(a,b,c){while(1){if(b){w[a>>1]=z[c>>1];b=b-1|0;a=a+2|0;continue}break}}function tda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return us(a,b,c,d,e,1110)|0}function sF(a,b,c){while(1){if(b){x[a>>2]=x[c>>2];b=b-1|0;a=a+4|0;continue}break}}function rda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return us(a,b,c,d,e,1112)|0}function qda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return us(a,b,c,d,e,1114)|0}function qV(a){if((y[a+14|0]-53&255)>>>0>=252){a=Ob(a,15788,14)}else{a=1}return!a}function mg(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,ec(a))>>2];fb=b+16|0;return a}function mfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return us(a,b,c,d,e,1003)|0}function kP(a,b){var c=0;c=fb-16|0;fb=c;x[c+12>>2]=b;lL(126176,a,b,0,0);fb=c+16|0}function Yi(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,vb(a))>>2];fb=b+16|0;return a}function Oo(a,b){a=yc(a,b,34);w[a+34>>1]=z[b+34>>1];yc(a+36|0,b+36|0,68);return a}function MQ(a,b,c){while(1){if(b){B[a>>2]=B[c>>2];b=b-1|0;a=a+4|0;continue}break}}function Kca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return JH(a,b,c,d,e,1125)|0}function Jf(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,mg(a))>>2];fb=b+16|0;return a}function $L(a,b){a=In(a);v[a+8|0]=0;x[a+4>>2]=b;x[a>>2]=77612;Nb(a+12|0);return a}function s2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ib[a|0](b,c,d)|0;gb=hb;return a|0}function m5(a,b,c){a=a|0;b=b|0;c=c|0;return(x[(c<<2)+112352>>2]&b)!=0&c>>>0<=127}function gP(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return JH(a,b,c,d,e,1004)|0}function gM(a){a=In(a);x[a>>2]=78076;Nb(a+4|0);v[a+20|0]=0;x[a+16>>2]=0;return a}function YN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ts(a,b,c,d,e,1109)|0}function VN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ts(a,b,c,d,e,1111)|0}function UN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ts(a,b,c,d,e,1113)|0}function TN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ts(a,b,c,d,e,1029)|0}function Pk(a,b){var c=0;c=x[b+4>>2];x[a>>2]=x[b>>2];x[a+4>>2]=c;ic(a+8|0,b+8|0)}function LN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zx(a,b,c,d,e,1110)|0}function KN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return qs(a,b,c,d,e,1110)|0}function JN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zx(a,b,c,d,e,1112)|0}function IN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return qs(a,b,c,d,e,1112)|0}function HN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return zx(a,b,c,d,e,1114)|0}function GN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return qs(a,b,c,d,e,1114)|0}function FN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return qs(a,b,c,d,e,1003)|0}function yx(a,b,c,d){if(b>>>0>=d>>>0){Xj();p()}c=Dc(b<<c);x[a+4>>2]=b;x[a>>2]=c}function wi(a){return(jk(x[a>>2],x[a+4>>2])|0)!=(0-jk(x[a+12>>2],x[a+16>>2])|0)}function v2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ib[a|0](b,c,d,e,f)}function rx(a,b){b=a+b|0;while(1){b=tb(b-12|0);if((b|0)!=(a|0)){continue}break}}function rba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return dN(a-88|0,b,c,d,e)|0}function r_(a,b,c){while(1){if(b){v[a|0]=y[c|0];b=b-1|0;a=a+1|0;continue}break}}function lg(a){var b=0,c=0;rc(a+4|0);Gc(a+8|0,0);b=a,c=ec(a),x[b>>2]=c;return a}function jra(a,b,c){a=a|0;b=b|0;c=c|0;Yc(a,nY(b,Jb(c),Bb(x[c+4>>2],y[c+11|0])))}function hH(a,b){x[a>>2]=b;Sb(a+52|0);Sb(a+40|0);Sb(a+28|0);tb(a+16|0);return a}function gH(a,b){x[a>>2]=b;tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);return a}function fU(a,b){var c=0;c=a;a=x[a>>2];x[c>>2]=a<<8^x[((a>>>24^b)<<2)+27804>>2]}function _f(a){var b=0;b=xb(a,2);return y[xb(a,1)|0]<<8|y[b|0]<<16|y[xb(a,0)|0]}function Vl(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;Td(a,b,d+12|0);fb=d+16|0}function Sp(a,b,c){var d=0;d=fb-16|0;fb=d;x[d+12>>2]=c;Qj(a,b,d+12|0);fb=d+16|0}function Sb(a){var b=0;if(Cd(y[a+11|0])){b=x[a>>2];bj(x[a+8>>2]);Db(b)}return a}function R5(a){a=a|0;if(!y[500864]){ln(500852,113820);v[500864]=1}return 500852}function P5(a){a=a|0;if(!y[500896]){ln(500884,113904);v[500896]=1}return 500884}function N5(a){a=a|0;if(!y[500800]){ln(500788,113748);v[500800]=1}return 500788}function MR(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+4|0;uC(d,1,b);Ec(a,d);fb=c+16|0}function L5(a){a=a|0;if(!y[500832]){ln(500820,113784);v[500832]=1}return 500820}function CI(){var a=0;a=fb-16|0;x[a+8>>2]=0;x[a+12>>2]=1048576;return C[a+8>>3]}function x5(a){a=a|0;if(!y[500816]){Cc(500804,13804);v[500816]=1}return 500804}function w_(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Ab(a)>>2]){TL(a,b);return}PL(a,b)}function rca(a,b){a=a|0;b=b|0;a=x[a+4>>2];return wO(x[a+24>>2],B[a+48>>2],b)|0}function qA(a,b){a=a|0;b=b|0;if(x[a+4>>2]!=x[Ab(a)>>2]){NR(a,b);return}_z(a,b)}function p2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return ib[a|0](b,c,d,e)|0}function iw(a,b){return Xe(zi((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function c3(a,b,c){a=a|0;b=b|0;c=c|0;if(!y[502432]){v[502432]=1}gc(a,c,126620)}function a4(a,b){a=a|0;b=b|0;a=Ij(a);x[a>>2]=125292;Lx(a+4|0,Jb(b));return a|0}function No(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0;v[a+4|0]=0;v[a+5|0]=0}function N9(a){a=a|0;a=x[a+24>>2];return ZL(x[(x[x[a>>2]-12>>2]+a|0)+16>>2])^1}function Jw(a,b){var c=0;if((b|0)<0){Xj();p()}c=Dc(b<<1);x[a+4>>2]=b;x[a>>2]=c}function D5(a){a=a|0;if(!y[500848]){Cc(500836,13595);v[500848]=1}return 500836}function z5(a){a=a|0;if(!y[500784]){Cc(500772,5285);v[500784]=1}return 500772}function yu(a,b){var c=0;c=a;a=(b>>>0)/1e6|0;return iB(Gl(c,a),D(a,-1e6)+b|0)}function ye(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;Fw(d,a);jm(d,b);fb=c+16|0}function vj(a,b,c){if(x[a+80>>2]){x[a+92>>2]=x[a+92>>2]+(c+7&-8);return}Db(b)}function vb(a){var b=0;b=fb-16|0;fb=b;a=x[zb(b+12|0,a)>>2];fb=b+16|0;return a}function rf(a){if(Cd(y[a+11|0])){ed(x[a>>2],0);Vd(a,0);return}ed(a,0);Ke(a,0)}function oV(a,b){a=UW(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2];return a}function mB(a){var b=0;if(!(y[a+2|0]|(y[a|0]|y[a+1|0]))){b=!y[a+3|0]}return b}function kB(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Gl(Gl(c,a),D(a,-100)+b|0)}function iB(a,b){var c=0;c=a;a=(b>>>0)/1e4|0;return kB(Gl(c,a),D(a,-1e4)+b|0)}function fm(a,b){var c=0,d=0;c=fb-16|0;fb=c;d=c+8|0;oE(d,a);jm(d,b);fb=c+16|0}function bba(a,b){a=a|0;b=b|0;un(x[a+4>>2]);NF(PF(x[a+4>>2],b));un(x[a+4>>2])}function aA(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function ZI(a,b){a=td(a,b);w[a+8>>1]=11310;x[a>>2]=113552;Fb(a+12|0);return a}function Vj(a){var b=0;b=fb-16|0;fb=b;a=x[uf(b+12|0,a)>>2];fb=b+16|0;return a}function Rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pn(a,b,c,d,12955,1089)|0}function R2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(kh(a,x[b+8>>2],0)){Gx(b,c,d)}}function Pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pn(a,b,c,d,13029,1091)|0}function PR(a,b){a=a|0;b=b|0;if(A[a+4>>2]<A[Ab(a)>>2]){NR(a,b);return}_z(a,b)}function Lga(a,b){a=a|0;b=b|0;return E(b>>>0<=4?B[((b<<2)+a|0)+4220>>2]:E(0))}function Ej(a){if(Pb(a+1074312|0,7)){a=on(x[a+480180>>2])^1}else{a=0}return a}function B5(a){a=a|0;if(!y[500880]){Cc(500868,9273);v[500880]=1}return 500868}function AT(a){x[a>>2]=0;x[a+4>>2]=0;x[a>>2]=-2078137563;x[a+4>>2]=-873292572}function $z(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function ce(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[b+8>>2];Yb(b,c);ax(a,b,d,c)}function VJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+32>>2]](a,b,c,d)|0}function Uda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pn(a,b,c,d,9440,1086)|0}function Se(a){var b=0;b=fb-16|0;fb=b;Fn(b+8|0,a);fb=b+16|0;return x[b+8>>2]}function RJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[x[x[a>>2]+48>>2]](a,b,c,d)|0}function Qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pn(a,b,c,d,9591,1090)|0}function Oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pn(a,b,c,d,9669,1092)|0}function Nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Pn(a,b,c,d,9471,1093)|0}function BS(a,b,c){var d=0;return!b|!(y[a+35|0]&4?!a|(c|0)!=1:1)?d:y[b+34|0]}function z7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nH(b,c,d,e,1)|0}function w7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nH(b,c,d,e,0)|0}function i5(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+98176>>2]}return b|0}function g5(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=x[(b<<2)+96640>>2]}return b|0}function eC(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function dU(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);XT(a,b,0,0,b+-1,0)}function cQ(a){a=a|0;x[a>>2]=44988;sc(a+4276|0);sc(a+4264|0);return Uf(a)|0}function Sl(a,b,c){x[a>>2]=b;b=x[b+4>>2];x[a+4>>2]=b;x[a+8>>2]=b+c;return a}function QL(a,b){a=a^-1;return x[(b&12)+81380>>2]>>>(a>>>3&1)>>>(a>>>4&1)|0}function NK(a,b,c,d,e,f,g,h){return ib[x[x[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function J7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return pH(b,c,d,e,1)|0}function G7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return pH(b,c,d,e,0)|0}function Eh(a,b){var c=0;c=a;a=x[a+8>>2];b=a-b|0;x[c+8>>2]=a>>>0>=b>>>0?b:0}function E8(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){KK(a,c);return}Cc(a,7940)}function CZ(a){var b=0;while(1){b=a;a=x[a>>2];if(a){continue}break}return b}function fG(a,b){a=a|0;b=b|0;a=Ij(a);x[a>>2]=125292;Lx(a+4|0,b);return a|0}function f3(a,b,c){a=a|0;b=b|0;c=c|0;return mc(a,x[b+4>>2])&x[b>>2]==(c|0)}function ei(a,b,c){x[a+8>>2]=b;x[a+12>>2]=c;x[a>>2]=0;x[a+4>>2]=0;return a}function Zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return mO(x[a+4>>2],b,c,d)|0}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return kO(x[a+4>>2],b,c,d)|0}function Vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return lO(x[a+4>>2],b,c,d)|0}function Uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return jO(x[a+4>>2],b,c,d)|0}function Tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return qO(x[a+4>>2],b,c,d)|0}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return iO(x[a+4>>2],b,c,d)|0}function Hha(a,b){a=a|0;b=b|0;a=x[a+20>>2];v[a+24|0]=y[a+24|0]&253|(b?2:0)}function Ck(a){var b=0;b=z[a+172>>1];a=z[a+156>>1];return(lV(a)?b:a)&65535}function ura(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=lp(a,b),x[d>>2]=e}function uj(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+12>>2]](a,b,c)|0}function tra(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=zw(a,b),w[d>>1]=e}function sc(a){var b=0;b=fb-16|0;fb=b;zQ(zb(b+12|0,a));fb=b+16|0;return a}function rF(a,b){while(1){if(b){x[a>>2]=0;b=b-1|0;a=a+4|0;continue}break}}function mz(a,b){var c=0,d=0;c=zb(a,x[x[b>>2]-12>>2]+b|0),d=b,x[c+4>>2]=d}function hd(a,b){a=mG(a,b);x[a+8>>2]=x[b+8>>2];mG(a+12|0,b+12|0);return a}function eG(a,b){a=zf(a,b);x[a+8>>2]=x[b+8>>2];zf(a+12|0,b+12|0);return a}function dc(a){var b=0;b=fb-16|0;fb=b;MY(zb(b+12|0,a));fb=b+16|0;return a}function cp(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+48>>2]](a,b,c)|0}function ad(a,b,c,d,e){v[a+3|0]=e;v[a+2|0]=d;v[a+1|0]=c;v[a|0]=b;return a}function PF(a,b){a=a|0;b=b|0;return dF(a,Jb(b),Bb(x[b+4>>2],y[b+11|0]))|0}function Mb(a,b,c){a=a|0;b=b|0;c=c|0;return ib[x[x[a>>2]+32>>2]](a,b,c)|0}function KX(a,b){v[a+6|0]=255;x[a+16>>2]=b;w[a+4>>1]=0;x[a>>2]=0;return a}function Jb(a){var b=0,c=0,d=0;return b=x[a>>2],c=a,d=Cd(y[a+11|0]),d?b:c}function eL(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ei(a,-1,-1)}function Hm(a,b){v[a|0]=b;v[a+1|0]=b>>>8;v[a+2|0]=b>>>16;v[a+3|0]=b>>>24}function By(a,b){var c=0;c=vt(a+4|0);x[a>>2]=95208;x[c>>2]=95228;go(c,b)}function Ay(a,b){var c=0;c=CK(a+4|0);x[a>>2]=95576;x[c>>2]=95596;go(c,b)}function uU(a,b){x[a+4>>2]=0;x[a+8>>2]=0;x[a>>2]=b?b:49716;x[a+12>>2]=0}function pda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rs(a,b,c,d,1116)|0}function pc(a,b){var c=0,d=0;x[a>>2]=b;c=a,d=gf(b),x[c+4>>2]=d;return a}function oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rs(a,b,c,d,1118)|0}function oK(a,b,c){var d=0;d=c;c=gf(b);if(d>>>0>c>>>0){$N(a,b)}return c}function nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rs(a,b,c,d,1120)|0}function nU(a){if(a>>>0<=8){return y[a+27792|0]}return y[a+27783|0]|256}function nN(a){a=a|0;return+(+A[x[a+32>>2]+480240>>2]*152587890625e-16)}function lda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return rs(a,b,c,d,1122)|0}function ZP(a){a=a|0;return E(E(E(B[wb(a+4208|0,5)>>2]*E(198))+E(-99)))}function Wy(a){return((Lh(a)+(Lh(a)<<8)|0)+(Lh(a)<<16)|0)+(Lh(a)<<24)|0}function QD(a,b,c){var d=0;d=(b|0)/(c|0)|0;x[a>>2]=d;x[a+4>>2]=b-D(c,d)}function Ota(a){a=a|0;x[a+16>>2]=x[a+16>>2]|1;if(v[a+20|0]&1){ua();p()}}function Op(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;x[e>>2]=c;return 3}function Lc(a){if(Cd(y[a+11|0])){a=bj(x[a+8>>2])-1|0}else{a=10}return a}function K2(a){a=a|0;if(!a){return 0}return(WA(a,124848,124992)|0)!=0|0}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return wH(a,b,c,d,1004)|0}function Hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return wH(a,b,c,d,1125)|0}function Boa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;PG(a,b,c,d,e,136)}function yq(a,b){if(b){yq(a,x[b>>2]);yq(a,x[b+4>>2]);JT(b+16|0);Db(b)}}function yX(a){if(Ob(a,13918,4)){a=1}else{a=Ob(a+8|0,13971,4)}return!a}function sqa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ax(a,b,c,d,589)|0}function sB(a,b){if(b){sB(a,x[b>>2]);sB(a,x[b+4>>2]);Ym(b+16|0);Db(b)}}function pA(a,b){if(b){pA(a,x[b>>2]);pA(a,x[b+4>>2]);Eb(b+16|0);Db(b)}}function kn(a){if(Cd(y[a+11|0])){a=bj(x[a+8>>2])-1|0}else{a=1}return a}function fi(a,b){a=a|0;b=b|0;v[a|0]=2;v[a+1|0]=3;v[a+2|0]=0;v[a+3|0]=4}function ct(a){return a>>>0<32|a-127>>>0<33|(a&-2)==8232|a-65529>>>0<3}function aD(a,b){if(b){aD(a,x[b>>2]);aD(a,x[b+4>>2]);Hk(b+16|0);Db(b)}}function Yra(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;PG(a,b,c,d,e,94)}function YA(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];v[a+6|0]=y[b+6|0]}function Xj(){var a=0;a=Om(ac(4));x[a>>2]=125176;da(a|0,125252,34);p()}function Vu(a,b){a=a&255;b=b&255;return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function SN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ss(a,b,c,d,1115)|0}function RN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ss(a,b,c,d,1117)|0}function Qr(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0;x[a+12>>2]=0;return a}function QN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ss(a,b,c,d,1119)|0}function PB(a,b){a=Nb(a);Fb(a+12|0);w[a+28>>1]=0;x[a+24>>2]=b;return a}function ON(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ss(a,b,c,d,1121)|0}function Hx(a,b,c){if(!(x[a+28>>2]==1|x[a+4>>2]!=(b|0))){x[a+28>>2]=c}}function EN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ps(a,b,c,d,1116)|0}function DN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ps(a,b,c,d,1118)|0}function CN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ps(a,b,c,d,1120)|0}function BN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ps(a,b,c,d,1122)|0}function $C(a,b){if(b){$C(a,x[b>>2]);$C(a,x[b+4>>2]);Hk(b+16|0);Db(b)}}function t2(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ib[a|0](b,c,d,e)}function bx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ax(a,b,c,d,166)|0}function Wx(a){a=a|0;if(x[a+8>>2]!=(Kd()|0)){nl(x[a+8>>2])}return a|0}function TR(a,b,c,d,e){x[a+12>>2]=e;x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b}function PT(a,b,c){if(Ge(a,b,c)){a=x[Vb(a,c)+12>>2]}else{a=1}return a}function MY(a){var b=0;b=x[a>>2];if(x[b>>2]){So(b);Db(x[x[a>>2]>>2])}}function LM(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){mo(c+120|0);Db(c)}}function IV(a,b,c,d,e){a=zb(a,b);zb(a+4|0,c);zb(a+8|0,d);zb(a+12|0,e)}function B_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ax(a,b,c,d,342)|0}function uY(a,b){x[a>>2]=x[b>>2];w[a+4>>1]=z[b+4>>1];ic(a+8|0,b+8|0)}function q2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return ib[a|0](b,c,d)|0}function mV(a,b){a=lC(a,b);v[a+16|0]=y[b+16|0];x[a+12>>2]=x[b+12>>2]}function b8(a){a=a|0;var b=0;b=x[125160]+1|0;x[125160]=b;x[a+4>>2]=b}function J6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;fg(a,f)}function I6(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Rp(a,f)}function zm(a,b){return b?a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24):a}function mO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return zH(a,b,c,d,4)|0}function lO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return zH(a,b,c,d,2)|0}function kO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return yH(a,b,c,d,4)|0}function jO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return yH(a,b,c,d,2)|0}function R$(a,b){return Pp(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function OH(a,b,c,d,e,f,g){return Ja(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function Nc(a,b,c){if(oc(a,b)>>>0<=c>>>0){tw();p()}return(c<<2)+a|0}function Hr(a,b){return Cw(x[b>>2],x[b+4>>2],x[a>>2],x[a+4>>2])?b:a}function Gk(a,b,c){var d=0;d=fb-16|0;fb=d;DX(d+8|0,a,b,c);fb=d+16|0}function FY(a){v[a+4|0]=0;v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function FS(a,b){x[a+852>>2]=x[a+852>>2]+b;v[a+851|0]=y[a+851|0]|64}function Er(a,b,c){if(Xc(a,b)>>>0<=c>>>0){tw();p()}return(c<<1)+a|0}function ng(a,b){a=a|0;b=b|0;var c=0;c=Dc(b);x[a+4>>2]=b;x[a>>2]=c}function lga(a,b){a=a|0;b=b|0;if(!x[31785]){x[31785]=a;x[31786]=b}}function ld(a){a=(a|0)>=32767?32767:a;return(a|0)<=-32768?-32768:a}function d5(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function Xx(a,b,c){a:{if((a|0)==(b|0)){v[b+120|0]=0;break a}Db(b)}}function Rj(a,b){a=a|0;b=b|0;var c=0;c=PX(b);x[a+4>>2]=b;x[a>>2]=c}function OU(a,b){var c=0,d=0;c=zb(a,x[b>>2]),d=y[b+4|0],v[c+4|0]=d}function G3(a,b){a=a|0;b=b|0;a=zI(a,b,1);x[a>>2]=121356;return a|0}function $fa(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,984,86224)|0}function $3(a,b){a=a|0;b=b|0;a=yI(a,b,1);x[a>>2]=121452;return a|0}function zh(a,b,c){a=zb(a,b);EZ(a+4|0,x[c>>2],x[c+4>>2]);return a}function yp(a,b,c){a=zf(a,b);x[a+8>>2]=0;zf(a+12|0,c);he(c);he(b)}function xha(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,973,4236)|0}function tia(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,949,4268)|0}function sm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+32>>2]](a,0,b)|0}function rga(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,981,5048)|0}function rL(a,b){a=pL(a-1|0);if(!a){a=pL(b);a=a?a+32|0:0}return a}function r1(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+16>>2]](a)|0}function qk(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+52>>2]](a,b,0)|0}function lN(a){a=a|0;return+(+x[x[a+32>>2]+1074456>>2]*.00390625)}function jo(a,b){if(A[a+4>>2]<A[Ab(a)>>2]){TL(a,b);return}PL(a,b)}function hp(a,b){x[a>>2]=x[(x[x[b>>2]-12>>2]+b|0)+24>>2];return a}function gga(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,983,4276)|0}function dha(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,976,4280)|0}function cia(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,957,4304)|0}function cY(a,b,c,d){a=Fe(a,b);w[a+22>>1]=d;w[a+20>>1]=c;return a}function ak(a,b){if(Hg(x[a>>2],x[a+4>>2])>>>0>b>>>0){v[a+16|0]=b}}function Wga(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,977,4276)|0}function QH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return aO(a,b,c,d)|0}function Pga(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,978,4268)|0}function Esa(a,b){a=a|0;b=b|0;a=Iv(a,b);x[a>>2]=125448;return a|0}function Ds(a){a=a|0;x[a>>2]=113384;nl(x[a+16>>2]);return Hs(a)|0}function Aga(a,b,c){a=a|0;b=b|0;c=c|0;return jj(a,b,c,980,4228)|0}function $ka(a,b){a=a|0;b=b|0;a=Iv(a,b);x[a>>2]=125500;return a|0}function ze(a){var b=0;b=fb-16|0;fb=b;pG(zb(b+12|0,a));fb=b+16|0}function s1(a){a=a|0;a=x[a+4>>2];return ib[x[x[a>>2]+8>>2]](a)|0}function oz(a){var b=0;b=fb-16|0;fb=b;TM(zb(b+12|0,a));fb=b+16|0}function mW(a){var b=0;b=fb-16|0;fb=b;gW(zb(b+12|0,a));fb=b+16|0}function kd(a){var b=0;b=fb-16|0;fb=b;zF(zb(b+12|0,a));fb=b+16|0}function jG(a,b,c){a=In(a);x[a+8>>2]=c;x[a+4>>2]=b;x[a>>2]=78928}function cn(a){var b=0;b=fb-16|0;fb=b;VV(zb(b+12|0,a));fb=b+16|0}function _X(a){var b=0;b=fb-16|0;fb=b;TX(zb(b+12|0,a));fb=b+16|0}function Yx(a){var b=0;b=fb-16|0;fb=b;PI(zb(b+12|0,a));fb=b+16|0}function Xba(a,b){a=a|0;b=b|0;return E(TO(x[x[a+4>>2]+24>>2],b))}function XV(a){var b=0;b=fb-16|0;fb=b;LV(zb(b+12|0,a));fb=b+16|0}function Wba(a,b){a=a|0;b=b|0;return E(SO(x[x[a+4>>2]+24>>2],b))}function Vba(a,b){a=a|0;b=b|0;return E(PO(x[x[a+4>>2]+24>>2],b))}function Rba(a,b){a=a|0;b=b|0;return E(RO(x[x[a+4>>2]+24>>2],b))}function RV(a){var b=0;b=fb-16|0;fb=b;EV(zb(b+12|0,a));fb=b+16|0}function Qp(a){var b=0;b=fb-16|0;fb=b;Ih(Jh(b+12|0,a));fb=b+16|0}function Qfa(a,b){a=a|0;b=b|0;if(!b){return 3}x[b>>2]=a;return 0}function Qc(a){var b=0;b=fb-16|0;fb=b;EE(zb(b+12|0,a));fb=b+16|0}function Qba(a,b){a=a|0;b=b|0;return E(QO(x[x[a+4>>2]+24>>2],b))}function Pq(a,b,c){a=Cb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function Pp(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function Pd(a){var b=0;b=fb-16|0;fb=b;KH(zb(b+12|0,a));fb=b+16|0}function Nk(a){var b=0;b=fb-16|0;fb=b;V_(zb(b+12|0,a));fb=b+16|0}function LA(a){tb(a+48|0);tb(a+36|0);tb(a+24|0);tb(a+12|0);tb(a)}function GP(a){return E(E(B[wb(a+4208|0,11)>>2]*E(19980))+E(20))}function FZ(a,b){a=a|0;b=b|0;a=Iv(a,b);x[a>>2]=125312;return a|0}function ys(a){var b=0;b=fb-16|0;C[b+8>>3]=a;return C[b+8>>3]*a}function xg(a){var b=0;b=Lq(gf(a)+1|0,1);if(b){$N(b,a)}return b}function uo(a,b,c,d){a=Vu(a,c);if(Pj(a)){a=GT(b,d)}return Cd(a)}function ry(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+12>>2]](a,b)|0}function psa(a,b){a=a|0;b=b|0;a=BZ(a,b);if(!a){AZ(b)}return a|0}function nx(a){var b=0;b=fb-16|0;B[b+12>>2]=a;return B[b+12>>2]}function it(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+44>>2]](a,b)|0}function gm(a,b){a=a|0;b=b|0;return ib[x[x[a>>2]+28>>2]](a,b)|0}function eq(a,b,c){if(!b){return 0}return Pt(a,vf(c<<24>>24),b)}function bca(a,b){a=a|0;b=b|0;return xO(x[x[a+4>>2]+24>>2],b)|0}function Uc(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){au(b)}return a}function SM(a,b,c,d){x[a+8>>2]=d;x[a+4>>2]=c;x[a>>2]=b;return a}function Mt(a,b){var c=0;c=G(a)+32|0;a=G(b);return(a|0)==32?c:a}function HP(a){return E(E(B[wb(a+4208|0,0)>>2]*E(1e4))+E(-1e4))}function Gka(a,b){a=a|0;b=b|0;a=BY(a,b);if(!a){AY(b)}return a|0}function Cw(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function B6(a){a=a|0;a=x[a+8>>2];if(!a){return 1}return hJ(a)|0}function yi(a,b){a=a|0;b=b|0;a=Zh(a,b);if(!a){bl(b)}return a|0}function w$(a,b){if(!b){return-1}b=eq(a,b,0);return b?b-a|0:-1}function sT(a,b){a=a|0;b=b|0;a=W_(a,b);if(!a){or(b)}return a|0}function pv(a,b){a=a|0;b=b|0;a=E_(a,b);if(!a){Sv(b)}return a|0}function nha(a,b,c){a=a|0;b=b|0;c=c|0;return Bx(a,b,c,0,975)|0}function ih(a,b){return ib[x[x[a>>2]+32>>2]](a,x[a+12>>2],b)|0}function iS(a,b,c,d){w[a>>1]=b;v[a+2|0]=y[c|0];v[a+3|0]=y[d|0]}function iD(a,b){a=a|0;b=b|0;a=NY(a,b);if(!a){ZC(b)}return a|0}function _o(a,b){a=a|0;b=b|0;a=D_(a,b);if(!a){G_(b)}return a|0}function XP(a){a=a|0;return Bk(E(B[wb(a+4208|0,4)>>2]*E(4)))|0}function Wca(a,b,c){a=a|0;b=b|0;c=c|0;return+fO(x[a+4>>2],b,c)}function V$(a,b){a=a|0;b=b|0;a=gE(a,b);if(!a){lE(b)}return a|0}function Sw(a,b){a=Yc(a,b);ic(a+12|0,b+12|0);oe(a+32|0,b+32|0)}function Pw(a,b){a=a|0;b=b|0;a=KF(a,b);if(!a){Pr(b)}return a|0}function Lr(a,b){var c=0;c=b+1|0;x[a>>2]=x[a>>2]>(c|0)?c:b+2|0}function JR(a,b){return b>>>0>=4e3?22485:((b<<5)+a|0)+946304|0}function Iga(a,b,c){a=a|0;b=b|0;c=c|0;return Bx(a,b,c,0,979)|0}function HW(a){return y[a+15|0]<<12|y[a+14|0]<<4|y[a+13|0]<<20}function ER(a,b,c,d){w[a+4>>1]=c;v[a+6|0]=b;x[a>>2]=d;return a}function Cr(a,b){a=a|0;b=b|0;a=Gn(a,b);if(!a){vn(b)}return a|0}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;return Bx(a,b,c,1,979)|0}function Ap(a,b){a=a|0;b=b|0;a=Xw(a,b);if(!a){Ww(b)}return a|0}function $r(a,b){a=a|0;b=b|0;a=TF(a,b);if(!a){gx(b)}return a|0}function $6(a,b){a=a|0;b=b|0;CS(a,Jy(x[b>>2])<<24>>24,x[b>>2])}function qG(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(dc(c))}}function mm(a,b,c){x[a+4>>2]=c;x[a>>2]=b;if(c){cl(c)}return a}function eha(a){a=a|0;return E(E(B[wb(a+4208|0,6)>>2]*E(20)))}function cM(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function _H(a,b){var c=0;c=a;a=x[a>>2]+b|0;x[c>>2]=a;return a}function Zaa(a,b){a=a|0;b=b|0;x[a>>2]=x[b>>2];fg(a+4|0,b+4|0)}function ZR(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(Cj(c))}}function Xl(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){ec(a);Db(b)}}function Xja(a){a=a|0;a=Iv(a,22485);x[a>>2]=125392;return a|0}function Tsa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;RG(a,b,c,d,366)}function PX(a){if(a>>>0>=1073741824){Xj();p()}return Dc(a<<2)}function Oha(a){a=a|0;a=Aj(a);if(a){ib[x[x[a>>2]+100>>2]](a)}}function Gra(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;RG(a,b,c,d,478)}function Ef(a,b,c){return(x[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function Bta(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;YG(a,b,c,d,136)}function $b(a){return a<<24|(a&65280)<<8|(a>>>8&65280|a>>>24)}function wc(a,b){var c=0;c=x[a>>2];x[a>>2]=x[b>>2];x[b>>2]=c}function uR(a,b){var c=0;c=z[a>>1];w[a>>1]=z[b>>1];w[b>>1]=c}function qN(a){a=a|0;return+(65536/+A[x[a+32>>2]+480244>>2])}function pm(a){a=kG(a,0);x[a+8>>2]=0;x[a>>2]=121592;return a}function pL(a){var b=0,c=0,d=0;return b=rua(a),c=0,d=a,d?b:c}function kt(a){a=a|0;x[a>>2]=93880;tb(a+32|0);return $n(a)|0}function kj(a){var b=0;o(+a);b=j(1)|0;j(0)|0;return b>>>20|0}function k1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bc(a,x[d>>2],0)}function fh(a,b,c,d){hb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function cI(a){a=a|0;x[a>>2]=112268;nl(x[a+8>>2]);return a|0}function bS(a){x[a>>2]=0;Nb(a+4|0);Tb(a+16|0,0,144);return a}function bI(a){a=a|0;x[a>>2]=112236;nl(x[a+8>>2]);return a|0}function aY(a){var b=0;b=x[a+100>>2];x[a+100>>2]=0;return b}
function YP(a){a=a|0;return E(E(B[wb(a+4208|0,2)>>2]*E(10)))}function XL(a){a=a|0;x[a>>2]=78464;dc(a+24|0);return Bt(a)|0}function Rz(a){a=a|0;x[a+32>>2]=0;x[a+28>>2]=x[a+28>>2]&-7|2}function Iv(a,b){a=Ij(a);x[a>>2]=125272;Lx(a+4|0,b);return a}function Ira(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;YG(a,b,c,d,94)}function Gs(a){a=a|0;x[a>>2]=113436;nl(x[a+8>>2]);return a|0}function Cga(a){a=a|0;return E(E(B[wb(a+4208|0,6)>>2]*E(4)))}function vl(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(mf(b))}}function u2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ib[a|0](b,c,d)}function tu(a,b){if(b){tu(a,x[b>>2]);tu(a,x[b+4>>2]);Db(b)}}function su(a,b){if(b){su(a,x[b>>2]);su(a,x[b+4>>2]);Db(b)}}function qo(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function qD(a,b){if(b){qD(a,x[b>>2]);qD(a,x[b+4>>2]);Db(b)}}function pD(a,b){if(b){pD(a,x[b>>2]);pD(a,x[b+4>>2]);Db(b)}}function nz(a,b,c,d,e,f){return tH(a,b,c,d,e,f,73860,74656)}function lz(a,b,c,d,e,f){return tH(a,b,c,d,e,f,74736,75500)}function lr(a){return x[a+20>>2]+(x[a+8>>2]-x[a+24>>2]|0)|0}function hja(a,b,c){a=a|0;b=b|0;c=c|0;return OG(a,b,c,65)|0}function h5(a,b,c){a=a|0;b=b|0;c=c|0;return lH(b,c,98176)|0}function f5(a,b,c){a=a|0;b=b|0;c=c|0;return lH(b,c,96640)|0}function eba(a,b,c){a=a|0;b=b|0;c=c|0;Yc(a,u$(c,0,b,gf(b)))}function e$(a){return!Ob(a,14300,4)&(y[a+4|0]-1&255)>>>0<10}function cC(a,b){if(b){cC(a,x[b>>2]);cC(a,x[b+4>>2]);Db(b)}}function bC(a,b){if(b){bC(a,x[b>>2]);bC(a,x[b+4>>2]);Db(b)}}function _pa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;NG(a,b,c,d,3)}function Z4(a,b,c){a=a|0;b=b|0;c=c|0;return kH(b,c,96640)|0}function Yw(a){var b=0;b=a;a=x[a>>2]-1|0;x[b>>2]=a;return a}function XM(a,b){a=a|0;b=+b;vH(a,b,1e4,1074420,9383,512,32)}function Vv(a,b,c){a=a|0;b=b|0;c=c|0;return aH(a,b,c,325)|0}function Uaa(a){a=a|0;Bz(a,2,100);ak(x[a+24>>2]+484360|0,0)}function T0(a){a=a|0;a=gG(a,13410);x[a>>2]=24684;return a|0}function QC(a,b){if(b){QC(a,x[b>>2]);QC(a,x[b+4>>2]);Db(b)}}function PE(a){return!Ob(a,14301,3)&(y[a+3|0]-10&255)>>>0<5}function P$(a,b,c){a=a|0;b=b|0;c=c|0;return aH(a,b,c,265)|0}function Ny(a,b){return ot(a,Jb(b),Bb(x[b+4>>2],y[b+11|0]))}function Mw(a,b){return WR(a,Jb(b),Bb(x[b+4>>2],y[b+11|0]))}function MS(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(ZA(b))}}function Jh(a,b){var c=0,d=0;c=a,d=iK(b),x[c>>2]=d;return a}function Epa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;NG(a,b,c,d,2)}function Bs(a,b){var c=0,d=0;c=a,d=tk(b),x[c>>2]=d;return a}function BM(a,b){a=a|0;b=b|0;return Tj(x[b>>2],x[b+4>>2])|0}function AM(a,b){a=a|0;b=b|0;return Od(x[b>>2],x[b+4>>2])|0}function $4(a,b,c){a=a|0;b=b|0;c=c|0;return kH(b,c,98176)|0}function w3(a){a=a|0;a=FZ(a,7976);x[a>>2]=40504;return a|0}function qz(a){return(Jb(a)+Bb(x[a+4>>2],y[a+11|0])|0)-1|0}function pp(a,b,c){a=a|0;b=b|0;c=c|0;pi(a,b,Ii(b,b+c|0,0))}function mA(a,b,c){C[a>>3]=C[a>>3]+b;C[a+8>>3]=C[a+8>>3]+c}function hr(a,b,c){if((a|0)!=(b|0)){b=b-a|0;ai(c-b|0,a,b)}}function _n(a,b,c,d){x[a+16>>2]=d;x[a+12>>2]=c;x[a+8>>2]=b}function X4(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function Uo(a){var b=0;b=x[a>>2];x[b>>2]=x[b>>2]|x[a+4>>2]}function PH(a,b,c){b=La(1014,a|0,b|0,c|0)|0;hb=gb;return b}function F1(a){a=a|0;a=gG(a,8724);x[a>>2]=29108;return a|0}function DO(a){return Lj(Wb(x[a+484360>>2],y[a+484376|0]))}function B8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hb=0;return 0}function xq(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function uA(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){Db(c)}}function tF(a,b){var c=0;c=Dc(b<<2);x[a+4>>2]=b;x[a>>2]=c}function rra(a,b,c){a=a|0;b=b|0;c=c|0;pi(a,b,Sc(b,c)+b|0)}function r$(a,b){v[a|0]=y[b|0];v[a+1|0]=y[b+1|0];return a}function qea(a,b){a=a|0;b=b|0;return Qn(a,b,11803,1066)|0}function pea(a,b){a=a|0;b=b|0;return IH(a,b,13382,1067)|0}function mN(a,b){a=a|0;b=+b;vH(a,b,256,1074456,11773,1,0)}function jg(a,b){if(Cd(y[a+11|0])){Vd(a,b);return}Ke(a,b)}function gg(a){var b=0;JP(a);b=x[a>>2];if(b){Kz(a);Db(b)}}function gea(a,b){a=a|0;b=b|0;return Qn(a,b,11838,1074)|0}function eea(a,b){a=a|0;b=b|0;return Qn(a,b,11868,1076)|0}function _da(a,b){a=a|0;b=b|0;return Qn(a,b,11964,1079)|0}function Yda(a,b){a=a|0;b=b|0;return Qn(a,b,11932,1080)|0}function YJ(a,b,c){a=a|0;b=b|0;c=c|0;mu(a,b,c);return a|0}function Vx(a){a=a|0;x[a>>2]=113592;tb(a+16|0);return a|0}function Ux(a){a=a|0;x[a>>2]=113552;tb(a+12|0);return a|0}function Mo(a){x[a>>2]=0;x[a+4>>2]=0;Gc(a+8|0,0);return a}function KM(a,b){var c=0;c=x[a>>2];x[a>>2]=b;if(c){au(c)}}function Hea(a,b){a=a|0;b=b|0;return Qn(a,b,11900,1059)|0}function Fy(a,b,c){x[a+28>>2]=c;x[a+20>>2]=b;x[a+24>>2]=b}function Fc(a,b){return cH(a,b,2147483647,-2147483648,-1)}function EL(a){while(1){if((xt(a)|0)!=-1){continue}break}}function $y(a,b){return x[((a>>>24^b)<<2)+496032>>2]^a<<8}function xv(a){sc(a+88|0);sc(a+68|0);sc(a+48|0);return a}function wj(a){return df(a)|df(a)<<8|df(a)<<16|df(a)<<24}function vn(a){v[a|0]=0;v[a+1|0]=0;v[a+2|0]=0;v[a+3|0]=0}function uga(a){a=a|0;MP(a);v[a+4202|0]=1;x[a+4224>>2]=0}function s9(a,b,c){a=a|0;b=b|0;c=c|0;return Ed(D(b,c))|0}function og(a,b){var c=0;c=y[a|0];v[a|0]=y[b|0];v[b|0]=c}function gha(a){a=a|0;return B[wb(a+4208|0,3)>>2]<E(1)|0}function dL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ei(a,-1,-1)}function Zka(a,b,c){a=a|0;b=b|0;c=c|0;return Mb(a,b,c)|0}function YB(a,b){wc(a,b);wc(a+4|0,b+4|0);wc(Ab(a),Ab(b))}function WZ(a){a=a|0;x[a>>2]=125272;WH(a+4|0);return a|0}function Mh(a,b,c){v[a|0]=y[a|0]|b;x[a+4>>2]=x[a+4>>2]|c}function JS(a,b){a=IS(a,b);IS(a+12|0,b+12|0);v[a+24|0]=1}function GG(a,b){cl(x[b>>2]);rm(x[a>>2]);x[a>>2]=x[b>>2]}function G1(a,b,c){a=a|0;b=b|0;c=c|0;ax(a,b,x[b+8>>2],c)}function FD(a,b){v[x[a>>2]]=y[b|0];v[x[a+4>>2]]=y[b+1|0]}function Ega(a){a=a|0;return B[wb(a+4208|0,1)>>2]<E(1)|0}function Efa(a,b){a=a|0;b=b|0;return IH(a,b,6452,1007)|0}function Bt(a){a=a|0;x[a>>2]=77612;dc(a+12|0);return a|0}function BB(a,b){C[a>>3]=C[a>>3]*b;C[a+8>>3]=C[a+8>>3]*b}function $w(a){a=a|0;x[a>>2]=125292;WH(a+4|0);return a|0}function zka(a,b,c){a=a|0;b=b|0;c=c|0;HG(a,b,c,841,840)}function yT(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){Db(b)}}function vD(a){a=a&255;return zd(a)^1|(a-49&255)>>>0<36}function tka(a,b,c){a=a|0;b=b|0;c=c|0;MH(a,b,c,845,846)}function oja(a,b,c){a=a|0;b=b|0;c=c|0;HG(a,b,c,917,916)}function lt(a){a=a|0;x[a>>2]=93816;Zb(a+4|0);return a|0}function hR(a){return(a|0)==1179012417|(a|0)==538987841}function fM(a){a=a|0;x[a>>2]=78076;dc(a+4|0);return a|0}function eK(a,b,c){a=zb(a,b);zb(a+4|0,x[c>>2]);return a}function dg(a,b,c,d,e){return Na(a|0,b|0,c|0,d|0,e|0)|0}function dG(a){a=a|0;x[a>>2]=41808;he(a+4|0);return a|0}function bda(a,b,c){a=a|0;b=b|0;c=c|0;Bz(x[a+4>>2],b,c)}function WH(a){a=On(x[a>>2]);if((Yw(a+8|0)|0)<0){Db(a)}}function Qj(a,b,c){x[a>>2]=b;x[a+4>>2]=x[c>>2];return a}function OL(a,b,c){x[a+4>>2]=0;x[a>>2]=b;x[a+8>>2]=c<<3}function OI(a){var b=0;b=x[a>>2];x[a>>2]=0;if(b){rm(b)}}function Nb(a){x[a>>2]=0;x[a+4>>2]=0;rc(a+8|0);return a}function Kn(a){var b=0;b=x[a+8>>2];x[a+8>>2]=0;return b}function Ht(a){a=a|0;x[a>>2]=48940;oz(a+4|0);return a|0}function Hd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function Gl(a,b){b=(b<<1)+124064|0;return Qi(b,b+2|0,a)}function CO(a){return Gu(x[a+484344>>2],x[a+484348>>2])}function Bca(a,b,c){a=a|0;b=b|0;c=c|0;FO(a,x[b+4>>2],c)}function $n(a){a=a|0;x[a>>2]=93752;Zb(a+4|0);return a|0}function td(a,b){a=kG(a,b-1|0);x[a>>2]=113960;return a}function rna(a,b){a=a|0;b=b|0;if(!kX(a,b)){Tb(b,0,40)}}function qra(a,b){a=a|0;b=b|0;return Cc(a,b?b:22485)|0}function pha(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4228|0,7)}function ph(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+20>>2]](a,b)}function nua(a,b){a=a|0;b=b|0;Gh(a,b,263,1025,-1284,2)}function lR(a,b){return D(b&65535,a&65535)+7>>>3&65535}function jca(a,b){a=a|0;b=b|0;return zO(x[a+4>>2],b)|0}function ii(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+24>>2]](a,b)}function iaa(a,b){a=a|0;b=b|0;rT(x[a>>2],b);return a|0}function hna(a,b){a=a|0;b=b|0;Gh(a,b,590,1058,-1332,3)}function hi(a,b){a=a|0;b=b|0;ib[x[x[b>>2]+28>>2]](a,b)}function h8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;pi(a,c,d)}function eia(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4260|0,8)}function e8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Xn(a,c,d)}function cz(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function ada(a,b){a=a|0;b=b|0;cO(x[x[a+4>>2]+24>>2],b)}function aL(a){a=a|0;return nt(x[x[a>>2]-12>>2]+a|0)|0}function Z5(){td(502232,1);MI(502240);x[125558]=117488}function Yja(a){a=a|0;Cj(127172);Cj(127164);tb(127152)}function Xra(a,b){a=a|0;b=b|0;Gh(a,b,419,1042,-1332,2)}function Xb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function XK(a){a=a|0;return mt(x[x[a>>2]-12>>2]+a|0)|0}function U6(a,b){a=a|0;b=b|0;gc(a,PK(x[b>>2]),x[b>>2])}function Pta(a,b){a=a|0;b=b|0;Gh(a,b,298,1058,-1332,2)}function Lh(a){var b=0;b=xt(a);x[a+1396>>2]=0;return b}function J8(a){a=a|0;return Yp(x[x[a>>2]-12>>2]+a|0)|0}function H8(a){a=a|0;return Af(x[x[a>>2]-12>>2]+a|0)|0}function Goa(a,b){a=a|0;b=b|0;Gh(a,b,263,1042,-1332,2)}function GT(a,b){return(a|0)!=(b|0)?a>>>0<b>>>0?-1:1:0}function Am(a,b){x[a+16>>2]=!x[a+24>>2]|(x[a+16>>2]|b)}function $p(a){return y[a+2|0]&2?(y[a+1|0]&6)==6?4:1:0}function $5(){td(502216,1);MI(502224);x[125554]=117332}function yra(a,b){a=a|0;b=b|0;Gh(a,b,82,1042,-1332,2)}function yca(a){a=a|0;return LO(x[x[a+4>>2]+24>>2])|0}function xca(a){a=a|0;return fq(x[x[a+4>>2]+24>>2])|0}function wqa(a,b,c){a=a|0;b=b|0;c=c|0;Yc(a,v$(c,0,b))}function wN(a,b){hb=0-(((a|0)!=0)+b|0)|0;return 0-a|0}function uca(a){a=a|0;return Nf(x[x[a+4>>2]+24>>2])|0}function uc(a,b){a=a|0;b=b|0;GF(a,b,Or(b));return a|0}function tv(a,b){a=a|0;b=b|0;Gh(a,b,591,1058,-1332,2)}function tca(a){a=a|0;return CO(x[x[a+4>>2]+24>>2])|0}function tb(a){if(Cd(y[a+11|0])){Db(x[a>>2])}return a}function sda(a,b){a=a|0;b=b|0;Gh(a,b,13,1025,-1284,2)}function rj(a){a=a|0;return ib[x[x[a>>2]+16>>2]](a)|0}function qj(a){a=a|0;return ib[x[x[a>>2]+12>>2]](a)|0}function qca(a){a=a|0;return vO(x[x[a+4>>2]+24>>2])|0}function nca(a){a=a|0;return OO(x[x[a+4>>2]+24>>2])|0}function mda(a,b){a=a|0;b=b|0;Gh(a,b,82,1025,-1284,2)}function mca(a){a=a|0;return KO(x[x[a+4>>2]+24>>2])|0}function lca(a){a=a|0;return JO(x[x[a+4>>2]+24>>2])|0}function lQ(a){sc(a+36|0);sc(a+24|0);Yt(a+12|0);Yt(a)}function jl(a,b){return ib[x[x[a>>2]+36>>2]](a,b,0)|0}function hh(a){a=a|0;return ib[x[x[a>>2]+24>>2]](a)|0}function hf(a,b,c,d){v[a+8|0]=d;x[a+4>>2]=c;x[a>>2]=b}function eca(a){a=a|0;return gq(x[x[a+4>>2]+24>>2])|0}function dR(a,b){return(b>>>0>15?63:y[a+b|0])<<24>>24}function cT(a,b,c,d){return dd(zo(a,b,c,d,0)-32768|0)}function cR(a,b){return(b>>>0>46?63:y[a+b|0])<<24>>24}function bg(a,b,c,d){b=b+d|0;hb=a+c>>>0<c>>>0?b+1|0:b}function bK(a,b,c){a=gK(a,b,c,0,-2147483648);return a}function Zr(a,b){a=ic(a,b);Tb(a+20|0,0,1040);return a}function ZA(a){tq(a+223860|0);dc(a+223848|0);return a}function Xca(a,b){a=a|0;b=b|0;Gh(a,b,83,1025,-1284,2)}function Uba(a){a=a|0;return MO(x[x[a+4>>2]+24>>2])|0}function Rl(a,b){return y[a|0]<<24>>24<y[b|0]<<24>>24}function Q1(a,b,c){a=a|0;b=b|0;c=c|0;MH(a,b,c,77,150)}function OD(a,b){a=Fe(a,b);Tb(a+20|0,0,1040);return a}function O3(a,b){a=a|0;b=b|0;return lI(b,x[a+8>>2])|0}function Mha(a){a=a|0;v[a+4202|0]=1;Zt(a);Qz(a);mQ(a)}function MC(a,b){a=a|0;b=b|0;Gh(a,b,590,1058,-1332,2)}function Cda(a,b){a=a|0;b=b|0;Gh(a,b,82,1025,-1284,4)}function Cc(a,b){a=a|0;b=b|0;mu(a,b,gf(b));return a|0}function C3(a,b){a=a|0;b=b|0;return lK(b&255)<<24>>24}function Aca(a){a=a|0;return DO(x[x[a+4>>2]+24>>2])|0}function A3(a,b){a=a|0;b=b|0;return kK(b&255)<<24>>24}function yr(a,b,c){if(b){XO(a+36|0,b,Ii(b,b+c|0,0))}}function xs(a,b,c,d,e,f){Ka(a|0,b|0,c|0,d|0,e|0,f|0)}function wJ(a,b,c,d){return Gp(a,b,c,d,24,178956971)}function vba(a,b,c){a=a|0;b=b|0;c=c|0;iN(a-88|0,b,c)}function ue(a,b){gc(a,Jb(b),Bb(x[b+4>>2],y[b+11|0]))}function uQ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function tba(a,b,c){a=a|0;b=b|0;c=c|0;gN(a-88|0,b,c)}function rua(a){if(a){return 31-G(a-1^a)|0}return 32}function o$(a,b,c,d){return Gp(a,b,c,d,28,153391690)}function nX(a){var b=0;a=a+8|0;hb=a>>>0<8|b;return a}function kG(a,b){x[a+4>>2]=b;x[a>>2]=124744;return a}function jr(a,b,c,d,e){gc(a,b+d|0,(e|0)==-1?c-d|0:e)}function hda(a){a=a|0;return Jz(x[a>>2],x[a+4>>2])|0}function fu(a){a=a|0;a=_h(a);x[a+20>>2]=0;return a|0}function fha(a){a=a|0;return E(B[wb(a+4208|0,1)>>2])}function bm(a){a=(a|0)>=120?120:a;return(a|0)<=1?1:a}function ae(a,b,c){v[a|0]=b;v[a+1|0]=y[c|0];return a}function XF(a,b,c,d){return Gp(a,b,c,d,36,119304648)}function Un(a,b,c,d){return(a|0)==(c|0)&(b|0)==(d|0)}function SB(a){a=Nb(a);x[a+12>>2]=0;w[a+16>>1]=65280}function Ow(a){a=a|0;return ib[x[x[a>>2]+8>>2]](a)|0}function O_(a,b,c,d){return Gp(a,b,c,d,40,107374183)}function I4(a,b){a=a|0;b=b|0;Gh(a,b,13,1058,-1332,2)}function Dga(a){a=a|0;return E(B[wb(a+4208|0,3)>>2])}function CF(a,b){return(y[b+34|0]&8)>>>3&(a&2050)==2}function xba(a,b,c){a=a|0;b=b|0;c=+c;kN(a-88|0,b,c)}function wT(a,b,c,d){return Gp(a,b,c,d,7,613566757)}function w2(a){a=a|0;a=ib[a|0]()|0;gb=hb;return a|0}function v9(a,b,c){a=a|0;b=b|0;c=c|0;ns(a,b,c,1171)}function uba(a,b){a=a|0;b=b|0;return hN(a-88|0,b)|0}function uN(a){a=a|0;a=x[a+4>>2];return(a?a:5031)|0}function spa(a,b){a=a|0;b=b|0;return bi(a,b,1030)|0}function sba(a,b){a=a|0;b=b|0;return fN(a-88|0,b)|0}function qF(a){return oL(a,E(2524354896707238e-44))}function op(a,b,c){gc(a,(c>>>3&536870908)+b|0,c&31)}function om(a){a=a|0;a=Ac(a);ib[x[x[a>>2]>>2]](a)|0}function lo(a,b,c){x[a>>2]=b;x[a+4>>2]=c-b;return a}function lba(a,b,c){a=a|0;b=b|0;c=+c;$M(a-92|0,b,c)}function jpa(a,b){a=a|0;b=b|0;return ux(a,b,1100)|0}function jba(a,b,c){a=a|0;b=b|0;c=+c;ZM(a-92|0,b,c)}function ix(a,b){a=a|0;b=b|0;return WR(a,b,Or(b))|0}function ie(a){var b=0;b=x[a>>2];x[a>>2]=0;return b}function gua(a,b,c){a=a|0;b=b|0;c=c|0;Jp(a,b,c,264)}function gca(a){a=a|0;return+IO(x[x[a+4>>2]+24>>2])}function g1(a,b){a=a|0;b=b|0;return dF(a,b,gf(b))|0}function fsa(a,b,c){a=a|0;b=b|0;c=c|0;IZ(a,c,b,0,0)}function csa(a,b){a=a|0;b=b|0;return ls(a,b,1189)|0}function aU(a,b){x[a+8>>2]=0;x[a+12>>2]=0;C[a>>3]=b}function _P(a){a=a|0;return E(B[wb(a+4208|0,0)>>2])}function Zba(a){a=a|0;return+CA(x[x[a+4>>2]+24>>2])}function Yta(a,b){a=a|0;b=b|0;sx(a,b,263,274,-1332)}function Xpa(a,b,c){a=a|0;b=b|0;c=c|0;ns(a,b,c,598)}function Wra(a,b,c){a=a|0;b=b|0;c=c|0;Jp(a,b,c,420)}function Wpa(a,b,c){a=a|0;b=b|0;c=c|0;ns(a,b,c,599)}function Tp(a,b,c){if(!c){return 0}return Ob(a,b,c)}function Spa(a,b,c){a=a|0;b=b|0;c=c|0;WG(a,b,c,506)}function Qpa(a,b,c){a=a|0;b=b|0;c=c|0;bH(a,b,c,306)}function Ppa(a,b,c){a=a|0;b=b|0;c=c|0;JG(a,b,c,306)}function Oj(a){if(!a){return 0}return x[a+44>>2]!=0}function Noa(a,b){a=a|0;b=b|0;return ls(a,b,1185)|0}function MA(a,b){x[a>>2]=b;x[a+4>>2]=b>>31;return a}function Kta(a,b,c){a=a|0;b=b|0;c=c|0;ns(a,b,c,301)}function Iaa(a,b){a=a|0;b=b|0;return ls(a,b,1188)|0}function Hta(a,b,c){a=a|0;b=b|0;c=c|0;TG(a,b,c,306)}function Hna(a,b,c){a=a|0;b=b|0;c=c|0;Yc(a,ix(b,c))}function HF(a){return oL(a,E(15845632502852868e13))}function Gj(a){if(!a){return 0}return Nj(y[a+31|0])}function DF(a,b,c){gc(a,(c>>>3&536870908)+b|0,1<<c)}function Aqa(a,b,c){a=a|0;b=b|0;c=c|0;XG(a,b,c,256)}function $ca(a,b){a=a|0;b=+b;return+dO(x[a+4>>2],b)}function $B(a){v[a+6|0]=0;w[a+4>>1]=65535;x[a>>2]=0}function rqa(a,b){a=a|0;b=b|0;return bi(a,b,422)|0}function nsa(a,b){a=a|0;b=b|0;return bi(a,b,308)|0}function mqa(a,b){a=a|0;b=b|0;return bi(a,b,826)|0}function lja(a,b){a=a|0;b=b|0;return bi(a,b,225)|0}function jga(a,b){a=a|0;b=b|0;return E(wm(a,b,12))}function j2(a,b){a=a|0;b=b|0;return ls(a,b,1187)|0}function ija(a,b){a=a|0;b=b|0;return bi(a,b,326)|0}function iY(a,b,c){a=a|0;b=b|0;c=c|0;Yc(a,Ny(b,c))}function iG(a,b,c){a=a|0;b=b|0;c=c|0;Yc(a,Mw(b,c))}function gG(a,b){a=fG(a,b);x[a>>2]=125552;return a}function fua(a,b,c){a=a|0;b=b|0;c=c|0;bH(a,b,c,48)}function cta(a,b){a=a|0;b=b|0;return SG(a,b,348)|0}function cba(a){a=a|0;x[a>>2]=48720;return Ot(a)|0}function bJ(a,b){a=td(a,b);x[a>>2]=115316;return a}function aJ(a,b){a=td(a,b);x[a>>2]=115348;return a}function _k(a,b){return(a&65535)>>>0<(b&65535)>>>0}function _I(a,b){a=td(a,b);x[a>>2]=114016;return a}function Xv(a,b,c){a=a|0;b=b|0;c=c|0;WG(a,b,c,126)}function XI(a,b){a=td(a,b);x[a>>2]=117848;return a}function Wm(a){Fj(a+724|0);Fj(a+732|0);Fj(a+740|0)}function WI(a,b){a=td(a,b);x[a>>2]=117996;return a}function VI(a,b){a=td(a,b);x[a>>2]=118112;return a}function UI(a,b){a=td(a,b);x[a>>2]=118228;return a}function Sy(a){if(!a){return 0}x[31660]=a;return-1}function RI(a,b){a=td(a,b);x[a>>2]=119416;return a}function QI(a,b){a=td(a,b);x[a>>2]=119536;return a}function Mca(a,b,c){a=a|0;b=b|0;c=c|0;Jp(a,b,c,84)}function Lba(a,b,c){a=a|0;b=b|0;c=c|0;JG(a,b,c,48)}function Fca(a,b,c){a=a|0;b=b|0;c=c|0;Jp(a,b,c,85)}function Bna(a,b,c){a=a|0;b=b|0;c=c|0;TG(a,b,c,48)}function yY(a){return(x[Ab(a)>>2]-x[a>>2]|0)/33|0}function yK(a){return(Kh(a)|0)!=0|(a|32)-97>>>0<6}function wga(a,b){a=a|0;b=b|0;return E(wm(a,b,1))}function wba(a,b){a=a|0;b=b|0;return+jN(a-88|0,b)}function usa(a,b){a=a|0;b=b|0;if(!BZ(a,b)){AZ(b)}}function uq(a,b){x[a+4>>2]=256;x[a>>2]=b;return a}function uja(a,b){a=a|0;b=b|0;if(!TF(a,b)){gx(b)}}function tsa(a,b){a=a|0;b=b|0;return bi(a,b,78)|0}function te(a,b,c){x[a>>2]=b;x[a+4>>2]=c;return a}function tZ(a){if(!(a&255)){return 1}return zd(a)}function qh(a,b){a=a|0;b=b|0;return ZK(a)^ZK(b)^1}function nja(a,b){a=a|0;b=b|0;return bi(a,b,73)|0}function nZ(a,b){a=a|0;b=b|0;return SG(a,b,325)|0}function kha(a,b){a=a|0;b=b|0;return E(wm(a,b,6))}function kba(a,b){a=a|0;b=b|0;return+_M(a-92|0,b)}function ju(a){return(x[Ab(a)>>2]-x[a>>2]|0)/52|0}function jqa(a,b){a=a|0;b=b|0;return bi(a,b,41)|0}function ji(a,b){a=a|0;b=b|0;return QK(a)^QK(b)^1}function iba(a,b){a=a|0;b=b|0;return+YM(a-92|0,b)}function iR(a,b){return(a|0)==1179011410&b>>>0>80}function i1(a,b){a=a|0;b=b|0;sx(a,b,13,257,-1284)}function gc(a,b,c){x[a+4>>2]=c;x[a>>2]=b;return a}function fja(a,b){a=a|0;b=b|0;return bi(a,b,60)|0}function el(a){return(x[Ab(a)>>2]-x[a>>2]|0)/12|0}function cga(a,b){a=a|0;b=b|0;return E(wm(a,b,2))}function Zs(a){return a-48>>>0<10|(a|32)-97>>>0<6}function Zm(a,b,c){x[a+4>>2]=c;w[a>>1]=b;return a}function Zga(a,b){a=a|0;b=b|0;return E(wm(a,b,5))}function Xfa(a,b){a=a|0;b=b|0;return E(wm(a,b,3))}function XW(a){return(x[Ab(a)>>2]-x[a>>2]|0)/56|0}function XN(a){x[a+4>>2]=0;x[a>>2]=47892;return a}function WE(a){return!Ob(a,24768,25)&y[a+34|0]<65}function UH(a){return(a<<1)+16777216>>>0<16777217}function Tw(a){return(x[Ab(a)>>2]-x[a>>2]|0)/36|0}function Tqa(a,b){a=a|0;b=b|0;return bi(a,b,91)|0}function Sga(a,b){a=a|0;b=b|0;return E(wm(a,b,4))}function R4(a,b){a=a|0;b=b|0;sx(a,b,13,290,-1332)}function Oqa(a,b){a=a|0;b=b|0;if(!BY(a,b)){AY(b)}}function Ml(a,b,c){C[a+8>>3]=c;C[a>>3]=b;return a}function L_(a){return(x[Ab(a)>>2]-x[a>>2]|0)/40|0}function Ks(a){return(x[Ab(a)>>2]-x[a>>2]|0)/24|0}function H0(a,b,c){a=a|0;b=b|0;c=c|0;Jp(a,b,c,18)}function DE(a){return(x[Ab(a)>>2]-x[a>>2]|0)/20|0}function Bpa(a,b){a=a|0;b=b|0;if(!gE(a,b)){lE(b)}}function $oa(a,b){a=a|0;b=b|0;return bi(a,b,71)|0}function $D(a){return(x[Ab(a)>>2]-x[a>>2]|0)/28|0}function yda(a){a=a|0;return xH(a,47832,12610)|0}function uB(a){return(x[Ab(a)>>2]-x[a>>2]|0)/7|0}function tM(a,b){a=a|0;b=b|0;fl(a,b,74696,74704)}function sz(a,b){x[a>>2]=x[b>>2];Yc(a+4|0,b+4|0)}function sQ(a){a=a|0;dc(a+4208|0);return Uf(a)|0}function sM(a,b){a=a|0;b=b|0;fl(a,b,74712,74720)}function qw(a,b){a=a|0;b=b|0;if(!Xw(a,b)){Ww(b)}}function pM(a,b){a=a|0;b=b|0;fl(a,b,75516,75524)}function oM(a,b){a=a|0;b=b|0;fl(a,b,75532,75540)}function nM(a,b){a=a|0;b=b|0;fl(a,b,76344,76352)}function mM(a,b){a=a|0;b=b|0;fl(a,b,76360,76368)}function jM(a,b){a=a|0;b=b|0;fl(a,b,77172,77180)}function iM(a,b){a=a|0;b=b|0;fl(a,b,77188,77196)}function hw(a,b){a=a|0;b=b|0;if(!tp(a,b)){ip(b)}}function gd(a,b,c,d){return Vc(a,D(Nf(b),c)+d|0)}function e0(a,b){a=a|0;b=b|0;if(!_$(a,b)){nE(b)}}function di(a,b,c){return Fa(1019,a|0,b|0,c|0)|0}function d_(a,b){x[a>>2]=x[a>>2]+D(b,6);return a}function cx(a){x[a>>2]=0;x[a+4>>2]=0;x[a+8>>2]=0}function c$(a,b){a=J_(a,b);if(!a){WD(b)}return a}function bu(a){a=a|0;sc(a+4208|0);return Uf(a)|0}function ap(a,b){a=a|0;b=b|0;if(!Zh(a,b)){bl(b)}}function Yl(a,b,c){v[a+2|0]=c;w[a>>1]=b;return a}function VP(a){a=a|0;sc(a+4256|0);return Uf(a)|0}function Tv(a){return(x[Ab(a)>>2]-x[a>>2]|0)/6|0}function TC(a,b){a=a|0;b=b|0;if(!NY(a,b)){ZC(b)}}function SD(a,b){a=a|0;b=b|0;if(!W_(a,b)){or(b)}}function RE(a,b){a=ME(a,b);if(!a){vn(b)}return a}function LZ(a,b){a=a|0;b=b|0;if(!KF(a,b)){Pr(b)}}function Jn(a,b,c){a=Jd(a);x[a+4>>2]=c;x[a>>2]=b}function HB(a){x[a+24>>2]=z[a+20>>1]<<z[a+22>>1]}function F_(a,b){a=a|0;b=b|0;if(!E_(a,b)){Sv(b)}}function EU(a,b){x[a>>2]=x[a>>2]+(b<<1);return a}function CS(a,b,c){x[a+4>>2]=c;v[a|0]=b;return a}function y4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500528))}function wda(a){a=a|0;return xH(a,47852,8211)|0}function v4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500536))}function t4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500544))}function se(a,b){return _k(z[a>>1],z[b>>1])?b:a}function r4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500552))}function pd(a,b){return Iq(x[b>>2],x[a>>2])?b:a}function p4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500496))}function n4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500504))}function lpa(a,b){a=a|0;b=b|0;Ip(a,b,652,651,8)}function k4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500512))}function i4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500520))}function hua(a,b,c){a=a|0;b=b|0;c=c|0;Q$(a,b,c)}function hga(a){a=a|0;IP(a);Lz(a);v[a+4202|0]=1}function hea(a,b,c){a=a|0;b=b|0;c=c|0;nO(a,b,c)}function hL(a,b){if(!a){return 0}return Py(a,b)}function h4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500592))}function gB(a){if(y[a+24|0]){NS(a);v[a+24|0]=0}}function g4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500600))}function fL(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function aca(a){a=a|0;return+C[x[a+4>>2]+16>>3]}function _ta(a,b){a=a|0;b=b|0;Ip(a,b,300,299,8)}function _sa(a,b){a=a|0;b=b|0;Ip(a,b,365,364,8)}function _c(a,b){return Qq(x[a>>2],x[b>>2])?b:a}function Zn(a){return ib[x[x[a>>2]+28>>2]](a)|0}function ZX(a){var b=0;b=x[a>>2];je(a);return b}function Xga(a){a=a|0;v[a+4202|0]=1;SP(a);UP(a)}function X$(a,b){return(b&255)==2&(a&255)>>>0<3}function We(a,b){return Iq(x[a>>2],x[b>>2])?b:a}function Vqa(a,b){a=a|0;b=b|0;Ip(a,b,523,522,6)}function Voa(a,b){a=a|0;b=b|0;Ip(a,b,685,684,8)}function Vka(a,b,c){a=a|0;b=b|0;c=c|0;ce(a,b,c)}function Qga(a){a=a|0;v[a+4202|0]=1;QP(a);PP(a)}function Q4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500448))}function Pz(a,b){return Av(B[a>>2],B[b>>2])?b:a}function Pm(a,b){return Av(B[b>>2],B[a>>2])?b:a}function Paa(a,b){a=a|0;b=b|0;Yc(a,_N(b,18463))}function O4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500456))}function N4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500652))}function Mc(a,b){return _k(z[b>>1],z[a>>1])?b:a}function MI(a){var b=0,c=0;b=a,c=Kd(),x[b>>2]=c}function M4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500644))}function M0(a,b){a=a|0;b=b|0;Ep(a,b);return a|0}function L4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500660))}function Kk(a){return ib[x[x[a>>2]+36>>2]](a)|0}function J4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500668))}function H4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500676))}function Gb(a,b){return Qq(x[b>>2],x[a>>2])?b:a}function GY(a){return!Ob(a,13976,4)&y[a+4|0]<32}function G4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500692))}function F4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500684))}function E4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500700))}function Cv(a,b){a=a|0;b=b|0;return Mb(a,b,1)^1}function C4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500708))}function A4(a,b){a=a|0;b=b|0;Zc(a,b,Tc(500716))}function xda(a,b){a=a|0;b=b|0;return Mw(a,b)|0}function ws(a,b,c,d,e){Ea(a|0,b|0,c|0,d|0,e|0)}function ska(a,b){a=a|0;b=b|0;return Ny(a,b)|0}function ri(a,b){return(D(b,104)+a|0)+484380|0}function oea(a){a=a|0;return EH(a,6646,1071)|0}function lf(a,b){v[a+4|0]=1;x[a>>2]=b;return a}function lZ(a,b,c){a=a|0;b=b|0;c=c|0;Y$(a,b,c)}function kpa(a,b){a=a|0;b=b|0;return kX(a,b)|0}function km(a){return(a>>>0<=127?-1:a^128)&255}function jU(a){CB(a);Tb(a+27|0,0,255);return a}function h3(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,c,b)}function eE(a,b,c){a=a|0;b=b|0;c=c|0;z$(a,b,c)}function b$(a,b,c){a=a|0;b=b|0;c=c|0;$$(a,b,c)}function aP(a){x[a>>2]=0;x[a+4>>2]=-1;return a}function Zi(a,b){return y[a+b|0]!=63&b>>>0<=46}function Tia(a,b){a=a|0;b=b|0;DA(_Q(a+24|0,b))}function Rn(a,b,c,d,e){Oa(a|0,b|0,c|0,d|0,e|0)}function Om(a){a=Ij(a);x[a>>2]=125156;return a}function Lv(a,b){return y[a+b|0]!=63&b>>>0<=15}function Lu(a){return(a>>>0<9?a:a-9|256)&65535}function Kg(a,b){v[a+4|0]=0;x[a>>2]=b;return a}function J3(a,b,c){a=a|0;b=b|0;c=c|0;jI(a,b,c)}function J$(a){return!Ob(a,15692,4)&y[a+4|0]<4}function Gea(a){a=a|0;return EH(a,7129,1063)|0}function Ff(a,b,c){if(!(y[a|0]&32)){bE(b,c,a)}}function Dt(a,b){return(a&255)>>>0<(b&255)>>>0}function Cg(a,b,c){a=tua(a,b,c,c>>31);return a}function $ba(a){a=a|0;return x[x[a+4>>2]+8>>2]}function xi(a,b){if(x[a>>2]>(b|0)){x[a>>2]=b}}function x1(a){a=a|0;x[a>>2]=78792;return a|0}function wca(a,b){a=a|0;b=b|0;AO(a,x[b+4>>2])}function vt(a){a=zL(a);x[a>>2]=95048;return a}function vc(a,b){if(A[a>>2]>b>>>0){x[a>>2]=b}}function py(a,b,c){a=gK(a,b,c,-1,-1);return a}function pca(a,b){a=a|0;b=b|0;uO(a,x[b+4>>2])}function oca(a,b){a=a|0;b=b|0;VO(a,x[b+4>>2])}function n_(a){a=(a&65535)-98|0;hb=0;return a}function nW(a){return Xe(443250/+(a>>>0)*1e4)}function lP(a,b){a=a|0;b=b|0;return _N(a,b)|0}function l1(a){a=a|0;x[a>>2]=41672;return a|0}function ksa(a,b){a=a|0;b=b|0;vx(a,b,17,3,16)}function jJ(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function j1(a){a=a|0;x[a>>2]=41432;return a|0}function ica(a,b){a=a|0;b=b|0;yO(a,x[b+4>>2])}function hca(a,b){a=a|0;b=b|0;tO(a,x[b+4>>2])}function faa(a,b){a=a|0;b=b|0;qH(a,b,1161,52)}function dn(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function dda(a,b){a=a|0;b=b|0;Cz(x[a+4>>2],b)}function cca(a,b){a=a|0;b=b|0;GO(a,x[b+4>>2])}function caa(a){a=a|0;dM(a);return x[a+16>>2]}function b0(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function af(a,b){return Dt(y[a|0],y[b|0])?b:a}function Y9(a){a=a|0;x[a>>2]=77712;return a|0}function Xta(a,b){a=a|0;b=b|0;vx(a,b,44,2,44)}function Xt(a,b){a=a|0;b=b|0;return fg(a,b)|0}function X1(a,b){a=a|0;b=b|0;return ix(a,b)|0}function Wz(a){return x[Ab(a)>>2]-x[a>>2]>>11}function WK(a){a=a|0;Iy(x[x[a>>2]-12>>2]+a|0)}function Ub(a,b){return Dt(y[b|0],y[a|0])?b:a}function R9(a){a=a|0;x[a>>2]=77212;return a|0}function Qsa(a,b){a=a|0;b=b|0;ZG(a,b,369,368)}function Pf(a,b){if(z[a>>1]>b>>>0){w[a>>1]=b}}function P9(a,b){a=a|0;b=b|0;qH(a,b,1165,308)}function Ot(a){a=a|0;x[a>>2]=48700;return a|0}function NW(a){a=sua(a&65535,0,80,0);return a}function L9(a){a=a|0;x[a>>2]=78520;return a|0}function Jd(a){x[a>>2]=0;x[a+4>>2]=0;return a}function I8(a){a=a|0;MK(x[x[a>>2]-12>>2]+a|0)}function G9(a){a=a|0;x[a>>2]=78132;return a|0}function G8(a){a=a|0;LK(x[x[a>>2]-12>>2]+a|0)}function Eta(a,b){a=a|0;b=b|0;ZG(a,b,309,308)}function CK(a){a=zL(a);x[a>>2]=95440;return a}function $_(a){v[a+12|0]=y[a+12|0]|2;return a}function $K(a){a=a|0;Ky(x[x[a>>2]-12>>2]+a|0)}function z6(a){a=a|0;Zc(a,501944,Tc(500456))}function y6(a){a=a|0;Zc(a,501952,Tc(500652))}function x6(a){a=a|0;Zc(a,501968,Tc(500644))}function wp(a,b,c,d){a=tua(a,b,c,d);return a}function w6(a){a=a|0;Zc(a,501976,Tc(500660))}function uk(a){a=a&255;return(a|0)==255?-1:a}function u6(a){a=a|0;Zc(a,501984,Tc(500668))}function sca(a){a=a|0;return BO(x[a+4>>2])|0}function s6(a){a=a|0;Zc(a,502008,Tc(500692))}function r6(a){a=a|0;Zc(a,502016,Tc(500684))}function q6(a){a=a|0;Zc(a,502024,Tc(500700))}function p6(a){a=a|0;Zc(a,502032,Tc(500708))}function o9(a){a=a|0;return Ba(x[a+60>>2])|0}function o6(a){a=a|0;Zc(a,502056,Tc(500716))}function n6(a){a=a|0;Zc(a,502088,Tc(500464))}function m6(a){a=a|0;Zc(a,502096,Tc(500472))}function l6(a){a=a|0;Zc(a,502104,Tc(500480))}function k6(a){a=a|0;Zc(a,502112,Tc(500488))}function j6(a){a=a|0;Zc(a,502120,Tc(500528))}function i6(a){a=a|0;Zc(a,502128,Tc(500536))}function hY(a,b,c){w[a>>1]=b;v[a+2|0]=y[c|0]}function h6(a){a=a|0;Zc(a,502136,Tc(500544))}function g6(a){a=a|0;Zc(a,502144,Tc(500552))}function fca(a){a=a|0;return NO(x[a+4>>2])|0}function f6(a){a=a|0;Zc(a,502152,Tc(500560))}function e6(a){a=a|0;Zc(a,502160,Tc(500568))}function daa(a){a=a|0;dM(a);return x[a+4>>2]}function d6(a){a=a|0;Zc(a,502168,Tc(500576))}function c6(a){a=a|0;Zc(a,502176,Tc(500584))}function b6(a){a=a|0;Zc(a,502184,Tc(500496))}function a6(a){a=a|0;Zc(a,502200,Tc(500504))}function _B(a){return x[Ab(a)>>2]-x[a>>2]>>8}function _5(a){a=a|0;Zc(a,502216,Tc(500512))}function Y5(a){a=a|0;Zc(a,502232,Tc(500520))}function XY(a,b,c){gc(a,b,Ii(b,b+c|0,0)-b|0)}function XA(a){v[a+24|0]=0;v[a|0]=0;return a}function X5(a){a=a|0;Zc(a,502248,Tc(500592))}function W5(a){a=a|0;Zc(a,502256,Tc(500600))}function Ve(a,b,c,d){bc(a,gd(b,c,d,0),Nf(c))}function Sz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function Su(a){return x[Ab(a)>>2]-x[a>>2]>>4}function Sq(a,b){return D((b-a|0)/6|0,6)+a|0}function Rg(a){return x[Ab(a)>>2]-x[a>>2]>>2}function Qh(a){return x[x[a+8>>2]>>2]==(a|0)}function Po(a){return x[Ab(a)>>2]-x[a>>2]>>5}function Mz(a){return E(E(a*E(7900))+E(100))}function Ln(a){return x[Ab(a)>>2]-x[a>>2]>>3}function Kz(a){return x[Ac(a)>>2]-x[a>>2]>>2}function Bn(a){return x[Ab(a)>>2]-x[a>>2]>>1}function Bk(a){return LG(a,E(4294967296),-1)}function Bb(a,b){if(!Cd(b)){a=Sh(b)}return a}function A6(a){a=a|0;Zc(a,501936,Tc(500448))}function $H(a,b,c){a=a|0;b=b|0;c=c|0;KK(a,c)}function tn(a,b,c){return pg(a,b)>>>0>c>>>0}function t6(a){a=a|0;Zc(a,502e3,Tc(500676))}function sy(){da(Om(ac(4))|0,125240,34);p()}function qB(a){v[a+4|0]=0;v[a|0]=0;return a}function iia(a,b){a=a|0;b=b|0;v[a+4201|0]=b}function hU(a,b){x[a>>2]=x[a>>2]+b;return a}function au(a){a=a|0;ib[x[x[a>>2]+4>>2]](a)}function ao(a){a=a|0;PK(x[a>>2]);return a|0}function Vo(a,b){w[a>>1]=b;w[a+2>>1]=b>>>16}function S3(a,b){a=a|0;b=b|0;return vy(b)|0}function Qo(a){return x[Ab(a)>>2]-x[a>>2]|0}function Ql(a,b){return Jq(z[a>>1],z[b>>1])}function Q3(a,b){a=a|0;b=b|0;return wy(b)|0}function Ki(a,b){a=a|0;b=b|0;return E(E(0))}function Jq(a,b){return a<<16>>16<b<<16>>16}function JO(a){return A[a+1074420>>2]/1e4|0}function If(a,b){if(y[a|0]>b>>>0){v[a|0]=b}}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;Jd(a)}function Ew(a,b){if(b){Cc(a,b);return}Fb(a)}function Bm(a){a=a|0;Jy(x[a>>2]);return a|0}function zt(a){return(a|0)<=65535&(a|0)>=0}function xU(a){x[a>>2]=x[a>>2]-32;return a}function tz(a){x[a>>2]=x[a>>2]-16;return a}function ty(a){a=a|0;return Th(a,500708)|0}function tm(a){x[a>>2]=x[a>>2]-12;return a}function sf(a,b,c){a=sua(c,0,a,b);return a}function rn(a){x[a>>2]=x[a>>2]+28;return a}function qoa(a,b){a=a|0;b=b|0;VG(a,b,2,31)}function qba(a,b){a=a|0;b=b|0;cN(a-88|0,b)}function p_(a){x[a>>2]=x[a>>2]-20;return a}function oL(a,b){return E(nx(a?E(-b):b)*b)}function nv(a){x[a>>2]=x[a>>2]+52;return a}function nba(a,b){a=a|0;b=b|0;bN(a-92|0,b)}function my(a){a=a|0;return Th(a,500716)|0}function mba(a,b){a=a|0;b=b|0;aN(a-92|0,b)}function lw(a){a=a|0;return Th(a,500652)|0}function lD(a){a=a|0;return Th(a,500668)|0}function iv(a){$e(a+24|0);dc(a+12|0);dc(a)}function il(a,b){ib[x[x[b>>2]+44>>2]](a,b)}function id(a,b){a=a|0;b=b|0;nO(a,b,gf(b))}function hn(a){QB(x[a+20>>2]);x[a+20>>2]=0}function hl(a,b){ib[x[x[b>>2]+32>>2]](a,b)}function gI(a){a=a|0;return hH(a,118656)|0}function fI(a){a=a|0;return hH(a,118552)|0}function eI(a){a=a|0;return gH(a,118448)|0}function dca(a){a=a|0;return+HO(x[a+4>>2])}function dI(a){a=a|0;return gH(a,118344)|0}function c9(a){a=a|0;return Th(a,500464)|0}function b4(a){a=a|0;os(a,165,125600,1195)}function av(a){x[a>>2]=x[a>>2]+32;return a}function Yn(a){a=a|0;os(a,165,125600,1060)}function Xf(a){x[a>>2]=x[a>>2]+20;return a}function X8(a){a=a|0;return Th(a,500480)|0}function VW(a){x[a>>2]=x[a>>2]-56;return a}function VQ(a){x[a>>2]=x[a>>2]-52;return a}function VF(a){x[a>>2]=x[a>>2]-36;return a}function Uq(a){x[a>>2]=x[a>>2]+12;return a}function UV(a,b,c,d){gc(a,b,(d|0)==-1?c:d)}function Rta(a,b){a=a|0;b=b|0;fw(a+36|0,b)}function Rr(a){_r(a+32|0);ub(a+12|0);tb(a)}function Mja(a,b){a=a|0;b=b|0;bs(a+40|0,b)}function Ls(a,b){ib[x[x[b>>2]+40>>2]](a,b)}function Kq(a){x[a>>2]=x[a>>2]+16;return a}function Gy(a){a=a|0;return Th(a,500644)|0}function Fg(a){return E(F(a))==E(Infinity)}function Fba(a,b){a=a|0;b=b|0;tN(a-88|0,b)}function Eba(a,b){a=a|0;b=b|0;sN(a-88|0,b)}function ES(a,b){return eH(a,b,2147483647)}function Dy(a){a=a|0;return Th(a,500660)|0}function Dl(a){tb(a+36|0);sc(a+24|0);Nk(a)}function D1(a){a=a|0;return x[a+4>>2]!=0|0}function BP(a){return E(E(a*E(96))+E(-96))}function $v(a){x[a>>2]=x[a>>2]-28;return a}function zba(a,b){a=a|0;b=+b;mN(a-88|0,b)}function zJ(a,b){a=a|0;b=b|0;Rp(a,b+52|0)}function yg(a,b,c){Qi(b,b+c|0,a);return a}function y9(a,b){a=a|0;b=b|0;nm(a,b+12|0)}function vq(a,b){v[a|0]=b+48;return a+1|0}function vpa(a,b){a=a|0;b=b|0;Ai(a,b,106)}function ve(a){return Cb(a&65535)<<16>>16}function rta(a,b){a=a|0;b=b|0;VG(a,b,3,8)}function rl(a){a=a|0;return _K(a)<<24>>24}function r5(a,b){a=a|0;b=b|0;ln(a,113624)}function qha(a){a=a|0;v[a+4202|0]=1;eQ(a)}function q5(a,b){a=a|0;b=b|0;ln(a,113644)}function pba(a){a=a|0;return cq(a-92|0)|0}function nt(a){a=a|0;sl(a+8|0);return a|0}function nga(a){a=a|0;return x[a+4260>>2]}function nB(a,b){if(B[a>>2]>b){B[a>>2]=b}}function mt(a){a=a|0;sl(a+4|0);return a|0}function ks(a,b){x[a>>2]=b;cl(b);return a}function je(a){x[a>>2]=x[a>>2]+1;return a}function isa(a,b){a=a|0;b=b|0;Ai(a,b,282)}function hba(a){a=a|0;return cq(a-96|0)|0}function gz(a,b,c){gc(a,(c<<12)+b|0,4096)}function fz(a,b){a=a|0;b=b|0;fg(a,b+36|0)}function fba(a,b){a=a|0;b=+b;XM(a-96|0,b)}function dy(a,b){a=a|0;b=b|0;fg(a,b+12|0)}function cq(a){a=a|0;hq(a+8|0);return a|0}function by(a,b){a=a|0;b=b|0;fg(a,b+16|0)}function bN(a,b){a=a|0;b=b|0;uH(a,b,2048)}function aw(a){x[a>>2]=x[a>>2]-2;return a}function ah(a){x[a>>2]=x[a>>2]+6;return a}function aN(a,b){a=a|0;b=b|0;uH(a,b,4096)}function Wd(a){x[a>>2]=x[a>>2]+2;return a}function Tg(a,b,c){Gk(b,b+c|0,a);return a}function Rm(a){return E(F(a))<E(Infinity)}function Pe(a){x[a>>2]=x[a>>2]+4;return a}function NH(a){a=Da(a|0)|0;hb=gb;return a}function Mu(a){Mm(a,Lo(a),79024);return a}function Mta(a,b){a=a|0;b=b|0;Ai(a,b,136)}function Kf(a){a=a|0;_h(a+8|0);return a|0}function Iba(a){a=a|0;return cq(a-88|0)|0}function IO(a){return+A[a+1074420>>2]/1e4}function Hu(a){x[a>>2]=x[a>>2]+8;return a}function GJ(a,b){a=a|0;b=b|0;fg(a,b+24|0)}function FJ(a,b){a=a|0;b=b|0;fg(a,b+48|0)}function EQ(a){x[a>>2]=x[a>>2]-4;return a}function Dba(a,b){a=a|0;b=+b;rN(a-88|0,b)}function CP(a){a=a|0;Tb(a+4296|0,0,81928)}function Bba(a,b){a=a|0;b=+b;oN(a-88|0,b)}function BJ(a,b){a=a|0;b=b|0;Rp(a,b+28|0)}function Apa(a,b){a=a|0;b=b|0;Ai(a,b,274)}function AJ(a,b){a=a|0;b=b|0;Rp(a,b+40|0)}function zqa(a,b){a=a|0;b=b|0;Ai(a,b,42)}function uw(a,b,c,d,e){dH(a,b,c,d,e,128)}function tpa(a,b){a=a|0;b=b|0;Ai(a,b,72)}function pl(a){return(a|0)==32|a-9>>>0<5}function p5(a,b){a=a|0;b=b|0;Cc(a,11301)}function oY(a,b){a=a|0;b=b|0;Ai(a,b,284)}function o5(a,b){a=a|0;b=b|0;Cc(a,11418)}function nf(a,b){x[a+8>>2]=b|-2147483648}function lK(a){return a-97>>>0<26?a&95:a}function lG(a,b){wc(a,b);wc(a+4|0,b+4|0)}function kK(a){return a-65>>>0<26?a|32:a}function jt(a,b){x[a+24>>2]=x[a+24>>2]+b}function jsa(a,b){a=a|0;b=b|0;yr(a,b,17)}function ig(a,b){a=tua(0,a,b,0);return a}function hia(a){a=a|0;return y[a+4201|0]}function hc(a){x[x[a>>2]+4>>2]=x[a+4>>2]}function gia(a){a=a|0;return y[a+4202|0]}function ge(a,b){return(b|0)!=0&(a|0)!=0}function fo(a,b,c){return ib[c|0](a,b)|0}function dj(a,b){v[a|0]=b;v[a+1|0]=b>>>8}function Vta(a,b){a=a|0;b=b|0;$G(a,b,28)}function Vsa(a,b){a=a|0;b=b|0;Ai(a,b,34)}function Ofa(a){a=a|0;return(a|0)==277|0}function Jx(a){return a-502448>>>2&65535}function Fj(a){w[a+4>>1]=65535;x[a>>2]=0}function EZ(a,b,c){x[a>>2]=b;x[a+4>>2]=c}function Dr(a,b,c,d,e){dH(a,b,c,d,e,256)}function $k(a){return D(Cn(a),Xd(a))&255}function yba(a){a=a|0;return+lN(a-88|0)}function wS(a,b){return(Nl(a,b)|0)!=255}function w0(a,b){a=a|0;b=b|0;Ai(a,b,59)}function uI(a){a=a|0;return qd(a-8|0)|0}function tI(a){a=a|0;return Sx(a-8|0)|0}function si(a){return(a&65535)>>>0<3999}function sI(a){a=a|0;return Rx(a-8|0)|0}function sD(a){return QG(a,65535,65535)}function s$(a,b){x[a>>2]=x[a>>2]+(b<<1)}function rX(a,b){a=a|0;b=b|0;return b|0}function rI(a){a=a|0;return Qx(a-8|0)|0}function qm(a){a=x[a+8>>2];if(a){Db(a)}}function qI(a){a=a|0;return Px(a-8|0)|0}function pI(a){a=a|0;return Ox(a-8|0)|0}function oI(a){a=a|0;return Nx(a-8|0)|0}function oB(a,b,c){return a<b?b:a>c?c:a}function kS(a,b,c,d){return Pp(a,b,c,d)}function j0(a,b){a=a|0;b=b|0;yr(a,b,11)}function hZ(a,b){a=a|0;b=b|0;yr(a,b,32)}function fY(a,b){x[a>>2]=x[a>>2]+(b<<2)}function _2(a){a=a|0;if(a){_H(At(a),1)}}function Zfa(a){a=a|0;return-2013527448}function Ys(a){return(a|0)==32|(a|0)==9}function YH(a){return(z[a+2>>1]<<2)+a|0}function Wg(a,b,c){v[a+4|0]=c;x[a>>2]=b}function Ty(a){return(q(a),j(2))>>>20|0}function TO(a,b){return DH(a,b,1075834)}function SW(a,b,c,d){return dn(c,d,a,b)}function RO(a,b){return CH(a,b,1075834)}function QO(a,b){return CH(a,b,1075835)}function PO(a,b){return DH(a,b,1075835)}function Nqa(a,b){a=a|0;b=b|0;pE(a,b,8)}function Jv(a,b,c){return a<b?b:a>c?c:a}function IJ(a,b){a=a|0;b=b|0;pf(a,1,45)}function Hj(a,b){return eB(a&255,b&255)}function HJ(a,b){a=a|0;b=b|0;gy(a,1,45)}function H$(a,b){a=a|0;b=b|0;Ai(a,b,50)}function DK(a){x[a+4>>2]=x[a+4>>2]|8192}function Cba(a){a=a|0;return+qN(a-88|0)}function Cb(a){return(a<<8|a>>>8)&65535}function Aba(a){a=a|0;return+nN(a-88|0)}function zd(a){return(a-1&255)>>>0<120}function yj(a,b){x[a+4>>2]=1;x[a>>2]=b}function yga(a){a=a|0;return-620920304}function yJ(a){a=a|0;return x[a+64>>2]}function xh(a){return LG(a,E(255),255)}function xQ(a){a=a|0;return 1869112133}function pw(a,b,c){return Fp(a,b,c,20)}function p1(a){a=a|0;return x[a+16>>2]}function ok(a,b){x[a+4>>2]=2;x[a>>2]=b}function oga(a){a=a|0;return-275227023}function mha(a){a=a|0;return-270114148}function le(a,b,c){lo(a,b,Sc(b,c)+b|0)}function lX(a,b){a=a|0;b=b|0;$G(a,b,4)}function jP(a,b,c){return OG(a,b,c,70)}function hx(a,b){x[a+4>>2]=3;x[a>>2]=b}function fna(a){a=a|0;IW(a);return a|0}function fJ(a,b,c){return Fp(a,b,c,24)}function f4(a,b){a=a|0;b=b|0;jH(a,b,0)}function ega(a){a=a|0;return 302837129}function ee(a){x[x[a+8>>2]>>2]=x[a>>2]}function e4(a,b){a=a|0;b=b|0;jH(a,b,1)}function dv(a,b,c){return Fp(a,b,c,12)}function d4(a,b){a=a|0;b=b|0;iH(a,b,0)}function d2(a,b){a=a|0;b=b|0;is(a,1,b)}function cy(a){a=a|0;return x[a+12>>2]}function c4(a,b){a=a|0;b=b|0;iH(a,b,1)}function aha(a){a=a|0;return-285139079}function Uga(a){a=a|0;return-284078960}function Tx(a,b){x[a+4>>2]=4;x[a>>2]=b}function Sd(a,b){return Jb(a)+(b<<2)|0}function Rfa(a,b){a=a|0;b=b|0;return 3}function R_(a,b,c){return Fp(a,b,c,40)}function Pfa(a,b){a=a|0;b=b|0;return 2}function Ns(a){a=a|0;return 2147483647}function Nga(a){a=a|0;return-281111764}function Ij(a){x[a>>2]=125852;return a}function IM(a){return a?(a|0)==2?3:2:1}function Gga(a){a=a|0;return-271958638}function EJ(a){a=a|0;return x[a+60>>2]}function DZ(a,b,c){Yl(a,b&65535,c&255)}function Cu(a,b,c){jg(a,c);ed(b+c|0,0)}function Au(a,b){return cH(a,b,-1,0,0)}function $ha(a){a=a|0;return 542066252}function zM(a){x[a>>2]=49020;return a}function zL(a){x[a>>2]=95076;return a}function xz(a){x[a>>2]=48536;return a}function wz(a){x[a>>2]=48560;return a}function wP(a){return Xi(yP(a)*32768)}function vz(a){x[a>>2]=48640;return a}function vi(a,b,c){return Hp(a,b,c,1)}function uz(a){x[a>>2]=48680;return a}function uM(a){x[a>>2]=74680;return a}function u8(a){a=a|0;return AK(a,0)|0}function th(a,b,c){return Hp(a,b,c,2)}function t8(a){a=a|0;return AK(a,1)|0}function sV(a,b,c){return xx(a,b,c,5)}function rp(a,b,c){return xx(a,b,c,1)}function rka(a,b){a=a|0;b=b|0;rr(a,b)}function rP(a,b){a=a|0;b=b|0;return 0}function pt(a,b){a=a|0;b=b|0;return-1}function pg(a,b){return Sk(a,b)&65535}function on(a){return(a&740327453)!=0}function nr(a,b,c){return Fp(a,b,c,6)}function n8(a){a=a|0;return zK(a,0)|0}function m8(a){a=a|0;return zK(a,1)|0}function lV(a){return(a&65535)==65534}function jT(a,b){return(0-b|0)!=(a|0)}function ika(a,b){a=a|0;b=b|0;RT(a,b)}function hta(a){a=a|0;return z_(a)|0}
function hka(a,b){a=a|0;b=b|0;DS(a,b)}function gl(a){a=x[a>>2];if(a){nl(a)}}function gR(a,b){ad(a,b&4?16:8,1,0,0)}function eP(a){a=a|0;HH(a,47696,1008)}function bt(a){return(wy(a)|0)!=(a|0)}function bG(a,b,c){bc(a,b,gh(b,c)<<3)}function at(a){return(vy(a)|0)!=(a|0)}function _N(a,b){return ot(a,b,gf(b))}function _9(a){a=a|0;return y[a+40|0]}function ZB(a,b,c){return Hp(a,b,c,5)}function Yr(a){a=a|0;return x[a+4>>2]}function Yka(a,b){a=a|0;b=b|0;Yb(a,b)}function Xr(a){a=a|0;return x[a+8>>2]}function Wi(a,b,c){NC(b,c,a);return a}function Ue(a,b){x[a+4>>2]=b;return a}function Tz(a,b){a=a|0;b=b|0;return 1}function Tr(a,b,c){return Hp(a,b,c,3)}function SH(a){a=E(a-a);return E(a/a)}function Ru(a,b,c){return Hp(a,b,c,4)}function OO(a){return z[a+1074448>>1]}function Nj(a){return(a-1&255)>>>0<17}function NC(a,b,c){Gk(a,(b<<2)+a|0,c)}function LO(a){return x[a+1074424>>2]}function KO(a){return x[a+1074416>>2]}function Iz(a){a=a|0;HH(a,47752,1010)}function Ita(a,b){a=a|0;b=b|0;Ny(a,b)}function In(a){x[a>>2]=77664;return a}function Ih(a){a=x[a>>2];if(a){iK(a)}}function HY(a,b,c){bc(a,b,oc(b,c)<<2)}function Gi(a,b,c){Yc(Yc(a,b)+12|0,c)}function EW(a){return(a|0)>=120?120:a}function EG(a,b){vs(a,b,12,357913942)}function Dha(a,b){a=a|0;b=b|0;YE(a,b)}function BE(a,b){vs(a,b,20,214748365)}function An(a,b,c){return xx(a,b,c,2)}function $o(a,b){w[a+8>>1]=b;return a}function $X(a){HL(a);He(x[a+80>>2],a)}function zP(a){x[a>>2]=0;x[a+4>>2]=0}function yh(a){mf(a+52|0);dc(a+40|0)}function yC(a,b){if(!GX(a,b)){AX(b)}}function wf(a){return F(a)==Infinity}function wV(a,b){yx(a,b,4,268435456)}function vQ(a,b,c){a=a|0;b=b|0;c=c|0}function vO(a){return x[a+480272>>2]}function tga(a){a=a|0;x[a+4224>>2]=0}function tV(a,b){yx(a,b,5,134217728)}function rr(a,b){a=a|0;b=b|0;Of(a,b)}function rd(a,b){return D(b,160)+a|0}function oka(a){a=a|0;return hh(a)|0}function m2(a,b){a=a|0;b=b|0;tx(a,b)}function gq(a){return z[a+480192>>1]}function fy(a){a=a|0;return v[a+8|0]}function fq(a){return z[a+480190>>1]}function ey(a){a=a|0;return v[a+9|0]}function e2(a,b){a=a|0;b=b|0;js(a,b)}function cl(a){x[a+4>>2]=x[a+4>>2]+1}function _F(a,b){yx(a,b,3,536870912)}function Z1(a,b){a=a|0;b=b|0;Cp(a,b)}function YE(a,b){a=a|0;b=b|0;NZ(a,b)}function Xy(a){return!Ob(a,126168,6)}function XQ(a,b){vs(a,b,52,82595525)}function VB(a,b,c,d,e){cU(a,b,c,d,e)}function V9(a){a=a|0;return y[a+8|0]}function Uk(a,b){a=a|0;b=b|0;nm(a,b)}function UB(a,b){a=a|0;b=b|0;VU(a,b)}function Tn(a,b){a=a|0;b=b|0;Uk(a,b)}function TV(a,b){return D(b,872)+a|0}function TS(a){return(a+5&255)>>>0<2}function SY(a,b){vs(a,b,6,715827883)}function SQ(a,b){return Ek(a,b-a>>2)}function Pu(a){return x[Ab(a)>>2]<<5}function Of(a,b){a=a|0;b=b|0;fg(a,b)}function Nf(a){return z[a+480188>>1]}function N1(a,b){a=a|0;b=b|0;Tn(a,b)}function MO(a){return z[a+480214>>1]}function L3(a,b){a=a|0;b=b|0;Mw(a,b)}function Kx(a){return(a<<2)+502448|0}function Jsa(a){a=a|0;return Dc(a)|0}function GD(a,b,c){zb(zb(a,b)+4|0,c)}function Fr(a,b){a=a|0;b=b|0;Rw(a,b)}function Eja(a){a=a|0;return Ni(a)|0}function Dsa(a){a=a|0;return uD(a)|0}function Cl(a){return(a&255)>>>0>250}function CW(a){return(a&255)>>>0<129}function B9(a,b){a=a|0;b=b|0;Xt(a,b)}function $j(a,b){a=a|0;b=b|0;h$(a,b)}function zv(a,b){return(b-a|0)/33|0}function zb(a,b){x[a>>2]=b;return a}function xF(a){a=a|0;return eh(a)|0}function vw(a,b){w[a>>1]=b;return a}function uka(a){a=a|0;LH(a,118,117)}function tq(a){if(y[a+24|0]){NS(a)}}function tf(a,b){return D(b,24)+a|0}function sr(a,b){return(b-a|0)/28|0}function sg(a,b){return D(b,52)+a|0}function qu(a){return!(a&204473357)}function ol(a,b,c){return YJ(a,b,c)}function oe(a,b){return Gc(a,ie(b))}function nC(a,b){return D(b,56)+a|0}function mr(a,b){return(b-a|0)/40|0}function mc(a,b){return(a|0)==(b|0)}function mF(a){a=a|0;return be(a)|0}function lx(a,b,c){return Ob(a,b,c)}function lj(a,b){return(b-a|0)/24|0}function lA(a,b){return D(b,28)+a|0}function kca(a,b){a=a|0;b=b|0;EO(a)}function jD(a,b,c){return Pt(a,b,c)}function hv(a,b){return(b-a|0)/56|0}function hW(a){if(!y[a+4|0]){gW(a)}}function h1(a){a=a|0;UF(Tb(a,0,36))}function h$(a,b){d$(a,x[a+16>>2]|b)}function f1(a){a=a|0;return _h(a)|0}function dm(a,b){return cm(Xc(a,b))}function cJ(a){if(!y[a+4|0]){PI(a)}}function bv(a,b){return D(b,36)+a|0}function am(a){if(!y[a+4|0]){V_(a)}}function aj(a){if(!y[a+4|0]){MY(a)}}function _g(a){if(!y[a+4|0]){zQ(a)}}function Zl(a){return QG(a,255,255)}function YY(a,b,c){return Qi(a,b,c)}function Xq(a){return(a&255)==1?1:2}function XX(a){if(!y[a+4|0]){TX(a)}}function Wj(a){if(!y[a+4|0]){zF(a)}}function Wb(a,b){return Me(a,b&255)}function VL(a){if(!y[a+4|0]){KH(a)}}function UM(a){if(!y[a+4|0]){TM(a)}}function UK(a){a=a|0;return sl(a)|0}function Sx(a){a=a|0;return a+184|0}function Sr(a,b){return(b-a|0)/36|0}function Sk(a,b){return(b-a|0)/52|0}function ST(a){if(!y[a+4|0]){VV(a)}}function Rx(a){a=a|0;return a+472|0}function Ri(a,b,c){return ai(a,b,c)}function Qx(a){a=a|0;return a+496|0}function Qq(a,b){return a>>>0<b>>>0}function Qd(a,b){return(b-a|0)/12|0}function Q8(a){a=a|0;return ql(a)|0}function Px(a){a=a|0;return a+508|0}function Pg(a,b){return(a|0)!=(b|0)}function Ox(a){a=a|0;return a+520|0}function Oia(a){a=a|0;yr(a,22485,1)}function Nx(a){a=a|0;return a+532|0}function Mba(a,b){a=a|0;b=b|0;UO(a)}function MV(a){if(!y[a+4|0]){LV(a)}}function Lf(a,b){return(b-a|0)/20|0}function Kj(a,b){return Hg(a,b)&255}function KC(a,b){return Ne(a,0-b|0)}function J1(a){a=a|0;return Mg(a)|0}function Iu(a){if(!y[a+4|0]){pG(a)}}function IK(a){a=a|0;return $w(a)|0}function I$(a){a=a|0;return Ow(a)|0}function Hw(a){v[a+2|0]=0;w[a>>1]=0}function HD(a,b){return Ne(a,b-a|0)}function H6(a){a=a|0;return $x(a)|0}function FV(a){if(!y[a+4|0]){EV(a)}}function FE(a){if(!y[a+4|0]){EE(a)}}function Dd(a,b){return D(b,12)+a|0}function DY(a,b){return D(b,33)+a|0}function Ae(a,b,c){return eK(a,b,c)}function $g(a,b){return D(b,20)+a|0}function xl(a,b){return(a+b|0)-1|0}function uJ(a){return Th(a,500536)}function tJ(a){return Th(a,500528)}function tB(a,b){return(b-a|0)/7|0}function r9(a,b){a=a|0;b=b|0;Db(b)}function qd(a){a=a|0;return a+16|0}function qJ(a){return Th(a,500552)}function q$(a,b){return Sl(a,b,28)}function px(a,b){return Sl(a,b,12)}function pJ(a){return Th(a,500544)}function no(a,b){x[a+1298472>>2]=b}function ml(a){return(a&255)>>>0>1}function ly(a,b){return!(b>>>31|0)}function kI(a){C[(fb-16|0)+8>>3]=a}function ip(a){v[a|0]=0;v[a+1|0]=0}function iF(a){return(a&255)+704|0}function gi(a,b){a=a|0;b=b|0;Fb(a)}function eu(a,b){return(a-b|0)/6|0}function bj(a){return a&2147483647}function _p(a,b){v[a|0]=b;return a}function ZF(a,b){return Sl(a,b,36)}function Vc(a,b){return D(b,6)+a|0}function US(a){ze(a+8|0);MS(a+4|0)}function Toa(a){a=a|0;lY(a,65535)}
function Rk(a,b){return D($k(b),a)}function Mr(a,b){return(b<<11)+a|0}function Jk(a,b){return(b-a|0)/6|0}function Ji(a){a=a|0;v[a+4202|0]=0}function Iq(a,b){return(a|0)<(b|0)}function Go(a,b){return(b<<13)+a|0}function FM(a){return(uk(a)|0)==-1}function Ey(a){return mc(a,-1)?0:a}function EM(a,b){a=a|0;b=b|0;dc(b)}function DM(a,b){a=a|0;b=b|0;Tm(b)}function Cd(a){return(a&128)>>>7|0}function Bc(a,b){return eH(a,b,-1)}function BZ(a,b){return ux(a,b,56)}function BY(a,b){return ux(a,b,18)}function xo(a){return a+1074328|0}function wb(a,b){return(b<<2)+a|0}function rz(a,b){return nR(a,b)^1}function rt(a){return IG(a,93752)}function rc(a){x[a>>2]=0;return a}function qn(a){x[a>>2]=2;return a}function me(a,b){return!Ob(a,b,4)}function er(a,b){return ke(a,b)^1}function e3(a){a=a|0;return 13227}function d3(a){a=a|0;return 10296}function cc(a,b){return Jb(a)+b|0}function cO(a,b){x[a+480272>>2]=b}function an(a,b){return(b<<8)+a|0}function a$(a){os(a,17,125480,33)}function _b(a,b){return(b<<1)+a|0}function Zz(a){x[a>>2]=x[a>>2]+24}function Zk(a){w[a>>1]=0;return a}function Ypa(a){a=a|0;cg(a,17026)}function XB(a,b){return Sl(a,b,4)}function Wf(a){return a!=a?E(0):a}function Vs(a,b){return eK(a,0,b)}function Vh(a){x[a>>2]=1;return a}function Ud(a,b){return(b<<4)+a|0}function Tja(a){a=a|0;tg(a,Lj(a))}function TK(a){return IG(a,93816)}function Re(a,b){return(b<<3)+a|0}function QB(a){if(a){Db(a+-64|0)}}function OE(a){return a>>>0>8?5:4}function Me(a,b){return(b<<5)+a|0}function Kh(a){return a-48>>>0<10}function Ib(a,b){return mc(a,b)^1}function I2(a){a=a|0;return 13113}function Hra(a){a=a|0;cg(a,16395)}function HA(a){dc(a+4|0);return a}function H2(a){a=a|0;return 10819}function Fx(a,b){return x[a+b>>2]}function F8(a){a=a|0;return 10416}function Cq(a){os(a,17,125532,52)}function CT(a,b){return Sl(a,b,8)}function AF(a){return(a&16)>>>4|0}function $d(a){return x[ec(a)>>2]}function xra(a){a=a|0;cg(a,4398)}function xN(a){a=a|0;dq(a);Db(a)}function rg(a,b,c,d){hf(a,c,d,b)}function qqa(a){a=a|0;bw(a,3883)}function oua(a){a=a|0;cg(a,4378)}function oqa(a){a=a|0;bw(a,4907)}function oba(a){a=a|0;Lt(a-92|0)}function mw(a,b,c,d){rB(a,b,c,d)}function mY(a,b){yc(a,b+4|0,256)}function kf(a,b,c){lo(a,b,b+c|0)}function iQ(a){return(a&8)>>>3|0}function i3(a){a=a|0;return 6940}function gba(a){a=a|0;Lt(a-96|0)}function fF(a,b,c,d){ax(a,b,c,d)}function eta(a){a=a|0;cg(a,3892)}function a3(a){a=a|0;return 6921}function _v(a,b,c){XG(a,b,c,128)}function Zpa(a){a=a|0;cg(a,4005)}function Yu(a){v[a|0]=0;return a}function XE(a){Mm(a,Bp(a),79024)}function R1(a){a=a|0;cg(a,17053)}function P1(a){a=a|0;LH(a,51,50)}function NN(a){a=a|0;Nt(a);Db(a)}function J2(a){a=a|0;return 9855}function Gg(a,b){zb(rc(a)+4|0,b)}function Gba(a){a=a|0;Lt(a-88|0)}function GK(a){x[a+72>>2]=499464}function G2(a){a=a|0;return 5740}function EK(a){x[a+72>>2]=499548}function Dw(a,b){return vua(a,b)}function Dra(a){a=a|0;cg(a,4504)}function Coa(a){a=a|0;cg(a,4185)}function BF(a){return(a&2)>>>1|0}function AN(a){a=a|0;Lm(a);Db(a)}function zy(a,b){return oh(a,b)}function zA(a){w[a+480214>>1]=0}function yd(a,b){return!Bb(a,b)}function yR(a,b){return wR(a,b)}function y5(a){a=a|0;tb(500772)}function xu(a){MT(a+12|0);QT(a)}function xf(a,b){return ch(a,b)}function wE(a){return(a&255)==1}function w5(a){a=a|0;tb(500804)}function vo(a,b){return Dt(a,b)}function vg(a){tb(a+20|0);tb(a)}function vB(a,b){return Xc(a,b)}function ui(a,b,c){hf(a,c,13,b)}function uh(a,b){return Wc(a,b)}function uf(a,b){return Gc(a,b)}function ub(a){he(a+12|0);he(a)}function uC(a,b,c){hf(a,c,64,b)}function tj(a,b){return a>>>b&1}function rJ(a,b){ms(a,b,24,-24)}function pga(a){a=a|0;Db(KP(a))}function oF(a,b){return kF(a,b)}function nl(a){if(pK(a)){Db(a)}}function mga(a){a=a|0;return 13}function jk(a,b){return b-a>>11}function jW(a,b){ms(a,b,12,-12)}function im(a,b,c){hf(a,c,22,b)}function ic(a,b){return eG(a,b)}function dE(a,b,c){hf(a,c,30,b)}function cA(a,b){return SQ(a,b)}function bq(a,b){return wb(a,b)}function bha(a){a=a|0;Db(VP(a))}function aia(a){a=a|0;Db(sQ(a))}function _i(a,b,c){hf(a,c,28,b)}function _D(a,b){return Qq(a,b)}function Zj(a,b,c){hf(a,c,20,b)}function ZD(a,b){return dp(b,a)}function Ym(a){tb(a+12|0);tb(a)}function Xi(a){return mn(De(a))}function Xh(a,b){return yw(a,b)}function Xe(a){return gr(De(a))}function Ws(a,b){return Qd(a,b)}function Wc(a,b){return Bb(a,b)}function Vg(a,b){return Ib(a,b)}function Vb(a,b){return sg(a,b)}function To(a,b){return _k(a,b)}function Tj(a,b){return Sc(a,b)}function Te(a,b,c){hf(a,c,32,b)}function Sj(a,b){return Me(a,b)}function Sg(a){return TS(a&255)}function S1(a){a=a|0;cg(a,4552)}function RZ(a,b,c){hf(a,c,24,b)}function RL(a,b){return gh(a,b)}function Q5(a){a=a|0;Sb(500852)}function Pi(a,b){return(a|b)!=0}function Pc(a,b,c){gc(a,b,1<<c)}function Os(a){a=a|0;return 127}function Ol(a){tb(a+12|0);kd(a)}function Od(a,b){return oc(a,b)}function O5(a){a=a|0;Sb(500884)}function N_(a,b){ms(a,b,40,-40)}function NS(a){LS(a+12|0);KS(a)}function M5(a){a=a|0;Sb(500788)}function Lk(a,b,c){hf(a,c,12,b)}function KD(a,b){return zk(b,a)}function K5(a){a=a|0;Sb(500820)}function Js(a){return Ab(a+8|0)}function Je(a){a=a|0;return a|0}function ID(a,b){return HD(a,b)}function Hc(a,b){return Mr(a,b)}function Hb(a,b){return(a&b)!=0}function Gc(a,b){return zb(a,b)}function Fe(a,b){return A$(a,b)}function Eg(a){return Si(a)?0:a}function Eaa(a){a=a|0;Db(Ht(a))}function DG(a,b){return Yc(a,b)}function Cj(a){uA(a,0);return a}function C5(a){a=a|0;tb(500836)}function Bw(a,b){return lF(a,b)}function Ad(a){return(a&255)!=0}function A5(a){a=a|0;tb(500868)}function zT(a,b){Cu(a,Jb(a),b)}function wv(a,b){return a-b>>2}function v3(a){a=a|0;Db(gI(a))}function u3(a){a=a|0;Db(fI(a))}function t3(a){a=a|0;Db(eI(a))}function t1(a){a=a|0;Db(dG(a))}function sd(a,b){jI(a,b,qC(b))}function s3(a){a=a|0;Db(dI(a))}function p3(a){a=a|0;Db(cI(a))}function oc(a,b){return b-a>>2}function nI(a){a=a|0;Db(Gs(a))}function mx(a){return Cx(a,12)}function m3(a){a=a|0;Db(bI(a))}function m$(a){return Cx(a,28)}function iJ(a){a=a|0;Db($x(a))}function hI(a){a=a|0;Db(Ds(a))}function hG(a){return a+1024|0}function gh(a,b){return b-a>>3}function gL(){return(db()|0)>0}function fc(a,b){x[a+100>>2]=b}function fC(a){return a+4096|0}function eO(a,b){KG(a,b,22485)}function eM(a){a=a|0;Db(fM(a))}function eB(a,b){return a<<8|b}function dp(a,b){return a-b>>1}function bo(a){return(a|0)==-1}function bQ(a){a=a|0;Db(cQ(a))}function b5(a){a=a|0;Db(Hs(a))}function _ha(a){a=a|0;return 9}function _U(a){return a+4896|0}function ZW(a,b){vx(a,b,5,3,4)}function ZN(a){a=a|0;Db(dq(a))}function Z3(a){a=a|0;Db(vI(a))}function Xd(a){return a&64?2:1}function Xc(a,b){return b-a>>1}function WM(a,b){KG(a,b,13580)}function W9(a){a=a|0;Db(Bt(a))}function Vz(a){a=a|0;Db(bu(a))}function Vt(a){return a>>>27^a}function V4(a){a=a|0;Db(AI(a))}function Ut(a){a=a|0;Db(Uf(a))}function Sn(a){a=a|0;Db(WZ(a))}function RM(a){return Cx(a,16)}function Ph(a,b){return b-a>>8}function Ok(a){return a>>>0<11}function OY(a,b){lo(a,b,qd(b))}function My(a){a=a|0;Db(sl(a))}function MK(a){a=a|0;Db(Yp(a))}function Ly(a){a=a|0;Db($n(a))}function Lt(a){a=a|0;Db(cq(a))}function LK(a){a=a|0;Db(Af(a))}function LI(a){a=a|0;Db(Vx(a))}function L8(a){a=a|0;Db(kt(a))}function Ky(a){a=a|0;Db(nt(a))}function KI(a){a=a|0;Db(Ux(a))}function J9(a){a=a|0;Db(XL(a))}function Iy(a){a=a|0;Db(mt(a))}function Is(a){a=a|0;Db(Wx(a))}function Hy(a){a=a|0;Db(lt(a))}function Hn(a){a=a|0;Db($w(a))}function Hg(a,b){return b-a>>5}function He(a,b){if(!a){Db(b)}}function E3(a){a=a|0;Db(iI(a))}function Dk(a,b){return b-a>>4}function $ga(a){a=a|0;return 6}function zk(a,b){return a-b|0}function zC(a){return a+128|0}function yQ(a,b){ci(a,b,2048)}function xd(a){return(a|0)!=0}function xb(a,b){return a+b|0}function wy(a){return jK(a,0)}function vy(a){return jK(a,1)}function vT(a,b){ms(a,b,7,-7)}function ro(a){a=a|0;return 4}function qP(){return 19988519}function pk(a){return(a&5)!=0}function mX(a,b){bc(a,b,1108)}function mR(a,b,c){Ml(a,b,-c)}function lc(a){a=a|0;return 0}function kp(a){return a>>>0<5}function k_(a,b){hf(a,b,40,2)}function gp(a,b){yb(a+12|0,b)}function fr(a){return a+256|0}function fQ(a){a=a|0;return 3}function cL(a){a=a|0;return-1}function aQ(a){a=a|0;return 7}function _e(a,b){w[a+28>>1]=b}function ZU(a){return a+512|0}function ZL(a){return pk(a)^1}function XC(a,b){bc(a,b,4896)}function Sc(a,b){return b-a|0}function RP(a){a=a|0;return 5}function Pj(a){return!(a&255)}function Nq(a){return a>>>0<2}function N$(a,b){bc(a,b,1954)}function Kt(a,b){x[a+32>>2]=b}function Kr(a,b){hf(a,b,26,3)}function JY(a){bp(Tb(a,0,40))}function Ie(a){a=a|0;return 2}function Ho(a,b){x[a+36>>2]=b}function Fb(a){cx(a);return a}function Dj(a){return a+4e4|0}function Cn(a){return a&1?2:1}function Be(a){a=a|0;return 1}function BC(a,b){bc(a,b,1024)}function Ak(a){return xd(a)^1}function $W(a,b){hf(a,b,33,1)}function yS(a,b,c){EZ(a,b,c)}function yG(a,b,c){ef(a,c,b)}function yD(a,b){hf(a,b,8,2)}function wX(a,b){bc(a,b,126)}function wB(a){v[a+6152|0]=0}function vZ(a,b){bc(a,b,576)}function vV(a){CV(a,x[a>>2])}function tA(a,b){v[a+34|0]=b}function sZ(a,b){bc(a,b,674)}function sA(a,b){v[a+32|0]=b}function rA(a,b){v[a+35|0]=b}function qr(a){return a-28|0}function qE(a,b,c){bf(a,c,b)}function pW(a,b){bc(a,b,204)}function od(a,b){return a>>b}function oP(a){return a+48|0}function oG(a){nG(a,x[a>>2])}function nq(a,b){B[a+8>>2]=b}function nn(a,b){x[a+8>>2]=b}function mq(a,b){B[a+4>>2]=b}function lq(a,b){v[a+33|0]=b}function ku(a){XR(a,x[a>>2])}function kZ(a){return a+36|0}function k$(a,b){bc(a,b,610)}function iA(a,b){uA(a,ie(b))}function hj(a){return a-36|0}function hF(a,b){bc(a,b,772)}function gj(a){yF(a,x[a>>2])}function fE(a,b){bc(a,b,512)}function fD(a,b,c){ae(a,b,c)}function ew(a,b){bc(a,b,192)}function ep(a,b){Fe(a,b+8|0)}function e_(a,b){bc(a,b,218)}function dx(a,b){qG(a,ie(b))}function dV(a,b){bc(a,b,263)}function bc(a,b,c){gc(a,b,c)}function b_(a,b){bc(a,b,157)}function _Y(a){kJ(a,x[a>>2])}function ZZ(a,b){bc(a,b,206)}function YX(a){return a+3&-4}function YW(a){return a-56|0}function Xz(a){yQ(a,x[a>>2])}function Xo(a){return a+14|0}function Wv(a){K_(a,x[a>>2])}function Vd(a,b){x[a+4>>2]=b}function U_(a){T_(a,x[a>>2])}function Td(a,b,c){Qj(a,b,c)}function TZ(a,b){bc(a,b,236)}function So(a){EY(a,x[a>>2])}function Rq(a,b){return a<<b}function Rh(a,b,c){r_(a,b,c)}function R8(a){a=a|0;h$(a,1)}function Qe(a,b){a=a|0;b=b|0}function QW(a,b){bc(a,b,146)}function QV(a,b){yc(a,b,128)}function PZ(a){return a+10|0}function On(a){return a-12|0}function Mq(a,b,c){op(a,b,c)}function MW(a,b){bc(a,b,608)}function Lo(a){return a+32|0}function LT(a){KT(a,x[a>>2])}function Ke(a,b){v[a+11|0]=b}function Kb(a,b,c){DF(a,b,c)}function KY(a,b){bc(a,b,128)}function KB(a){return a-32|0}function JZ(a,b){bc(a,b,102)}function IX(a){HX(a,x[a>>2])}function Gf(a){rQ(a,x[a>>2])}function FC(a,b){bc(a,b,130)}function EX(a,b){bc(a,b,600)}function DR(a){return a+24|0}function CV(a,b){ci(a,b,256)}function Bp(a){return a+20|0}function BU(a){AU(a,x[a>>2])}function BT(a,b,c){te(a,b,c)}function At(a){return a-24|0}function Ac(a){return a+12|0}function AV(a){zV(a,x[a>>2])}function $E(a,b){bc(a,b,497)}function zn(a,b){gc(a,b,32)}function zV(a,b){ci(a,b,16)}function yE(a,b){bc(a,b,32)}function xY(a,b){ci(a,b,33)}function ww(a,b){bc(a,b,11)}function vf(a){return a&255}function ug(a,b){v[a+3|0]=b}function t$(a){return a-2|0}function sG(a,b){bc(a,b,24)}function rv(a,b){bc(a,b,30)}function rY(a,b){bc(a,b,52)}function qi(a){return a-4|0}function pq(a){Tb(a,0,8192)}function pP(){return 458752}function ow(a,b){bc(a,b,65)}function of(){a$(11044);p()}function oE(a,b){gc(a,b,20)}function mp(a,b){v[a+1|0]=b}function m_(a,b){bc(a,b,98)}function kr(a,b){bc(a,b,12)}function kJ(a,b){ci(a,b,24)}function jV(a,b){return a<b}function h_(a,b){bc(a,b,48)}function gU(a,b){bc(a,b,27)}function fda(a){a=a|0;mP(a)}function ec(a){return a+4|0}function eN(a){return 0-a|0}function cw(a,b){_G(a,b,64)}function cu(a){Tb(a,0,2048)}function cj(a){return a+3|0}function cE(a,b){_G(a,b,32)}function bX(a,b){bc(a,b,96)}function Zv(a,b){bc(a,b,64)}function Ze(a){return a+2|0}function Z$(a,b){bc(a,b,17)}function Yv(a,b){bc(a,b,66)}function XD(a){x[a+12>>2]=0}function Vw(a,b){bc(a,b,20)}function VC(a,b){bc(a,b,33)}function UE(a,b){bc(a,b,38)}function Sh(a){return a&127}function SE(a,b){Ai(a,b,37)}function Q_(a,b){yc(a,b,40)}function QZ(a){return a+6|0}function Pl(){Cq(11044);p()}function PC(a,b){bc(a,b,40)}function Nv(a,b){bc(a,b,22)}function Nr(a,b){bc(a,b,36)}function M$(a){Tb(a,0,1954)}function LY(a,b){bc(a,b,80)}function K_(a,b){ci(a,b,40)}function Ic(a){return a+1|0}function IA(a){Tb(a,0,4096)}function HX(a,b){ci(a,b,32)}function Fw(a,b){gc(a,b,22)}function Br(a,b){bc(a,b,16)}function Av(a,b){return a<b}function Ab(a){return a+8|0}function yF(a,b){ci(a,b,2)}function xc(a){x[a+8>>2]=0}function wk(a,b){B[a>>2]=b}function wC(a){Tb(a,0,130)}function vv(a){QC(a,$d(a))}function vd(a,b){x[a>>2]=b}function vX(a){Tb(a,0,126)}function ur(a,b){bc(a,b,7)}function uZ(a){Tb(a,0,576)}function tw(){Cq(7738);p()}function tc(a){a=a|0;Db(a)}function sp(a,b){bc(a,b,2)}function rQ(a,b){ci(a,b,4)}function qR(a){pA(a,$d(a))}function pZ(a){Tb(a,0,192)}function p0(a){a=a|0;_h(a)}function oW(a){Tb(a,0,204)}function nG(a,b){ci(a,b,8)}function lh(a,b){bc(a,b,4)}function kfa(){return fb|0}function j$(a){Tb(a,0,610)}function gF(a){Tb(a,0,772)}function fn(a,b){op(a,b,0)}function eF(a,b){Rh(a,2,b)}function dZ(a){$C(a,$d(a))}function cs(a){a=a|0;es(a)}function ck(a,b){bc(a,b,5)}function cd(){a$(7738);p()}function bZ(a){aD(a,$d(a))}function al(a,b){bc(a,b,8)}function a_(a){Tb(a,0,157)}function _E(a){Tb(a,0,497)}function Zb(a){rm(x[a>>2])}function YZ(a){Tb(a,0,206)}function Xda(a){a=a|0;fb=a}function T_(a,b){ci(a,b,6)}function Si(a){return a!=a}function SZ(a){Tb(a,0,236)}function Qw(a,b){bc(a,b,3)}function PW(a){Tb(a,0,146)}function MT(a){yq(a,$d(a))}function LW(a){Tb(a,0,608)}function LS(a){su(a,$d(a))}function Kl(a){sB(a,$d(a))}function KV(a){bC(a,$d(a))}function KS(a){tu(a,$d(a))}function JV(a){cC(a,$d(a))}function Hv(a){pD(a,$d(a))}function Hba(a){a=a|0;gb=a}function Gr(a,b){bc(a,b,1)}function GZ(a){qD(a,$d(a))}function Fs(a){nl(x[a>>2])}function EY(a,b){ci(a,b,1)}function ED(a,b){bc(a,b,6)}function CX(a){Tb(a,0,600)}function BV(a){Tb(a,0,256)}function $P(a,b){MQ(a,3,b)}function wY(a){Tb(a,0,33)}function up(a){return a&1}function qY(a){Tb(a,0,52)}function l_(a){Tb(a,0,98)}function i_(a){Tb(a,0,48)}function ed(a,b){v[a|0]=b}function cX(a){Tb(a,0,96)}function bO(){return 2048}function ZC(a){Tb(a,0,80)}function WD(a){Tb(a,0,66)}function TE(a){Tb(a,0,38)}function Sv(a){Tb(a,0,64)}function Pr(a){Tb(a,0,36)}function Md(a){v[a+4|0]=1}function Dh(a){tb(a+16|0)}function AZ(a){Tb(a,0,56)}function AQ(a){vm(a,2048)}function zX(a){wx(a,512)}function zU(a,b){AU(a,b)}function y_(a,b){hU(a,b)}function xn(a,b){yF(a,b)}function wU(a,b){kg(a,b)}function ul(a,b){_p(a,b)}function po(a,b){zb(a,b)}function kU(a,b){Eh(a,b)}function hs(a,b){DG(a,b)}function hX(a,b){Fe(a,b)}function eg(a,b){d$(a,b)}function dk(a,b){vw(a,b)}function cD(a,b){T_(a,b)}function bW(a,b){Tl(a,b)}function aG(a,b){nG(a,b)}function ZQ(a,b){XR(a,b)}function Yz(a,b){oe(a,b)}function Yh(a,b){rQ(a,b)}function YD(a,b){Pk(a,b)}function UC(a,b){uY(a,b)}function Tq(a,b){EY(a,b)}function Oh(a,b){Ko(a,b)}function OC(a,b){fY(a,b)}function Ng(a){a=a|0;p()}function Nd(a,b){Kg(a,b)}function Ko(a,b){Yc(a,b)}function Jc(a){dc(a+8|0)}function JT(a){ze(a+8|0)}function Hk(a){tb(a+4|0)}function Hi(a,b){ki(a,b)}function Fn(a,b){QF(a,b)}function Fd(a){ub(a+8|0)}function EV(a){MG(a,872)}function Du(a,b){GR(a,b)}function DD(a,b){ic(a,b)}function $c(a,b){ks(a,b)}function zE(a){wx(a,16)}function wg(a){rx(a,24)}function np(a){fH(a,11)}function nJ(a){vm(a,24)}function mI(a){rx(a,48)}function Zo(a){fH(a,16)}function Wh(a){v[a|0]=0}function Nn(a){rx(a,36)}function M_(a){vm(a,40)}function Kja(){ua();p()}function yl(a){LM(a,0)}function uT(a){vm(a,7)}function sh(a){MM(a,0)}function rh(a){KM(a,0)}function gW(a){MG(a,9)}function fj(a){vm(a,2)}function _r(a){qG(a,0)}function ZH(){va();p()}function YC(a){wx(a,4)}function X2(){ZH();p()}function Ur(a){vm(a,8)}function TY(a){vm(a,6)}function Kc(a){Oe(a,0)}function KA(a){_R(a,0)}function JA(a){ZR(a,0)}function Ig(a){cZ(a,0)}function BR(a){cS(a,0)}function vC(a){ah(a)}function fs(a){Ac(a)}function eV(a){rc(a)}function dW(a){Nb(a)}function YV(a){Pe(a)}function UU(a){je(a)}function Tm(a){sc(a)}function Kw(a){Zk(a)}function FW(a){Yu(a)}function Eb(a){tb(a)}function ET(a){Mo(a)}function Cf(a){a=a|0}
// EMSCRIPTEN_END_FUNCS
e=y;var ib=c([null,uc,iG,nm,u1,$F,i1,g1,d1,PF,NF,ne,L0,H0,YE,D0,FZ,WZ,Bna,kna,gna,mua,bua,dw,$j,Ota,Z,fsa,lw,gm,VK,hh,cp,Esa,Je,$2,Kna,Cc,U4,lD,Uj,Wq,ln,jra,IZ,pi,VU,UB,$la,Ala,RT,Oka,$ka,ng,aka,Rj,Yja,Sja,Kja,Ija,Hja,kA,hja,$ia,Ufa,ria,wQ,j9,i9,qt,wQ,afa,XO,fg,xea,hea,Cda,xda,sda,mda,gda,Xca,Mca,Fca,Lba,vca,Jy,ua,Mb,s5,R4,I4,x4,m4,Tn,X3,ika,L3,hka,w3,da,T2,C2,o2,n2,m2,l2,sH,k2,j2,i2,h2,g2,e2,d2,f2,C8,js,Ep,ng,c2,BG,AG,b2,jx,a2,zG,Of,$1,Z1,X1,cs,bs,$h,cg,U1,Cp,W1,V1,T1,_1,S1,wG,R1,wG,Y1,xG,Q1,P1,O1,N1,M1,bd,Mb,J1,Ap,I1,hh,H1,md,G1,dl,md,bx,F1,$w,Zw,h1,E1,w1,v1,f1,b1,_0,Z0,Ow,UF,Y0,X0,Cja,Dja,rT,Aja,Bja,qA,fu,Yb,Eja,ce,RF,U0,T0,xF,R0,Q0,xF,mF,Aw,M0,bh,mF,xw,Pia,Zia,Oia,jf,pka,S0,Zf,eua,oka,pta,KE,JE,z0,y0,IE,x0,qg,w0,v0,Ec,qw,u0,t0,s0,$f,r0,hm,q0,GE,p0,m0,tE,l0,k0,j0,jw,i0,ZE,sE,h0,g0,f0,e0,d0,mE,rE,V$,Bd,fw,oua,nua,kE,jE,lua,kua,jua,qw,iua,U$,hua,kw,gua,fua,Yk,_ta,tr,Zta,Lb,Yf,cg,Yta,eE,Xta,id,Qk,Wta,Vta,Uta,I$,H$,jd,Tta,fp,Sta,Rta,Qta,E$,D$,Uj,bw,Pta,Nta,hla,Mta,dh,Lta,Kta,Eta,_j,Hta,Gta,Fta,Jta,Ita,Of,v$,Zh,Kf,Bta,Ata,zta,wta,_j,Yj,vta,uta,tta,TD,b$,SD,sta,rta,qta,Yk,I_,F_,mta,jta,B_,ko,ita,tg,i$,hta,jw,gta,fta,MD,eta,A_,Zw,dta,cta,w_,XZ,bta,Yk,_sa,tr,Wk,Zsa,Ysa,H$,Xsa,Wsa,Vsa,t_,s_,wn,Usa,Tsa,Ssa,Qsa,_j,q_,Rsa,Zh,Kf,RD,Lsa,Xv,Hsa,A_,Csa,Bsa,Asa,zsa,wsa,tr,vsa,usa,ap,t_,tsa,ssa,cg,rsa,qsa,psa,osa,nsa,OZ,msa,lsa,YJ,MZ,ksa,jsa,T$,LZ,isa,hsa,gsa,nla,esa,KZ,dsa,KZ,Dsa,bsa,_j,csa,Zh,Kf,ek,Yra,Xra,Wra,Vra,Sra,Rra,Qra,Pra,Ora,ap,Nra,Mra,Lra,iD,N0,Kra,Jra,Ira,Hra,Gra,nZ,Fra,K0,Era,Dra,Cra,Bra,mZ,Ara,cg,zra,yra,VD,Zra,xra,wra,_ra,vra,ura,tra,eD,eD,lZ,sra,rra,jZ,eD,gZ,qra,A8,pra,ora,nra,mra,lra,kra,ira,fZ,md,Yq,Zqa,Fv,hra,Bia,Aia,zia,yia,xia,wia,gra,fra,kg,era,dra,cra,bra,iG,gla,ela,Mia,Xia,Yia,ara,eZ,$qa,_qa,Oja,uia,Uk,zG,cla,jla,bla,ala,Vqa,Uqa,Tqa,Sqa,Rqa,Qqa,Pqa,Oqa,Nqa,Mqa,Lqa,Jqa,Iqa,Kqa,vY,Kf,oY,TC,Fqa,SC,Eqa,Dqa,Cqa,Bqa,RC,Aqa,Aw,IE,zqa,lY,kY,yqa,Cr,xqa,pf,wqa,iY,ap,hw,ap,LZ,Fr,cg,KE,ap,ko,tqa,sqa,rqa,qqa,MC,tv,pqa,oqa,nqa,mqa,lqa,kqa,jqa,iqa,hqa,gqa,fqa,eqa,dqa,cqa,bqa,bD,aqa,$pa,_pa,cg,iZ,hZ,mD,Zpa,Ypa,kE,Zw,Xpa,Wpa,Vpa,Upa,Tpa,Mka,Lka,Kka,Ppa,Qpa,rr,Rpa,Spa,Vv,MX,Mpa,nka,Rka,Fu,mka,lka,lT,zu,fT,kka,XS,pU,jka,EB,Jj,yi,Fpa,Epa,pv,Npa,Cv,Bpa,P$,Apa,zpa,tX,Yq,ypa,xpa,rw,wpa,eZ,vpa,upa,ov,tpa,spa,rpa,qpa,tC,lpa,rC,kpa,jpa,lX,pp,ipa,_j,Zh,Kf,yi,fpa,epa,dpa,cpa,SC,$oa,_oa,ov,Zoa,hm,_ia,Woa,Voa,Yj,iX,rC,kw,Uoa,lX,Toa,Soa,Roa,kv,Qoa,kv,Poa,sm,O0,Moa,_j,Ooa,kC,UW,fv,Noa,Zh,Kf,pv,Joa,Goa,TC,Foa,Coa,Boa,IW,rw,iD,Aoa,kE,cg,roa,qoa,qw,poa,ooa,noa,moa,Kv,loa,fp,ioa,hoa,goa,foa,eoa,doa,bn,_V,coa,boa,aoa,$na,_na,Zna,Yna,Xna,Wna,Vna,Una,Tna,Sna,SC,Rna,Qna,Pna,Cv,Ona,Nna,Mna,tr,Bka,Ap,I$,Ika,Hka,tr,Gka,yi,Ap,Fka,Eka,Dka,Lna,GV,Hna,Gna,Fna,Ena,Dna,Cna,Ir,yna,xna,wna,vna,una,tna,sna,rna,qna,pna,ona,Y2,BI,nna,cg,mna,lna,Nka,ola,Jsa,CU,lla,kla,MB,ila,fla,dla,qU,Xka,Zka,Yka,Wka,be,Vka,eU,Uka,Tka,Ska,WT,VT,TT,Fo,OT,Qka,Pka,Jka,_o,zka,Yj,sT,$r,zja,yja,xja,qka,wja,P0,vja,Pw,$r,V$,uja,sT,xka,tja,Cka,_j,Zh,Kf,Aka,_j,Zh,Kf,yka,_j,Zh,Kf,vka,ska,rka,Je,rE,gka,fka,eka,dka,cka,bka,mla,fna,sP,$ja,Dc,Zja,Sia,Xja,L1,e1,W0,a1,Vja,Uja,V0,c1,K1,$0,QR,Tja,Rja,Qja,PR,OR,FA,Pja,_ka,Nja,Mja,Lja,Jja,UQ,Kia,aja,ix,DS,$F,rG,qA,PR,Fja,Uk,is,Ar,uka,wka,pja,oja,Yj,nja,rC,mja,lja,kja,pv,jja,yi,ija,gja,fja,eja,dja,_j,Zh,Kf,qja,Wia,Via,Uia,Tia,ki,Km,Ria,Qia,du,so,Nia,Iia,Hia,Gia,Fia,Eia,QQ,Lia,kq,PQ,ll,ki,kg,Cia,via,Y8,Dia,Jia,sia,qia,Kha,pia,vk,BQ,hg,OQ,bia,Lha,gn,Fha,sja,Eha,Cha,Bha,Aha,qA,Dha,pe,Xt,Xt,zha,yha,wha,oQ,dQ,cha,Vga,Oga,Hga,zga,qga,sga,fga,_fa,tP,Tt,Tfa,Sfa,gaa,haa,nP,Lfa,mP,lP,Gja,jaa,Hfa,tP,Gfa,Raa,Faa,Uaa,gP,WL,eP,Iz,Dfa,yda,dq,wda,Jm,dP,Oaa,bP,Naa,cP,Maa,$O,YJ,eba,yfa,Paa,Hz,iY,Gz,Fz,Ez,ofa,mfa,eP,Iz,ifa,hfa,gfa,ffa,efa,dfa,cfa,bfa,$ea,_ea,Zea,Yea,Xea,Wea,Vea,Uea,Tea,Sea,Rea,Qea,Pea,Oea,Nea,Mea,Lea,YO,WO,VO,fG,w9,Vaa,UO,HO,Kaa,GO,FO,dba,z9,A9,EO,F9,BO,AO,fz,yO,Iz,wO,uO,tO,oo,y9,x9,sO,rO,qO,pO,oO,mO,lO,kO,jO,iO,hO,gO,Cz,fO,dO,LR,qv,Bz,Az,Dda,aO,Bda,Ada,zda,WN,tda,gP,rda,Lca,qda,Kca,pda,Jca,oda,Ica,nda,Hca,lda,Gca,jda,Q9,WL,Oq,tka,tx,as,TT,$aa,_aa,Zaa,Xaa,Taa,_ja,Qaa,Iaa,Laa,d9,X8,W8,Jaa,hm,Yk,Yk,Gaa,Wja,Saa,aba,Waa,_w,_,iaa,OM,NM,Az,hM,faa,eaa,X9,_L,P9,O9,K9,E9,D9,C9,B9,v9,u9,t9,FR,hna,s9,r9,q9,p9,l9,k9,JK,IK,j3,c9,b9,a9,$8,_8,Z8,S8,hh,R8,Je,b3,a4,D8,IK,z8,un,SK,Dy,k8,j8,ty,ii,hi,Xs,Db,sy,qh,rl,ry,Bm,b8,a8,rj,ph,VJ,qj,Gy,my,ii,hi,Ts,ji,Q8,gm,ao,rj,ph,RJ,qj,I7,D7,OK,y7,it,cp,t7,Qs,Cf,b7,Yn,a7,$6,_6,vJ,Y6,ot,W6,V6,uj,U6,vJ,S6,nY,Q6,P6,M6,L6,A6,z6,y6,x6,w6,v6,u6,t6,s6,r6,q6,p6,o6,n6,m6,l6,k6,j6,i6,h6,g6,f6,e6,d6,c6,b6,a6,$5,_5,Z5,Y5,X5,W5,dJ,V5,H5,I5,J5,Q5,O5,M5,K5,t5,u5,v5,C5,A5,y5,w5,T4,S4,Q4,P4,O4,zI,N4,yI,M4,L4,K4,J4,H4,G4,F4,E4,D4,C4,B4,A4,z4,y4,w4,v4,u4,t4,s4,r4,q4,p4,o4,n4,l4,k4,j4,i4,h4,g4,b4,q3,r3,f4,e4,d4,c4,xm,Rp,G3,F3,$3,_3,J3,I3,H3,qk,y3,x3,Xn,gy,pi,ZH,Hn,Yr,ena,dna,cna,bna,ana,$ma,_ma,Zma,Yma,Xma,Wma,Vma,Uma,Tma,Sma,Rma,Qma,Pma,Oma,Nma,Mma,Lma,Kma,Jma,Ima,Hma,Gma,Fma,Ema,Dma,Cma,Bma,Ama,zma,yma,xma,wma,vma,uma,tma,sma,rma,qma,pma,oma,nma,mma,lma,kma,jma,ima,hma,gma,fma,ema,dma,cma,bma,ama,_la,Zla,Yla,Xla,Wla,Vla,Ula,Tla,Sla,Rla,Qla,Pla,Ola,Nla,Mla,Lla,Kla,Jla,Ila,Hla,Gla,Fla,Ela,Dla,Cla,Bla,zla,yla,xla,wla,vla,ula,tla,sla,rla,qla,pla,Hn,Ana,zna,Ura,Tra,Eoa,Doa,xoa,woa,Hqa,Gqa,ppa,opa,Xqa,Wqa,aua,$ta,Psa,Osa,o0,n0,qua,pua,hpa,gpa,Ioa,Hoa,Jna,Ina,yta,xta,ota,nta,E0,C0,B0,A0,Yoa,Xoa,Loa,Koa,Dpa,Cpa,Yqa,b0,Ksa,Isa,asa,$ra,Dta,Cta,ata,$sa,bpa,apa,rja,cja,bja,ysa,xsa,Gsa,Fsa,Hpa,Gpa,koa,joa,npa,mpa,Nsa,Msa,zoa,yoa,toa,soa,lta,kta,voa,uoa,Opa,Jpa,Ipa,G0,F0,J0,I0,dua,cua,vqa,uqa,Lpa,Kpa,jna,ina,Sn,Yr,j1,tc,om,rP,tc,Je,tc,lc,Be,Be,lc,lc,k1,z1,y1,l1,tc,om,tc,dG,t1,s1,Be,r1,q1,p1,o1,n1,m1,bu,Vz,au,xQ,lc,Cf,lc,lc,lc,Qe,ro,oia,nia,mia,lia,kia,Ki,Tz,Tz,Sz,vQ,Sz,uQ,Sz,uQ,Cf,b0,jia,iia,hia,gia,fia,Ji,tQ,Hha,lc,lc,Be,Rz,Ie,Ie,Be,eia,dia,Qe,Cf,Qe,Cf,sQ,aia,$ha,lc,Cf,lc,lc,lc,Qe,_ha,qQ,Zha,Yha,Xha,Wha,Ki,Vha,Uha,Tha,Sha,Rha,Qha,Pha,Oha,Nha,Mha,Ji,mQ,lc,lc,Be,Ie,Ie,Be,pQ,nQ,Uf,Ng,X2,Jha,Uz,Iha,lc,Gha,vQ,nha,dha,Wga,Pga,Iga,Aga,rga,gga,$fa,Bga,tia,cia,xha,bu,Vz,xQ,lc,Cf,lc,lc,lc,Qe,fQ,vha,uha,tha,sha,rha,Ki,qha,Ji,eQ,lc,lc,Be,Ie,Ie,Be,pha,oha,VP,bha,aha,lc,Cf,lc,lc,lc,Qe,$ga,_ga,Zga,Yga,Ki,Xga,Ji,SP,lc,lc,Be,Ie,Ie,Ut,Uga,lc,Cf,lc,lc,lc,Qe,RP,Tga,Sga,Rga,Ki,Qga,Ji,PP,lc,lc,Be,Ie,Ie,bu,Vz,Nga,lc,Cf,lc,lc,lc,Qe,RP,Mga,Lga,Kga,Ki,Jga,Ji,NP,lc,lc,Be,Ie,Ie,cQ,bQ,Gga,lc,Cf,lc,lc,lc,Qe,aQ,Fga,kha,jha,Ki,iha,Ji,hha,lc,lc,Be,Ie,Ie,Qe,Cf,_P,Ega,Dga,ZP,Cga,YP,XP,bQ,mha,aQ,lha,_P,gha,fha,ZP,eha,YP,XP,Ut,yga,lc,Cf,lc,lc,lc,Qe,Ie,xga,wga,vga,Ki,uga,Ji,tga,lc,lc,Be,Ie,Ie,KP,pga,oga,lc,Cf,lc,lc,nga,Qe,mga,kga,jga,iga,Ki,hga,Ji,Lz,lc,lc,Be,Ie,Ie,Qe,Cf,Ut,ega,lc,Cf,lc,lc,lc,Qe,fQ,dga,cga,bga,Ki,aga,Ji,EP,lc,lc,Be,Ie,Ie,Ut,Zfa,lc,Cf,lc,lc,lc,Qe,ro,Yfa,Xfa,Wfa,Ki,Vfa,Ji,CP,lc,lc,Be,Ie,Ie,Ot,tc,vda,ZN,uN,ZN,xN,Lm,AN,Nt,NN,cq,Lt,Kba,Jba,tN,sN,rN,qN,oN,nN,mN,lN,kN,jN,iN,hN,gN,fN,dN,cN,bN,aN,$M,_M,ZM,YM,XM,Iba,Gba,Fba,Eba,Dba,Cba,Bba,Aba,zba,yba,xba,wba,vba,uba,tba,sba,rba,qba,pba,oba,nba,mba,lba,kba,jba,iba,hba,gba,fba,Je,Ng,Je,Ng,Je,Ng,Je,Ng,Ng,cba,tc,bba,Ht,Eaa,Yaa,Je,Ng,Je,tc,Daa,Caa,Ng,BM,AM,BM,AM,Qe,It,Qe,It,EM,DM,EM,DM,tc,Haa,Je,tc,Baa,Aaa,tc,tM,sM,Ng,xaa,qM,waa,qM,zaa,rM,yaa,rM,tc,vaa,uaa,tc,pM,oM,Et,Et,Et,Et,taa,kz,kz,kz,tc,saa,raa,tc,nM,mM,oaa,kM,naa,kM,qaa,lM,paa,lM,tc,maa,laa,tc,jM,iM,Ct,Ct,Ct,Ct,kaa,jz,jz,jz,R9,tc,om,tc,Bt,W9,Be,Be,V9,U9,Yr,T9,S9,Ng,Ng,Y9,tc,om,tc,fM,eM,Be,lc,Be,daa,caa,baa,aaa,$9,_9,Z9,Ng,G9,tc,om,tc,XL,J9,I9,H9,Ng,L9,tc,om,tc,eM,N9,M9,x1,tc,om,tc,tc,D1,Be,Be,Yr,Xr,C1,B1,A1,Qe,It,Qe,It,o9,n9,m9,$n,Ly,Qe,fL,eL,dL,lc,lc,g9,cL,f9,pt,e9,pt,lt,Hy,Qe,fL,eL,dL,lc,lc,V8,cL,U8,pt,T8,pt,kt,L8,M8,K8,P8,O8,N8,Yp,MK,J8,I8,mt,Iy,XK,WK,Af,LK,H8,G8,nt,Ky,aL,$K,Je,tc,F8,h3,g3,f3,E8,Hn,h9,lc,B8,Ly,o8,n8,m8,l8,UK,My,sl,My,Ly,r8,BK,q8,p8,Hy,v8,u8,t8,s8,nt,Ky,aL,$K,UK,My,Hy,y8,BK,x8,w8,mt,Iy,XK,WK,AI,V4,au,bI,m3,l3,k3,g8,cI,p3,o3,n3,d8,Hs,b5,a5,$4,_4,Z4,rX,Y4,X4,W4,Ds,hI,C3,B3,A3,z3,Gs,nI,W3,V3,U3,T3,S3,R3,Q3,P3,O3,N3,M3,K3,$x,iJ,G6,F6,E6,D6,lc,C6,B6,Ux,KI,fy,ey,dy,p5,o5,Vx,LI,Xr,cy,by,r5,q5,KI,LI,Je,tc,tc,m5,l5,k5,j5,i5,h5,g5,f5,rX,e5,d5,c5,tc,DI,DI,Op,Be,Be,n5,Be,tc,GI,FI,Op,lc,lc,EI,ro,tc,GI,FI,Op,lc,lc,EI,ro,tc,JI,II,Op,lc,lc,HI,ro,tc,JI,II,Op,lc,lc,HI,ro,Je,tc,i8,h8,Je,tc,f8,e8,tc,c8,$7,_7,Z7,_J,_J,Y7,X7,W7,V7,U7,tc,T7,S7,R7,Q7,QJ,QJ,P7,O7,N7,M7,L7,tc,K7,J7,H7,G7,F7,E7,C7,B7,tc,A7,z7,x7,w7,v7,u7,s7,r7,Je,tc,Ie,q7,p7,o7,n7,m7,l7,G5,F5,E5,D5,B5,z5,x5,Je,tc,Ie,k7,j7,i7,h7,g7,f7,U5,T5,S5,R5,P5,N5,L5,iI,E3,D3,qd,Sx,Rx,Qx,Px,Ox,Nx,uI,tI,sI,rI,qI,pI,oI,vI,Z3,Y3,qd,Sx,Rx,Qx,Px,Ox,Nx,uI,tI,sI,rI,qI,pI,oI,Wx,Is,e7,Wx,Is,d7,Is,Is,tc,Os,Os,gi,gi,gi,IJ,lc,fi,fi,tc,Os,Os,gi,gi,gi,IJ,lc,fi,fi,tc,Ns,Ns,gi,gi,gi,HJ,lc,fi,fi,tc,Ns,Ns,gi,gi,gi,HJ,lc,fi,fi,dI,s3,fy,ey,dy,GJ,fz,FJ,EJ,DJ,Ms,eI,t3,fy,ey,dy,GJ,fz,FJ,EJ,DJ,Ms,fI,u3,Xr,cy,by,BJ,AJ,zJ,yJ,Ms,xJ,gI,v3,Xr,cy,by,BJ,AJ,zJ,yJ,Ms,xJ,tc,c7,Z6,tc,X6,T6,tc,R6,O6,tc,N6,K6,tc,jJ,J6,Qe,tc,jJ,I6,Qe,tc,tc,Je,tc,H6,iJ,Je,tc,Je,tc,Je,tc,Je,tc,hI,nI,Je,Ng,tc,i3,tc,e3,$H,tc,d3,c3,$H,Hn,Ng,tc,a3,va,Je,tc,Cf,Cf,W2,N2,P2,Q2,tc,I2,tc,H2,Sn,Hn,Sn,Sn,Sn,Sn,Hn,tc,G2,tc,M2,O2,R2,tc,V2,U2,S2,tc,J2]);function jb(){return u.byteLength/65536|0}function ob(pb){pb=pb|0;var kb=jb()|0;var lb=kb+pb|0;if(kb<lb&&lb<65536){var mb=new ArrayBuffer(D(lb,65536));var nb=new Int8Array(mb);nb.set(v);v=new Int8Array(mb);w=new Int16Array(mb);x=new Int32Array(mb);y=new Uint8Array(mb);z=new Uint16Array(mb);A=new Uint32Array(mb);B=new Float32Array(mb);C=new Float64Array(mb);u=mb;t.buffer=u;e=y}return kb}return{"va":c0,"wa":pP,"xa":pP,"ya":qP,"za":qP,"Aa":tc,"Ba":Mfa,"Ca":nP,"Da":Kfa,"Ea":Jfa,"Fa":Tt,"Ga":Qe,"Ha":Ofa,"Ia":Nfa,"Ja":Rfa,"Ka":Tz,"La":Pfa,"Ma":rP,"Na":Qfa,"Oa":Je,"Pa":vP,"Qa":uP,"Ra":vP,"Sa":bO,"Ta":F2,"Ua":E2,"Va":D2,"Wa":Ifa,"Xa":iP,"Ya":Ffa,"Za":hP,"_a":ufa,"$a":Ida,"ab":Jda,"bb":sfa,"cb":rfa,"db":qfa,"eb":tfa,"fb":Kda,"gb":Zda,"hb":Eda,"ib":$da,"jb":rea,"kb":Gda,"lb":bea,"mb":Hda,"nb":aea,"ob":Fda,"pb":Nda,"qb":Lda,"rb":Mda,"sb":Uda,"tb":Sda,"ub":Tda,"vb":Oda,"wb":Pda,"xb":Qda,"yb":Rda,"zb":oea,"Ab":pea,"Bb":Aea,"Cb":uea,"Db":tea,"Eb":sea,"Fb":zea,"Gb":yea,"Hb":vea,"Ib":wea,"Jb":Eea,"Kb":Fea,"Lb":Bea,"Mb":Dea,"Nb":Cea,"Ob":iea,"Pb":nea,"Qb":lea,"Rb":kea,"Sb":mea,"Tb":jea,"Ub":Yda,"Vb":Hea,"Wb":gea,"Xb":eea,"Yb":qea,"Zb":_da,"_b":fea,"$b":dea,"ac":cea,"bc":Iea,"cc":Vda,"dc":Jea,"ec":Wda,"fc":Gea,"gc":Efa,"hc":Cfa,"ic":B2,"jc":Bfa,"kc":Afa,"lc":zfa,"mc":xfa,"nc":A2,"oc":wfa,"pc":vfa,"qc":pfa,"rc":nfa,"sc":lfa,"tc":Kea,"uc":jfa,"vc":nc,"wc":uN,"xc":dq,"yc":yN,"zc":zN,"Ac":Dca,"Bc":Eca,"Cc":xN,"Dc":fda,"Ec":ida,"Fc":hda,"Gc":MN,"Hc":MN,"Ic":bO,"Jc":RH,"Kc":RH,"Lc":QH,"Mc":QH,"Nc":z2,"Oc":BN,"Pc":EN,"Qc":LN,"Rc":KN,"Sc":CN,"Tc":HN,"Uc":GN,"Vc":DN,"Wc":JN,"Xc":IN,"Yc":FN,"Zc":Lm,"_c":AN,"$c":dda,"ad":$ba,"bd":ada,"cd":qca,"dd":dca,"ed":$ca,"fd":aca,"gd":Wca,"hd":rca,"id":bda,"jd":Qca,"kd":Pca,"ld":Oca,"md":Tca,"nd":Sca,"od":Rca,"pd":Uca,"qd":Yca,"rd":Vca,"sd":Zca,"td":kca,"ud":Bca,"vd":Zba,"wd":mca,"xd":lca,"yd":gca,"zd":nca,"Ad":fca,"Bd":yca,"Cd":Uba,"Dd":Wba,"Ed":Xba,"Fd":Vba,"Gd":Rba,"Hd":Qba,"Id":sca,"Jd":uca,"Kd":Aca,"Ld":tca,"Md":eca,"Nd":xca,"Od":hca,"Pd":oca,"Qd":wca,"Rd":ica,"Sd":cca,"Td":pca,"Ud":jca,"Vd":bca,"Wd":Sba,"Xd":Pba,"Yd":Oba,"Zd":Yba,"_d":Tba,"$d":Mba,"ae":Nba,"be":zca,"ce":y2,"de":_ba,"ee":Cca,"fe":Nca,"ge":cda,"he":x2,"ie":_ca,"je":eda,"ke":ON,"le":QN,"me":RN,"ne":SN,"oe":UN,"pe":VN,"qe":YN,"re":TN,"se":Nt,"te":NN,"ue":PN,"ve":kda,"we":uda,"xe":nc,"ye":yN,"ze":zN,"Ae":dq,"Be":BN,"Ce":EN,"De":LN,"Ee":KN,"Fe":CN,"Ge":HN,"He":GN,"Ie":DN,"Je":JN,"Ke":IN,"Le":FN,"Me":Lm,"Ne":ON,"Oe":QN,"Pe":RN,"Qe":SN,"Re":UN,"Se":VN,"Te":YN,"Ue":TN,"Ve":Nt,"We":PN,"Xe":ib,"Ye":lga,"Ze":Hba,"_e":kfa,"$e":Xda,"af":Z2,"bf":_2,"cf":L2,"df":K2,"ef":w2,"ff":v2,"gf":t2,"hf":p2,"jf":u2,"kf":t2,"lf":s2,"mf":q2,"nf":r2,"of":q2,"pf":p2,"qf":p2}}return qb(sb)}
// EMSCRIPTEN_END_ASM


)(info);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module, info)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


